@@ -20,7 +20,7 @@
 
 vb2_error_t vb2_validate_gbb_signature(uint8_t *sig)
 {
-	const static uint8_t sig_xor[VB2_GBB_SIGNATURE_SIZE] =
+	static const uint8_t sig_xor[VB2_GBB_SIGNATURE_SIZE] =
 			VB2_GBB_XOR_SIGNATURE;
 	int i;
 	for (i = 0; i < VB2_GBB_SIGNATURE_SIZE; i++) {
@@ -263,7 +263,7 @@ vb2_error_t vb2_check_dev_switch(struct vb2_context *ctx)
 
 	/*
 	 * Check if we've been asked by the caller to disable dev mode.  Note
-	 * that hardware switch and GBB flag will take precedence over this.
+	 * that GBB flag will take precedence over this.
 	 */
 	if (ctx->flags & VB2_CONTEXT_DISABLE_DEVELOPER_MODE)
 		flags &= ~VB2_SECDATA_FIRMWARE_FLAG_DEV_MODE;
@@ -311,8 +311,8 @@ vb2_error_t vb2_check_dev_switch(struct vb2_context *ctx)
 		 * Note that we do this even if secdata_firmware is having
 		 * issues, since the TPM owner and secdata_firmware may be
 		 * independent, and we want the owner to be cleared if *this
-		 * boot* is different than the last one (perhaps due to GBB or
-		 * hardware override).
+		 * boot* is different than the last one (perhaps due to GBB flag
+		 * override).
 		 */
 		rv = vb2ex_tpm_clear_owner(ctx);
 		/* Check for failure to clear owner */
@@ -492,6 +492,7 @@ void vb2api_clear_recovery(struct vb2_context *ctx)
 	}
 }
 
+test_mockable
 int vb2api_need_reboot_for_display(struct vb2_context *ctx)
 {
 	if (!(vb2_get_sd(ctx)->flags & VB2_SD_FLAG_DISPLAY_AVAILABLE)) {
@@ -543,10 +544,10 @@ void vb2api_export_vbsd(struct vb2_context *ctx, void *dest)
 	if (sd->flags & VB2_SD_FLAG_KERNEL_SIGNED)
 		vbsd->flags |= VBSD_KERNEL_KEY_VERIFIED;
 
-	vbsd->fw_version_tpm_start = sd->fw_version_secdata;
-	vbsd->fw_version_tpm = sd->fw_version;
-	vbsd->kernel_version_tpm_start = sd->kernel_version_secdata;
-	vbsd->kernel_version_tpm = sd->kernel_version;
+	vbsd->fw_version_tpm = sd->fw_version_secdata;
+	vbsd->fw_version_act = sd->fw_version;
+	vbsd->kernel_version_tpm = sd->kernel_version_secdata;
+	vbsd->kernel_version_act = sd->kernel_version;
 
 	vbsd->recovery_reason = sd->recovery_reason;
 	if (sd->recovery_reason)
@@ -557,23 +558,6 @@ void vb2api_export_vbsd(struct vb2_context *ctx, void *dest)
 _Static_assert(VB2_VBSD_SIZE == sizeof(VbSharedDataHeader),
 	       "VB2_VBSD_SIZE incorrect");
 
-int vb2api_phone_recovery_enabled(struct vb2_context *ctx)
-{
-	return !(vb2_secdata_kernel_get(ctx, VB2_SECDATA_KERNEL_FLAGS) &
-		 VB2_SECDATA_KERNEL_FLAG_PHONE_RECOVERY_DISABLED);
-}
-
-int vb2api_phone_recovery_ui_enabled(struct vb2_context *ctx)
-{
-	/*
-	 * When phone recovery functionality is disabled, return 0 even if
-	 * PHONE_RECOVERY_UI_DISABLED is not set.
-	 */
-	return vb2api_phone_recovery_enabled(ctx) &&
-	       !(vb2_secdata_kernel_get(ctx, VB2_SECDATA_KERNEL_FLAGS) &
-		 VB2_SECDATA_KERNEL_FLAG_PHONE_RECOVERY_UI_DISABLED);
-}
-
 test_mockable
 int vb2api_diagnostic_ui_enabled(struct vb2_context *ctx)
 {
@@ -804,6 +788,7 @@ void vb2_set_boot_mode(struct vb2_context *ctx)
 	}
 }
 
+test_mockable
 bool vb2api_hwcrypto_allowed(struct vb2_context *ctx)
 {
 	struct vb2_shared_data *sd = vb2_get_sd(ctx);
