@@ -1,4 +1,4 @@
-/* Copyright (c) 2014 The Chromium OS Authors. All rights reserved.
+/* Copyright 2014 The ChromiumOS Authors
  * Use of this source code is governed by a BSD-style license that can be
  * found in the LICENSE file.
  *
@@ -10,6 +10,7 @@
 
 #include "2api.h"
 #include "2gbb.h"
+#include "2misc.h"
 #include "2packed_key.h"
 #include "2return_codes.h"
 #include "2sha.h"
@@ -66,7 +67,8 @@ struct vb2_public_key;
 
 #define VB2_REC_OR_DIE(ctx, format, args...) do { \
 	VB2_DEBUG(format, ## args); \
-	if (!(ctx->flags & VB2_CONTEXT_RECOVERY_MODE)) { \
+	if ((vb2_get_sd(ctx)->status & VB2_SD_STATUS_RECOVERY_DECIDED) && \
+	    !(ctx->flags & VB2_CONTEXT_RECOVERY_MODE)) { \
 		vb2ex_abort(); \
 		for (;;); \
 	} \
@@ -95,6 +97,17 @@ struct vb2_public_key;
 #define VBOOT_FALLTHROUGH ((void)0)
 #endif
 
+/**
+ * Round down a number to a multiple of VB2_WORKBUF_ALIGN
+ *
+ * @param v		Number to round down
+ * @return The number, rounded down.
+ */
+static inline uint32_t vb2_wb_round_down(uint32_t v)
+{
+	return v & ~(VB2_WORKBUF_ALIGN - 1);
+}
+
 /**
  * Round up a number to a multiple of VB2_WORKBUF_ALIGN
  *
