@@ -7,6 +7,7 @@
 # be exactly like the real keys except that the private keys aren't secret.
 
 # Load common constants and functions.
+# shellcheck source=common.sh
 . "$(dirname "$0")/common.sh"
 
 usage() {
@@ -25,6 +26,8 @@ Options:
   --output <dir>         Where to write the keys (default is cwd)
   --arv-root-path <dir>  Path to AP RO verificaton root key directory,
                          defaults to ./${ARV_ROOT_DIR}
+  --arv-root-uri <uri>   URI to remote AP RO verification root key (stored in
+                         GCP, accessed using CloudKMS).
 EOF
 
   if [[ $# -ne 0 ]]; then
@@ -47,6 +50,7 @@ main() {
   local keyname
   local output_dir="${PWD}" setperms="false"
   local arv_root_path=""
+  local arv_root_uri=""
 
   while [[ $# -gt 0 ]]; do
     case $1 in
@@ -102,6 +106,10 @@ main() {
       arv_root_path="$(readlink -f "$2")"
       shift
       ;;
+    --arv-root-uri)
+      arv_root_uri="$2"
+      shift
+      ;;
 
     --key-name)
       keyname="$2"
@@ -133,17 +141,19 @@ main() {
     chmod 700 .
   fi
 
-  if [[ -z "${arv_root_path}" ]]; then
-    # If not explicitly set, expect AP RO verification root key directory one
-    # level above the output directory where the specific board keys are going
-    # to be placed.
-    arv_root_path="$(readlink -f "../${ARV_ROOT_DIR}")"
-  fi
+  if [[ -z "${arv_root_uri}" ]]; then
+    if [[ -z "${arv_root_path}" ]]; then
+      # If not explicitly set, expect AP RO verification root key directory one
+      # level above the output directory where the specific board keys are going
+      # to be placed.
+      arv_root_path="$(readlink -f "../${ARV_ROOT_DIR}")"
+    fi
 
-  if [[ ! -d "${arv_root_path}" ]]; then
-    die "AP RO root key directory \"${arv_root_path}\" not found." \
-        "Run make_arv_root.sh to create it or specify --arv-root-path."
-    exit 1
+    if [[ ! -d "${arv_root_path}" ]]; then
+      die "AP RO root key directory \"${arv_root_path}\" not found." \
+          "Run make_arv_root.sh to create it or specify --arv-root-path."
+      exit 1
+    fi
   fi
 
   if [[ ! -e "${VERSION_FILE}" ]]; then
@@ -156,10 +166,9 @@ main() {
     ) > "${VERSION_FILE}"
   fi
 
-  local eckey_version fkey_version ksubkey_version kdatakey_version
+  local fkey_version ksubkey_version kdatakey_version
 
   # Get the key versions for normal keypairs
-  eckey_version=$(get_version "ec_key_version")
   fkey_version=$(get_version "firmware_key_version")
   # Firmware version is the kernel subkey version.
   ksubkey_version=$(get_version "firmware_version")
@@ -167,8 +176,6 @@ main() {
   kdatakey_version=$(get_version "kernel_key_version")
 
   # Create the normal keypairs
-  make_pair ec_root_key              ${EC_ROOT_KEY_ALGOID}
-  make_pair ec_data_key              ${EC_DATAKEY_ALGOID} ${eckey_version}
   make_pair root_key                 ${root_key_algoid}
   make_pair firmware_data_key        ${FIRMWARE_DATAKEY_ALGOID} ${fkey_version}
   make_pair kernel_subkey            ${KERNEL_SUBKEY_ALGOID} ${ksubkey_version}
@@ -181,15 +188,13 @@ main() {
   make_pair installer_kernel_data_key ${installer_kernel_algoid}
   make_pair arv_platform "${ARV_PLATFORM_ALGOID}"
 
-  # Make sure there is a copy of the AP RO verification root public key in the
-  # keyset directory.
+  # Make sure there is a copy of the AP RO
+  # verification root public key in the keyset directory.
   cp "${arv_root_path}/${ARV_ROOT_NAME_BASE}.vbpubk" .
 
   # Create the firmware keyblock for use only in Normal mode. This is redundant,
   # since it's never even checked during Recovery mode.
   make_keyblock firmware ${FIRMWARE_KEYBLOCK_MODE} firmware_data_key root_key
-  # Ditto EC keyblock
-  make_keyblock ec ${EC_KEYBLOCK_MODE} ec_data_key ec_root_key
 
   # Create the recovery kernel keyblock for use only in Recovery mode.
   make_keyblock recovery_kernel ${RECOVERY_KERNEL_KEYBLOCK_MODE} recovery_kernel_data_key recovery_key
@@ -206,7 +211,7 @@ main() {
 
   # Create AP RO verification platform keyblock.
   make_keyblock arv_platform "${ARV_KEYBLOCK_MODE}" arv_platform \
-                "${arv_root_path}/${ARV_ROOT_NAME_BASE}"
+                "${arv_root_path}/${ARV_ROOT_NAME_BASE}" "${arv_root_uri}"
 
   # Copy AP RO verification root public key into the output directory, it is
   # necessary for AP RO verification signing.
@@ -219,6 +224,7 @@ main() {
 
   if [[ "${uefi_keys}" == "true" ]]; then
     mkdir -p uefi
+    "${SCRIPT_DIR}"/uefi/create_new_crdyshim_key.sh uefi
     "${SCRIPT_DIR}"/uefi/create_new_uefi_keys.sh --output uefi
   fi
 
