@@ -1,5 +1,4 @@
 /*
- * This file is part of the coreboot project.
  *
  * Copyright 2014 Google Inc.
  *
@@ -42,7 +41,14 @@ static unsigned int max_tables;
 static uint64_t *xlat_addr;
 
 static int free_idx;
-static uint8_t ttb_buffer[TTB_DEFAULT_SIZE] __attribute__((aligned(GRANULE_SIZE)));
+
+/*
+ * We refer to the section ".bss.ttb_buffer" in the linker script for ChromeOS's depthcharge
+ * payload. Please DO NOT change the section name without discussing with us.
+ * Please contact: jwerner@chromium.org or yich@chromium.org
+ */
+static uint8_t ttb_buffer[TTB_DEFAULT_SIZE] __aligned(GRANULE_SIZE)
+	__section(".bss.ttb_buffer");
 
 static const char * const tag_to_string[] = {
 	[TYPE_NORMAL_MEM] = "normal",
@@ -172,6 +178,7 @@ static uint64_t init_xlat_table(uint64_t base_addr,
 				uint64_t size,
 				uint64_t tag)
 {
+	uint64_t l0_index = (base_addr & L0_ADDR_MASK) >> L0_ADDR_SHIFT;
 	uint64_t l1_index = (base_addr & L1_ADDR_MASK) >> L1_ADDR_SHIFT;
 	uint64_t l2_index = (base_addr & L2_ADDR_MASK) >> L2_ADDR_SHIFT;
 	uint64_t l3_index = (base_addr & L3_ADDR_MASK) >> L3_ADDR_SHIFT;
@@ -179,12 +186,12 @@ static uint64_t init_xlat_table(uint64_t base_addr,
 	uint64_t desc;
 	uint64_t attr = get_block_attr(tag);
 
-	/* L1 table lookup
-	 * If VA has bits more than L2 can resolve, lookup starts at L1
-	 * Assumption: we don't need L0 table in coreboot */
-	if (BITS_PER_VA > L1_ADDR_SHIFT) {
-		if ((size >= L1_XLAT_SIZE) &&
-		    IS_ALIGNED(base_addr, (1UL << L1_ADDR_SHIFT))) {
+	/* L0 entry stores a table descriptor (doesn't support blocks) */
+	table = get_next_level_table(&table[l0_index], L1_XLAT_SIZE);
+
+	/* L1 table lookup */
+	if ((size >= L1_XLAT_SIZE) &&
+	    IS_ALIGNED(base_addr, (1UL << L1_ADDR_SHIFT))) {
 			/* If block address is aligned and size is greater than
 			 * or equal to size addressed by each L1 entry, we can
 			 * directly store a block desc */
@@ -192,13 +199,12 @@ static uint64_t init_xlat_table(uint64_t base_addr,
 			table[l1_index] = desc;
 			/* L2 lookup is not required */
 			return L1_XLAT_SIZE;
-		}
-		table = get_next_level_table(&table[l1_index], L2_XLAT_SIZE);
 	}
 
-	/* L2 table lookup
-	 * If lookup was performed at L1, L2 table addr is obtained from L1 desc
-	 * else, lookup starts at ttbr address */
+	/* L1 entry stores a table descriptor */
+	table = get_next_level_table(&table[l1_index], L2_XLAT_SIZE);
+
+	/* L2 table lookup */
 	if ((size >= L2_XLAT_SIZE) &&
 	    IS_ALIGNED(base_addr, (1UL << L2_ADDR_SHIFT))) {
 		/* If block address is aligned and size is greater than
@@ -226,6 +232,7 @@ static void sanity_check(uint64_t addr, uint64_t size)
 {
 	assert(!(addr & GRANULE_SIZE_MASK) &&
 	       !(size & GRANULE_SIZE_MASK) &&
+	       (addr + size < (1UL << BITS_PER_VA)) &&
 	       size >= GRANULE_SIZE);
 }
 
@@ -251,7 +258,7 @@ void mmu_config_range(void *start, size_t size, uint64_t tag)
 
 	/* ARMv8 MMUs snoop L1 data cache, no need to flush it. */
 	dsb();
-	tlbiall_current();
+	tlbiall_el2();
 	dsb();
 	isb();
 }
@@ -272,7 +279,7 @@ uint64_t mmu_init(struct mmu_ranges *mmu_ranges)
 	max_tables = (TTB_DEFAULT_SIZE >> GRANULE_SIZE_SHIFT);
 	free_idx = 1;
 
-	printf("Libpayload ARM64: TTB_BUFFER: 0x%p Max Tables: %d\n",
+	printf("Libpayload ARM64: TTB_BUFFER: %p Max Tables: %d\n",
 	       (void*)xlat_addr, max_tables);
 
 	/*
@@ -297,36 +304,11 @@ static uint32_t is_mmu_enabled(void)
 {
 	uint32_t sctlr;
 
-	sctlr = raw_read_sctlr_current();
+	sctlr = raw_read_sctlr_el2();
 
 	return (sctlr & SCTLR_M);
 }
 
-/*
- * Func: mmu_disable
- * Desc: Invalidate caches and disable mmu
- */
-void mmu_disable(void)
-{
-	uint32_t el = get_current_el();
-	uint32_t sctlr;
-
-	sctlr = raw_read_sctlr(el);
-	sctlr &= ~(SCTLR_C | SCTLR_M | SCTLR_I);
-
-	tlbiall_current();
-	dcache_clean_invalidate_all();
-
-	dsb();
-	isb();
-
-	raw_write_sctlr(sctlr, el);
-
-	dcache_clean_invalidate_all();
-	dsb();
-	isb();
-}
-
 /*
  * Func: mmu_enable
  * Desc: Initialize MAIR, TCR, TTBR and enable MMU by setting appropriate bits
@@ -337,26 +319,26 @@ void mmu_enable(void)
 	uint32_t sctlr;
 
 	/* Initialize MAIR indices */
-	raw_write_mair_current(MAIR_ATTRIBUTES);
+	raw_write_mair_el2(MAIR_ATTRIBUTES);
 
 	/* Invalidate TLBs */
-	tlbiall_current();
+	tlbiall_el2();
 
 	/* Initialize TCR flags */
-	raw_write_tcr_current(TCR_TOSZ | TCR_IRGN0_NM_WBWAC | TCR_ORGN0_NM_WBWAC |
-			      TCR_SH0_IS | TCR_TG0_4KB | TCR_PS_64GB |
+	raw_write_tcr_el2(TCR_TOSZ | TCR_IRGN0_NM_WBWAC | TCR_ORGN0_NM_WBWAC |
+			      TCR_SH0_IS | TCR_TG0_4KB | TCR_PS_256TB |
 			      TCR_TBI_USED);
 
 	/* Initialize TTBR */
-	raw_write_ttbr0_current((uintptr_t)xlat_addr);
+	raw_write_ttbr0_el2((uintptr_t)xlat_addr);
 
 	/* Ensure system register writes are committed before enabling MMU */
 	isb();
 
 	/* Enable MMU */
-	sctlr = raw_read_sctlr_current();
+	sctlr = raw_read_sctlr_el2();
 	sctlr |= SCTLR_C | SCTLR_M | SCTLR_I;
-	raw_write_sctlr_current(sctlr);
+	raw_write_sctlr_el2(sctlr);
 
 	isb();
 
@@ -414,7 +396,7 @@ struct mmu_new_range_prop {
 
 /*
  * Func: mmu_is_range_free
- * Desc: We need to ensure that the new range being allocated doesnt overlap
+ * Desc: We need to ensure that the new range being allocated doesn't overlap
  * with any used memory range. Basically:
  * 1. Memory ranges used by the payload (usedmem_ranges)
  * 2. Any area that falls below _end symbol in linker script (Kernel needs to be
@@ -599,8 +581,6 @@ static struct mmu_memrange *_mmu_add_fb_range(
 
 	prop.type = TYPE_DMA_MEM;
 
-	/* make sure to allocate a size of multiple of GRANULE_SIZE */
-	size = ALIGN_UP(size, GRANULE_SIZE);
 	prop.size = size;
 	prop.lim_excl = MIN_64_BIT_ADDR;
 	prop.align = MB_SIZE;
@@ -650,18 +630,17 @@ static void mmu_extract_ranges(struct memrange *cb_ranges,
 static void mmu_add_fb_range(struct mmu_ranges *mmu_ranges)
 {
 	struct mmu_memrange *fb_range;
-	static struct cb_framebuffer modified_fb;
-	struct cb_framebuffer *framebuffer = lib_sysinfo.framebuffer;
+	struct cb_framebuffer *framebuffer = &lib_sysinfo.framebuffer;
 	uint32_t fb_size;
 
 	/* Check whether framebuffer is needed */
-	if (framebuffer == NULL)
-		return;
-
 	fb_size = framebuffer->bytes_per_line * framebuffer->y_resolution;
 	if (!fb_size)
 		return;
 
+	/* make sure to allocate a size of multiple of GRANULE_SIZE */
+	fb_size = ALIGN_UP(fb_size, GRANULE_SIZE);
+
 	/* framebuffer address has been set already, so just add it as DMA */
 	if (framebuffer->physical_address) {
 		if (mmu_add_memrange(mmu_ranges,
@@ -677,16 +656,7 @@ static void mmu_add_fb_range(struct mmu_ranges *mmu_ranges)
 	if (fb_range == NULL)
 		mmu_error();
 
-	/*
-	 * Set framebuffer address. However, one needs to use a freshly
-	 * allocated framebuffer structure because the one in the coreboot
-	 * table is part of a checksum calculation. Therefore, one cannot
-	 * modify a field without recomputing the necessary checksum
-	 * calcuation.
-	 */
-	modified_fb = *framebuffer;
-	modified_fb.physical_address = fb_range->base;
-	lib_sysinfo.framebuffer = &modified_fb;
+	framebuffer->physical_address = fb_range->base;
 }
 
 /*
@@ -743,3 +713,8 @@ void mmu_presysinfo_enable(void)
 	mmu_init(&usedmem_ranges);
 	mmu_enable();
 }
+
+const struct mmu_ranges *mmu_get_used_ranges(void)
+{
+	return &usedmem_ranges;
+}
