@@ -224,6 +224,9 @@ static void cb_parse_cbmem_entry(void *ptr, struct sysinfo_t *info)
 	case CBMEM_ID_ACPI_GNVS:
 		info->acpi_gnvs = cbmem_entry->address;
 		break;
+	case CBMEM_ID_SMBIOS:
+		info->smbios = cbmem_entry->address;
+		break;
 	case CBMEM_ID_CBFS_RO_MCACHE:
 		info->cbfs_ro_mcache_offset = cbmem_entry->address;
 		info->cbfs_ro_mcache_size = cbmem_entry->entry_size;
@@ -259,6 +262,12 @@ static void cb_parse_cbmem_entry(void *ptr, struct sysinfo_t *info)
 	case CBMEM_ID_MEM_CHIP_INFO:
 		info->mem_chip_base = cbmem_entry->address;
 		break;
+	case CBMEM_ID_CSE_BP_INFO:
+		info->cse_bp_info = cbmem_entry->address;
+		break;
+	case CBMEM_ID_CSE_INFO:
+		info->cse_info = cbmem_entry->address;
+		break;
 	default:
 		break;
 	}
