@@ -14,6 +14,7 @@
  */
 
 #include <acpi/acpi.h>
+#include <acpi/acpi_iort.h>
 #include <acpi/acpi_ivrs.h>
 #include <acpi/acpigen.h>
 #include <cbfs.h>
@@ -21,8 +22,12 @@
 #include <commonlib/helpers.h>
 #include <console/console.h>
 #include <cpu/cpu.h>
+#include <device/device.h>
 #include <device/mmio.h>
 #include <device/pci.h>
+#include <drivers/crb/tpm.h>
+#include <drivers/uart/pl011.h>
+#include <security/tpm/tss.h>
 #include <string.h>
 #include <types.h>
 #include <version.h>
@@ -47,7 +52,7 @@ void acpi_add_table(acpi_rsdp_t *rsdp, void *table)
 {
 	int i, entries_num;
 	acpi_rsdt_t *rsdt;
-	acpi_xsdt_t *xsdt = NULL;
+	acpi_xsdt_t *xsdt;
 
 	/* The 32bit RSDT may not be valid if tables live above 4GiB */
 	rsdt = (acpi_rsdt_t *)(uintptr_t)rsdp->rsdt_address;
@@ -116,12 +121,11 @@ static enum cb_err acpi_fill_header(acpi_header_t *header, const char name[4],
 	return CB_SUCCESS;
 }
 
-static int acpi_create_mcfg_mmconfig(acpi_mcfg_mmconfig_t *mmconfig, u32 base,
+static int acpi_create_mcfg_mmconfig(acpi_mcfg_mmconfig_t *mmconfig, u64 base,
 				u16 seg_nr, u8 start, u8 end)
 {
 	memset(mmconfig, 0, sizeof(*mmconfig));
 	mmconfig->base_address = base;
-	mmconfig->base_reserved = 0;
 	mmconfig->pci_segment_group_number = seg_nr;
 	mmconfig->start_bus_number = start;
 	mmconfig->end_bus_number = end;
@@ -148,9 +152,14 @@ static void acpi_create_madt(acpi_header_t *header, void *unused)
 
 static unsigned long acpi_fill_mcfg(unsigned long current)
 {
-	current += acpi_create_mcfg_mmconfig((acpi_mcfg_mmconfig_t *)current,
-			CONFIG_ECAM_MMCONF_BASE_ADDRESS, 0, 0,
-			CONFIG_ECAM_MMCONF_BUS_NUMBER - 1);
+	for (int i = 0; i < PCI_SEGMENT_GROUP_COUNT; i++) {
+		current += acpi_create_mcfg_mmconfig((acpi_mcfg_mmconfig_t *)current,
+			CONFIG_ECAM_MMCONF_BASE_ADDRESS + i * PCI_PER_SEGMENT_GROUP_ECAM_SIZE,
+			i,
+			0,
+			PCI_BUSES_PER_SEGMENT_GROUP - 1);
+	}
+
 	return current;
 }
 
@@ -198,7 +207,7 @@ static void *get_tcpa_log(u32 *size)
 
 static void acpi_create_tcpa(acpi_header_t *header, void *unused)
 {
-	if (!CONFIG(TPM1))
+	if (tlcl_get_family() != TPM_1)
 		return;
 
 	acpi_tcpa_t *tcpa = (acpi_tcpa_t *)header;
@@ -244,7 +253,7 @@ static void *get_tpm2_log(u32 *size)
 
 static void acpi_create_tpm2(acpi_header_t *header, void *unused)
 {
-	if (!CONFIG(TPM2))
+	if (tlcl_get_family() != TPM_2)
 		return;
 
 	acpi_tpm2_t *tpm2 = (acpi_tpm2_t *)header;
@@ -264,7 +273,7 @@ static void acpi_create_tpm2(acpi_header_t *header, void *unused)
 
 	/* Hard to detect for coreboot. Just set it to 0 */
 	tpm2->platform_class = 0;
-	if (CONFIG(CRB_TPM)) {
+	if (CONFIG(CRB_TPM) && crb_tpm_is_active()) {
 		/* Must be set to 7 for CRB Support */
 		tpm2->control_area = CONFIG_CRB_TPM_BASE_ADDRESS + 0x40;
 		tpm2->start_method = 7;
@@ -295,10 +304,15 @@ static void acpi_ssdt_write_cbtable(void)
 	acpigen_write_device("CTBL");
 	acpigen_write_coreboot_hid(COREBOOT_ACPI_ID_CBTABLE);
 	acpigen_write_name_integer("_UID", 0);
-	acpigen_write_STA(ACPI_STATUS_DEVICE_ALL_ON);
+	if (CONFIG(EC_GOOGLE_CHROMEEC))
+		acpigen_write_STA(ACPI_STATUS_DEVICE_ALL_ON);
+	else
+		acpigen_write_STA(ACPI_STATUS_DEVICE_HIDDEN_ON);
 	acpigen_write_name("_CRS");
 	acpigen_write_resourcetemplate_header();
-	acpigen_write_mem32fixed(0, base, size);
+	acpigen_resource_consumer_mmio(base, base + size - 1,
+				       MEM_RSRC_FLAG_MEM_READ_ONLY
+				       | MEM_RSRC_FLAG_MEM_ATTR_CACHE);
 	acpigen_write_resourcetemplate_footer();
 	acpigen_pop_len();
 }
@@ -343,17 +357,22 @@ int acpi_create_srat_mem(acpi_srat_mem_t *mem, u8 node, u32 basek, u32 sizek,
 }
 
 int acpi_create_srat_gia_pci(acpi_srat_gia_t *gia, u32 proximity_domain,
-				u16 seg, u8 bus, u8 dev, u8 func, u32 flags)
+			     struct device *dev, u32 flags)
 {
+	/* Only handle PCI devices. */
+	if (dev->path.type != DEVICE_PATH_PCI)
+		return 0;
+
 	gia->type = ACPI_SRAT_STRUCTURE_GIA;
 	gia->length = sizeof(acpi_srat_gia_t);
 	gia->proximity_domain = proximity_domain;
 	gia->dev_handle_type = ACPI_SRAT_GIA_DEV_HANDLE_PCI;
 	/* First two bytes has segment number */
-	memcpy(gia->dev_handle, &seg, 2);
-	gia->dev_handle[2] = bus; /* Byte 2 has bus number */
+	gia->dev_handle[0] = dev->upstream->segment_group;
+	gia->dev_handle[1] = 0;
+	gia->dev_handle[2] = dev->upstream->secondary; /* Byte 2 has bus number */
 	/* Byte 3 has bits 7:3 for dev, bits 2:0 for func */
-	gia->dev_handle[3] = PCI_SLOT(dev) | PCI_FUNC(func);
+	gia->dev_handle[3] = dev->path.pci.devfn;
 	gia->flags = flags;
 
 	return gia->length;
@@ -691,7 +710,8 @@ void acpi_create_ipmi(const struct device *device,
 
 	if (device->path.type == DEVICE_PATH_PCI) {
 		spmi->pci_device_flag = ACPI_IPMI_PCI_DEVICE_FLAG;
-		spmi->pci_bus = device->bus->secondary;
+		spmi->pci_segment_group = device->upstream->segment_group;
+		spmi->pci_bus = device->upstream->secondary;
 		spmi->pci_device = device->path.pci.devfn >> 3;
 		spmi->pci_function = device->path.pci.devfn & 0x7;
 	} else if (type != IPMI_INTERFACE_SSIF) {
@@ -817,13 +837,49 @@ static void acpi_create_dbg2(acpi_dbg2_header_t *dbg2,
 	header->checksum = acpi_checksum((uint8_t *)dbg2, header->length);
 }
 
-unsigned long acpi_write_dbg2_pci_uart(acpi_rsdp_t *rsdp, unsigned long current,
-				const struct device *dev, uint8_t access_size)
+static unsigned long acpi_write_dbg2_uart(acpi_rsdp_t *rsdp, unsigned long current,
+					  int space_id, uint64_t base, uint32_t size,
+					  int access_size, const char *name)
 {
 	acpi_dbg2_header_t *dbg2 = (acpi_dbg2_header_t *)current;
-	struct resource *res;
 	acpi_addr_t address;
 
+	memset(&address, 0, sizeof(address));
+
+	address.space_id = space_id;
+	address.addrl = (uint32_t)base;
+	address.addrh = (uint32_t)((base >> 32) & 0xffffffff);
+	address.access_size = access_size;
+
+	int subtype;
+	/* 16550-compatible with parameters defined in Generic Address Structure */
+	if (CONFIG(DRIVERS_UART_8250IO) || CONFIG(DRIVERS_UART_8250MEM))
+		subtype = ACPI_DBG2_PORT_SERIAL_16550;
+	else if (CONFIG(DRIVERS_UART_PL011))
+		subtype = ACPI_DBG2_PORT_SERIAL_ARM_PL011;
+	else
+		return current;
+
+	acpi_create_dbg2(dbg2,
+			 ACPI_DBG2_PORT_SERIAL,
+			 subtype,
+			 &address, size,
+			 name);
+
+	if (dbg2->header.length) {
+		current += dbg2->header.length;
+		current = acpi_align_current(current);
+		acpi_add_table(rsdp, dbg2);
+	}
+
+	return current;
+}
+
+unsigned long acpi_write_dbg2_pci_uart(acpi_rsdp_t *rsdp, unsigned long current,
+				       const struct device *dev, uint8_t access_size)
+{
+	struct resource *res;
+
 	if (!dev) {
 		printk(BIOS_DEBUG, "%s: Device not found\n", __func__);
 		return current;
@@ -839,33 +895,33 @@ unsigned long acpi_write_dbg2_pci_uart(acpi_rsdp_t *rsdp, unsigned long current,
 		return current;
 	}
 
-	memset(&address, 0, sizeof(address));
+	int space_id;
 	if (res->flags & IORESOURCE_IO)
-		address.space_id = ACPI_ADDRESS_SPACE_IO;
+		space_id = ACPI_ADDRESS_SPACE_IO;
 	else if (res->flags & IORESOURCE_MEM)
-		address.space_id = ACPI_ADDRESS_SPACE_MEMORY;
+		space_id = ACPI_ADDRESS_SPACE_MEMORY;
 	else {
 		printk(BIOS_ERR, "%s: Unknown address space type\n", __func__);
 		return current;
 	}
 
-	address.addrl = (uint32_t)res->base;
-	address.addrh = (uint32_t)((res->base >> 32) & 0xffffffff);
-	address.access_size = access_size;
+	return acpi_write_dbg2_uart(rsdp, current, space_id, res->base, res->size, access_size, acpi_device_path(dev));
+}
 
-	acpi_create_dbg2(dbg2,
-			 ACPI_DBG2_PORT_SERIAL,
-			 ACPI_DBG2_PORT_SERIAL_16550,
-			 &address, res->size,
-			 acpi_device_path(dev));
+unsigned long acpi_pl011_write_dbg2_uart(acpi_rsdp_t *rsdp, unsigned long current,
+					 uint64_t base, const char *name)
+{
+	return acpi_write_dbg2_uart(rsdp, current, ACPI_ADDRESS_SPACE_MEMORY, base,
+				    sizeof(struct pl011_uart), ACPI_ACCESS_SIZE_DWORD_ACCESS,
+				    name);
+}
 
-	if (dbg2->header.length) {
-		current += dbg2->header.length;
-		current = acpi_align_current(current);
-		acpi_add_table(rsdp, dbg2);
-	}
-
-	return current;
+unsigned long acpi_16550_mmio32_write_dbg2_uart(acpi_rsdp_t *rsdp, unsigned long current,
+					 uint64_t base, const char *name)
+{
+	return acpi_write_dbg2_uart(rsdp, current, ACPI_ADDRESS_SPACE_MEMORY, base,
+				    0x100, ACPI_ACCESS_SIZE_DWORD_ACCESS,
+				    name);
 }
 
 static void acpi_create_facs(void *header)
@@ -1158,6 +1214,45 @@ unsigned long acpi_gtdt_add_watchdog(unsigned long current, uint64_t refresh_fra
 	return current + sizeof(struct acpi_gtdt_watchdog);
 }
 
+static void acpi_create_iort(acpi_header_t *header, void *unused)
+{
+	if (!CONFIG(ACPI_IORT))
+		return;
+
+	acpi_iort_t *iort = (acpi_iort_t *)header;
+	unsigned long current = (unsigned long)iort + sizeof(acpi_iort_t);
+
+	if (acpi_fill_header(header, "IORT", IORT, sizeof(acpi_iort_t)) != CB_SUCCESS)
+		return;
+
+	iort->node_count = 0;
+	iort->node_offset = current - (unsigned long)iort;
+
+	current = acpi_soc_fill_iort(iort, current);
+
+	/* (Re)calculate length */
+	header->length = current - (unsigned long)iort;
+}
+
+static void acpi_create_wdat(acpi_header_t *header, void *unused)
+{
+	if (!CONFIG(ACPI_WDAT_WDT))
+		return;
+
+	acpi_wdat_t *wdat = (acpi_wdat_t *)header;
+	unsigned long current = (unsigned long)wdat + sizeof(acpi_wdat_t);
+
+	memset((void *)wdat, 0, sizeof(acpi_wdat_t));
+
+	if (acpi_fill_header(header, "WDAT", WDAT, sizeof(acpi_wdat_t)) != CB_SUCCESS)
+		return;
+
+	current = acpi_soc_fill_wdat(wdat, current);
+
+	/* (Re)calculate length. */
+	header->length = current - (unsigned long)wdat;
+}
+
 unsigned long acpi_create_lpi_desc_ncst(acpi_lpi_desc_ncst_t *lpi_desc, uint16_t uid)
 {
 	memset(lpi_desc, 0, sizeof(acpi_lpi_desc_ncst_t));
@@ -1168,6 +1263,18 @@ unsigned long acpi_create_lpi_desc_ncst(acpi_lpi_desc_ncst_t *lpi_desc, uint16_t
 	return lpi_desc->header.length;
 }
 
+static void acpi_create_pptt(acpi_header_t *header, void *unused)
+{
+	if (!CONFIG(ACPI_PPTT))
+		return;
+
+	if (acpi_fill_header(header, "PPTT", PPTT, sizeof(acpi_pptt_t)) != CB_SUCCESS)
+		return;
+
+	acpi_pptt_t *pptt = (acpi_pptt_t *)header;
+	acpi_create_pptt_body(pptt);
+}
+
 static uint8_t acpi_spcr_type(void)
 {
 	/* 16550-compatible with parameters defined in Generic Address Structure */
@@ -1265,9 +1372,6 @@ static void acpi_create_dsdt(acpi_header_t *header, void *dsdt_file_arg)
 		if (CONFIG(CHROMEOS_NVS))
 			acpi_fill_cnvs();
 
-		for (const struct device *dev = all_devices; dev; dev = dev->next)
-			if (dev->ops && dev->ops->acpi_inject_dsdt)
-				dev->ops->acpi_inject_dsdt(dev);
 		current = (unsigned long)acpigen_get_current();
 		memcpy((char *)current,
 		       (char *)dsdt_file + sizeof(acpi_header_t),
@@ -1319,6 +1423,8 @@ static void acpixtract_compatible_hexdump(const void *memory, size_t length)
 
 static void acpidump_print(void *table_ptr)
 {
+	if (table_ptr == NULL)
+		return;
 	const acpi_header_t *header = (acpi_header_t *)table_ptr;
 	const size_t table_size = header->length;
 	printk(BIOS_SPEW, "%.4s @ 0x0000000000000000\n", header->signature);
@@ -1358,6 +1464,9 @@ unsigned long write_acpi_tables(const unsigned long start)
 		{ acpi_create_bert, NULL, sizeof(acpi_bert_t) },
 		{ acpi_create_spcr, NULL, sizeof(acpi_spcr_t) },
 		{ acpi_create_gtdt, NULL, sizeof(acpi_gtdt_t) },
+		{ acpi_create_pptt, NULL, sizeof(acpi_pptt_t) },
+		{ acpi_create_iort, NULL, sizeof(acpi_iort_t) },
+		{ acpi_create_wdat, NULL, sizeof(acpi_wdat_t) },
 	};
 
 	current = start;
@@ -1380,10 +1489,41 @@ unsigned long write_acpi_tables(const unsigned long start)
 		if (!rsdp)
 			return fw;
 
+		current = fw;
+		current = acpi_align_current(current);
+		if (rsdp->xsdt_address == 0) {
+			acpi_rsdt_t *existing_rsdt = (acpi_rsdt_t *)(uintptr_t)rsdp->rsdt_address;
+
+			/*
+			 * Qemu only provides a smaller ACPI 1.0 RSDP, thus
+			 * allocate a bigger ACPI 2.0 RSDP structure.
+			 */
+			rsdp = (acpi_rsdp_t *)current;
+			current += sizeof(acpi_rsdp_t);
+			coreboot_rsdp = (uintptr_t)rsdp;
+
+			xsdt = (acpi_xsdt_t *)current;
+			current += sizeof(acpi_xsdt_t);
+			current = acpi_align_current(current);
+
+			/*
+			 * Qemu only creates an RSDT.
+			 * Add an XSDT based on the existing RSDT entries.
+			 */
+			acpi_write_rsdp(rsdp, existing_rsdt, xsdt, oem_id);
+			acpi_write_xsdt(xsdt, oem_id, oem_table_id);
+			/*
+			 * Copy existing entries to the new XSDT. This will override existing
+			 * RSDT entries with the same value.
+			 */
+			for (int i = 0; existing_rsdt->entry[i]; i++)
+				acpi_add_table(rsdp, (void *)(uintptr_t)existing_rsdt->entry[i]);
+		}
+
 		/* Add BOOT0000 for Linux google firmware driver */
 		printk(BIOS_DEBUG, "ACPI:     * SSDT\n");
-		ssdt = (acpi_header_t *)fw;
-		current = (unsigned long)ssdt + sizeof(acpi_header_t);
+		ssdt = (acpi_header_t *)current;
+		current += sizeof(acpi_header_t);
 
 		memset((void *)ssdt, 0, sizeof(acpi_header_t));
 
@@ -1409,7 +1549,7 @@ unsigned long write_acpi_tables(const unsigned long start)
 
 		acpi_add_table(rsdp, ssdt);
 
-		return fw;
+		return current;
 	}
 
 	dsdt_file = cbfs_map(CONFIG_CBFS_PREFIX "/dsdt.aml", &dsdt_size);
@@ -1684,6 +1824,12 @@ int get_acpi_table_revision(enum acpi_tables table)
 		return 4;
 	case GTDT:
 		return 3;
+	case PPTT: /* ACPI 6.4 */
+		return 3;
+	case IORT: /* IO Remapping Table E.e */
+		return 6;
+	case WDAT:
+		return 1;
 	default:
 		return -1;
 	}
