@@ -15,10 +15,6 @@ typedef struct {
 
 #define SPIN_LOCK_UNLOCKED { 1 }
 
-#define STAGE_HAS_SPINLOCKS !ENV_ROMSTAGE_OR_BEFORE
-
-#if STAGE_HAS_SPINLOCKS
-
 #define DECLARE_SPIN_LOCK(x)	\
 	static spinlock_t x = SPIN_LOCK_UNLOCKED;
 
@@ -29,17 +25,17 @@ typedef struct {
  * We make no fairness assumptions. They have a cost.
  */
 #define barrier() __asm__ __volatile__("" : : : "memory")
-#define spin_is_locked(x)	(*(volatile char *)(&(x)->lock) <= 0)
+#define spin_is_locked(x)	(*(volatile int *)(&(x)->lock) <= 0)
 #define spin_unlock_wait(x)	do { barrier(); } while (spin_is_locked(x))
 #undef barrier
 
 #define spin_lock_string \
 	"\n1:\t" \
-	"lock ; decb %0\n\t" \
+	"lock ; decl %0\n\t" \
 	"js 2f\n" \
 	".section .text.lock,\"ax\"\n" \
 	"2:\t" \
-	"cmpb $0,%0\n\t" \
+	"cmpl $0,%0\n\t" \
 	"rep;nop\n\t" \
 	"jle 2b\n\t" \
 	"jmp 1b\n" \
@@ -49,7 +45,7 @@ typedef struct {
  * This works. Despite all the confusion.
  */
 #define spin_unlock_string \
-	"movb $1,%0"
+	"movl $1,%0"
 
 static __always_inline void spin_lock(spinlock_t *lock)
 {
@@ -59,7 +55,6 @@ static __always_inline void spin_lock(spinlock_t *lock)
 
 	/* Switching contexts while holding a spinlock will lead to deadlocks */
 	thread_coop_disable();
-
 }
 
 static __always_inline void spin_unlock(spinlock_t *lock)
@@ -71,14 +66,4 @@ static __always_inline void spin_unlock(spinlock_t *lock)
 		: "=m" (lock->lock) : : "memory");
 }
 
-#else
-
-#define DECLARE_SPIN_LOCK(x)
-#define spin_is_locked(lock)	0
-#define spin_unlock_wait(lock)	do {} while (0)
-#define spin_lock(lock)		do {} while (0)
-#define spin_unlock(lock)	do {} while (0)
-
-#endif
-
 #endif /* ARCH_SMP_SPINLOCK_H */
