@@ -4,7 +4,7 @@
 #define _CBMEM_ID_H_
 
 #define CBMEM_ID_ACPI		0x41435049
-#define CBMEM_ID_ACPI_BERT      0x42455254
+#define CBMEM_ID_ACPI_BERT	0x42455254
 #define CBMEM_ID_ACPI_CNVS	0x434e5653
 #define CBMEM_ID_ACPI_GNVS	0x474e5653
 #define CBMEM_ID_ACPI_HEST	0x48455354
@@ -56,12 +56,12 @@
 #define CBMEM_ID_ROMSTAGE_INFO	0x47545352
 #define CBMEM_ID_ROMSTAGE_RAM_STACK 0x90357ac4
 #define CBMEM_ID_ROOT		0xff4007ff
-#define CBMEM_ID_SMBIOS         0x534d4254
+#define CBMEM_ID_SMBIOS		0x534d4254
 #define CBMEM_ID_SMM_SAVE_SPACE	0x07e9acee
 #define CBMEM_ID_STAGEx_META	0x57a9e000
 #define CBMEM_ID_STAGEx_CACHE	0x57a9e100
 #define CBMEM_ID_STAGEx_RAW	0x57a9e200
-#define CBMEM_ID_STORAGE_DATA	0x53746f72
+#define CBMEM_ID_STORAGE_DATA	0x53746f72 /* deprecated */
 #define CBMEM_ID_TPM_CB_LOG	0x54435041 /* TPM log in coreboot-specific format */
 #define CBMEM_ID_TCPA_TCG_LOG	0x54445041 /* TPM log per TPM 1.2 specification */
 #define CBMEM_ID_TIMESTAMP	0x54494d45
@@ -88,6 +88,8 @@
 #define CBMEM_ID_AMD_STB	0x5f425453
 #define CBMEM_ID_AMD_MP2	0x5f32504d
 #define CBMEM_ID_CSE_INFO	0x4553435F
+#define CBMEM_ID_CSE_BP_INFO	0x42455343
+#define CBMEM_ID_AMD_OPENSIL	0x4153494C
 
 #define CBMEM_ID_TO_NAME_TABLE				 \
 	{ CBMEM_ID_ACPI,		"ACPI       " }, \
@@ -106,7 +108,7 @@
 	{ CBMEM_ID_CB_EARLY_DRAM,	"EARLY DRAM USAGE" }, \
 	{ CBMEM_ID_CONSOLE,		"CONSOLE    " }, \
 	{ CBMEM_ID_COVERAGE,		"COVERAGE   " }, \
-	{ CBMEM_ID_CPU_CRASHLOG,	"CPU CRASHLOG"}, \
+	{ CBMEM_ID_CPU_CRASHLOG,	"CPU CRASHLOG (deprecated)"}, \
 	{ CBMEM_ID_EHCI_DEBUG,		"USBDEBUG   " }, \
 	{ CBMEM_ID_ELOG,		"ELOG       " }, \
 	{ CBMEM_ID_FREESPACE,		"FREE SPACE " }, \
@@ -125,7 +127,7 @@
 	{ CBMEM_ID_MMC_STATUS,		"MMC STATUS " }, \
 	{ CBMEM_ID_MPTABLE,		"SMP TABLE  " }, \
 	{ CBMEM_ID_MRCDATA,		"MRC DATA   " }, \
-	{ CBMEM_ID_PMC_CRASHLOG,	"PMC CRASHLOG"}, \
+	{ CBMEM_ID_PMC_CRASHLOG,	"PMC CRASHLOG (deprecated)"}, \
 	{ CBMEM_ID_VAR_MRCDATA,		"VARMRC DATA" }, \
 	{ CBMEM_ID_MTC,			"MTC        " }, \
 	{ CBMEM_ID_PIRQ,		"IRQ TABLE  " }, \
@@ -165,8 +167,10 @@
 	{ CBMEM_ID_FSP_LOGO,		"FSP LOGO   "}, \
 	{ CBMEM_ID_SMM_COMBUFFER,	"SMM COMBUFFER"}, \
 	{ CBMEM_ID_TYPE_C_INFO,		"TYPE_C INFO"},\
-	{ CBMEM_ID_MEM_CHIP_INFO,       "MEM CHIP INFO"},\
+	{ CBMEM_ID_MEM_CHIP_INFO,	"MEM CHIP INFO"},\
 	{ CBMEM_ID_AMD_STB,		"AMD STB"},\
 	{ CBMEM_ID_AMD_MP2,		"AMD MP2 BUFFER"},\
-	{ CBMEM_ID_CSE_INFO,		"CSE SPECIFIC INFORMATION"}
+	{ CBMEM_ID_CSE_INFO,		"CSE SPECIFIC INFO"},\
+	{ CBMEM_ID_CSE_BP_INFO,		"CSE BP INFO"}, \
+	{ CBMEM_ID_AMD_OPENSIL,		"OPENSIL DATA"}
 #endif /* _CBMEM_ID_H_ */
