@@ -46,6 +46,12 @@ struct sdhci_ctrlr {
 
 	/* Number of ADMA descriptors currently in the array. */
 	int adma_desc_count;
+
+	/*
+	 * Point to function to run before running initialization.
+	 * This would include anything non-standard.
+	 */
+	int (*attach)(struct sdhci_ctrlr *ctrlr);
 };
 
 int add_sdhci(struct sdhci_ctrlr *sdhci_ctrlr);
@@ -57,6 +63,7 @@ void sdhci_display_setup(struct sdhci_ctrlr *sdhci_ctrlr);
 struct sd_mmc_ctrlr *new_pci_sdhci_controller(uint32_t dev);
 
 /* Add SDHCI controller with memory address */
-struct sd_mmc_ctrlr *new_mem_sdhci_controller(void *ioaddr);
+struct sd_mmc_ctrlr *new_mem_sdhci_controller(void *ioaddr,
+					      int (*pre_init_func)(struct sdhci_ctrlr *host));
 
 #endif /* __COMMONLIB_SDHCI_H__ */
