@@ -84,6 +84,8 @@ enum timestamp_id {
 	TS_COPYVPD_RW_END = 552,
 	TS_TPM_ENABLE_UPDATE_START = 553,
 	TS_TPM_ENABLE_UPDATE_END = 554,
+	TS_ESOL_START = 555,
+	TS_ESOL_END = 556,
 
 	/* 900-940 reserved for vendorcode extensions (900-940: AMD) */
 	TS_AGESA_INIT_RESET_START = 900,
@@ -138,6 +140,8 @@ enum timestamp_id {
 	TS_FSP_END_OF_FIRMWARE_END = 961,
 	TS_FSP_MULTI_PHASE_SI_INIT_START = 962,
 	TS_FSP_MULTI_PHASE_SI_INIT_END = 963,
+	TS_FSP_MULTI_PHASE_MEM_INIT_START = 964,
+	TS_FSP_MULTI_PHASE_MEM_INIT_END = 965,
 	TS_FSP_MEMORY_INIT_LOAD = 970,
 	TS_FSP_SILICON_INIT_LOAD = 971,
 
@@ -161,6 +165,7 @@ enum timestamp_id {
 	TS_VB_EC_VBOOT_DONE = 1030,
 	TS_VB_STORAGE_INIT_DONE = 1040,
 	TS_VB_READ_KERNEL_DONE = 1050,
+	TS_VB_AUXFW_SYNC_DONE = 1060,
 	TS_VB_VBOOT_DONE = 1100,
 
 	TS_KERNEL_START = 1101,
@@ -263,6 +268,8 @@ static const struct timestamp_id_to_name {
 	TS_NAME_DEF(TS_TPM_ENABLE_UPDATE_START, TS_TPM_ENABLE_UPDATE_END,
 		    "started TPM enable update"),
 	TS_NAME_DEF(TS_TPM_ENABLE_UPDATE_END, 0, "finished TPM enable update"),
+	TS_NAME_DEF(TS_ESOL_START, 0, "started early sign-off life (eSOL) notification"),
+	TS_NAME_DEF(TS_ESOL_END, 0, "finished early sign-off life (eSOL) notification"),
 
 	/* AMD related timestamps */
 	TS_NAME_DEF(TS_AGESA_INIT_RESET_START, TS_AGESA_INIT_RESET_END, "calling AmdInitReset"),
@@ -295,7 +302,7 @@ static const struct timestamp_id_to_name {
 
 	/* Intel ME related timestamps */
 	TS_NAME_DEF(TS_ME_INFORM_DRAM_START, TS_ME_INFORM_DRAM_END,
-		    "waiting for ME acknowledgement of raminit"),
+		    "waiting for ME acknowledgment of raminit"),
 	TS_NAME_DEF(TS_ME_INFORM_DRAM_END, 0, "finished waiting for ME response"),
 	TS_NAME_DEF(TS_ME_END_OF_POST_START, TS_ME_END_OF_POST_END, "before sending EOP to ME"),
 	TS_NAME_DEF(TS_ME_END_OF_POST_END, 0, "after sending EOP to ME"),
@@ -319,6 +326,9 @@ static const struct timestamp_id_to_name {
 	TS_NAME_DEF(TS_FSP_MULTI_PHASE_SI_INIT_START, TS_FSP_MULTI_PHASE_SI_INIT_END,
 		    "calling FspMultiPhaseSiInit"),
 	TS_NAME_DEF(TS_FSP_MULTI_PHASE_SI_INIT_END, 0, "returning from FspMultiPhaseSiInit"),
+	TS_NAME_DEF(TS_FSP_MULTI_PHASE_MEM_INIT_START, TS_FSP_MULTI_PHASE_MEM_INIT_END,
+		    "calling FspMultiPhaseMemInit"),
+	TS_NAME_DEF(TS_FSP_MULTI_PHASE_MEM_INIT_END, 0, "returning from FspMultiPhaseMemInit"),
 	TS_NAME_DEF(TS_FSP_ENUMERATE_START, TS_FSP_ENUMERATE_END,
 		    "calling FspNotify(AfterPciEnumeration)"),
 	TS_NAME_DEF(TS_FSP_ENUMERATE_END, 0, "returning from FspNotify(AfterPciEnumeration)"),
@@ -349,6 +359,7 @@ static const struct timestamp_id_to_name {
 	TS_NAME_DEF(TS_VB_EC_VBOOT_DONE, 0, "finished EC verification"),
 	TS_NAME_DEF(TS_VB_STORAGE_INIT_DONE, 0, "finished storage device initialization"),
 	TS_NAME_DEF(TS_VB_READ_KERNEL_DONE, 0, "finished reading kernel from disk"),
+	TS_NAME_DEF(TS_VB_AUXFW_SYNC_DONE, 0, "finished AuxFW Sync"),
 	TS_NAME_DEF(TS_VB_VBOOT_DONE, 0, "finished vboot kernel verification"),
 
 	TS_NAME_DEF(TS_KERNEL_START, 0, "jumping to kernel"),
