@@ -6,7 +6,7 @@
 #include "bouncebuf.h"
 #include <commonlib/sd_mmc_ctrlr.h>
 #include <commonlib/sdhci.h>
-#include <commonlib/stdlib.h>
+#include <commonlib/bsd/stdlib.h>
 #include <commonlib/storage.h>
 #include <delay.h>
 #include <endian.h>
@@ -18,14 +18,9 @@
 
 #define DMA_AVAILABLE	((CONFIG(SDHCI_ADMA_IN_BOOTBLOCK) && ENV_BOOTBLOCK) \
 			|| (CONFIG(SDHCI_ADMA_IN_VERSTAGE) && ENV_SEPARATE_VERSTAGE) \
-			|| (CONFIG(SDHCI_ADMA_IN_ROMSTAGE) && ENV_ROMSTAGE) \
+			|| (CONFIG(SDHCI_ADMA_IN_ROMSTAGE) && ENV_SEPARATE_ROMSTAGE) \
 			|| ENV_POSTCAR || ENV_RAMSTAGE)
 
-__weak void *dma_malloc(size_t length_in_bytes)
-{
-	return malloc(length_in_bytes);
-}
-
 void sdhci_reset(struct sdhci_ctrlr *sdhci_ctrlr, u8 mask)
 {
 	struct stopwatch sw;
@@ -320,8 +315,7 @@ static int sdhci_send_command(struct sd_mmc_ctrlr *ctrlr,
 		if (!dma_coherent(buf)) {
 			bbstate = &bbstate_val;
 			if (bounce_buffer_start(bbstate, buf, len, bbflags)) {
-				sdhc_error(
-					"ERROR: Failed to get bounce buffer.\n");
+				sdhc_error("Failed to get bounce buffer.\n");
 				return -1;
 			}
 		}
@@ -586,6 +580,16 @@ static int sdhci_pre_init(struct sdhci_ctrlr *sdhci_ctrlr)
 	struct sd_mmc_ctrlr *ctrlr = &sdhci_ctrlr->sd_mmc_ctrlr;
 	unsigned int caps, caps_1;
 
+	/*
+	 * If the device needs to do anything non-standard before
+	 * sdhci initialization, run it here.
+	 */
+	if (sdhci_ctrlr->attach) {
+		int rv = sdhci_ctrlr->attach(sdhci_ctrlr);
+		if (rv)
+			return rv;
+	}
+
 	/* Get controller version and capabilities */
 	ctrlr->version = sdhci_readw(sdhci_ctrlr, SDHCI_HOST_VERSION) & 0xff;
 	caps = sdhci_readl(sdhci_ctrlr, SDHCI_CAPABILITIES);
