@@ -20,18 +20,11 @@
 #include <smp/node.h>
 #include <types.h>
 
-static void configure_thermal_target(void)
+static void configure_thermal_target(struct device *dev)
 {
-	struct cpu_intel_model_2065x_config *conf;
-	struct device *lapic;
+	struct cpu_intel_model_2065x_config *conf = dev->upstream->dev->chip_info;
 	msr_t msr;
 
-	/* Find pointer to CPU configuration */
-	lapic = dev_find_lapic(SPEEDSTEP_APIC_MAGIC);
-	if (!lapic || !lapic->chip_info)
-		return;
-	conf = lapic->chip_info;
-
 	/* Set TCC activation offset if supported */
 	msr = rdmsr(MSR_PLATFORM_INFO);
 	if ((msr.lo & (1 << 30)) && conf->tcc_offset) {
@@ -101,7 +94,7 @@ static void model_2065x_init(struct device *cpu)
 	configure_misc();
 
 	/* Thermal throttle activation offset */
-	configure_thermal_target();
+	configure_thermal_target(cpu);
 
 	/* Set Max Ratio */
 	set_max_ratio();
@@ -182,12 +175,12 @@ static struct device_operations cpu_dev_ops = {
 
 /* Arrandale / Clarkdale CPU IDs */
 static const struct cpu_device_id cpu_table[] = {
-	{ X86_VENDOR_INTEL, 0x20650 },
-	{ X86_VENDOR_INTEL, 0x20651 },
-	{ X86_VENDOR_INTEL, 0x20652 },
-	{ X86_VENDOR_INTEL, 0x20654 },
-	{ X86_VENDOR_INTEL, 0x20655 },
-	{ 0, 0 },
+	{ X86_VENDOR_INTEL, 0x20650, CPUID_EXACT_MATCH_MASK },
+	{ X86_VENDOR_INTEL, 0x20651, CPUID_EXACT_MATCH_MASK },
+	{ X86_VENDOR_INTEL, 0x20652, CPUID_EXACT_MATCH_MASK },
+	{ X86_VENDOR_INTEL, 0x20654, CPUID_EXACT_MATCH_MASK },
+	{ X86_VENDOR_INTEL, 0x20655, CPUID_EXACT_MATCH_MASK },
+	CPU_TABLE_END
 };
 
 static const struct cpu_driver driver __cpu_driver = {
