@@ -35,11 +35,10 @@ static struct device_operations cpu_dev_ops = {
  * http://download.intel.com/design/intarch/specupdt/24445358.pdf
  */
 static const struct cpu_device_id cpu_table[] = {
-	{ X86_VENDOR_INTEL, 0x0671 },
-	{ X86_VENDOR_INTEL, 0x0672 }, /* PIII, kB0 */
-	{ X86_VENDOR_INTEL, 0x0673 }, /* PIII, kC0 */
-
-	{ 0, 0 },
+	{ X86_VENDOR_INTEL, 0x0671, CPUID_EXACT_MATCH_MASK },
+	{ X86_VENDOR_INTEL, 0x0672, CPUID_EXACT_MATCH_MASK }, /* PIII, kB0 */
+	{ X86_VENDOR_INTEL, 0x0673, CPUID_EXACT_MATCH_MASK }, /* PIII, kC0 */
+	CPU_TABLE_END
 };
 
 static const struct cpu_driver driver __cpu_driver = {
