@@ -17,7 +17,6 @@
 #include <cpu/x86/mp.h>
 #include <delay.h>
 #include <device/device.h>
-#include <device/path.h>
 #include <smp/atomic.h>
 #include <smp/spinlock.h>
 #include <symbols.h>
@@ -98,6 +97,7 @@ struct sipi_params {
 	uint32_t msr_table_ptr;
 	uint32_t msr_count;
 	uint32_t c_handler;
+	uint32_t cr3;
 	atomic_t ap_count;
 } __packed;
 
@@ -204,7 +204,7 @@ static asmlinkage void ap_init(unsigned int index)
 	dev->path.apic.initial_lapicid = initial_lapicid();
 	dev->enabled = 1;
 
-	set_cpu_topology_from_leaf_b(dev);
+	set_cpu_topology(dev);
 
 	if (cpu_is_intel())
 		printk(BIOS_INFO, "AP: slot %u apic_id %x, MCU rev: 0x%08x\n", index,
@@ -361,6 +361,7 @@ static atomic_t *load_sipi_vector(struct mp_params *mp_params)
 	else
 		sp->microcode_lock = 0;
 	sp->c_handler = (uintptr_t)&ap_init;
+	sp->cr3 = read_cr3();
 	ap_count = &sp->ap_count;
 	atomic_set(ap_count, 0);
 
@@ -561,7 +562,7 @@ static enum cb_err init_bsp(struct bus *cpu_bus)
 		return CB_ERR;
 	}
 	bsp->path.apic.initial_lapicid = initial_lapicid();
-	set_cpu_topology_from_leaf_b(bsp);
+	set_cpu_topology(bsp);
 
 	/* Find the device structure for the boot CPU. */
 	set_cpu_info(0, bsp);
@@ -763,6 +764,7 @@ static enum cb_err install_relocation_handler(int num_cpus, size_t save_state_si
 		.cpu_save_state_size = save_state_size,
 		.num_concurrent_save_states = 1,
 		.handler = smm_do_relocation,
+		.cr3 = read_cr3(),
 	};
 
 	if (smm_setup_relocation_handler(&smm_params)) {
@@ -777,7 +779,7 @@ static enum cb_err install_permanent_handler(int num_cpus, uintptr_t smbase,
 				     size_t smsize, size_t save_state_size)
 {
 	/*
-	 * All the CPUs will relocate to permanaent handler now. Set parameters
+	 * All the CPUs will relocate to permanent handler now. Set parameters
 	 * needed for all CPUs. The placement of each CPUs entry point is
 	 * determined by the loader. This code simply provides the beginning of
 	 * SMRAM region, the number of CPUs who will use the handler, the stack
@@ -1087,10 +1089,7 @@ static void fill_mp_state_smm(struct mp_state *state, const struct mp_ops *ops)
 	/*
 	 * Make sure there is enough room for the SMM descriptor
 	 */
-	if (CONFIG(STM)) {
-		state->smm_save_state_size +=
-			ALIGN_UP(sizeof(TXT_PROCESSOR_SMM_DESCRIPTOR), 0x100);
-	}
+	state->smm_save_state_size += STM_PSD_SIZE;
 
 	/*
 	 * Default to smm_initiate_relocation() if trigger callback isn't
