@@ -1,7 +1,6 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
 #include <arch/io.h>
-#include <commonlib/bsd/compiler.h>
 #include <commonlib/region.h>
 #include <console/cbmem_console.h>
 #include <console/console.h>
@@ -107,7 +106,7 @@ struct global_nvs *gnvs;
 
 void *smm_get_save_state(int cpu)
 {
-	if (cpu > smm_runtime.num_cpus)
+	if (cpu >= smm_runtime.num_cpus)
 		return NULL;
 
 	return (void *)(smm_runtime.save_state_top[cpu] -
