@@ -5,19 +5,17 @@
 #include <commonlib/helpers.h>
 #include <commonlib/region.h>
 #include <console/console.h>
+#include <cpu/cpu.h>
 #include <cpu/x86/smm.h>
+#include <device/device.h>
+#include <device/mmio.h>
 #include <rmodule.h>
+#include <smmstore.h>
 #include <stdio.h>
 #include <string.h>
 #include <types.h>
 
-#define FXSAVE_SIZE 512
 #define SMM_CODE_SEGMENT_SIZE 0x10000
-/* FXSAVE area during relocation. While it may not be strictly needed the
-   SMM stub code relies on the FXSAVE area being non-zero to enable SSE
-   instructions within SMM mode. */
-static uint8_t fxsave_area_relocation[CONFIG_MAX_CPUS][FXSAVE_SIZE]
-__attribute__((aligned(16)));
 
 /*
  * Components that make up the SMRAM:
@@ -54,7 +52,7 @@ struct cpu_smm_info cpus[CONFIG_MAX_CPUS] = { 0 };
  * developer's manuals (volume 3, chapter 34). SMRAM is divided up into the
  * following regions:
  * +-----------------+ Top of SMRAM
- * |                 | <- MSEG, FXSAVE
+ * |      MSEG       |
  * +-----------------+
  * |    common       |
  * |  smi handler    | 64K
@@ -117,11 +115,10 @@ static int smm_create_map(const uintptr_t smbase, const unsigned int num_cpus,
 		const size_t segment_number = i / cpus_per_segment;
 		cpus[i].smbase = smbase - SMM_CODE_SEGMENT_SIZE * segment_number
 			- needed_ss_size * (i % cpus_per_segment);
-		cpus[i].stub_code.offset = cpus[i].smbase + SMM_ENTRY_OFFSET;
-		cpus[i].stub_code.size = stub_size;
-		cpus[i].ss.offset = cpus[i].smbase + SMM_CODE_SEGMENT_SIZE
-			- params->cpu_save_state_size;
-		cpus[i].ss.size = params->cpu_save_state_size;
+		cpus[i].stub_code = region_create(cpus[i].smbase + SMM_ENTRY_OFFSET, stub_size);
+		cpus[i].ss = region_create(
+				cpus[i].smbase + SMM_CODE_SEGMENT_SIZE - params->cpu_save_state_size,
+				params->cpu_save_state_size);
 		cpus[i].active = 1;
 	}
 
@@ -238,8 +235,7 @@ static void smm_stub_place_staggered_entry_points(const struct smm_loader_params
  * by the permanent handler can be used during relocation.
  */
 static int smm_module_setup_stub(const uintptr_t smbase, const size_t smm_size,
-				 struct smm_loader_params *params,
-				 void *const fxsave_area)
+				 struct smm_loader_params *params)
 {
 	struct rmodule smm_stub;
 	if (rmodule_parse(&_binary_smmstub_start, &smm_stub)) {
@@ -264,21 +260,27 @@ static int smm_module_setup_stub(const uintptr_t smbase, const size_t smm_size,
 	stub_params->stack_top = stack_top;
 	stub_params->stack_size = g_stack_size;
 	stub_params->c_handler = (uintptr_t)params->handler;
-	stub_params->fxsave_area = (uintptr_t)fxsave_area;
-	stub_params->fxsave_area_size = FXSAVE_SIZE;
+	stub_params->cr3 = params->cr3;
 
-	/* Initialize the APIC id to CPU number table to be 1:1 */
-	for (int i = 0; i < params->num_cpus; i++)
-		stub_params->apic_id_to_cpu[i] = i;
+	/* This runs on the BSP. All the APs are its siblings */
+	struct cpu_info *info = cpu_info();
+	if (!info || !info->cpu) {
+		printk(BIOS_ERR, "%s: Failed to find BSP struct device\n", __func__);
+		return -1;
+	}
+	int i = 0;
+	for (struct device *dev = info->cpu; dev; dev = dev->sibling)
+		if (dev->enabled)
+			stub_params->apic_id_to_cpu[i++] = dev->path.apic.initial_lapicid;
 
-	/* Allow the initiator to manipulate SMM stub parameters. */
-	params->stub_params = stub_params;
+	if (i != params->num_cpus) {
+		printk(BIOS_ERR, "%s: Failed to set up apic map correctly\n", __func__);
+		return -1;
+	}
 
 	printk(BIOS_DEBUG, "%s: stack_top = 0x%x\n", __func__, stub_params->stack_top);
 	printk(BIOS_DEBUG, "%s: per cpu stack_size = 0x%x\n", __func__,
 	       stub_params->stack_size);
-	printk(BIOS_DEBUG, "%s: runtime.start32_offset = 0x%x\n", __func__,
-	       stub_params->start32_offset);
 	printk(BIOS_DEBUG, "%s: runtime.smm_size = 0x%zx\n", __func__, smm_size);
 
 	smm_stub_place_staggered_entry_points(params);
@@ -313,17 +315,19 @@ int smm_setup_relocation_handler(struct smm_loader_params *params)
 		params->num_cpus = CONFIG_MAX_CPUS;
 
 	printk(BIOS_SPEW, "%s: exit\n", __func__);
-	return smm_module_setup_stub(smram, SMM_DEFAULT_SIZE,
-				     params, fxsave_area_relocation);
+	return smm_module_setup_stub(smram, SMM_DEFAULT_SIZE, params);
 }
 
 static void setup_smihandler_params(struct smm_runtime *mod_params,
-				    uintptr_t smram_base,
-				    uintptr_t smram_size,
 				    struct smm_loader_params *loader_params)
 {
-	mod_params->smbase = smram_base;
-	mod_params->smm_size = smram_size;
+	uintptr_t tseg_base;
+	size_t tseg_size;
+
+	smm_region(&tseg_base, &tseg_size);
+
+	mod_params->smbase = tseg_base;
+	mod_params->smm_size = tseg_size;
 	mod_params->save_state_size = loader_params->cpu_save_state_size;
 	mod_params->num_cpus = loader_params->num_cpus;
 	mod_params->gnvs_ptr = (uint32_t)(uintptr_t)acpi_get_gnvs();
@@ -337,17 +341,41 @@ static void setup_smihandler_params(struct smm_runtime *mod_params,
 	}
 
 	for (int i = 0; i < loader_params->num_cpus; i++)
-		mod_params->save_state_top[i] = region_end(&cpus[i].ss);
+		mod_params->save_state_top[i] = region_last(&cpus[i].ss) + 1;
+
+	if (CONFIG(RUNTIME_CONFIGURABLE_SMM_LOGLEVEL))
+		mod_params->smm_log_level = mainboard_set_smm_log_level();
+	else
+		mod_params->smm_log_level = 0;
+
+	if (CONFIG(SMM_PCI_RESOURCE_STORE))
+		smm_pci_resource_store_init(mod_params);
+
+	if (CONFIG(SMMSTORE_V2)) {
+		struct smmstore_params_info info;
+		if (smmstore_get_info(&info) < 0) {
+			printk(BIOS_INFO, "SMMSTORE: Failed to get meta data\n");
+			return;
+		}
+
+		void *ptr = cbmem_add(CBMEM_ID_SMM_COMBUFFER, info.block_size);
+		if (!ptr) {
+			printk(BIOS_ERR, "SMMSTORE: Failed to add com buffer\n");
+			return;
+		}
+		mod_params->smmstore_com_buffer_base = (uintptr_t)ptr;
+		mod_params->smmstore_com_buffer_size = info.block_size;
+	}
 }
 
 static void print_region(const char *name, const struct region region)
 {
 	printk(BIOS_DEBUG, "%-12s [0x%zx-0x%zx]\n", name, region_offset(&region),
-	       region_end(&region));
+	       region_last(&region));
 }
 
-/* STM + FX_SAVE + Handler + (Stub + Save state) * CONFIG_MAX_CPUS + stacks */
-#define SMM_REGIONS_ARRAY_SIZE (1 + 1 + 1 + CONFIG_MAX_CPUS * 2 + 1)
+/* STM + Handler + (Stub + Save state) * CONFIG_MAX_CPUS + stacks + page tables*/
+#define SMM_REGIONS_ARRAY_SIZE (1  + 1 + CONFIG_MAX_CPUS * 2 + 1 + 1)
 
 static int append_and_check_region(const struct region smram,
 				   const struct region region,
@@ -356,7 +384,7 @@ static int append_and_check_region(const struct region smram,
 {
 	unsigned int region_counter = 0;
 	for (; region_counter < SMM_REGIONS_ARRAY_SIZE; region_counter++)
-		if (region_list[region_counter].size == 0)
+		if (region_sz(&region_list[region_counter]) == 0)
 			break;
 
 	if (region_counter >= SMM_REGIONS_ARRAY_SIZE) {
@@ -382,6 +410,39 @@ static int append_and_check_region(const struct region smram,
 	return 0;
 }
 
+#define _PRES (1ULL << 0)
+#define _RW   (1ULL << 1)
+#define _US   (1ULL << 2)
+#define _A    (1ULL << 5)
+#define _D    (1ULL << 6)
+#define _PS   (1ULL << 7)
+#define _GEN_DIR(a) (_PRES + _RW + _US + _A + (a))
+#define _GEN_PAGE(a) (_PRES + _RW + _US + _PS + _A +  _D + (a))
+#define PAGE_SIZE 8
+
+/* Return the PM4LE */
+static uintptr_t install_page_table(const uintptr_t handler_base)
+{
+	const bool one_g_pages = !!(cpuid_edx(0x80000001) & (1 << 26));
+	/* 4 1G pages or 4 PDPE entries with 512 * 2M pages */
+	const size_t pages_needed = one_g_pages ? 4 : 2048 + 4;
+	const uintptr_t pages_base = ALIGN_DOWN(handler_base - pages_needed * PAGE_SIZE, 4096);
+	const uintptr_t pm4le = ALIGN_DOWN(pages_base - 8, 4096);
+
+	if (one_g_pages) {
+		for (size_t i = 0; i < 4; i++)
+			write64p(pages_base + i * PAGE_SIZE, _GEN_PAGE(1ull * GiB * i));
+		write64p(pm4le, _GEN_DIR(pages_base));
+	} else {
+		for (size_t i = 0; i < 2048; i++)
+			write64p(pages_base + i * PAGE_SIZE, _GEN_PAGE(2ull * MiB * i));
+		write64p(pm4le, _GEN_DIR(pages_base + 2048 * PAGE_SIZE));
+		for (size_t i = 0; i < 4; i++)
+			write64p(pages_base + (2048 + i) * PAGE_SIZE, _GEN_DIR(pages_base + 4096 * i));
+	}
+	return pm4le;
+}
+
 /*
  *The SMM module is placed within the provided region in the following
  * manner:
@@ -389,10 +450,10 @@ static int append_and_check_region(const struct region smram,
  * | BIOS resource   |
  * | list (STM)      |
  * +-----------------+
- * |  fxsave area    |
- * +-----------------+
  * |  smi handler    |
  * |      ...        |
+ * +-----------------+
+ * |  page tables    |
  * +-----------------+ <- cpu0
  * |    stub code    | <- cpu1
  * |    stub code    | <- cpu2
@@ -420,54 +481,39 @@ int smm_load_module(const uintptr_t smram_base, const size_t smram_size,
 	if (rmodule_parse(&_binary_smm_start, &smi_handler))
 		return -1;
 
-	const struct region smram = { .offset = smram_base, .size = smram_size };
-	const uintptr_t smram_top = region_end(&smram);
+	const struct region smram = region_create(smram_base, smram_size);
+	const uintptr_t smram_top = region_last(&smram) + 1;
 
 	const size_t stm_size =
 		CONFIG(STM) ? CONFIG_MSEG_SIZE + CONFIG_BIOS_RESOURCE_LIST_SIZE : 0;
 
 	if (CONFIG(STM)) {
-		struct region stm = {};
-		stm.offset = smram_top - stm_size;
-		stm.size = stm_size;
+		struct region stm = region_create(smram_top - stm_size, stm_size);
 		if (append_and_check_region(smram, stm, region_list, "STM"))
 			return -1;
 		printk(BIOS_DEBUG, "MSEG size     0x%x\n", CONFIG_MSEG_SIZE);
 		printk(BIOS_DEBUG, "BIOS res list 0x%x\n", CONFIG_BIOS_RESOURCE_LIST_SIZE);
 	}
 
-	const size_t fx_save_area_size = CONFIG(SSE) ? FXSAVE_SIZE * params->num_cpus : 0;
-	struct region fx_save = {};
-	if (CONFIG(SSE)) {
-		fx_save.offset = smram_top - stm_size - fx_save_area_size;
-		fx_save.size = fx_save_area_size;
-		if (append_and_check_region(smram, fx_save, region_list, "FX_SAVE"))
-			return -1;
-	}
-
 	const size_t handler_size = rmodule_memory_size(&smi_handler);
 	const size_t handler_alignment = rmodule_load_alignment(&smi_handler);
 	const uintptr_t handler_base =
-		ALIGN_DOWN(smram_top - stm_size - fx_save_area_size - handler_size,
+		ALIGN_DOWN(smram_top - stm_size - handler_size,
 			   handler_alignment);
-	struct region handler = {
-		.offset = handler_base,
-		.size = handler_size
-	};
+	struct region handler = region_create(handler_base, handler_size);
 	if (append_and_check_region(smram, handler, region_list, "HANDLER"))
 		return -1;
 
 	uintptr_t stub_segment_base;
-
-	if (CONFIG(SMM_TSEG)) {
-		stub_segment_base = handler_base - SMM_CODE_SEGMENT_SIZE;
-	} else if (CONFIG(SMM_ASEG)) {
-		stub_segment_base = smram_base;
-		if (smram_base != SMM_BASE || smram_size != SMM_CODE_SEGMENT_SIZE) {
-			printk(BIOS_ERR, "SMM base & size are 0x%lx, 0x%zx, but must be 0x%x, 0x%x\n",
-			       smram_base, smram_size, SMM_BASE, SMM_CODE_SEGMENT_SIZE);
+	if (ENV_X86_64) {
+		uintptr_t pt_base = install_page_table(handler_base);
+		struct region page_tables = region_create(pt_base, handler_base - pt_base);
+		if (append_and_check_region(smram, page_tables, region_list, "PAGE TABLES"))
 			return -1;
-		}
+		params->cr3 = pt_base;
+		stub_segment_base = pt_base - SMM_CODE_SEGMENT_SIZE;
+	} else {
+		stub_segment_base = handler_base - SMM_CODE_SEGMENT_SIZE;
 	}
 
 	if (!smm_create_map(stub_segment_base, params->num_concurrent_save_states, params)) {
@@ -485,10 +531,8 @@ int smm_load_module(const uintptr_t smram_base, const size_t smram_size,
 			return -1;
 	}
 
-	struct region stacks = {
-		.offset = smram_base,
-		.size = params->num_concurrent_save_states * CONFIG_SMM_MODULE_STACK_SIZE
-	};
+	struct region stacks = region_create(smram_base,
+			params->num_concurrent_save_states * CONFIG_SMM_MODULE_STACK_SIZE);
 	printk(BIOS_DEBUG, "\n");
 	if (append_and_check_region(smram, stacks, region_list, "stacks"))
 		return -1;
@@ -498,8 +542,7 @@ int smm_load_module(const uintptr_t smram_base, const size_t smram_size,
 
 	struct smm_runtime *smihandler_params = rmodule_parameters(&smi_handler);
 	params->handler = rmodule_entry(&smi_handler);
-	setup_smihandler_params(smihandler_params, smram_base, smram_size, params);
+	setup_smihandler_params(smihandler_params, params);
 
-	return smm_module_setup_stub(stub_segment_base, smram_size, params,
-				     (void *)region_offset(&fx_save));
+	return smm_module_setup_stub(stub_segment_base, smram_size, params);
 }
