@@ -5,6 +5,7 @@
 #include <console/console.h>
 #include <device/device.h>
 #include <device/pci_def.h>
+#include <device/pci_ids.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -230,6 +231,9 @@ const char *dev_path(const struct device *dev)
 		case DEVICE_PATH_MDIO:
 			snprintf(buffer, sizeof(buffer), "MDIO: %02x", dev->path.mdio.addr);
 			break;
+		case DEVICE_PATH_GICC_V3:
+			snprintf(buffer, sizeof(buffer), "GICV3: %02x", dev->path.gicc_v3.mpidr);
+			break;
 		default:
 			printk(BIOS_ERR, "Unknown device path type: %d\n",
 			       dev->path.type);
@@ -543,7 +547,7 @@ const char *resource_type(const struct resource *resource)
 void report_resource_stored(struct device *dev, const struct resource *resource,
 			    const char *comment)
 {
-	char buf[10];
+	char buf[16];
 	unsigned long long base, end;
 
 	if (!(resource->flags & IORESOURCE_STORED))
@@ -651,7 +655,7 @@ void disable_children(struct bus *bus)
  * Returns true if the device is an enabled bridge that has at least
  * one enabled device on its secondary bus that is not of type NONE.
  */
-bool dev_is_active_bridge(struct device *dev)
+bool dev_is_active_bridge(const struct device *dev)
 {
 	struct device *child;
 
@@ -966,3 +970,10 @@ bool is_pci_bridge(const struct device *pci)
 {
 	return is_pci(pci) && ((pci->hdr_type & 0x7f) == PCI_HEADER_TYPE_BRIDGE);
 }
+
+bool is_pci_ioapic(const struct device *pci)
+{
+	return is_pci(pci) && ((pci->class >> 16) == PCI_BASE_CLASS_SYSTEM) &&
+		((pci->class >> 8) == PCI_CLASS_SYSTEM_PIC) &&
+		((pci->class & 0xff) >= 0x10);
+}
