@@ -1345,6 +1345,24 @@ uint16_t pci_find_cap_recursive(const struct device *dev, uint16_t cap)
 	return pos;
 }
 
+/**
+ * Returns if the device support PMEs.
+ *
+ * @param dev Pointer to the device structure.
+ * @return Returns true when the device support PMEs. The PME generation can be
+ *  disabled though.
+ */
+bool pci_has_pme_pin(const struct device *dev)
+{
+	const uint16_t cap = pci_find_capability(dev, PCI_CAP_ID_PM);
+	if (!cap)
+		return false;
+
+	const uint16_t pmecap = pci_read_config16(dev, cap + PCI_PM_PMC);
+
+	return !!(pmecap & PCI_PM_CAP_PME);
+}
+
 /**
  * PCI devices that are marked as "hidden" do not get probed. However, the same
  * initialization logic is still performed as if it were. This is useful when
