@@ -28,69 +28,69 @@ static const struct agesa_mapping entrypoint[] = {
 		.func = AMD_INIT_RESET,
 		.name = "AmdInitReset",
 		.entry_id = TS_AGESA_INIT_RESET_START,
-		.exit_id = TS_AGESA_INIT_RESET_DONE,
+		.exit_id = TS_AGESA_INIT_RESET_END,
 	},
 	{
 		.func = AMD_INIT_EARLY,
 		.name = "AmdInitEarly",
 		.entry_id = TS_AGESA_INIT_EARLY_START,
-		.exit_id = TS_AGESA_INIT_EARLY_DONE,
+		.exit_id = TS_AGESA_INIT_EARLY_END,
 	},
 	{
 		.func = AMD_INIT_POST,
 		.name = "AmdInitPost",
 		.entry_id = TS_AGESA_INIT_POST_START,
-		.exit_id = TS_AGESA_INIT_POST_DONE,
+		.exit_id = TS_AGESA_INIT_POST_END,
 	},
 	{
 		.func = AMD_INIT_RESUME,
 		.name = "AmdInitResume",
 		.entry_id = TS_AGESA_INIT_RESUME_START,
-		.exit_id = TS_AGESA_INIT_RESUME_DONE,
+		.exit_id = TS_AGESA_INIT_RESUME_END,
 	},
 	{
 		.func = AMD_INIT_ENV,
 		.name = "AmdInitEnv",
 		.entry_id = TS_AGESA_INIT_ENV_START,
-		.exit_id = TS_AGESA_INIT_ENV_DONE,
+		.exit_id = TS_AGESA_INIT_ENV_END,
 	},
 	{
 		.func = AMD_INIT_MID,
 		.name = "AmdInitMid",
 		.entry_id = TS_AGESA_INIT_MID_START,
-		.exit_id = TS_AGESA_INIT_MID_DONE,
+		.exit_id = TS_AGESA_INIT_MID_END,
 	},
 	{
 		.func = AMD_INIT_LATE,
 		.name = "AmdInitLate",
 		.entry_id = TS_AGESA_INIT_LATE_START,
-		.exit_id = TS_AGESA_INIT_LATE_DONE,
+		.exit_id = TS_AGESA_INIT_LATE_END,
 	},
 	{
 		.func = AMD_S3LATE_RESTORE,
 		.name = "AmdS3LateRestore",
 		.entry_id = TS_AGESA_S3_LATE_START,
-		.exit_id = TS_AGESA_S3_LATE_DONE,
+		.exit_id = TS_AGESA_S3_LATE_END,
 	},
 #if !defined(AMD_S3_SAVE_REMOVED)
 	{
 		.func = AMD_S3_SAVE,
 		.name = "AmdS3Save",
 		.entry_id = TS_AGESA_INIT_RTB_START,
-		.exit_id = TS_AGESA_INIT_RTB_DONE,
+		.exit_id = TS_AGESA_INIT_RTB_END,
 	},
 #endif
 	{
 		.func = AMD_S3FINAL_RESTORE,
 		.name = "AmdS3FinalRestore",
 		.entry_id = TS_AGESA_S3_FINAL_START,
-		.exit_id = TS_AGESA_S3_FINAL_DONE,
+		.exit_id = TS_AGESA_S3_FINAL_END,
 	},
 	{
 		.func = AMD_INIT_RTB,
 		.name = "AmdInitRtb",
 		.entry_id = TS_AGESA_INIT_RTB_START,
-		.exit_id = TS_AGESA_INIT_RTB_DONE,
+		.exit_id = TS_AGESA_INIT_RTB_END,
 	},
 };
 
@@ -151,13 +151,13 @@ static const char *decodeAGESA_STATUS(AGESA_STATUS sret)
 
 static void show_event(EVENT_PARAMS *Event)
 {
-	printk(BIOS_DEBUG,"\nEventLog:  EventClass = %x, EventInfo = %x.\n",
+	printk(BIOS_DEBUG, "\nEventLog:  EventClass = %x, EventInfo = %x.\n",
 			(unsigned int)Event->EventClass,
 			(unsigned int)Event->EventInfo);
-	printk(BIOS_DEBUG,"  Param1 = %x, Param2 = %x.\n",
+	printk(BIOS_DEBUG, "  Param1 = %x, Param2 = %x.\n",
 			(unsigned int)Event->DataParam1,
 			(unsigned int)Event->DataParam2);
-	printk(BIOS_DEBUG,"  Param3 = %x, Param4 = %x.\n",
+	printk(BIOS_DEBUG, "  Param3 = %x, Param4 = %x.\n",
 			(unsigned int)Event->DataParam3,
 			(unsigned int)Event->DataParam4);
 }
@@ -194,7 +194,7 @@ void agesawrapper_trace(AGESA_STATUS ret, AMD_CONFIG_PARAMS *StdHeader,
 	amd_flush_eventlog(&AmdEventParams);
 }
 
-AGESA_STATUS agesawrapper_amdreadeventlog (UINT8 HeapStatus)
+AGESA_STATUS agesawrapper_amdreadeventlog(UINT8 HeapStatus)
 {
 	EVENT_PARAMS AmdEventParams;
 
