@@ -1,7 +1,6 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
 #include <arch/io.h>
-#include <edid.h>
 #include <console/console.h>
 #include <device/device.h>
 #include <device/pci.h>
@@ -14,7 +13,7 @@
 static void aspeed_ast2050_read_resources(struct device *dev)
 {
 	/* Reserve VGA regions */
-	mmio_resource_kb(dev, 3, 0xa0000 >> 10, 0x1ffff >> 10);
+	mmio_from_to(dev, 3, 0xa0000, 0xc0000);
 
 	/* Run standard resource read routine */
 	pci_dev_read_resources(dev);
