@@ -14,8 +14,6 @@
 #include "tpm.h"
 #include "chip.h"
 
-static unsigned int tpm_is_open;
-
 static const struct {
 	uint16_t vid;
 	uint16_t did;
@@ -25,7 +23,7 @@ static const struct {
 	{0xa13a, 0x8086, "Intel iTPM"}
 };
 
-static const char *tis_get_dev_name(struct tpm2_info *info)
+static const char *tis_get_dev_name(struct crb_tpm_info *info)
 {
 	int i;
 
@@ -35,50 +33,45 @@ static const char *tis_get_dev_name(struct tpm2_info *info)
 	return "Unknown";
 }
 
-int tis_open(void)
+static tpm_result_t crb_tpm_sendrecv(const uint8_t *sendbuf, size_t sbuf_size, uint8_t *recvbuf,
+				     size_t *rbuf_len)
 {
-	if (tpm_is_open) {
-		printk(BIOS_ERR, "%s called twice.\n", __func__);
-		return -1;
-	}
+	int len = crb_tpm_process_command(sendbuf, sbuf_size, recvbuf, *rbuf_len);
+
+	if (len == 0)
+		return TPM_CB_FAIL;
+
+	*rbuf_len = len;
+
+	return TPM_SUCCESS;
+}
+
+tis_sendrecv_fn crb_tis_probe(enum tpm_family *family)
+{
+	struct crb_tpm_info info;
 
 	if (CONFIG(HAVE_INTEL_PTT)) {
 		if (!ptt_active()) {
 			printk(BIOS_ERR, "%s: Intel PTT is not active.\n", __func__);
-			return -1;
+			return NULL;
 		}
 		printk(BIOS_DEBUG, "%s: Intel PTT is active.\n", __func__);
 	}
 
-	return 0;
-}
+	/* Wake TPM up (if necessary) */
+	if (crb_tpm_init())
+		return NULL;
 
-int tis_init(void)
-{
-	struct tpm2_info info;
+	/* CRB interface exists only in TPM2 */
+	if (family != NULL)
+		*family = TPM_2;
 
-	// Wake TPM up (if necessary)
-	if (tpm2_init() != 0)
-		return -1;
-
-	tpm2_get_info(&info);
+	crb_tpm_get_info(&info);
 
 	printk(BIOS_INFO, "Initialized TPM device %s revision %d\n", tis_get_dev_name(&info),
 	       info.revision);
 
-	return 0;
-}
-
-int tis_sendrecv(const uint8_t *sendbuf, size_t sbuf_size, uint8_t *recvbuf, size_t *rbuf_len)
-{
-	int len = tpm2_process_command(sendbuf, sbuf_size, recvbuf, *rbuf_len);
-
-	if (len == 0)
-		return -1;
-
-	*rbuf_len = len;
-
-	return 0;
+	return &crb_tpm_sendrecv;
 }
 
 static void crb_tpm_fill_ssdt(const struct device *dev)
@@ -97,7 +90,10 @@ static void crb_tpm_fill_ssdt(const struct device *dev)
 
 	acpi_device_write_uid(dev);
 
-	acpigen_write_STA(ACPI_STATUS_DEVICE_ALL_ON);
+	if (CONFIG(HAVE_INTEL_PTT) && ptt_active())
+		acpigen_write_STA(ACPI_STATUS_DEVICE_ALL_ON);
+	else
+		acpigen_write_STA(ACPI_STATUS_DEVICE_ALL_OFF);
 
 	/* Resources */
 	acpigen_write_name("_CRS");
@@ -118,38 +114,41 @@ static const char *crb_tpm_acpi_name(const struct device *dev)
 }
 
 #if CONFIG(GENERATE_SMBIOS_TABLES) && CONFIG(TPM2)
-static int tpm_get_cap(uint32_t property, uint32_t *value)
+static tpm_result_t tpm_get_cap(uint32_t property, uint32_t *value)
 {
 	TPMS_CAPABILITY_DATA cap_data;
 	int i;
-	uint32_t status;
+	tpm_result_t rc;
 
 	if (!value)
-		return -1;
+		return TPM_CB_INVALID_ARG;
 
-	status = tlcl_get_capability(TPM_CAP_TPM_PROPERTIES, property, 1, &cap_data);
+	rc = tlcl2_get_capability(TPM_CAP_TPM_PROPERTIES, property, 1, &cap_data);
 
-	if (status)
-		return -1;
+	if (rc)
+		return rc;
 
 	for (i = 0 ; i < cap_data.data.tpmProperties.count; i++) {
 		if (cap_data.data.tpmProperties.tpmProperty[i].property == property) {
 			*value = cap_data.data.tpmProperties.tpmProperty[i].value;
-			return 0;
+			return TPM_SUCCESS;
 		}
 	}
 
-	return -1;
+	return TPM_CB_FAIL;
 }
 
 static int smbios_write_type43_tpm(struct device *dev, int *handle, unsigned long *current)
 {
-	struct tpm2_info info;
+	struct crb_tpm_info info;
 	uint32_t tpm_manuf, tpm_family;
 	uint32_t fw_ver1, fw_ver2;
 	uint8_t major_spec_ver, minor_spec_ver;
 
-	tpm2_get_info(&info);
+	if (tlcl_get_family() == TPM_1)
+		return 0;
+
+	crb_tpm_get_info(&info);
 
 	/* If any of these have invalid values, assume TPM not present or disabled */
 	if (info.vendor_id == 0 || info.vendor_id == 0xFFFF ||
@@ -211,12 +210,17 @@ static struct device_operations __maybe_unused crb_ops = {
 
 static void enable_dev(struct device *dev)
 {
+	if (crb_tis_probe(NULL) == NULL) {
+		dev->enabled = 0;
+		return;
+	}
+
 #if !DEVTREE_EARLY
 	dev->ops = &crb_ops;
 #endif
 }
 
 struct chip_operations drivers_crb_ops = {
-	CHIP_NAME("CRB TPM")
+	.name = "CRB TPM",
 	.enable_dev = enable_dev
 };
