@@ -11,6 +11,7 @@
 struct drivers_i2c_generic_config {
 	const char *hid;	/* ACPI _HID (required) */
 	const char *cid;	/* ACPI _CID */
+	const char *sub;	/* ACPI _SUB */
 	const char *name;	/* ACPI Device Name */
 	const char *desc;	/* Device Description */
 	unsigned int uid;		/* ACPI _UID */
@@ -46,9 +47,6 @@ struct drivers_i2c_generic_config {
 	unsigned int device_present_gpio;
 	unsigned int device_present_gpio_invert;
 
-	/* Disable reset and enable GPIO export in _CRS */
-	bool disable_gpio_export_in_crs;
-
 	/* Does the device have a power resource? */
 	bool has_power_resource;
 
@@ -71,6 +69,44 @@ struct drivers_i2c_generic_config {
 	/* Delay to be inserted after enabling stop. */
 	unsigned int stop_off_delay_ms;
 
+	/*
+	 * The Rotation Matrix' allows specifying a 3x3 matrix representing
+	 * the orientation of devices, such as accelerometers. Each value in
+	 * the matrix can be one of -1, 0, or 1, indicating the transformation
+	 * applied to the device's axes.
+	 *
+	 * It is expected by linux and required for the OS to correctly interpret
+	 * the data from the device.
+	 */
+	bool has_rotation_matrix;
+	int rotation_matrix[9];
+
+	/*
+	 * Chip Direct Mapping is exclusive to Windows, a allows specifying the
+	 * position where a chip is mounted. There are 8 positions:
+	 *	1:	90 Degrees
+	 *	2:	270 Degrees
+	 *	3:	180 Degrees
+	 *	4:	0 Degrees
+	 *	5:	90 Degrees (Inverted)
+	 *	6:	270 Degrees (Inverted)
+	 *	7:	180 Degrees (Inverted)
+	 *	8:	0 Degrees (Inverted)
+	 *
+	 * The _CDM method should return 0xabcd0X, where X is the position.
+	 */
+	enum {
+		CDM_NOT_PRESENT = 0,
+		CDM_ROT_90,
+		CDM_ROT_180,
+		CDM_ROT_270,
+		CDM_ROT_0,
+		CDM_ROT_90_INVERT,
+		CDM_ROT_180_INVERT,
+		CDM_ROT_270_INVERT,
+		CDM_ROT_0_INVERT,
+	} cdm_index;
+
 	/* Generic properties for exporting device-specific data to the OS */
 	struct acpi_dp property_list[MAX_GENERIC_PROPERTY_LIST];
 	int property_count;
