@@ -1,5 +1,8 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
+#ifndef __DRIVERS_I2C_MAX98373_CHIP_H__
+#define __DRIVERS_I2C_MAX98373_CHIP_H__
+
 /*
  * Maxim MAX98373 audio codec devicetree bindings
  */
@@ -22,3 +25,5 @@ struct drivers_i2c_max98373_config {
 	/* slot number where current feedback will be received */
 	uint32_t imon_slot_no;
 };
+
+#endif /* __DRIVERS_I2C_MAX98373_CHIP_H__ */
