@@ -1,5 +1,8 @@
 /* SPDX-License-Identifier: GPL-2.0-or-later */
 
+#ifndef __DRIVERS_I2C_MAX98390_CHIP_H__
+#define __DRIVERS_I2C_MAX98390_CHIP_H__
+
 /*
  * MAXIM MAX98390 audio codec devicetree bindings
  */
@@ -19,3 +22,5 @@ struct drivers_i2c_max98390_config {
 	/* slot number where current feedback will be received */
 	uint32_t imon_slot_no;
 };
+
+#endif /* __DRIVERS_I2C_MAX98390_CHIP_H__ */
