@@ -5,7 +5,6 @@
 #include <console/console.h>
 #include <device/i2c_simple.h>
 #include <device/device.h>
-#include <device/path.h>
 #include <stdint.h>
 #include "chip.h"
 
@@ -67,7 +66,7 @@ static void nau8825_fill_ssdt(const struct device *dev)
 	NAU8825_DP_INT("sar-sampling-time", config->sar_sampling_time);
 	NAU8825_DP_INT("short-key-debounce", config->short_key_debounce);
 	NAU8825_DP_INT("jack-insert-debounce", config->jack_insert_debounce);
-	NAU8825_DP_INT("jack-eject-deboune", config->jack_eject_debounce);
+	NAU8825_DP_INT("jack-eject-debounce", config->jack_eject_debounce);
 	NAU8825_DP_INT("sar-threshold-num", config->sar_threshold_num);
 	NAU8825_DP_INT("adcout-drive-strong", config->adcout_ds ? 1 : 0);
 	acpi_dp_add_integer_array(dp, "nuvoton,sar-threshold",
@@ -103,6 +102,6 @@ static void nau8825_enable(struct device *dev)
 }
 
 struct chip_operations drivers_i2c_nau8825_ops = {
-	CHIP_NAME("Nuvoton NAU8825 Codec")
+	.name = "Nuvoton NAU8825 Codec",
 	.enable_dev = nau8825_enable
 };
