@@ -5,6 +5,7 @@
 #include <console/console.h>
 #include <device/device.h>
 #include <intelblocks/pmc_ipc.h>
+#include <stdio.h>
 #include <soc/dptf.h>
 #include <soc/pci_devs.h>
 #include "chip.h"
@@ -112,7 +113,7 @@ static void dptf_write_generic_participant(const char *name,
 	acpigen_write_STA(sta_val);
 
 	if (str)
-		acpigen_write_name_string("_STR", str);
+		acpigen_write_name_unicode("_STR", str);
 
 	acpigen_write_name_integer("PTYP", ptype);
 
@@ -143,7 +144,7 @@ static void write_fan(const struct drivers_intel_dptf_config *config,
 	acpigen_write_name("_HID");
 	dptf_write_hid(platform_info->use_eisa_hids, platform_info->fan_hid);
 	acpigen_write_name_integer("_UID", fan_uid++);
-	acpigen_write_name_string("_STR", DEFAULT_FAN_STR);
+	acpigen_write_name_unicode("_STR", DEFAULT_FAN_STR);
 	acpigen_write_name_integer("PTYP", DPTF_GENERIC_PARTICIPANT_TYPE_FAN);
 	acpigen_write_STA(get_STA_value(config, participant));
 	acpigen_pop_len(); /* Device */
@@ -158,6 +159,12 @@ static void write_imok(void)
 	acpigen_emit_byte(ARG0_OP);
 	acpigen_write_method_end();
 }
+
+static void write_dcfg_variable(const struct drivers_intel_dptf_config *config)
+{
+	acpigen_write_name_integer("DCFG", config->dcfg);
+}
+
 /* \_SB.DPTF */
 static void write_oem_variables(const struct drivers_intel_dptf_config *config)
 {
@@ -329,7 +336,7 @@ static void write_create_tpch(const struct dptf_platform_info *platform_info)
 	acpigen_write_device("TPCH");
 	acpigen_write_name("_HID");
 	dptf_write_hid(platform_info->use_eisa_hids, platform_info->tpch_device_hid);
-	acpigen_write_name_string("_STR", DEFAULT_TPCH_STR);
+	acpigen_write_name_unicode("_STR", DEFAULT_TPCH_STR);
 	acpigen_write_name_integer("PTYP", DPTF_GENERIC_PARTICIPANT_TYPE_TPCH);
 	acpigen_write_STA(ACPI_STATUS_DEVICE_ALL_ON);
 }
@@ -402,7 +409,7 @@ static void write_create_tpwr(const struct drivers_intel_dptf_config *config,
 	if (platform_info->tpwr_device_hid != NULL)
 		dptf_write_hid(platform_info->use_eisa_hids, platform_info->tpwr_device_hid);
 	acpigen_write_name_string("_UID", "TPWR");
-	acpigen_write_name_string("_STR", DEFAULT_POWER_STR);
+	acpigen_write_name_unicode("_STR", DEFAULT_POWER_STR);
 	acpigen_write_name_integer("PTYP", DPTF_GENERIC_PARTICIPANT_TYPE_POWER);
 	acpigen_write_STA(ACPI_STATUS_DEVICE_ALL_ON);
 
@@ -429,7 +436,7 @@ static void write_create_tbat(const struct dptf_platform_info *platform_info)
 	if (platform_info->tbat_device_hid != NULL)
 		dptf_write_hid(platform_info->use_eisa_hids, platform_info->tbat_device_hid);
 	acpigen_write_name_string("_UID", "1");
-	acpigen_write_name_string("_STR", DEFAULT_BATTERY_STR);
+	acpigen_write_name_unicode("_STR", DEFAULT_BATTERY_STR);
 	acpigen_write_name_integer("PTYP", DPTF_GENERIC_PARTICIPANT_TYPE_BATTERY);
 	acpigen_write_STA(ACPI_STATUS_DEVICE_ALL_ON);
 	acpigen_write_device_end(); /* TBAT Battery Participant Device */
@@ -503,7 +510,7 @@ static void write_device_definitions(const struct device *dev)
 	enum dptf_participant p;
 
 	/* The CPU device gets an _ADR that matches the ACPI PCI address for 00:04.00 */
-	parent = dev && dev->bus ? dev->bus->dev : NULL;
+	parent = dev && dev->upstream ? dev->upstream->dev : NULL;
 	if (!parent || parent->path.type != DEVICE_PATH_PCI) {
 		printk(BIOS_ERR, "%s: DPTF objects must live under 00:04.0 PCI device\n",
 		       __func__);
@@ -520,6 +527,7 @@ static void write_device_definitions(const struct device *dev)
 	} else
 		write_fan(config, platform_info, DPTF_FAN);
 
+	write_dcfg_variable(config);
 	write_oem_variables(config);
 	write_imok();
 	write_generic_devices(config, platform_info);
@@ -537,7 +545,7 @@ static void write_device_definitions(const struct device *dev)
 	acpigen_pop_len(); /* Scope */
 }
 
-/* Emites policy definitions for each policy type */
+/* Emits policy definitions for each policy type */
 static void write_policies(const struct drivers_intel_dptf_config *config)
 {
 	dptf_write_enabled_policies(config->policies.active, DPTF_MAX_ACTIVE_POLICIES,
@@ -636,6 +644,6 @@ static void dptf_enable_dev(struct device *dev)
 }
 
 struct chip_operations drivers_intel_dptf_ops = {
-	CHIP_NAME("Intel DPTF")
+	.name = "Intel DPTF",
 	.enable_dev = dptf_enable_dev,
 };
