@@ -6,7 +6,6 @@
 #include <fsp/ramstage.h>
 #include <fsp/util.h>
 #include <framebuffer_info.h>
-#include <lib.h>
 #include <stage_cache.h>
 #include <string.h>
 #include <timestamp.h>
@@ -77,9 +76,11 @@ static void fsp_run_silicon_init(FSP_INFO_HEADER *fsp_info_header)
 		load_vbt(&silicon_init_params);
 	mainboard_silicon_init_params(&silicon_init_params);
 
-	if (CONFIG(BMP_LOGO))
-		bmp_load_logo(&silicon_init_params.PcdLogoPtr,
-			      &silicon_init_params.PcdLogoSize);
+	if (CONFIG(BMP_LOGO)) {
+		size_t logo_size;
+		silicon_init_params.PcdLogoPtr = (uint32_t)(uintptr_t)bmp_load_logo(&logo_size);
+		silicon_init_params.PcdLogoSize = (uint32_t)logo_size;
+	}
 
 	/* Display the UPD data */
 	if (CONFIG(DISPLAY_UPD_DATA))
@@ -93,7 +94,7 @@ static void fsp_run_silicon_init(FSP_INFO_HEADER *fsp_info_header)
 	timestamp_add_now(TS_FSP_SILICON_INIT_START);
 	printk(BIOS_DEBUG, "Calling FspSiliconInit(%p) at %p\n",
 		&silicon_init_params, fsp_silicon_init);
-	post_code(POST_FSP_SILICON_INIT);
+	post_code(POSTCODE_FSP_SILICON_INIT);
 	status = fsp_silicon_init(&silicon_init_params);
 	timestamp_add_now(TS_FSP_SILICON_INIT_END);
 	printk(BIOS_DEBUG, "FspSiliconInit returned 0x%08x\n", status);
