@@ -2,7 +2,6 @@
 
 #include <console/console.h>
 #include <fsp/util.h>
-#include <lib.h>
 
 #define TIMESTAMP_TO_MICRO(x) ((x) / 1000ull)
 
@@ -32,7 +31,7 @@ struct generic_event_record {
 } __packed;
 
 /*
- * Performance Hob:
+ * Performance HOB:
  *   GUID - fpdt_guid;
  *   Data - FPDT_PEI_EXT_PERF_HEADER one or more FPDT records
 */
