@@ -14,4 +14,14 @@
 void fsp_report_framebuffer_info(const uintptr_t framebuffer_bar,
 				 enum lb_fb_orientation orientation);
 
+/* SoC Overrides */
+/*
+ * Check and report if an external display is attached
+ *
+ * Possible return values:
+ * 1 - An external device is attached.
+ * 0 - On-board display alone.
+ */
+int fsp_soc_report_external_display(void);
+
 #endif /* _FSP2_0_GRAPHICS_H_ */
