@@ -1,6 +1,7 @@
 /* SPDX-License-Identifier: GPL-2.0-or-later */
 
 #include <arch/null_breakpoint.h>
+#include <arch/stack_canary_breakpoint.h>
 #include <bootsplash.h>
 #include <bootstate.h>
 #include <cbfs.h>
@@ -131,12 +132,14 @@ static void do_silicon_init(struct fsp_header *hdr)
 	post_code(POSTCODE_FSP_SILICON_INIT);
 
 	/* FSP disables the interrupt handler so remove debug exceptions temporarily  */
-	null_breakpoint_disable();
+	null_breakpoint_remove();
+	stack_canary_breakpoint_remove();
 	if (ENV_X86_64 && CONFIG(PLATFORM_USES_FSP2_X86_32))
 		status = protected_mode_call_1arg(silicon_init, (uintptr_t)upd);
 	else
 		status = silicon_init(upd);
 	null_breakpoint_init();
+	stack_canary_breakpoint_init();
 
 	fsp_printk(status, BIOS_INFO, "FSPS");
 
