@@ -8,6 +8,7 @@
 #include <commonlib/fsp.h>
 #include <console/console.h>
 #include <fsp/util.h>
+#include <stdio.h>
 #include <string.h>
 #include <types.h>
 #include <assert.h>
@@ -83,18 +84,18 @@ enum cb_err fsp_validate_component(struct fsp_header *hdr, void *fsp_file, size_
 	return CB_SUCCESS;
 }
 
-static bool fsp_reset_requested(uint32_t status)
+static bool fsp_reset_requested(efi_return_status_t status)
 {
 	return (status >= FSP_STATUS_RESET_REQUIRED_COLD &&
 		status <= FSP_STATUS_RESET_REQUIRED_8);
 }
 
-void fsp_handle_reset(uint32_t status)
+void fsp_handle_reset(efi_return_status_t status)
 {
 	if (!fsp_reset_requested(status))
 		return;
 
-	printk(BIOS_SPEW, "FSP: handling reset type %x\n", status);
+	fsp_printk(status, BIOS_SPEW, "FSP: handling reset type");
 
 	switch (status) {
 	case FSP_STATUS_RESET_REQUIRED_COLD:
@@ -182,8 +183,8 @@ void fsp_verify_upd_header_signature(uint64_t upd_signature, uint64_t expected_s
 	if (upd_signature != expected_signature) {
 		/* The UPD signatures are non-zero-terminated ASCII stored as a little endian
 		   uint64_t, so this needs some casts. */
-		die_with_post_code(POST_INVALID_VENDOR_BINARY,
-			"Invalid UPD signature! FSP provided \"%8s\", expected was \"%8s\".\n",
+		die_with_post_code(POSTCODE_INVALID_VENDOR_BINARY,
+			"Invalid UPD signature! FSP provided \"%.8s\", expected was \"%.8s\".\n",
 			(char *)&upd_signature,
 			(char *)&expected_signature);
 	}
