@@ -5,15 +5,18 @@
 #include <acpi/acpi_device.h>
 #include <acpi/acpigen.h>
 #include <acpi/acpigen_pci.h>
-#include <cpu/cpu.h>
 #include <console/console.h>
-#include <cpu/intel/cpu_ids.h>
 #include <device/i2c_simple.h>
 #include <device/device.h>
-#include <device/path.h>
 #include <device/pci_def.h>
+#include <stdio.h>
+
 #include "chip.h"
 
+#define CSI2_DATA_STREAM_INTERFACE_GUID \
+	GUID_INIT(0x8A395669, 0x11F7, 0x4EA9, \
+	0x9C, 0x7D, 0x20, 0xEE, 0x0A, 0xB5, 0xCA, 0x40)
+
 #define SENSOR_NAME_UUID	"822ace8f-2814-4174-a56b-5f029fe079ee"
 #define SENSOR_TYPE_UUID	"26257549-9271-4ca4-bb43-c4899d5a4881"
 #define DEFAULT_ENDPOINT	0
@@ -136,14 +139,8 @@ static void camera_fill_cio2(const struct device *dev)
 
 		snprintf(name, sizeof(name), "port%u", i);
 		port_name[i] = strdup(name);
-		if (CONFIG(ACPI_ADL_IPU_ES_SUPPORT)) {
-			u32 cpu_id = cpu_get_cpuid();
-			if (cpu_id == CPUID_ALDERLAKE_J0 || cpu_id == CPUID_ALDERLAKE_Q0)
-				acpi_dp_add_integer(dsd, "is_es", 1);
-			else
-				acpi_dp_add_integer(dsd, "is_es", 0);
-		}
-
+		acpi_dp_add_integer(dsd, "is_es",
+			CONFIG(DRIVERS_INTEL_MIPI_SUPPORTS_PRE_PRODUCTION_SOC));
 		acpi_dp_add_child(dsd, port_name[i], port_table);
 	}
 
@@ -207,7 +204,7 @@ static void camera_generate_pld(const struct device *dev)
 static uint32_t address_for_dev_type(const struct device *dev, uint8_t dev_type)
 {
 	struct drivers_intel_mipi_camera_config *config = dev->chip_info;
-	uint16_t i2c_bus = dev->bus ? dev->bus->secondary : 0xFFFF;
+	uint16_t i2c_bus = dev->upstream ? dev->upstream->secondary : 0xFFFF;
 	uint16_t i2c_addr;
 
 	switch (dev_type) {
@@ -294,6 +291,8 @@ static void camera_fill_ssdb_defaults(struct drivers_intel_mipi_camera_config *c
 	if (config->disable_ssdb_defaults)
 		return;
 
+	guidcpy(&config->ssdb.csi2_data_stream_interface, &CSI2_DATA_STREAM_INTERFACE_GUID);
+
 	if (!config->ssdb.bdf_value)
 		config->ssdb.bdf_value = PCI_DEVFN(CIO2_PCI_DEV, CIO2_PCI_FN);
 
@@ -424,7 +423,7 @@ static void camera_fill_sensor(const struct device *dev)
 				.type = DEVICE_PATH_I2C,
 				.i2c.device = config->vcm_address,
 			};
-			struct device *vcm_dev = find_dev_path(dev->bus, &path);
+			struct device *vcm_dev = find_dev_path(dev->upstream, &path);
 			struct drivers_intel_mipi_camera_config *vcm_config;
 			vcm_config = vcm_dev ? vcm_dev->chip_info : NULL;
 
@@ -935,7 +934,7 @@ static void camera_fill_ssdt(const struct device *dev)
 	const struct device *pdev;
 
 	if (config->has_power_resource) {
-		pdev = dev->bus->dev;
+		pdev = dev->upstream->dev;
 		if (!pdev || !pdev->enabled)
 			return;
 
@@ -959,7 +958,7 @@ static void camera_fill_ssdt(const struct device *dev)
 		write_i2c_camera_device(dev, scope);
 		break;
 	case DEVICE_PATH_GENERIC:
-		pdev = dev->bus->dev;
+		pdev = dev->upstream->dev;
 		scope = acpi_device_scope(pdev);
 		if (!scope)
 			return;
@@ -1041,6 +1040,6 @@ static void camera_enable(struct device *dev)
 }
 
 struct chip_operations drivers_intel_mipi_camera_ops = {
-	CHIP_NAME("Intel MIPI Camera Device")
+	.name = "Intel MIPI Camera Device",
 	.enable_dev = camera_enable
 };
