@@ -28,11 +28,11 @@ SMC8416 PIO support added by Andrew Bettison (andrewb@zip.com.au) on 4/3/02
 */
 
 #include <arch/io.h>
+#include <commonlib/bsd/ipchksum.h>
 #include <console/ne2k.h>
 #include <device/device.h>
 #include <device/pci.h>
 #include <device/pci_ops.h>
-#include <ip_checksum.h>
 
 #include "ns8390.h"
 
@@ -130,10 +130,10 @@ static void str2mac(const char *str, unsigned char *mac)
 			acc += (c - '0');
 		} else if ((c >= 'a') && (c <= 'f')) {
 			acc *= 16;
-			acc += ((c - 'a') + 10) ;
+			acc += ((c - 'a') + 10);
 		} else if ((c >= 'A') && (c <= 'F')) {
 			acc *= 16;
-			acc += ((c - 'A') + 10) ;
+			acc += ((c - 'A') + 10);
 		} else {
 			*mac++ = acc;
 			acc = 0;
@@ -184,7 +184,7 @@ static void ns8390_tx_header(unsigned int eth_nic_base, int pktlen)
 	hdr[38] = (8 + pktlen) >> 8;
 	hdr[39] = 8 + pktlen;
 
-	chksum = compute_ip_checksum(&hdr[14], 20);
+	chksum = ipchksum(&hdr[14], 20);
 
 	hdr[25] = chksum >> 8;
 	hdr[24] = chksum;
@@ -216,7 +216,8 @@ void ne2k_transmit(unsigned int eth_nic_base)
 	outb(D8390_COMMAND_PS0 | D8390_COMMAND_TXP | D8390_COMMAND_RD2 | D8390_COMMAND_STA, eth_nic_base + D8390_P0_COMMAND);
 
 	/* wait for operation finish */
-	while ((inb(eth_nic_base + D8390_P0_ISR) & D8390_ISR_PTX) != D8390_ISR_PTX) ;
+	while ((inb(eth_nic_base + D8390_P0_ISR) & D8390_ISR_PTX) != D8390_ISR_PTX)
+		;
 
 	set_count(eth_nic_base, 0);
 }
@@ -265,8 +266,7 @@ int ne2k_init(unsigned int eth_nic_base)
 	pci_devfn_t dev;
 	unsigned char c;
 
-	/* FIXME: This console is not enabled for bootblock. */
-	if (!ENV_ROMSTAGE)
+	if (!ENV_ROMSTAGE_OR_BEFORE)
 		return 0;
 
 	/* For this to work, mainboard code must have configured
@@ -281,7 +281,7 @@ int ne2k_init(unsigned int eth_nic_base)
 	c = inb(eth_nic_base + NE_ASIC_OFFSET + NE_RESET);
 	outb(c, eth_nic_base + NE_ASIC_OFFSET + NE_RESET);
 
-	(void) inb(0x84);
+	(void)inb(0x84);
 
 	outb(D8390_COMMAND_STP | D8390_COMMAND_RD2, eth_nic_base + D8390_P0_COMMAND);
 	outb(D8390_RCR_MON, eth_nic_base + D8390_P0_RCR);
