@@ -1,11 +1,12 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
 #include <boot_device.h>
-#include <fmap.h>
-#include <fmap_config.h>
 #include <commonlib/helpers.h>
 #include <commonlib/region.h>
 #include <console/console.h>
+#include <cpu/x86/smm.h>
+#include <fmap.h>
+#include <fmap_config.h>
 #include <smmstore.h>
 #include <types.h>
 
@@ -88,6 +89,29 @@ static int lookup_store(struct region_device *rstore)
 	return rdev_chain(rstore, rdev, 0, region_device_sz(rdev));
 }
 
+ /* this function is non reentrant */
+int smmstore_lookup_region(struct region_device *rstore)
+{
+	static int done;
+	static int ret;
+	static struct region_device rdev;
+
+	if (!done) {
+		done = 1;
+
+		if (fmap_locate_area_as_rdev_rw(SMMSTORE_REGION, &rdev)) {
+			printk(BIOS_WARNING,
+			       "smm store: Unable to find SMM store FMAP region '%s'\n",
+				SMMSTORE_REGION);
+			ret = -1;
+		} else {
+			ret = 0;
+		}
+	}
+
+	*rstore = rdev;
+	return ret;
+}
 /*
  * Read entire store into user provided buffer
  *
@@ -161,7 +185,7 @@ static enum cb_err scan_end(struct region_device *store)
 
 	if (k_sz != 0xffffffff) {
 		printk(BIOS_WARNING,
-			"eof of data marker looks invalid: 0x%x\n", k_sz);
+			"EOF of data marker looks invalid: 0x%x\n", k_sz);
 		return CB_ERR;
 	}
 
@@ -259,14 +283,10 @@ int smmstore_clear_region(void)
 
 /* Implementation of Version 2 */
 
-static bool store_initialized;
 static struct region_device mdev_com_buf;
 
 static int smmstore_rdev_chain(struct region_device *rdev)
 {
-	if (!store_initialized)
-		return -1;
-
 	return rdev_chain_full(rdev, &mdev_com_buf);
 }
 
@@ -279,13 +299,11 @@ int smmstore_init(void *buf, size_t len)
 	if (!buf || len < SMM_BLOCK_SIZE)
 		return -1;
 
-	if (store_initialized)
+	if (smm_points_to_smram(buf, len))
 		return -1;
 
 	rdev_chain_mem_rw(&mdev_com_buf, buf, len);
 
-	store_initialized = true;
-
 	return 0;
 }
 
