@@ -5,8 +5,6 @@
 
 #include "tpm.h"
 
-static unsigned int tpm_is_open;
-
 static const struct {
 	uint16_t vid;
 	uint16_t did;
@@ -29,16 +27,20 @@ static const char *tis_get_dev_name(struct tpm2_info *info)
 	return "Unknown";
 }
 
-int tis_open(void)
+static tpm_result_t tpm_sendrecv(const uint8_t *sendbuf, size_t sbuf_size,
+				 uint8_t *recvbuf, size_t *rbuf_len)
 {
-	if (tpm_is_open) {
-		printk(BIOS_ERR, "%s() called twice.\n", __func__);
-		return -1;
-	}
-	return 0;
+	int len = tpm2_process_command(sendbuf, sbuf_size, recvbuf, *rbuf_len);
+
+	if (len == 0)
+		return TPM_CB_FAIL;
+
+	*rbuf_len = len;
+
+	return TPM_SUCCESS;
 }
 
-int tis_init(void)
+tis_sendrecv_fn spi_tis_probe(enum tpm_family *family)
 {
 	struct spi_slave spi;
 	struct tpm2_info info;
@@ -46,31 +48,22 @@ int tis_init(void)
 	if (spi_setup_slave(CONFIG_DRIVER_TPM_SPI_BUS,
 			    CONFIG_DRIVER_TPM_SPI_CHIP, &spi)) {
 		printk(BIOS_ERR, "Failed to setup TPM SPI slave\n");
-		return -1;
+		return NULL;
 	}
 
 	if (tpm2_init(&spi)) {
 		printk(BIOS_ERR, "Failed to initialize TPM SPI interface\n");
-		return -1;
+		return NULL;
 	}
 
+	/* tpm2_process_command() is used unconditionally in tpm_sendrecv() */
+	if (family != NULL)
+		*family = TPM_2;
+
 	tpm2_get_info(&info);
 
 	printk(BIOS_INFO, "Initialized TPM device %s revision %d\n",
 	       tis_get_dev_name(&info), info.revision);
 
-	return 0;
-}
-
-int tis_sendrecv(const uint8_t *sendbuf, size_t sbuf_size,
-		 uint8_t *recvbuf, size_t *rbuf_len)
-{
-	int len = tpm2_process_command(sendbuf, sbuf_size, recvbuf, *rbuf_len);
-
-	if (len == 0)
-		return -1;
-
-	*rbuf_len = len;
-
-	return 0;
+	return &tpm_sendrecv;
 }
