@@ -24,4 +24,7 @@ enum cb_err cr50_set_board_cfg(void);
 /* Wait for IRQ to indicate the TPM is ready */
 enum cb_err cr50_wait_tpm_ready(void);
 
+/* Check TPM IRQ and clear it, returns 1 when IRQ pending or 0 when not */
+int cr50_plat_irq_status(void);
+
 #endif /* __DRIVERS_TPM_CR50_H__ */
