@@ -46,7 +46,7 @@ static int uart8250_mem_can_tx_byte(void *base)
 
 static void uart8250_mem_tx_byte(void *base, unsigned char data)
 {
-	unsigned long int i = SINGLE_CHAR_TIMEOUT;
+	unsigned long i = SINGLE_CHAR_TIMEOUT;
 	while (i-- && !uart8250_mem_can_tx_byte(base))
 		udelay(1);
 	uart8250_write(base, UART8250_TBR, data);
@@ -54,7 +54,7 @@ static void uart8250_mem_tx_byte(void *base, unsigned char data)
 
 static void uart8250_mem_tx_flush(void *base)
 {
-	unsigned long int i = FIFO_TIMEOUT;
+	unsigned long i = FIFO_TIMEOUT;
 	while (i-- && !(uart8250_read(base, UART8250_LSR) & UART8250_LSR_TEMT))
 		udelay(1);
 }
@@ -66,7 +66,7 @@ static int uart8250_mem_can_rx_byte(void *base)
 
 static unsigned char uart8250_mem_rx_byte(void *base)
 {
-	unsigned long int i = SINGLE_CHAR_TIMEOUT;
+	unsigned long i = SINGLE_CHAR_TIMEOUT;
 	while (i && !uart8250_mem_can_rx_byte(base)) {
 		udelay(1);
 		i--;
@@ -133,21 +133,18 @@ void uart_tx_flush(unsigned int idx)
 	uart8250_mem_tx_flush(base);
 }
 
-void uart_fill_lb(void *data)
+enum cb_err fill_lb_serial(struct lb_serial *serial)
 {
-	struct lb_serial serial;
-	serial.type = LB_SERIAL_TYPE_MEMORY_MAPPED;
-	serial.baseaddr = uart_platform_base(CONFIG_UART_FOR_CONSOLE);
-	if (!serial.baseaddr)
-		return;
-	serial.baud = get_uart_baudrate();
+	serial->type = LB_SERIAL_TYPE_MEMORY_MAPPED;
+	serial->baseaddr = uart_platform_base(CONFIG_UART_FOR_CONSOLE);
+	if (!serial->baseaddr)
+		return CB_ERR;
+	serial->baud = get_uart_baudrate();
 	if (CONFIG(DRIVERS_UART_8250MEM_32))
-		serial.regwidth = sizeof(uint32_t);
+		serial->regwidth = sizeof(uint32_t);
 	else
-		serial.regwidth = sizeof(uint8_t);
-	serial.input_hertz = uart_platform_refclk();
-	serial.uart_pci_addr = CONFIG_UART_PCI_ADDR;
-	lb_add_serial(&serial, data);
+		serial->regwidth = sizeof(uint8_t);
+	serial->input_hertz = uart_platform_refclk();
 
-	lb_add_console(LB_TAG_CONSOLE_SERIAL8250MEM, data);
+	return CB_SUCCESS;
 }
