@@ -16,8 +16,10 @@
 #include "wifi_private.h"
 
 /* Domain type */
-#define DOMAIN_TYPE_WIFI 0x7
-#define DOMAIN_TYPE_BLUETOOTH 0x12
+enum sar_domain {
+	DOMAIN_TYPE_WIFI = 0x7,
+	DOMAIN_TYPE_BLUETOOTH = 0x12
+};
 
 /* Maximum number DSM UUID bifurcations in _DSM */
 #define MAX_DSM_FUNCS 2
@@ -582,6 +584,9 @@ static void sar_emit_brds(const struct bsar_profile *bsar)
 	size_t package_size, table_size;
 	const uint8_t *set;
 
+	if (bsar == NULL)
+		return;
+
 	/*
 	 * Name ("BRDS", Package () {
 	 *   Revision,
@@ -596,7 +601,7 @@ static void sar_emit_brds(const struct bsar_profile *bsar)
 	 *   }
 	 * })
 	 */
-	if (bsar->revision != BSAR_REVISION) {
+	if (bsar->revision == 0 || bsar->revision > MAX_BSAR_REVISION) {
 		printk(BIOS_ERR, "Unsupported BSAR table revision: %d\n",
 		       bsar->revision);
 		return;
@@ -606,11 +611,14 @@ static void sar_emit_brds(const struct bsar_profile *bsar)
 	acpigen_write_package(2);
 	acpigen_write_dword(bsar->revision);
 
-	table_size = sizeof(*bsar) -
-		offsetof(struct bsar_profile, sar_lb_power_restriction);
+	if (bsar->revision == 1)
+		table_size = sizeof(bsar->revs.rev1);
+	else
+		table_size = sizeof(bsar->revs.rev2);
+
 	/*
 	 * Emit 'Domain Type' + 'Dynamic SAR Enable' + 'Increase Power Mode'
-	 * + ('SAR Power Restriction' + SAR table).
+	 * + ('SAR Power Restriction' + SAR table) | (Chain A and B SAR tables).
 	 */
 	package_size = 1 + 1 + 1 + table_size;
 	acpigen_write_package(package_size);
@@ -618,7 +626,7 @@ static void sar_emit_brds(const struct bsar_profile *bsar)
 	acpigen_write_dword(1);
 	acpigen_write_dword(bsar->increased_power_mode_limitation);
 
-	set = (const uint8_t *)&bsar->sar_lb_power_restriction;
+	set = (const uint8_t *)&bsar->revs;
 	for (int i = 0; i < table_size; i++)
 		acpigen_write_byte(set[i]);
 
@@ -663,11 +671,341 @@ static void sar_emit_wbem(const struct wbem_profile *wbem)
 	acpigen_write_package_end();
 }
 
-static void emit_sar_acpi_structures(const struct device *dev, struct dsm_profile *dsm,
-				     struct bsar_profile *bsar, bool *bsar_loaded)
+static void sar_emit_bpag(const struct bpag_profile *bpag)
 {
-	union wifi_sar_limits sar_limits = {0};
+	if (bpag == NULL)
+		return;
 
+	/*
+	 * Name ("BPAG", Package () {
+	 *   Revision,
+	 *   Package () {
+	 *     Domain Type,			// 0x12:Bluetooth
+	 *     Bluetooth Per-Platform Antenna Gain Mode
+	 *   }
+	 * })
+	 */
+	if (bpag->revision == 0 || bpag->revision > BPAG_REVISION) {
+		printk(BIOS_ERR, "Unsupported BPAG table revision: %d\n",
+		       bpag->revision);
+		return;
+	}
+
+	acpigen_write_name("BPAG");
+	acpigen_write_package(2);
+	acpigen_write_dword(bpag->revision);
+
+	/*
+	 * Emit 'Domain Type' + 'Antenna Gain Mode'
+	 */
+	acpigen_write_package(2);
+	acpigen_write_dword(DOMAIN_TYPE_BLUETOOTH);
+	acpigen_write_dword(bpag->antenna_gain_country_enablement);
+
+	acpigen_write_package_end();
+	acpigen_write_package_end();
+}
+
+static void sar_emit_bbfb(const struct bbfb_profile *bbfb)
+{
+	if (bbfb == NULL)
+		return;
+
+	/*
+	 * Name ("BBFB", Package () {
+	 *   Revision,
+	 *   Package () {
+	 *     Domain Type,			// 0x12:Bluetooth
+	 *     By Pass Enabled			// Enable ByPass
+	 *   }
+	 * })
+	 */
+	if (bbfb->revision != BBFB_REVISION) {
+		printk(BIOS_ERR, "Unsupported BBFB table revision: %d\n",
+		       bbfb->revision);
+		return;
+	}
+
+	acpigen_write_name("BBFB");
+	acpigen_write_package(2);
+	acpigen_write_dword(bbfb->revision);
+
+	/*
+	 * Emit 'Domain Type' + 'Enable ByPass'
+	 */
+	acpigen_write_package(2);
+	acpigen_write_dword(DOMAIN_TYPE_BLUETOOTH);
+	acpigen_write_dword(bbfb->enable_quad_filter_bypass);
+
+	acpigen_write_package_end();
+	acpigen_write_package_end();
+}
+
+static void sar_emit_bdcm(const struct bdcm_profile *bdcm)
+{
+	if (bdcm == NULL)
+		return;
+
+	/*
+	 * Name ("BDCM", Package () {
+	 *   Revision,
+	 *   Package () {
+	 *     Domain Type,			// 0x12:Bluetooth
+	 *     Dual Chain Mode
+	 *   }
+	 * })
+	 */
+	if (bdcm->revision != BDCM_REVISION) {
+		printk(BIOS_ERR, "Unsupported BDCM table revision: %d\n",
+		       bdcm->revision);
+		return;
+	}
+
+	acpigen_write_name("BDCM");
+	acpigen_write_package(2);
+	acpigen_write_dword(bdcm->revision);
+
+	/*
+	 * Emit 'Domain Type' + 'Dual Chain Mode'
+	 */
+	acpigen_write_package(2);
+	acpigen_write_dword(DOMAIN_TYPE_BLUETOOTH);
+	acpigen_write_dword(bdcm->dual_chain_mode);
+
+	acpigen_write_package_end();
+	acpigen_write_package_end();
+}
+
+static void sar_emit_bbsm(const struct bbsm_profile *bbsm)
+{
+	if (bbsm == NULL)
+		return;
+
+	/*
+	 * Name ("BBSM", Package () {
+	 *   Revision,
+	 *   Package () {
+	 *     Domain Type,			// 0x12:Bluetooth
+	 *     Bluetooth Bands Selection
+	 *   }
+	 * })
+	 */
+	if (bbsm->revision != BBSM_REVISION) {
+		printk(BIOS_ERR, "Unsupported BBSM table revision: %d\n",
+		       bbsm->revision);
+		return;
+	}
+
+	acpigen_write_name("BBSM");
+	acpigen_write_package(2);
+	acpigen_write_dword(bbsm->revision);
+
+	/*
+	 * Emit 'Domain Type' + 'Bluetooth Bands Selection'
+	 */
+	acpigen_write_package(2);
+	acpigen_write_dword(DOMAIN_TYPE_BLUETOOTH);
+	acpigen_write_dword(bbsm->bands_selection);
+
+	acpigen_write_package_end();
+	acpigen_write_package_end();
+}
+
+static void sar_emit_bucs(const struct bucs_profile *bucs)
+{
+	if (bucs == NULL)
+		return;
+
+	/*
+	 * Name ("BUCS", Package () {
+	 *   Revision,
+	 *   Package () {
+	 *     Domain Type,			// 0x12:Bluetooth
+	 *     UHB country selection bits
+	 *   }
+	 * })
+	 */
+	if (bucs->revision != BUCS_REVISION) {
+		printk(BIOS_ERR, "Unsupported BUCS table revision: %d\n",
+		       bucs->revision);
+		return;
+	}
+
+	acpigen_write_name("BUCS");
+	acpigen_write_package(2);
+	acpigen_write_dword(bucs->revision);
+
+	/*
+	 * Emit 'Domain Type' + 'UHB country selection bits'
+	 */
+	acpigen_write_package(2);
+	acpigen_write_dword(DOMAIN_TYPE_BLUETOOTH);
+	acpigen_write_dword(bucs->uhb_country_selection);
+
+	acpigen_write_package_end();
+	acpigen_write_package_end();
+}
+
+static void sar_emit_bdmm(const struct bdmm_profile *bdmm)
+{
+	if (bdmm == NULL)
+		return;
+
+	/*
+	 * Name ("BDMM", Package () {
+	 *   Revision,
+	 *   Package () {
+	 *     Domain Type,			// 0x12:Bluetooth
+	 *     Dual Mac Enable
+	 *   }
+	 * })
+	 */
+	if (bdmm->revision != BDMM_REVISION) {
+		printk(BIOS_ERR, "Unsupported BDMM table revision: %d\n",
+		       bdmm->revision);
+		return;
+	}
+
+	acpigen_write_name("BDMM");
+	acpigen_write_package(2);
+	acpigen_write_dword(bdmm->revision);
+
+	/*
+	 * Emit 'Domain Type' + 'Dual Mac Enable'
+	 */
+	acpigen_write_package(2);
+	acpigen_write_dword(DOMAIN_TYPE_BLUETOOTH);
+	acpigen_write_dword(bdmm->dual_mac_enable);
+
+	acpigen_write_package_end();
+	acpigen_write_package_end();
+}
+
+static void sar_emit_ebrd(const struct ebrd_profile *ebrd)
+{
+	if (ebrd == NULL)
+		return;
+
+	size_t package_size, table_size;
+	const uint8_t *set;
+
+	/*
+	 * Name ("EBRD", Package () {
+	 *   Revision,
+	 *   Package () {
+	 *     Domain Type,			// 0x12:Bluetooth
+	 *     Dynamic SAR Enable,
+	 *     Number of Optional SAR,
+	 *     Three SAR Sets
+	 *   }
+	 * })
+	 */
+	if (ebrd->revision != EBRD_REVISION) {
+		printk(BIOS_ERR, "Unsupported EBRD table revision: %d\n",
+		       ebrd->revision);
+		return;
+	}
+
+	acpigen_write_name("EBRD");
+	acpigen_write_package(2);
+	acpigen_write_dword(ebrd->revision);
+
+	/*
+	 * Emit 'Domain Type' + 'Dynamic Sar Enabled' + 'Number of Optional SAR' +
+	 * 'Three SAR Sets'
+	 */
+	table_size = sizeof(*ebrd) - offsetof(struct ebrd_profile, sar_table_sets);
+	package_size = 1 + 1 + 1 + table_size;
+	acpigen_write_package(package_size);
+	acpigen_write_dword(DOMAIN_TYPE_BLUETOOTH);
+	acpigen_write_dword(ebrd->dynamic_sar_enable);
+	acpigen_write_dword(ebrd->number_of_optional_sar);
+
+	set = (const uint8_t *)&ebrd->sar_table_sets;
+	for (size_t i = 0; i < table_size; i++)
+		acpigen_write_byte(set[i]);
+
+	acpigen_write_package_end();
+	acpigen_write_package_end();
+}
+
+static void sar_emit_wpfc(const struct wpfc_profile *wpfc)
+{
+	if (wpfc == NULL)
+		return;
+
+	/*
+	 * Name ("WPFC", Package() {
+	 * {
+	 *   Revision,
+	 *   Package()
+	 *   {
+	 *     DomainType,				// 0x7:WiFi
+	 *     Chain A Filter Platform Configuration
+	 *     Chain B Filter Platform Configuration
+	 *     Chain C Filter Platform Configuration
+	 *     Chain D Filter Platform Configuration
+	 *   }
+	 } })
+	 */
+	if (wpfc->revision != WPFC_REVISION) {
+		printk(BIOS_ERR, "Unsupported WPFC table revision: %d\n",
+		       wpfc->revision);
+		return;
+	}
+
+	acpigen_write_name("WPFC");
+	acpigen_write_package(2);
+	acpigen_write_dword(wpfc->revision);
+
+	acpigen_write_package(5);
+	acpigen_write_dword(DOMAIN_TYPE_WIFI);
+	acpigen_write_byte(wpfc->filter_cfg_chain_a);
+	acpigen_write_byte(wpfc->filter_cfg_chain_b);
+	acpigen_write_byte(wpfc->filter_cfg_chain_c);
+	acpigen_write_byte(wpfc->filter_cfg_chain_d);
+
+	acpigen_write_package_end();
+	acpigen_write_package_end();
+}
+
+static void sar_emit_dsbr(const struct dsbr_profile *dsbr, enum sar_domain domain)
+{
+	if (dsbr == NULL)
+		return;
+
+	/*
+	 * Name ("DSBR", Package() {
+	 * {
+	 *   Revision,
+	 *   Package()
+	 *   {
+	 *     DomainType,				// 0x7:WiFi
+	 *     BRI Resistor Value			// in Ohm
+	 *   }
+	 } })
+	 */
+	if (dsbr->revision > DSBR_REVISION) {
+		printk(BIOS_ERR, "Unsupported DSBR table revision: %d\n",
+		       dsbr->revision);
+		return;
+	}
+
+	acpigen_write_name("DSBR");
+	acpigen_write_package(2);
+	acpigen_write_dword(dsbr->revision);
+
+	acpigen_write_package(2);
+	acpigen_write_dword(domain);
+	acpigen_write_dword(dsbr->bri_resistor_value);
+
+	acpigen_write_package_end();
+	acpigen_write_package_end();
+}
+
+static void emit_wifi_sar_acpi_structures(const struct device *dev,
+					  union wifi_sar_limits *sar_limits)
+{
 	/*
 	 * If device type is PCI, ensure that the device has Intel vendor ID. CBFS SAR and SAR
 	 * ACPI tables are currently used only by Intel WiFi devices.
@@ -675,30 +1013,14 @@ static void emit_sar_acpi_structures(const struct device *dev, struct dsm_profil
 	if (dev->path.type == DEVICE_PATH_PCI && dev->vendor != PCI_VID_INTEL)
 		return;
 
-	/* Retrieve the SAR limits data */
-	if (get_wifi_sar_limits(&sar_limits) < 0) {
-		printk(BIOS_ERR, "failed getting SAR limits!\n");
-		return;
-	}
-
-	sar_emit_wrds(sar_limits.sar);
-	sar_emit_ewrd(sar_limits.sar);
-	sar_emit_wgds(sar_limits.wgds);
-	sar_emit_ppag(sar_limits.ppag);
-	sar_emit_wtas(sar_limits.wtas);
-	sar_emit_wbem(sar_limits.wbem);
-
-	/* copy the dsm data to be later used for creating _DSM function */
-	if (sar_limits.dsm != NULL)
-		memcpy(dsm, sar_limits.dsm, sizeof(struct dsm_profile));
-
-	/* copy the bsar data to be later used for creating Bluetooth BRDS method */
-	if (sar_limits.bsar != NULL) {
-		memcpy(bsar, sar_limits.bsar, sizeof(struct bsar_profile));
-		*bsar_loaded = true;
-	}
-
-	free(sar_limits.sar);
+	sar_emit_wrds(sar_limits->sar);
+	sar_emit_ewrd(sar_limits->sar);
+	sar_emit_wgds(sar_limits->wgds);
+	sar_emit_ppag(sar_limits->ppag);
+	sar_emit_wtas(sar_limits->wtas);
+	sar_emit_wbem(sar_limits->wbem);
+	sar_emit_wpfc(sar_limits->wpfc);
+	sar_emit_dsbr(sar_limits->dsbr, DOMAIN_TYPE_WIFI);
 }
 
 static void wifi_ssdt_write_device(const struct device *dev, const char *path)
@@ -756,26 +1078,32 @@ static void wifi_ssdt_write_properties(const struct device *dev, const char *sco
 	}
 
 	struct dsm_uuid dsm_ids[MAX_DSM_FUNCS];
-	/* We will need a copy dsm data to be used later for creating _DSM function */
-	struct dsm_profile dsm = {0};
-	/* We will need a copy of bsar data to be used later for creating BRDS function */
-	struct bsar_profile bsar = {0};
-	bool bsar_loaded = false;
-	uint8_t dsm_count = 0;
+
+	/* Retrieve the SAR limits data */
+	union wifi_sar_limits sar_limits = {0};
+	bool sar_loaded = false;
+	if (CONFIG(USE_SAR)) {
+		if (get_wifi_sar_limits(&sar_limits) < 0)
+			printk(BIOS_ERR, "failed getting SAR limits!\n");
+		else
+			sar_loaded = true;
+	}
 
 	/* Fill Wifi SAR related ACPI structures */
-	if (CONFIG(USE_SAR)) {
-		emit_sar_acpi_structures(dev, &dsm, &bsar, &bsar_loaded);
+	uint8_t dsm_count = 0;
+	if (sar_loaded) {
+		emit_wifi_sar_acpi_structures(dev, &sar_limits);
 
-		if (dsm.supported_functions != 0) {
+		struct dsm_profile *dsm = sar_limits.dsm;
+		if (dsm && dsm->supported_functions != 0) {
 			for (int i = 1; i < ARRAY_SIZE(wifi_dsm_callbacks); i++)
-				if (!(dsm.supported_functions & (1 << i)))
+				if (!(dsm->supported_functions & (1 << i)))
 					wifi_dsm_callbacks[i] = NULL;
 
 			dsm_ids[dsm_count].uuid = ACPI_DSM_OEM_WIFI_UUID;
 			dsm_ids[dsm_count].callbacks = &wifi_dsm_callbacks[0];
 			dsm_ids[dsm_count].count = ARRAY_SIZE(wifi_dsm_callbacks);
-			dsm_ids[dsm_count].arg = &dsm;
+			dsm_ids[dsm_count].arg = dsm;
 			dsm_count++;
 		}
 	}
@@ -804,11 +1132,19 @@ static void wifi_ssdt_write_properties(const struct device *dev, const char *sco
 	acpigen_write_scope_end(); /* Scope */
 
 	/* Fill Bluetooth companion SAR related ACPI structures */
-	if (bsar_loaded && is_dev_enabled(config->bluetooth_companion)) {
+	if (sar_loaded && is_dev_enabled(config->bluetooth_companion)) {
 		const char *path = acpi_device_path(config->bluetooth_companion);
 		if (path) {	/* Bluetooth device under USB Hub scope or PCIe root port */
 			acpigen_write_scope(path);
-			sar_emit_brds(&bsar);
+			sar_emit_brds(sar_limits.bsar);
+			sar_emit_bpag(sar_limits.bpag);
+			sar_emit_bbfb(sar_limits.bbfb);
+			sar_emit_bdcm(sar_limits.bdcm);
+			sar_emit_bbsm(sar_limits.bbsm);
+			sar_emit_bucs(sar_limits.bucs);
+			sar_emit_bdmm(sar_limits.bdmm);
+			sar_emit_ebrd(sar_limits.ebrd);
+			sar_emit_dsbr(sar_limits.dsbr, DOMAIN_TYPE_BLUETOOTH);
 			acpigen_write_scope_end();
 		} else {
 			printk(BIOS_ERR, "Failed to get %s Bluetooth companion ACPI path\n",
@@ -816,6 +1152,9 @@ static void wifi_ssdt_write_properties(const struct device *dev, const char *sco
 		}
 	}
 
+	if (sar_loaded)
+		free(sar_limits.sar);
+
 	printk(BIOS_INFO, "%s: %s %s\n", scope, dev->chip_ops ? dev->chip_ops->name : "",
 	       dev_path(dev));
 }
