@@ -11,7 +11,7 @@ struct drivers_wifi_generic_config {
 	unsigned int wake;
 	/* When set to true, this will add a _DSD which contains a single
 	   property, `DmaProperty`, set to 1, under the ACPI Device. */
-	bool is_untrusted;
+	bool add_acpi_dma_property;
 
 	/*
 	 * Applicable for Intel chipsets that use CNVi WiFi only. Set this to 1
@@ -19,6 +19,9 @@ struct drivers_wifi_generic_config {
 	 * SoC code propagates this value the applicable FSP UPD.
 	 */
 	bool enable_cnvi_ddr_rfim;
+
+	/* Pointer to the Bluetooth companion device */
+	DEVTREE_CONST struct device *bluetooth_companion;
 };
 
 #endif /* _GENERIC_WIFI_H_ */
