@@ -1,8 +1,8 @@
 /* SPDX-License-Identifier: GPL-2.0-or-later */
 
-#include <stddef.h>
 #include <ec/google/chromeec/ec.h>
 #include <console/console.h>
+#include <stdio.h>
 #include <string.h>
 #include <smbios.h>
 
