@@ -1,12 +1,12 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
-#include <acpi/acpi.h>
 #include <acpi/acpi_device.h>
+#include <acpi/acpi.h>
 #include <acpi/acpigen.h>
-#include <arch/cpu.h>
 #include <bootstate.h>
 #include <cbmem.h>
 #include <console/console.h>
+#include <cpu/cpu.h>
 #include <device/pnp.h>
 #include <ec/acpi/ec.h>
 #include <intelblocks/cpulib.h>
@@ -196,7 +196,7 @@ static void wilco_ec_fill_ssdt_generator(const struct device *dev)
 	opreg.regionoffset = (uintptr_t)region_ptr;
 	opreg.regionlen = ucsi_alloc_region_len;
 
-	acpigen_write_scope(acpi_device_path_join(dev, "UCSI"));
+	acpigen_write_scope("\\_SB.UCSI");
 	acpigen_write_name("_CRS");
 	acpigen_write_resourcetemplate_header();
 	acpigen_write_mem32fixed(1, (uintptr_t)region_ptr, ucsi_region_len);
@@ -230,6 +230,6 @@ static void wilco_ec_enable_dev(struct device *dev)
 }
 
 struct chip_operations ec_google_wilco_ops = {
-	CHIP_NAME("Google Wilco EC")
+	.name = "Google Wilco EC",
 	.enable_dev = wilco_ec_enable_dev,
 };
