@@ -5,22 +5,47 @@
 #include <device/pnp.h>
 #include <ec/acpi/ec.h>
 #include <option.h>
-#include <pc80/keyboard.h>
+#include <pc80/mc146818rtc.h>
+#include <halt.h>
 
-#include "ec.h"
 #include "ecdefs.h"
+#include "option_table.h"
+#include "ec.h"
+
 
 uint16_t ec_get_version(void)
 {
 	return (ec_read(ECRAM_MAJOR_VERSION) << 8) | ec_read(ECRAM_MINOR_VERSION);
 }
 
-static uint8_t get_ec_value_from_option(const char *name,
-					unsigned int fallback,
-					const uint8_t *lut,
-					size_t lut_size)
+static uint8_t get_cmos_value(uint32_t bit, uint32_t length)
 {
-	unsigned int index = get_uint_option(name, fallback);
+	uint32_t byte, byte_bit;
+	uint8_t uchar;
+
+	byte = bit / 8; // find the byte where the data starts
+	byte_bit = bit % 8; // find the bit in the byte where the data starts
+
+	uchar = cmos_read(byte); // load the byte
+	uchar >>= byte_bit;     // shift the bits to byte align
+	// clear unspecified bits
+	return uchar & ((1U << length) - 1);
+}
+
+static uint8_t get_ec_value_from_option(const char *name,
+					uint32_t fallback,
+					const uint8_t *lut,
+					size_t lut_size,
+					uint32_t cmos_start_bit,
+					uint32_t cmos_length)
+{
+	unsigned int index;
+
+	if (cmos_start_bit != UINT_MAX)
+		index = get_cmos_value(cmos_start_bit, cmos_length);
+	else
+		index = get_uint_option(name, fallback);
+
 	if (index >= lut_size)
 		index = fallback;
 	return lut[index];
@@ -56,8 +81,6 @@ static void merlin_init(struct device *dev)
 		return;
 	}
 
-	pc_keyboard_init(NO_AUX_DEVICE);
-
 	/*
 	 * Restore settings from CMOS into EC RAM:
 	 *
@@ -92,7 +115,9 @@ static void merlin_init(struct device *dev)
 		get_ec_value_from_option("kbl_timeout",
 					 0,
 					 kbl_timeout,
-					 ARRAY_SIZE(kbl_timeout)));
+					 ARRAY_SIZE(kbl_timeout),
+					 UINT_MAX,
+					 UINT_MAX));
 
 	/*
 	 * Fn Ctrl Reverse
@@ -112,7 +137,9 @@ static void merlin_init(struct device *dev)
 		get_ec_value_from_option("fn_ctrl_swap",
 					 0,
 					 fn_ctrl_swap,
-					 ARRAY_SIZE(fn_ctrl_swap)));
+					 ARRAY_SIZE(fn_ctrl_swap),
+					 UINT_MAX,
+					 UINT_MAX));
 
 	/*
 	 * Maximum Charge Level
@@ -134,7 +161,9 @@ static void merlin_init(struct device *dev)
 			get_ec_value_from_option("max_charge",
 						 0,
 						 max_charge,
-						 ARRAY_SIZE(max_charge)));
+						 ARRAY_SIZE(max_charge),
+						 UINT_MAX,
+						 UINT_MAX));
 
 	/*
 	 * Fast Charge
@@ -155,7 +184,9 @@ static void merlin_init(struct device *dev)
 			get_ec_value_from_option("fast_charge",
 						 0,
 						 fast_charge,
-						 ARRAY_SIZE(fast_charge)));
+						 ARRAY_SIZE(fast_charge),
+						 UINT_MAX,
+						 UINT_MAX));
 
 	/*
 	 * Fan Mode
@@ -177,7 +208,9 @@ static void merlin_init(struct device *dev)
 			get_ec_value_from_option("fan_mode",
 						 0,
 						 fan_mode,
-						 ARRAY_SIZE(fan_mode)));
+						 ARRAY_SIZE(fan_mode),
+						 UINT_MAX,
+						 UINT_MAX));
 
 	/*
 	 * Function Lock
@@ -188,6 +221,7 @@ static void merlin_init(struct device *dev)
 	 * Default:	Locked
 	 *
 	 */
+#ifdef CMOS_VLEN_fn_lock_state
 	const uint8_t fn_lock_state[] = {
 		UNLOCKED,
 		LOCKED
@@ -197,7 +231,10 @@ static void merlin_init(struct device *dev)
 		get_ec_value_from_option("fn_lock_state",
 					 1,
 					 fn_lock_state,
-					 ARRAY_SIZE(fn_lock_state)));
+					 ARRAY_SIZE(fn_lock_state),
+					 CMOS_VSTART_fn_lock_state,
+					 CMOS_VLEN_fn_lock_state));
+#endif
 
 	/*
 	 * Trackpad State
@@ -208,6 +245,7 @@ static void merlin_init(struct device *dev)
 	 * Default:	Enabled
 	 *
 	 */
+#ifdef CMOS_VSTART_trackpad_state
 	const uint8_t trackpad_state[] = {
 		TRACKPAD_ENABLED,
 		TRACKPAD_DISABLED
@@ -217,7 +255,10 @@ static void merlin_init(struct device *dev)
 		get_ec_value_from_option("trackpad_state",
 					 0,
 					 trackpad_state,
-					 ARRAY_SIZE(trackpad_state)));
+					 ARRAY_SIZE(trackpad_state),
+					 CMOS_VSTART_trackpad_state,
+					 CMOS_VLEN_trackpad_state));
+#endif
 
 	/*
 	 * Keyboard Backlight Brightness
@@ -228,6 +269,7 @@ static void merlin_init(struct device *dev)
 	 * Default:	Low
 	 *
 	 */
+#ifdef CMOS_VSTART_kbl_brightness
 	const uint8_t kbl_brightness[] = {
 		KBL_ON,
 		KBL_OFF,
@@ -235,18 +277,16 @@ static void merlin_init(struct device *dev)
 		KBL_HIGH
 	};
 
-	if (CONFIG(EC_STARLABS_KBL_LEVELS))
-		ec_write(ECRAM_KBL_BRIGHTNESS,
-			get_ec_value_from_option("kbl_brightness",
-						 2,
-						 kbl_brightness,
-						 ARRAY_SIZE(kbl_brightness)));
-	else
-		ec_write(ECRAM_KBL_BRIGHTNESS,
-			get_ec_value_from_option("kbl_brightness",
-						 0,
-						 kbl_brightness,
-						 ARRAY_SIZE(kbl_brightness)));
+	ec_write(ECRAM_KBL_BRIGHTNESS,
+		get_ec_value_from_option("kbl_brightness",
+			CONFIG(EC_STARLABS_KBL_LEVELS) ? 2 : 0,
+			kbl_brightness,
+			ARRAY_SIZE(kbl_brightness),
+			CMOS_VSTART_kbl_brightness,
+			CMOS_VLEN_kbl_brightness));
+
+#endif
+
 
 	/*
 	 * Keyboard Backlight State
@@ -256,17 +296,11 @@ static void merlin_init(struct device *dev)
 	 * Values:	Off, On
 	 * Default:	On
 	 *
+	 * Note:	Always enable, as the brightness level of `off` disables it.
+	 *
 	 */
-	const uint8_t kbl_state[] = {
-		KBL_DISABLED,
-		KBL_ENABLED
-	};
 
-	ec_write(ECRAM_KBL_STATE,
-		get_ec_value_from_option("kbl_state",
-					 1,
-					 kbl_state,
-					 ARRAY_SIZE(kbl_state)));
+	ec_write(ECRAM_KBL_STATE, KBL_ENABLED);
 }
 
 static struct device_operations ops = {
@@ -303,6 +337,6 @@ static void enable_dev(struct device *dev)
 }
 
 struct chip_operations ec_starlabs_merlin_ops = {
-	CHIP_NAME("NUVOTON EC")
+	.name = "NUVOTON EC",
 	.enable_dev = enable_dev
 };
