@@ -205,7 +205,8 @@ void dptf_write_fan_perf(const struct dptf_fan_perf *perf, int max_count,
 				enum dptf_participant participant);
 
 void dptf_write_multifan_perf(
-			const struct dptf_multifan_perf (*states)[DPTF_MAX_FAN_PERF_STATES],
+			const struct dptf_multifan_perf
+				states[DPTF_MAX_FAN_PARTICIPANTS][DPTF_MAX_FAN_PERF_STATES],
 			int max_count, enum dptf_participant participant, int fan_num);
 
 int dptf_write_fan_perf_fps(uint8_t percent, uint16_t power, uint16_t speed,
