@@ -8,7 +8,7 @@
 void spkmodem_init(void);
 void spkmodem_tx_byte(unsigned char c);
 
-#if CONFIG(SPKMODEM) && (ENV_ROMSTAGE || ENV_RAMSTAGE)
+#if CONFIG(SPKMODEM) && (ENV_ROMSTAGE_OR_BEFORE || ENV_RAMSTAGE)
 static inline void __spkmodem_init(void)		{ spkmodem_init(); }
 static inline void __spkmodem_tx_byte(u8 data)	{ spkmodem_tx_byte(data); }
 #else
