@@ -3,7 +3,6 @@
 #ifndef CONSOLE_SYSTEM76_EC_H
 #define CONSOLE_SYSTEM76_EC_H 1
 
-#include <stddef.h>
 #include <stdint.h>
 
 void system76_ec_init(void);
@@ -11,7 +10,7 @@ void system76_ec_flush(void);
 void system76_ec_print(uint8_t byte);
 
 #define __CONSOLE_SYSTEM76_EC_ENABLE__	(CONFIG(CONSOLE_SYSTEM76_EC) && \
-	(ENV_BOOTBLOCK || ENV_ROMSTAGE || ENV_RAMSTAGE \
+	(ENV_BOOTBLOCK || ENV_SEPARATE_ROMSTAGE || ENV_RAMSTAGE \
 	 || ENV_SEPARATE_VERSTAGE || ENV_POSTCAR \
 	 || (ENV_SMM && CONFIG(DEBUG_SMI))))
 
