@@ -4,6 +4,9 @@
 #define CPU_AMD_MICROCODE_H
 
 void amd_update_microcode_from_cbfs(void);
+void amd_load_microcode_from_cbfs(void);
+void amd_free_microcode(void);
+void amd_apply_microcode_patch(void);
 void preload_microcode(void);
 
 #endif /* CPU_AMD_MICROCODE_H */
