@@ -12,6 +12,7 @@
 #define MTRR_WRITE_MEM			(1 << 3)
 
 #define SYSCFG_MSR			0xC0010010
+#define SYSCFG_MSR_SMEE			(1 << 23)
 #define SYSCFG_MSR_TOM2WB		(1 << 22)
 #define SYSCFG_MSR_TOM2En		(1 << 21)
 #define SYSCFG_MSR_MtrrVarDramEn	(1 << 20)
@@ -29,16 +30,8 @@
 #define IORRBase_MSR(reg) (0xC0010016 + 2 * (reg))
 #define IORRMask_MSR(reg) (0xC0010016 + 2 * (reg) + 1)
 
-#if defined(__ASSEMBLER__)
-#define TOP_MEM		0xC001001A
-#define TOP_MEM2	0xC001001D
-#else
-#define TOP_MEM		0xC001001Aul
-#define TOP_MEM2	0xC001001Dul
-#endif
-
-#define TOP_MEM_MASK			0x007fffff
-#define TOP_MEM_MASK_KB			(TOP_MEM_MASK >> 10)
+#define TOP_MEM_MSR	0xC001001A
+#define TOP_MEM2_MSR	0xC001001D
 
 #if !defined(__ASSEMBLER__)
 
@@ -68,14 +61,14 @@ static __always_inline void wrmsr_amd(unsigned int index, msr_t msr)
 		);
 }
 
-static inline uint64_t amd_topmem(void)
+static inline uint32_t get_top_of_mem_below_4gb(void)
 {
-	return rdmsr(TOP_MEM).lo;
+	return rdmsr(TOP_MEM_MSR).lo;
 }
 
-static inline uint64_t amd_topmem2(void)
+static inline uint64_t get_top_of_mem_above_4gb(void)
 {
-	msr_t msr = rdmsr(TOP_MEM2);
+	msr_t msr = rdmsr(TOP_MEM2_MSR);
 	return (uint64_t)msr.hi << 32 | msr.lo;
 }
 #endif
