@@ -57,6 +57,8 @@
 #define CPUID_SAPPHIRERAPIDS_SP_E3	0x806f6
 #define CPUID_SAPPHIRERAPIDS_SP_E4	0x806f7
 #define CPUID_SAPPHIRERAPIDS_SP_Ex	0x806f8
+#define CPUID_GRANITERAPIDS		0xA06D0
+#define CPUID_SIERRAFOREST		0xA06F0
 #define CPUID_ELKHARTLAKE_A0		0x90660
 #define CPUID_ELKHARTLAKE_B0		0x90661
 #define CPUID_ALDERLAKE_A0		0x90670
