@@ -4,7 +4,6 @@
 #define __FRAMEBUFFER_INFO_H_
 
 #include <stdint.h>
-#include <stdbool.h>
 #include <commonlib/coreboot_tables.h>
 
 struct fb_info;
@@ -15,6 +14,8 @@ fb_add_framebuffer_info_ex(const struct lb_framebuffer *fb);
 struct fb_info *fb_add_framebuffer_info(uintptr_t fb_addr, uint32_t x_resolution,
 					uint32_t y_resolution, uint32_t bytes_per_line,
 					uint8_t bits_per_pixel);
+int fb_add_framebuffer_info_simple(uintptr_t fb_addr, uint32_t x_res, uint32_t y_res,
+				   uint32_t bytes_per_line, uint8_t bits_per_pixel);
 
 void fb_set_orientation(struct fb_info *info,
 			enum lb_fb_orientation orientation);
