@@ -16,7 +16,7 @@
 #define SMMSTORE_CMD_APPEND 3
 
 /* Version 2 */
-#define SMMSTORE_CMD_INIT 4
+#define SMMSTORE_CMD_INIT_DEPRECATED 4
 #define SMMSTORE_CMD_RAW_READ 5
 #define SMMSTORE_CMD_RAW_WRITE 6
 #define SMMSTORE_CMD_RAW_CLEAR 7
@@ -115,6 +115,8 @@ int smmstore_rawclear_region(uint32_t block_id);
 #if ENV_RAMSTAGE
 int smmstore_get_info(struct smmstore_params_info *info);
 #endif
+struct region_device;
+int smmstore_lookup_region(struct region_device *rstore);
 
 /* Advertise SMMSTORE v2 support */
 struct lb_header;
