@@ -1,7 +1,9 @@
+/* SPDX-License-Identifier: GPL-2.0-only */
+
 #ifndef _SMP_NODE_H_
 #define _SMP_NODE_H_
 
-#if IS_ENABLED(CONFIG_SMP)
+#if CONFIG(SMP)
 int boot_cpu(void);
 #else
 #define boot_cpu(x) 1
@@ -9,7 +11,7 @@ int boot_cpu(void);
 
 static inline int is_smp_boot(void)
 {
-	return IS_ENABLED(CONFIG_SMP) && CONFIG_MAX_CPUS > 1;
+	return CONFIG(SMP) && CONFIG_MAX_CPUS > 1;
 }
 
 #endif /* _SMP_NODE_H_ */
