@@ -1183,13 +1183,13 @@ int decode_edid(unsigned char *edid, int size, struct edid *out)
 		switch (edid[0x13]) {
 		case 4:
 			c.claims_one_point_four = 1;
-			/* fall through */
+			__fallthrough;
 		case 3:
 			c.claims_one_point_three = 1;
-			/* fall through */
+			__fallthrough;
 		case 2:
 			c.claims_one_point_two = 1;
-			/* fall through */
+			__fallthrough;
 		default:
 			c.claims_one_point_oh = 1;
 		}
@@ -1389,7 +1389,6 @@ int decode_edid(unsigned char *edid, int size, struct edid *out)
 					out->mode_is_supported[j] = 1;
 			}
 		}
-
 	}
 
 	printk(BIOS_SPEW, "Standard timings supported:\n");
@@ -1507,7 +1506,7 @@ int decode_edid(unsigned char *edid, int size, struct edid *out)
 			printk(BIOS_ERR,
 				"EDID block does NOT conform to EDID 1.3!\n");
 		else if (!c.has_name_descriptor || !c.has_range_descriptor)
-			printk(BIOS_WARNING, "WARNING: EDID block does NOT "
+			printk(BIOS_WARNING, "EDID block does NOT "
 			       "fully conform to EDID 1.3.\n");
 
 		if (c.nonconformant_digital_display)
