@@ -1,13 +1,15 @@
+/* SPDX-License-Identifier: GPL-2.0-only */
+
 #include <fallback.h>
 #include <watchdog.h>
 
 /* Implement platform specific override. */
-void __attribute__((weak)) set_boot_successful(void) { }
+void __weak set_boot_successful(void) { }
 
 void boot_successful(void)
 {
-	if (IS_ENABLED(CONFIG_FRAMEBUFFER_SET_VESA_MODE) &&
-	    IS_ENABLED(CONFIG_VGA_TEXT_FRAMEBUFFER)) {
+	if (CONFIG(FRAMEBUFFER_SET_VESA_MODE) &&
+	    CONFIG(VGA_TEXT_FRAMEBUFFER)) {
 		void vbe_textmode_console(void);
 
 		vbe_textmode_console();
