@@ -13,11 +13,11 @@ const u32 cim_verb_data[] = {
 	AZALIA_PIN_CFG(0, 0x15, 0x02211010),
 	AZALIA_PIN_CFG(0, 0x17, 0x40000000),
 	AZALIA_PIN_CFG(0, 0x18, 0x02a11030),
-	AZALIA_PIN_CFG(0, 0x19, 0x411111f0),
-	AZALIA_PIN_CFG(0, 0x1a, 0x411111f0),
-	AZALIA_PIN_CFG(0, 0x1b, 0x411111f0),
+	AZALIA_PIN_CFG(0, 0x19, AZALIA_PIN_CFG_NC(0)),
+	AZALIA_PIN_CFG(0, 0x1a, AZALIA_PIN_CFG_NC(0)),
+	AZALIA_PIN_CFG(0, 0x1b, AZALIA_PIN_CFG_NC(0)),
 	AZALIA_PIN_CFG(0, 0x1d, 0x40f4a205),
-	AZALIA_PIN_CFG(0, 0x1e, 0x411111f0),
+	AZALIA_PIN_CFG(0, 0x1e, AZALIA_PIN_CFG_NC(0)),
 
 	/* Intel iGPU HDMI */
 	0x8086280b,
