@@ -15,10 +15,10 @@
 static uint32_t encode_pciexbar_length(void)
 {
 	switch (CONFIG_ECAM_MMCONF_BUS_NUMBER) {
-		case 256: return 0 << 1;
-		case 128: return 1 << 1;
-		case  64: return 2 << 1;
-		default:  return dead_code_t(uint32_t);
+	case 256: return 0 << 1;
+	case 128: return 1 << 1;
+	case  64: return 2 << 1;
+	default:  return dead_code_t(uint32_t);
 	}
 }
 
@@ -34,41 +34,57 @@ void mainboard_machine_check(void)
 		die("You must run qemu for machine Q35 (-M q35)");
 }
 
-/* QEMU-specific register */
-#define EXT_TSEG_MBYTES	0x50
-#define SMRAMC	0x9d
-#define C_BASE_SEG	((0 << 2) | (1 << 1) | (0 << 0))
-#define G_SMRAME	(1 << 3)
-#define D_LCK		(1 << 4)
-#define D_CLS		(1 << 5)
-#define D_OPEN		(1 << 6)
-#define ESMRAMC	0x9e
-#define T_EN		(1 << 0)
-#define TSEG_SZ_MASK	(3 << 1)
-#define H_SMRAME	(1 << 7)
+/* Decodes TSEG region size to bytes. */
+static size_t decode_tseg_size(u8 esmramc)
+{
+	/* If we intent to enable TSEG, fake it always enabled. */
+	if (CONFIG(SMM_TSEG))
+		esmramc |= T_EN;
+
+	if (!(esmramc & T_EN))
+		return 0;
+
+	switch ((esmramc & TSEG_SZ_MASK) >> 1) {
+	case 0:
+		return 1 * MiB;
+	case 1:
+		return 2 * MiB;
+	case 2:
+		return 8 * MiB;
+	default:
+		return pci_read_config16(HOST_BRIDGE, EXT_TSEG_MBYTES) * MiB;
+	}
+}
 
 void smm_region(uintptr_t *start, size_t *size)
 {
 	uint8_t esmramc = pci_read_config8(HOST_BRIDGE, ESMRAMC);
 
-	switch ((esmramc & TSEG_SZ_MASK) >> 1) {
-	case 0:
-		*size = 1 * MiB;
-		break;
-	case 1:
-		*size = 2 * MiB;
-		break;
-	case 2:
-		*size = 8 * MiB;
-		break;
-	default:
-		*size = pci_read_config16(HOST_BRIDGE, EXT_TSEG_MBYTES) * MiB;
-	}
-
+	*size = decode_tseg_size(esmramc);
 	*start = qemu_get_memory_size() * KiB - *size;
 	printk(BIOS_SPEW, "SMM_BASE: 0x%08lx, SMM_SIZE: %zu MiB\n", *start, *size / MiB);
 }
 
+void smm_open(void)
+{
+	/* Set D_OPEN */
+	if (CONFIG(SMM_ASEG))
+		pci_write_config8(HOST_BRIDGE, SMRAMC, D_OPEN | G_SMRAME | C_BASE_SEG);
+
+	if (CONFIG(SMM_TSEG))
+		pci_and_config8(HOST_BRIDGE, ESMRAMC, ~T_EN);
+}
+
+void smm_close(void)
+{
+	/* Clear D_OPEN */
+	if (CONFIG(SMM_ASEG))
+		pci_write_config8(HOST_BRIDGE, SMRAMC, G_SMRAME | C_BASE_SEG);
+
+	if (CONFIG(SMM_TSEG))
+		pci_or_config8(HOST_BRIDGE, ESMRAMC, T_EN);
+}
+
 void smm_lock(void)
 {
 	/*
@@ -78,12 +94,5 @@ void smm_lock(void)
 	 */
 	printk(BIOS_DEBUG, "Locking SMM.\n");
 
-	if (CONFIG(SMM_TSEG))
-		pci_or_config8(PCI_DEV(0, 0, 0), ESMRAMC, T_EN);
-	pci_write_config8(PCI_DEV(0, 0, 0), SMRAMC, D_LCK | G_SMRAME | C_BASE_SEG);
-}
-
-void smm_open_aseg(void)
-{
-	pci_write_config8(PCI_DEV(0, 0, 0), SMRAMC, G_SMRAME | C_BASE_SEG | D_OPEN);
+	pci_write_config8(HOST_BRIDGE, SMRAMC, D_LCK | G_SMRAME | C_BASE_SEG);
 }
