@@ -11,9 +11,8 @@
 #include <gpio.h>
 #include <soc/bl31.h>
 #include <soc/ddp.h>
-#include <soc/dpm.h>
+#include <soc/dpm_v1.h>
 #include <soc/dsi.h>
-#include <soc/gpio.h>
 #include <soc/gpio_common.h>
 #include <soc/i2c.h>
 #include <soc/msdc.h>
