@@ -2,6 +2,7 @@
 
 #include <baseboard/gpio.h>
 #include <baseboard/variants.h>
+#include <intelblocks/early_graphics.h>
 #include <types.h>
 #include <soc/gpio.h>
 #include <vendorcode/google/chromeos/chromeos.h>
@@ -238,11 +239,11 @@ static const struct pad_config gpio_table[] = {
 	/* F14 : GSXDIN ==> EN_PP3300_SSD */
 	PAD_CFG_GPO_LOCK(GPP_F14, 1, LOCK_CONFIG),
 	/* F15 : GSXSRESET# ==> FPMCU_INT_L */
-	PAD_CFG_GPI_IRQ_WAKE_LOCK(GPP_F15, NONE, LEVEL, INVERT, LOCK_CONFIG),
+	PAD_CFG_GPI_IRQ_WAKE(GPP_F15, NONE, PWROK, LEVEL, INVERT),
 	/* F16 : GSXCLK ==> GSPI_PCH_CS_FPMCU_R_L */
 	PAD_CFG_NF_LOCK(GPP_F16, NONE, NF4, LOCK_CONFIG),
 	/* F17 : THC1_SPI2_RST# ==> EC_PCH_INT_ODL */
-	PAD_CFG_GPI_IRQ_WAKE_LOCK(GPP_F17, NONE, LEVEL, INVERT, LOCK_CONFIG),
+	PAD_CFG_GPI_IRQ_WAKE(GPP_F17, NONE, PWROK, LEVEL, INVERT),
 	/* F18 : THC1_SPI2_INT# ==> EC_IN_RW_OD */
 	PAD_CFG_GPI_LOCK(GPP_F18, NONE, LOCK_CONFIG),
 	/* F19 : SRCCLKREQ6# ==> LAN_CLKREQ_ODL */
@@ -403,6 +404,33 @@ static const struct pad_config romstage_gpio_table[] = {
 	PAD_CFG_GPO(GPP_B4, 1, DEEP),
 };
 
+const struct pad_config early_graphics_gpio_table[] = {
+	/* A18 : DDSP_HPDB ==> HDMI_HPD */
+	PAD_CFG_NF(GPP_A18, NONE, DEEP, NF1),
+	/* D1  : ISH_GP1 ==> HDMI_IN_PLUGIN */
+	PAD_CFG_GPO_LOCK(GPP_D1, 1, LOCK_CONFIG),
+	/* D11 : ISH_SPI_MISO ==> HDMIA_CTRLCLK */
+	PAD_CFG_NF_LOCK(GPP_D11, NONE, NF2, LOCK_CONFIG),
+	/* D12 : ISH_SPI_MOSI ==> HDMIA_CTRLDATA */
+	PAD_CFG_NF_LOCK(GPP_D12, NONE, NF2, LOCK_CONFIG),
+	/* E14 : DDSP_HPDA ==> HDMIA_HPD */
+	PAD_CFG_NF(GPP_E14, NONE, DEEP, NF1),
+	/* E20 : DDP2_CTRLCLK ==> HDMIA_CTRLCLK */
+	PAD_CFG_NF(GPP_E20, NONE, DEEP, NF1),
+	/* E21 : DDP2_CTRLDATA ==> HDMIA_CTRLDATA_STRAP */
+	PAD_CFG_NF(GPP_E21, NONE, DEEP, NF1),
+	/* H15 : DDPB_CTRLCLK ==> DDIB_HDMI_CTRLCLK */
+	PAD_CFG_NF(GPP_H15, NONE, DEEP, NF1),
+	/* H17 : DDPB_CTRLDATA ==> DDIB_HDMI_CTRLDATA */
+	PAD_CFG_NF(GPP_H17, NONE, DEEP, NF1),
+};
+
+const struct pad_config *variant_early_graphics_gpio_table(size_t *num)
+{
+	*num = ARRAY_SIZE(early_graphics_gpio_table);
+	return early_graphics_gpio_table;
+}
+
 const struct pad_config *__weak variant_gpio_table(size_t *num)
 {
 	*num = ARRAY_SIZE(gpio_table);
