@@ -1,18 +1,4 @@
-/*
- * This file is part of the coreboot project.
- *
- * Copyright (C) 2013 Google Inc.
- * Copyright (C) 2015 Intel Corp.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- */
+/* SPDX-License-Identifier: GPL-2.0-only */
 
 #ifndef ONBOARD_H
 #define ONBOARD_H
@@ -30,8 +16,6 @@
  * GPSE_SIZE = 86
  */
 
-#define BOARD_TOUCH_IRQ			184
-
 /* KBD: Gpio index in N bank */
 #define BOARD_I8042_GPIO_INDEX		17
 /* Audio: Gpio index in SW bank */
@@ -40,6 +24,8 @@
 #define BOARD_SCI_GPIO_INDEX		15
 /* Trackpad: Gpio index in N bank */
 #define BOARD_TRACKPAD_GPIO_INDEX	18
+/* Touch: Gpio index in N bank */
+#define BOARD_TOUCH_GPIO_INDEX		19
 
 #define BOARD_TRACKPAD_NAME		"trackpad"
 #define BOARD_TRACKPAD_WAKE_GPIO	ACPI_ENABLE_WAKE_SUS_GPIO(1)
