@@ -118,6 +118,7 @@ static struct mem_timings *setup_clock(void)
 	return mem;
 }
 
+#if CONFIG(SEPARATE_ROMSTAGE)
 void main(void)
 {
 	timestamp_init(timestamp_get());
@@ -126,10 +127,11 @@ void main(void)
 	/*
 	 * From the clocks comment below it looks like serial console won't
 	 * work in the bootblock so keep in the romstage_main flow even with
-	 * !CONFIG  SEPARATE_ROMSTAGE.
+	 * !CONFIG(SEPARATE_ROMSTAGE).
 	 */
 	romstage_main();
 }
+#endif
 
 void __noreturn romstage_main(void)
 {
