@@ -8,3 +8,6 @@
 
 /* EC ENABLE MULTIPLE DPTF PROFILES */
 #define EC_ENABLE_MULTIPLE_DPTF_PROFILES
+
+/* Enable Tablet switch */
+#define EC_ENABLE_TBMC_DEVICE
