@@ -3,8 +3,9 @@
 #include <baseboard/variants.h>
 #include <boardid.h>
 #include <device/device.h>
-#include <soc/gpio.h>
 #include <amdblocks/cpu.h>
+#include <gpio.h>
+#include <static.h>
 
 bool variant_has_pcie_wwan(void)
 {
