@@ -8,7 +8,7 @@
 void bootblock_mainboard_early_init(void)
 {
 	/* Early SuperIO setup */
-	it8772f_ac_resume_southbridge(IT8772F_SUPERIO_DEV);
+	ite_ac_resume_southbridge(IT8772F_EC_DEV);
 	ite_kill_watchdog(IT8772F_GPIO_DEV);
 	ite_enable_serial(IT8772F_SERIAL_DEV, CONFIG_TTYS0_BASE);
 
