@@ -1,10 +1,8 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
 #include <acpi/acpi.h>
-#include <boardid.h>
 #include <sar.h>
 #include <baseboard/variants.h>
-#include <delay.h>
 #include <gpio.h>
 #include <ec/google/chromeec/ec.h>
 #include <soc/intel/apollolake/chip.h>
