@@ -1,24 +1,10 @@
-/*
- * This file is part of the coreboot project.
- *
- * Copyright 2016 Google Inc.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- */
+/* SPDX-License-Identifier: GPL-2.0-only */
 
-#include <arch/acpi.h>
+#include <acpi/acpi.h>
 #include <console/console.h>
 #include <ec/ec.h>
 #include <ec/google/chromeec/ec.h>
 #include <intelblocks/lpc_lib.h>
-#include <rules.h>
 #include <variant/ec.h>
 
 static void ramstage_ec_init(void)
@@ -28,9 +14,10 @@ static void ramstage_ec_init(void)
 		.sci_events = MAINBOARD_EC_SCI_EVENTS,
 		.s3_wake_events = MAINBOARD_EC_S3_WAKE_EVENTS,
 		.s5_wake_events = MAINBOARD_EC_S5_WAKE_EVENTS,
+		.s0ix_wake_events = MAINBOARD_EC_S0IX_WAKE_EVENTS,
 	};
 
-	printk(BIOS_ERR, "mainboard: EC init\n");
+	printk(BIOS_INFO, "mainboard: EC init\n");
 
 	google_chromeec_events_init(&info, acpi_is_wakeup_s3());
 }
