@@ -13,10 +13,6 @@ void mainboard_fill_gnvs(struct global_nvs *gnvs)
 	gnvs->s3u0 = 1;
 	gnvs->s3u1 = 1;
 
-	/* Disable USB ports in S5 */
-	gnvs->s5u0 = 0;
-	gnvs->s5u1 = 0;
-
 	/* TPM Present */
 	gnvs->tpmp = 1;
 
