@@ -8,9 +8,11 @@
 
 #include <southbridge/intel/bd82x6x/pch.h>
 #include <southbridge/intel/common/gpio.h>
+#include <types.h>
 #include <vendorcode/google/chromeos/chromeos.h>
 #include "ec.h"
 #include <ec/quanta/it8518/ec.h>
+#include "onboard.h"
 
 void fill_lb_gpios(struct lb_gpios *gpios)
 {
@@ -34,7 +36,7 @@ void fill_lb_gpios(struct lb_gpios *gpios)
 
 int get_write_protect_state(void)
 {
-	return !get_gpio(7);
+	return !get_gpio(GPIO_SPI_WP);
 }
 
 int get_lid_switch(void)
@@ -47,8 +49,7 @@ int get_lid_switch(void)
  * The recovery-switch is virtual on Stout and is handled via the EC.
  * Stout recovery mode is only valid if RTC_PWR_STS is set and the EC
  * indicated the recovery keys were pressed. We use a global flag for
- * rec_mode to be used after RTC_POWER_STS has been cleared. This function
- * is complicated by romstage support, which can't use a global variable.
+ * rec_mode to be used after RTC_POWER_STS has been cleared.
  * Note, rec_mode is the only time the EC is in RO mode, otherwise, RW.
  */
 int get_recovery_mode_switch(void)
@@ -75,14 +76,7 @@ int get_recovery_mode_switch(void)
 
 static const struct cros_gpio cros_gpios[] = {
 	CROS_GPIO_REC_AH(CROS_GPIO_VIRTUAL, CROS_GPIO_DEVICE_NAME),
-	CROS_GPIO_REC_AH(CROS_GPIO_VIRTUAL, CROS_GPIO_DEVICE_NAME),
-	CROS_GPIO_WP_AL(7, CROS_GPIO_DEVICE_NAME),
+	CROS_GPIO_WP_AL(GPIO_SPI_WP, CROS_GPIO_DEVICE_NAME),
 };
 
-void mainboard_chromeos_acpi_generate(void)
-{
-	if (CONFIG(CHROMEOS_NVS) && !get_recovery_mode_switch())
-		chromeos_set_ecfw_rw();
-
-	chromeos_acpi_gpio_generate(cros_gpios, ARRAY_SIZE(cros_gpios));
-}
+DECLARE_CROS_GPIOS(cros_gpios);
