@@ -4,6 +4,7 @@
 #include <boot/coreboot_tables.h>
 #include <gpio.h>
 #include <variant/gpio.h>
+#include <types.h>
 #include <vendorcode/google/chromeos/chromeos.h>
 
 void fill_lb_gpios(struct lb_gpios *gpios)
@@ -27,8 +28,10 @@ static const struct cros_gpio cros_gpios[] = {
 	CROS_GPIO_REC_AL(CROS_GPIO_VIRTUAL, GPIO_DEVICE_NAME),
 	CROS_GPIO_WP_AL(CROS_WP_GPIO, GPIO_DEVICE_NAME),
 };
+DECLARE_CROS_GPIOS(cros_gpios);
 
-void mainboard_chromeos_acpi_generate(void)
+int get_ec_is_trusted(void)
 {
-	chromeos_acpi_gpio_generate(cros_gpios, ARRAY_SIZE(cros_gpios));
+	/* EC is trusted if not in RW. */
+	return !gpio_get(GPIO_EC_IN_RW);
 }
