@@ -4,6 +4,7 @@
 #include <device/device.h>
 #include <ec/google/chromeec/ec.h>
 #include <ec/google/chromeec/i2c_tunnel/chip.h>
+#include <static.h>
 
 #define DALBOZ_DB_HDMI 0x1
 
@@ -59,7 +60,7 @@ void variant_devtree_update(void)
 			cfg->emmc_config.timing = SD_EMMC_EMMC_HS200;
 		}
 	} else {
-		cfg->emmc_config.timing = SD_EMMC_DISABLE;
+		DEV_PTR(emmc)->enabled = 0;
 	}
 
 	update_audio_configuration();
