@@ -1,35 +1,13 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
-#include <console/console.h>
 #include <cpu/x86/smm.h>
 #include <ec/google/chromeec/smm.h>
 #include <soc/iomap.h>
-#include <soc/nvs.h>
 #include <soc/pm.h>
 #include <intelblocks/smihandler.h>
 #include "ec.h"
 #include <variant/gpio.h>
 
-int mainboard_io_trap_handler(int smif)
-{
-	switch (smif) {
-	case 0x99:
-		printk(BIOS_DEBUG, "Sample\n");
-		gnvs->smif = 0;
-		break;
-	default:
-		return 0;
-	}
-
-	/* On success, the IO Trap Handler returns 0
-	 * On failure, the IO Trap Handler returns a value != 0
-	 *
-	 * For now, we force the return value to 0 and log all traps to
-	 * see what's going on.
-	 */
-	return 1;
-}
-
 void mainboard_smi_gpi_handler(const struct gpi_status *sts)
 {
 	if (CONFIG(BOARD_INTEL_KBLRVP8))
@@ -43,9 +21,8 @@ void mainboard_smi_gpi_handler(const struct gpi_status *sts)
 void mainboard_smi_sleep(u8 slp_typ)
 {
 	if (CONFIG(EC_GOOGLE_CHROMEEC))
-		if (CONFIG(EC_GOOGLE_CHROMEEC))
-			chromeec_smi_sleep(slp_typ, MAINBOARD_EC_S3_WAKE_EVENTS,
-					MAINBOARD_EC_S5_WAKE_EVENTS);
+		chromeec_smi_sleep(slp_typ, MAINBOARD_EC_S3_WAKE_EVENTS,
+				MAINBOARD_EC_S5_WAKE_EVENTS);
 }
 
 int mainboard_smi_apmc(u8 apmc)
