@@ -8,19 +8,6 @@
 
 #define MAINBOARD_SPD_H
 
-#define SPD_LEN			256
-
-#define SPD_DRAM_TYPE		2
-#define  SPD_DRAM_DDR3		0x0b
-#define  SPD_DRAM_LPDDR3	0xf1
-#define SPD_DENSITY_BANKS	4
-#define SPD_ADDRESSING		5
-#define SPD_ORGANIZATION	7
-#define SPD_BUS_DEV_WIDTH	8
-#define SPD_PART_OFF		128
-#define  SPD_PART_LEN		18
-#define SPD_MANU_OFF		148
-
 #define HYNIX_SINGLE_CHAN	0x1
 #define SAMSUNG_SINGLE_CHAN	0x4
 #define MIC_SINGLE_CHAN		0x5
