@@ -1,11 +1,10 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
 #include <baseboard/gpio.h>
-#include <baseboard/variants.h>
 #include <bootmode.h>
 #include <boot/coreboot_tables.h>
 #include <gpio.h>
-#include <vendorcode/google/chromeos/chromeos.h>
+#include <types.h>
 
 void fill_lb_gpios(struct lb_gpios *gpios)
 {
@@ -38,11 +37,9 @@ int get_write_protect_state(void)
 	return 0;
 }
 
-void mainboard_chromeos_acpi_generate(void)
+int get_ec_is_trusted(void)
 {
-	const struct cros_gpio *gpios;
-	size_t num;
-
-	gpios = variant_cros_gpios(&num);
-	chromeos_acpi_gpio_generate(gpios, num);
+	/* Do not have a Chrome EC involved in entering recovery mode;
+	   Always return trusted. */
+	return 1;
 }
