@@ -7,7 +7,7 @@
 static void *smp_write_config_table(void *v)
 {
 	struct mp_config_table *mc;
-	struct device *riser = NULL, *firewire = NULL;
+	struct device *riser = nullptr, *firewire = nullptr;
 	int firewire_bus = 0, riser_bus = 0, isa_bus;
 
 	mc = (void *)(((char *)v) + SMP_FLOATING_TABLE_LEN);
@@ -18,7 +18,7 @@ static void *smp_write_config_table(void *v)
 
 	firewire = dev_find_device(0x104c, 0x8023, 0);
 	if (firewire) {
-		firewire_bus = firewire->bus->secondary;
+		firewire_bus = firewire->upstream->secondary;
 	}
 
 	/* If a riser card is used, this riser is detected on bus 4, so its secondary bus is the */
@@ -27,13 +27,13 @@ static void *smp_write_config_table(void *v)
 	if (!riser)
 		riser = dev_find_device(0x3388, 0x0022, 0);
 	if (riser) {
-		riser_bus = riser->link_list->secondary;
+		riser_bus = riser->downstream->secondary;
 	}
 
-	mptable_write_buses(mc, NULL, &isa_bus);
+	mptable_write_buses(mc, nullptr, &isa_bus);
 
 	/* I/O APICs:	APIC ID	Version	State		Address */
-	u8 ioapic_id = smp_write_ioapic_from_hw(mc, VIO_APIC_VADDR);
+	u8 ioapic_id = smp_write_ioapic_from_hw(mc, IO_APIC_ADDR);
 
 	/* Legacy Interrupts */
 	mptable_add_isa_interrupts(mc, isa_bus, ioapic_id, 0);
