@@ -37,7 +37,7 @@ static void mainboard_init(struct device *dev)
 	idedev = pcidev_on_root(0x1f, 1);
 	if (idedev && idedev->chip_info && dock_ultrabay_device_present()) {
 		struct southbridge_intel_i82801gx_config *config = idedev->chip_info;
-		config->ide_enable_primary = 1;
+		config->ide_enable_primary = true;
 		/* enable Ultrabay power */
 		outb(inb(0x1628) | 0x01, 0x1628);
 		ec_write(0x0c, 0x84);
@@ -48,7 +48,7 @@ static void mainboard_init(struct device *dev)
 	}
 
 	/* Set SDHCI write protect polarity "SDWPPol" */
-	sdhci_dev = dev_find_device(PCI_VENDOR_ID_RICOH, PCI_DEVICE_ID_RICOH_R5C822, 0);
+	sdhci_dev = dev_find_device(PCI_VID_RICOH, PCI_DID_RICOH_R5C822, 0);
 	if (sdhci_dev) {
 		if (pci_read_config8(sdhci_dev, 0xfa) != 0x20) {
 			/* unlock */
