@@ -2,7 +2,7 @@
 
 #include <device/device.h>
 #include <northbridge/intel/ironlake/ironlake.h>
-#include <southbridge/intel/bd82x6x/pch.h>
+#include <southbridge/intel/ibexpeak/pch.h>
 #include <ec/acpi/ec.h>
 #include <drivers/intel/gma/int15.h>
 #include <pc80/keyboard.h>
@@ -30,7 +30,7 @@ static void mainboard_enable(struct device *dev)
 	};
 
 	for (i = 0; i < 256; i++)
-		ec_write (i, dmp[i]);
+		ec_write(i, dmp[i]);
 
 	install_intel_vga_int15_handler(GMA_INT15_ACTIVE_LFP_INT_LVDS, GMA_INT15_PANEL_FIT_DEFAULT, GMA_INT15_BOOT_DISPLAY_LFP, 2);
 
