@@ -3,22 +3,14 @@
 #include <soc/pei_data.h>
 #include <soc/pei_wrapper.h>
 
-void mainboard_fill_spd_data(struct pei_data *pei_data)
+void mb_get_spd_map(struct spd_info *spdi)
 {
-	pei_data->dq_pins_interleaved = 1;
-
-	/* One DIMM slot */
-	pei_data->dimm_channel0_disabled = 2;
-	pei_data->dimm_channel1_disabled = 2;
-
-	pei_data->spd_addresses[0] = 0xa0;
-	pei_data->spd_addresses[2] = 0xa4;
+	spdi->addresses[0] = 0x50;
+	spdi->addresses[2] = 0x52;
 }
 
 void mainboard_fill_pei_data(struct pei_data *pei_data)
 {
-	pei_data->ec_present = 1;
-
 	/* P1: Right Side Port (USB2) */
 	pei_data_usb2_port(pei_data, 0, 0x0080, 1, USB_OC_PIN_SKIP, USB_PORT_BACK_PANEL);
 	/* P2: Right Side Port (USB2) */
