@@ -14,25 +14,22 @@
 #include <baseboard/variants.h>
 #include <types.h>
 
-#define TX_DWORD3	0xa8c
-
 void variant_mainboard_final(void)
 {
 	struct device *dev = NULL;
 
 	/* PIR6 register mapping for PCIe root ports
-	 * INTA#->PIRQD#, INTB#->PIRQA#, INTC#->PIRQB#, INTD#-> PIRQC#
-	 */
+	   INTA#->PIRQD#, INTB#->PIRQA#, INTC#->PIRQB#, INTD#-> PIRQC# */
 	pcr_write16(PID_ITSS, 0x314c, 0x2103);
 
 	/* Enable CLKRUN_EN for power gating LPC */
 	lpc_enable_pci_clk_cntl();
 
 	/*
-	 * Enable LPC PCE (Power Control Enable) by setting IOSF-SB port 0xD2
-	 * offset 0x341D bit3 and bit0.
-	 * Enable LPC CCE (Clock Control Enable) by setting IOSF-SB port 0xD2
-	 * offset 0x341C bit [3:0].
+	 * Enable LPC PCE (Power Control Enable) by setting IOSF-SB port 0xD2 offset 0x341D
+	 * bit3 and bit0.
+	 * Enable LPC CCE (Clock Control Enable) by setting IOSF-SB port 0xD2 offset 0x341C bit
+	 * [3:0].
 	 */
 	pcr_or32(PID_LPC, PCR_LPC_PRC, (PCR_LPC_CCE_EN | PCR_LPC_PCE_EN));
 
@@ -42,29 +39,25 @@ void variant_mainboard_final(void)
 		if (CONFIG(PCI_ALLOW_BUS_MASTER_ANY_DEVICE))
 			pci_or_config16(dev, PCI_COMMAND, PCI_COMMAND_MASTER);
 
-		/* Disable clock outputs 0-3 (CLKOUT) for upstream
-		 * XIO2001 PCIe to PCI Bridge.
-		 */
-		struct device *parent = dev->bus->dev;
+		/* Disable clock outputs 0-3 (CLKOUT) for upstream XIO2001 PCIe to PCI
+		   Bridge. */
+		struct device *parent = dev->upstream->dev;
 		if (parent && parent->device == PCI_DID_TI_XIO2001)
 			pci_write_config8(parent, 0xd8, 0x0F);
 	}
 
-	/* Disable clock outputs 2-5 (CLKOUT) for another XIO2001 PCIe to PCI
-	 * Bridge on this mainboard.
-	 */
+	/* Disable clock outputs 2-5 (CLKOUT) for another XIO2001 PCIe to PCI Bridge on this
+	   mainboard. */
 	dev = dev_find_device(PCI_VID_SIEMENS, 0x403f, 0);
 	if (dev) {
-		struct device *parent = dev->bus->dev;
+		struct device *parent = dev->upstream->dev;
 		if (parent && parent->device == PCI_DID_TI_XIO2001)
 			pci_write_config8(parent, 0xd8, 0x3c);
 	}
 
-	/* Set Full Reset Bit in Reset Control Register (I/O port CF9h).
-	 * When Bit 3 is set to 1 and then the reset button is pressed the PCH
-	 * will drive SLP_S3 active (low). SLP_S3 is then used on the mainboard
-	 * to generate the right reset timing.
-	 */
+	/* Set Full Reset Bit in Reset Control Register (I/O port CF9h). When Bit 3 is set to 1
+	   and then the reset button is pressed the PCH will drive SLP_S3 active (low). SLP_S3
+	   is then used on the mainboard to generate the right reset timing. */
 	outb(FULL_RST, RST_CNT);
 }
 
