@@ -1,6 +1,5 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
-#include <console/console.h>
 #include <device/device.h>
 #include <device/pci_def.h>
 #include <ec/starlabs/merlin/ec.h>
@@ -9,11 +8,6 @@
 #include <uuid.h>
 #include <variants.h>
 
-const char *smbios_mainboard_bios_version(void)
-{
-	return "8";
-}
-
 /* Get the Embedded Controller firmware version */
 void smbios_ec_revision(uint8_t *ec_major_revision, uint8_t *ec_minor_revision)
 {
