@@ -6,18 +6,19 @@ const u32 cim_verb_data[] = {
 	/* Realtek, ALC269VC */
 	0x10ec0269, /* Vendor ID */
 	0x15581414, /* Subsystem ID */
-	11, /* Number of entries */
+	12, /* Number of entries */
 	AZALIA_SUBVENDOR(0, 0x15581414),
+	AZALIA_RESET(1),
 	AZALIA_PIN_CFG(0, 0x12, 0x90a60140),
 	AZALIA_PIN_CFG(0, 0x14, 0x90170120),
 	AZALIA_PIN_CFG(0, 0x15, 0x02211010),
 	AZALIA_PIN_CFG(0, 0x17, 0x40000000),
 	AZALIA_PIN_CFG(0, 0x18, 0x02a11030),
-	AZALIA_PIN_CFG(0, 0x19, 0x411111f0),
-	AZALIA_PIN_CFG(0, 0x1a, 0x411111f0),
-	AZALIA_PIN_CFG(0, 0x1b, 0x411111f0),
+	AZALIA_PIN_CFG(0, 0x19, AZALIA_PIN_CFG_NC(0)),
+	AZALIA_PIN_CFG(0, 0x1a, AZALIA_PIN_CFG_NC(0)),
+	AZALIA_PIN_CFG(0, 0x1b, AZALIA_PIN_CFG_NC(0)),
 	AZALIA_PIN_CFG(0, 0x1d, 0x40f4a205),
-	AZALIA_PIN_CFG(0, 0x1e, 0x411111f0),
+	AZALIA_PIN_CFG(0, 0x1e, AZALIA_PIN_CFG_NC(0)),
 	/* Intel, KabylakeHDMI */
 	0x8086280b, /* Vendor ID */
 	0x80860101, /* Subsystem ID */
