@@ -34,8 +34,8 @@ static void i440bx_domain_read_resources(struct device *dev)
 
 	pci_domain_read_resources(dev);
 
-	pci_tolm = find_pci_tolm(dev->link_list);
-	mc_dev = dev->link_list->children;
+	pci_tolm = find_pci_tolm(dev->downstream);
+	mc_dev = dev->downstream->children;
 	if (mc_dev) {
 		unsigned long tomk, tolmk;
 		int idx;
@@ -61,15 +61,15 @@ static void i440bx_domain_read_resources(struct device *dev)
 
 		/* Report the memory regions. */
 		idx = 10;
-		ram_resource_kb(dev, idx++, 0, 640);
-		ram_resource_kb(dev, idx++, 768, tolmk - 768);
+		ram_range(dev, idx++, 0, 0xa0000);
+		ram_from_to(dev, idx++, 0xc0000, tolmk * KiB);
 	}
 }
 
 static struct device_operations pci_domain_ops = {
 	.read_resources		= i440bx_domain_read_resources,
 	.set_resources		= pci_domain_set_resources,
-	.scan_bus		= pci_domain_scan_bus,
+	.scan_bus		= pci_host_bridge_scan_bus,
 };
 
 static int get_cpu_count(void)
@@ -105,6 +105,6 @@ static void enable_dev(struct device *dev)
 }
 
 struct chip_operations northbridge_intel_i440bx_ops = {
-	CHIP_NAME("Intel 82443BX (440BX) Northbridge")
+	.name = "Intel 82443BX (440BX) Northbridge",
 	.enable_dev = enable_dev,
 };
