@@ -8,6 +8,7 @@
 #include <device/pci_def.h>
 #include <device/smbus_host.h>
 #include <console/console.h>
+#include <commonlib/console/post_codes.h>
 #include <timestamp.h>
 #include "i440bx.h"
 #include "raminit.h"
@@ -358,7 +359,7 @@ static void do_ram_command(u32 command)
 	/* Configure the RAM command. */
 	reg16 = pci_read_config16(NB, SDRAMC);
 	reg16 &= 0xff1f;		/* Clear bits 7-5. */
-	reg16 |= (u16) (command << 5);	/* Write command into bits 7-5. */
+	reg16 |= (u16)(command << 5);	/* Write command into bits 7-5. */
 	pci_write_config16(NB, SDRAMC, reg16);
 
 	/*
@@ -644,7 +645,7 @@ static void sdram_set_registers(void)
 {
 	int i, max;
 
-	PRINT_DEBUG("Northbridge prior to SDRAM init:\n");
+	PRINT_DEBUG("Northbridge %s SDRAM init:\n", "prior to");
 	DUMPNORTH();
 
 	max = ARRAY_SIZE(register_values);
@@ -712,13 +713,13 @@ static struct dimm_size spd_get_dimm_size(unsigned int device)
 	 * modules by setting them to a supported size.
 	 */
 	if (sz.side1 > 128) {
-		PRINT_DEBUG("Side1 was %dMB but only 128MB will be used.\n",
-			sz.side1);
+		PRINT_DEBUG("Side%d was %dMB but only 128MB will be used.\n",
+			1, sz.side1);
 		sz.side1 = 128;
 
 		if (sz.side2 > 128) {
-			PRINT_DEBUG("Side2 was %dMB but only 128MB will be used.\n",
-				sz.side2);
+			PRINT_DEBUG("Side%d was %dMB but only 128MB will be used.\n",
+				2, sz.side2);
 			sz.side2 = 128;
 		}
 	}
@@ -754,7 +755,6 @@ static void set_dram_row_attributes(void)
 		/* This is 440BX! We do EDO too! */
 		if (value == SPD_MEMORY_TYPE_EDO
 			|| value == SPD_MEMORY_TYPE_SDRAM) {
-
 			if (value == SPD_MEMORY_TYPE_EDO) {
 				edo = 1;
 			} else if (value == SPD_MEMORY_TYPE_SDRAM) {
@@ -763,8 +763,8 @@ static void set_dram_row_attributes(void)
 			PRINT_DEBUG("Found DIMM in slot %d\n", i);
 
 			if (edo && sd) {
-				printk(BIOS_ERR, "Mixing EDO/SDRAM unsupported!\n");
-				die("HALT\n");
+				die_with_post_code(POSTCODE_RAM_FAILURE,
+					"Mixing EDO/SDRAM unsupported!\n");
 			}
 
 			/* "DRA" is our RPS for the two rows on this DIMM. */
@@ -868,12 +868,12 @@ static void set_dram_row_attributes(void)
 				if (col == 4)
 					bpr |= 0xc0;
 			} else {
-				printk(BIOS_ERR, "# of banks of DIMM unsupported!\n");
-				die("HALT\n");
+				die_with_post_code(POSTCODE_RAM_FAILURE,
+					"# of banks of DIMM unsupported!\n");
 			}
 			if (dra == -1) {
-				printk(BIOS_ERR, "Page size not supported\n");
-				die("HALT\n");
+				die_with_post_code(POSTCODE_RAM_FAILURE,
+					"Page size not supported!\n");
 			}
 
 			/*
@@ -883,9 +883,9 @@ static void set_dram_row_attributes(void)
 			 */
 			struct dimm_size sz = spd_get_dimm_size(device);
 			if ((sz.side1 < 8)) {
-				printk(BIOS_ERR, "DIMMs smaller than 8MB per side\n"
-					  "are not supported on this NB.\n");
-				die("HALT\n");
+				die_with_post_code(POSTCODE_RAM_FAILURE,
+					"DIMMs smaller than 8MB per side "
+					"are not supported!\n");
 			}
 
 			/* Divide size by 8 to set up the DRB registers. */
@@ -918,7 +918,7 @@ static void set_dram_row_attributes(void)
 
 	/* Set paging policy register. */
 	pci_write_config8(NB, PGPOL + 1, bpr);
-	PRINT_DEBUG("PGPOL[BPR] has been set to 0x%02x\n", bpr);
+	PRINT_DEBUG("%s has been set to 0x%02x\n", "PGPOL[BPR]", bpr);
 
 	/* Set DRAM row page size register. */
 	pci_write_config16(NB, RPS, rps);
@@ -926,7 +926,7 @@ static void set_dram_row_attributes(void)
 
 	/* ### ECC */
 	pci_write_config8(NB, NBXCFG + 3, nbxecc);
-	PRINT_DEBUG("NBXECC[31:24] has been set to 0x%02x\n", nbxecc);
+	PRINT_DEBUG("%s has been set to 0x%02x\n", "NBXCFG[31:24]", nbxecc);
 
 	/* Set DRAMC[4:3] to proper memory type (EDO/SDRAM/Registered SDRAM). */
 
@@ -942,16 +942,7 @@ static void set_dram_row_attributes(void)
 	value = pci_read_config8(NB, DRAMC) & 0xe7;
 	value |= i;
 	pci_write_config8(NB, DRAMC, value);
-	PRINT_DEBUG("DRAMC has been set to 0x%02x\n", value);
-}
-
-static void sdram_set_spd_registers(void)
-{
-	/* Setup DRAM row boundary registers and other attributes. */
-	set_dram_row_attributes();
-
-	/* Setup DRAM buffer strength. */
-	set_dram_buffer_strength();
+	PRINT_DEBUG("%s has been set to 0x%02x\n", "DRAMC", value);
 }
 
 static void sdram_enable(void)
@@ -962,45 +953,44 @@ static void sdram_enable(void)
 	udelay(200);
 
 	/* 1. Apply NOP. Wait 200 clock cycles (200us should do). */
-	PRINT_DEBUG("RAM Enable 1: Apply NOP\n");
+	PRINT_DEBUG("RAM Enable %d: %s\n", 1, "Apply NOP");
 	do_ram_command(RAM_COMMAND_NOP);
 	udelay(200);
 
 	/* 2. Precharge all. Wait tRP. */
-	PRINT_DEBUG("RAM Enable 2: Precharge all\n");
+	PRINT_DEBUG("RAM Enable %d: %s\n", 2, "Precharge all");
 	do_ram_command(RAM_COMMAND_PRECHARGE);
 	udelay(1);
 
 	/* 3. Perform 8 refresh cycles. Wait tRC each time. */
-	PRINT_DEBUG("RAM Enable 3: CBR\n");
+	PRINT_DEBUG("RAM Enable %d: %s\n", 3, "CBR");
 	for (i = 0; i < 8; i++) {
 		do_ram_command(RAM_COMMAND_CBR);
 		udelay(1);
 	}
 
 	/* 4. Mode register set. Wait two memory cycles. */
-	PRINT_DEBUG("RAM Enable 4: Mode register set\n");
+	PRINT_DEBUG("RAM Enable %d: %s\n", 4, "Mode register set");
 	do_ram_command(RAM_COMMAND_MRS);
 	udelay(2);
 
 	/* 5. Normal operation. */
-	PRINT_DEBUG("RAM Enable 5: Normal operation\n");
+	PRINT_DEBUG("RAM Enable %d: %s\n", 5, "Normal operation");
 	do_ram_command(RAM_COMMAND_NORMAL);
 	udelay(1);
 
 	/* 6. Finally enable refresh. */
-	PRINT_DEBUG("RAM Enable 6: Enable refresh\n");
+	PRINT_DEBUG("RAM Enable %d: %s\n", 6, "Enable refresh");
 	pci_write_config8(NB, PMCR, 0x10);
 	spd_enable_refresh();
 	udelay(1);
 
-	PRINT_DEBUG("Northbridge following SDRAM init:\n");
+	PRINT_DEBUG("Northbridge %s SDRAM init:\n", "following");
 	DUMPNORTH();
 }
 
 /* Implemented under mainboard. */
 void __weak enable_spd(void) { }
-void __weak disable_spd(void) { }
 
 void sdram_initialize(int s3resume)
 {
@@ -1009,9 +999,16 @@ void sdram_initialize(int s3resume)
 
 	dump_spd_registers();
 	sdram_set_registers();
-	sdram_set_spd_registers();
+	/* Set up DRAM row boundary registers and other attributes. */
+	set_dram_row_attributes();
+	/* Set up DRAM buffer strength. */
+	set_dram_buffer_strength();
 	sdram_enable();
 
-	disable_spd();
+	/* Clear any errors reported during raminit. */
+	pci_write_config32(NB, EAP, 0x3);
+	pci_write_config8(NB, ERRSTS, 0x11);
+	pci_write_config8(NB, ERRSTS + 1, 0x1f);
+
 	timestamp_add_now(TS_INITRAM_END);
 }
