@@ -49,7 +49,6 @@ static int get_dimm_spd_address(struct sys_info *sysinfo, int device)
 		return sysinfo->spd_addresses[device];
 	else
 		return 0x50 + device;
-
 }
 
 static __attribute__((noinline)) void do_ram_command(u32 command)
@@ -216,7 +215,7 @@ static int sdram_capabilities_core_frequencies(void)
 static void sdram_detect_errors(struct sys_info *sysinfo)
 {
 	u8 reg8;
-	u8 do_reset = 0;
+	bool do_reset = false;
 
 	reg8 = pci_read_config8(PCI_DEV(0, 0x1f, 0), GEN_PMCON_2);
 
@@ -225,15 +224,14 @@ static void sdram_detect_errors(struct sys_info *sysinfo)
 			printk(BIOS_DEBUG, "SLP S4# Assertion Width Violation.\n");
 			/* Write back clears bit 2 */
 			pci_write_config8(PCI_DEV(0, 0x1f, 0), GEN_PMCON_2, reg8);
-			do_reset = 1;
-
+			do_reset = true;
 		}
 
 		if (reg8 & (1 << 7)) {
 			printk(BIOS_DEBUG, "DRAM initialization was interrupted.\n");
 			reg8 &= ~(1 << 7);
 			pci_write_config8(PCI_DEV(0, 0x1f, 0), GEN_PMCON_2, reg8);
-			do_reset = 1;
+			do_reset = true;
 		}
 
 		/* Set SLP_S3# Assertion Stretch Enable */
@@ -258,12 +256,12 @@ static void sdram_detect_errors(struct sys_info *sysinfo)
 		if (((sysinfo->dimm[0] != SYSINFO_DIMM_NOT_POPULATED) ||
 		     (sysinfo->dimm[1] != SYSINFO_DIMM_NOT_POPULATED)) &&
 		    !(mchbar_read8(SLFRCS) & (1 << 0))) {
-			do_reset = 1;
+			do_reset = true;
 		}
 		if (((sysinfo->dimm[2] != SYSINFO_DIMM_NOT_POPULATED) ||
 		     (sysinfo->dimm[3] != SYSINFO_DIMM_NOT_POPULATED)) &&
 		    !(mchbar_read8(SLFRCS) & (1 << 1))) {
-			do_reset = 1;
+			do_reset = true;
 		}
 	}
 
@@ -289,7 +287,6 @@ struct timings {
  */
 static void gather_common_timing(struct sys_info *sysinfo, struct timings *saved_timings)
 {
-
 	int i, j;
 	u8 raw_spd[SPD_SIZE_MAX_DDR2];
 	u8 dimm_mask = 0;
@@ -314,10 +311,10 @@ static void gather_common_timing(struct sys_info *sysinfo, struct timings *saved
 
 	printk(BIOS_DEBUG, "This mainboard supports ");
 	if (sdram_capabilities_dual_channel()) {
-		sysinfo->dual_channel = 1;
+		sysinfo->dual_channel = true;
 		printk(BIOS_DEBUG, "Dual Channel Operation.\n");
 	} else {
-		sysinfo->dual_channel = 0;
+		sysinfo->dual_channel = false;
 		printk(BIOS_DEBUG, "only Single Channel Operation.\n");
 	}
 
@@ -426,11 +423,12 @@ static void gather_common_timing(struct sys_info *sysinfo, struct timings *saved
 			die("DDR-II rank size smaller than 128MB is not supported.\n");
 
 		sysinfo->banksize[i * 2] = dimm_info.ranksize_mb / 32;
-		printk(BIOS_DEBUG, "DIMM %d side 0 = %d MB\n", i, sysinfo->banksize[i * 2] * 32);
+		printk(BIOS_DEBUG, "DIMM %d side 0 = %zu MB\n", i,
+			sysinfo->banksize[i * 2] * 32);
 		if (dimm_info.ranks == 2) {
 			sysinfo->banksize[(i * 2) + 1] =
 				dimm_info.ranksize_mb / 32;
-			printk(BIOS_DEBUG, "DIMM %d side 1 = %d MB\n",
+			printk(BIOS_DEBUG, "DIMM %d side 1 = %zu MB\n",
 				i, sysinfo->banksize[(i * 2) + 1] * 32);
 		}
 
@@ -765,7 +763,7 @@ static const u8 single_channel_slew_group_lookup[] = {
 	DQ2330, NC,      CTL3215, NC,      CLK2030, CLK2030, DQ2030, CMD3210
 };
 
-static const u32 *slew_group_lookup(int dual_channel, int index)
+static const u32 *slew_group_lookup(bool dual_channel, int index)
 {
 	const u8 *slew_group;
 	/* Dual Channel needs different tables. */
@@ -902,7 +900,8 @@ static const u8 single_channel_strength_multiplier[] = {
 static void sdram_rcomp_buffer_strength_and_slew(struct sys_info *sysinfo)
 {
 	const u8 *strength_multiplier;
-	int idx, dual_channel;
+	int idx;
+	bool dual_channel;
 
 	/* Set Strength Multipliers */
 
@@ -910,12 +909,12 @@ static void sdram_rcomp_buffer_strength_and_slew(struct sys_info *sysinfo)
 	if (sdram_capabilities_dual_channel()) {
 		printk(BIOS_DEBUG, "Programming Dual Channel RCOMP\n");
 		strength_multiplier = dual_channel_strength_multiplier;
-		dual_channel = 1;
+		dual_channel = true;
 		idx = 5 * sysinfo->dimm[0] + sysinfo->dimm[2];
 	} else {
 		printk(BIOS_DEBUG, "Programming Single Channel RCOMP\n");
 		strength_multiplier = single_channel_strength_multiplier;
-		dual_channel = 0;
+		dual_channel = false;
 		idx = 5 * sysinfo->dimm[0] + sysinfo->dimm[1];
 	}
 
@@ -1141,9 +1140,9 @@ static void sdram_enable_system_memory_io(struct sys_info *sysinfo)
 static int sdram_program_row_boundaries(struct sys_info *sysinfo)
 {
 	int i;
-	int cum0, cum1, tolud, tom, pci_mmio_size;
+	size_t cum0, cum1, tolud, tom, pci_mmio_size;
 	const struct device *dev;
-	const struct northbridge_intel_i945_config *cfg = NULL;
+	const struct northbridge_intel_i945_config *cfg = nullptr;
 
 	printk(BIOS_DEBUG, "Setting RAM size...\n");
 
@@ -1536,9 +1535,9 @@ static void sdram_set_channel_mode(struct sys_info *sysinfo)
 	     (sysinfo->banksize[4] + sysinfo->banksize[5] +
 	      sysinfo->banksize[6] + sysinfo->banksize[7]))) {
 		/* Both channels equipped with DIMMs of the same size */
-		sysinfo->interleaved = 1;
+		sysinfo->interleaved = true;
 	} else {
-		sysinfo->interleaved = 0;
+		sysinfo->interleaved = false;
 	}
 
 	reg32 = mchbar_read32(DCC);
@@ -1602,7 +1601,8 @@ static void sdram_program_pll_settings(struct sys_info *sysinfo)
 static void sdram_program_graphics_frequency(struct sys_info *sysinfo)
 {
 	u8 reg8;
-	u8 freq, second_vco, voltage;
+	u8 freq, voltage;
+	bool second_vco = false;
 
 #define CRCLK_166MHz	0x00
 #define CRCLK_200MHz	0x01
@@ -1678,10 +1678,8 @@ static void sdram_program_graphics_frequency(struct sys_info *sysinfo)
 	else
 		sysinfo->mvco4x = 0;
 
-	second_vco = 0;
-
 	if (voltage == VOLTAGE_1_50) {
-		second_vco = 1;
+		second_vco = true;
 	} else if ((i945_silicon_revision() > 0) && (freq == CRCLK_250MHz)) {
 		u16 mem = sysinfo->memory_frequency;
 		u16 fsb = sysinfo->fsb_frequency;
@@ -1689,17 +1687,14 @@ static void sdram_program_graphics_frequency(struct sys_info *sysinfo)
 		if ((fsb == 667 && mem == 533) ||
 		    (fsb == 533 && mem == 533) ||
 		    (fsb == 533 && mem == 400)) {
-			second_vco = 1;
+			second_vco = true;
 		}
 
 		if (fsb == 667 && mem == 533)
 			sysinfo->mvco4x = 1;
 	}
 
-	if (second_vco)
-		sysinfo->clkcfg_bit7 = 1;
-	else
-		sysinfo->clkcfg_bit7 = 0;
+	sysinfo->clkcfg_bit7 = second_vco;
 
 	/* Graphics Core Render Clock */
 	pci_update_config16(IGD_DEV, GCFC, ~((7 << 0) | (1 << 13)), freq);
@@ -2315,7 +2310,6 @@ static void sdram_power_management(struct sys_info *sysinfo)
 
 static void sdram_thermal_management(void)
 {
-
 	mchbar_write8(TCO1, 0);
 	mchbar_write8(TCO0, 0);
 
