@@ -87,6 +87,6 @@ static const unsigned short pci_device_ids[] = {
 
 static const struct pci_driver gma __pci_driver = {
 	.ops = &gma_func0_ops,
-	.vendor = PCI_VENDOR_ID_INTEL,
+	.vendor = PCI_VID_INTEL,
 	.devices = pci_device_ids,
 };
