@@ -56,7 +56,7 @@ void vboot_sync_ec(void)
 
 	case VB2_REQUEST_REBOOT_EC_TO_RO:
 		printk(BIOS_INFO, "EC Reboot requested. Doing cold reboot\n");
-		if (google_chromeec_reboot(0, EC_REBOOT_COLD, 0))
+		if (google_chromeec_reboot(EC_REBOOT_COLD, 0))
 			printk(BIOS_EMERG, "Failed to get EC to cold reboot\n");
 
 		halt();
@@ -65,7 +65,7 @@ void vboot_sync_ec(void)
 	/* Only for EC-EFS */
 	case VB2_REQUEST_REBOOT_EC_SWITCH_RW:
 		printk(BIOS_INFO, "Switch EC slot requested. Doing cold reboot\n");
-		if (google_chromeec_reboot(0, EC_REBOOT_COLD,
+		if (google_chromeec_reboot(EC_REBOOT_COLD,
 						EC_REBOOT_FLAG_SWITCH_RW_SLOT))
 			printk(BIOS_EMERG, "Failed to get EC to cold reboot\n");
 
@@ -186,15 +186,12 @@ static vb2_error_t ec_hash_image(enum vb2_firmware_selection select,
 /*
  * Asks the EC to protect or unprotect the specified flash region.
  */
-static vb2_error_t ec_protect_flash(enum vb2_firmware_selection select, int enable)
+static vb2_error_t ec_protect_flash(int enable)
 {
 	struct ec_response_flash_protect resp;
 	uint32_t protected_region = EC_FLASH_PROTECT_ALL_NOW;
 	const uint32_t mask = EC_FLASH_PROTECT_ALL_NOW | EC_FLASH_PROTECT_ALL_AT_BOOT;
 
-	if (select == VB_SELECT_FIRMWARE_READONLY)
-		protected_region = EC_FLASH_PROTECT_RO_NOW;
-
 	if (google_chromeec_flash_protect(mask, enable ? mask : 0, &resp) != 0)
 		return VB2_ERROR_UNKNOWN;
 
@@ -331,7 +328,7 @@ static vb2_error_t ec_update_image(enum vb2_firmware_selection select)
 	size_t image_size;
 
 	/* Un-protect the flash region */
-	rv = ec_protect_flash(select, 0);
+	rv = ec_protect_flash(0);
 	if (rv != VB2_SUCCESS)
 		return rv;
 
@@ -490,9 +487,9 @@ vb2_error_t vb2ex_ec_hash_image(enum vb2_firmware_selection select,
 /*
  * Vboot callback for EC flash protection.
  */
-vb2_error_t vb2ex_ec_protect(enum vb2_firmware_selection select)
+vb2_error_t vb2ex_ec_protect(void)
 {
-	return ec_protect_flash(select, 1);
+	return ec_protect_flash(1);
 }
 
 /*
@@ -510,7 +507,7 @@ vb2_error_t vb2ex_ec_get_expected_image_hash(enum vb2_firmware_selection select,
  */
 vb2_error_t vb2ex_ec_disable_jump(void)
 {
-	if (google_chromeec_reboot(0, EC_REBOOT_DISABLE_JUMP, 0))
+	if (google_chromeec_reboot(EC_REBOOT_DISABLE_JUMP, 0))
 		return VB2_ERROR_UNKNOWN;
 
 	return VB2_SUCCESS;
@@ -531,7 +528,7 @@ vb2_error_t vb2ex_ec_jump_to_rw(void)
 {
 	struct stopwatch sw;
 
-	if (google_chromeec_reboot(0, EC_REBOOT_JUMP_RW, 0))
+	if (google_chromeec_reboot(EC_REBOOT_JUMP_RW, 0))
 		return VB2_ERROR_UNKNOWN;
 
 	/* Give the EC 3 seconds to sysjump */
