@@ -4,11 +4,13 @@
 #include <amdblocks/ioapic.h>
 #include <amdblocks/memmap.h>
 #include <assert.h>
+#include <console/console.h>
 #include <console/uart.h>
 #include <device/device.h>
 #include <fsp/api.h>
 #include <soc/platform_descriptors.h>
 #include <soc/pci_devs.h>
+#include <static.h>
 #include <string.h>
 #include <types.h>
 #include <vendorcode/amd/fsp/cezanne/FspUsb.h>
@@ -153,12 +155,18 @@ void platform_fsp_memory_init_params_cb(FSPM_UPD *mupd, uint32_t version)
 		/* devicetree config is const, use local copy */
 		static struct usb_phy_config lcl_usb_phy;
 		lcl_usb_phy = config->usb_phy;
-		mcfg->usb_phy = &lcl_usb_phy;
-		mcfg->usb_phy->Version_Major = FSP_USB_STRUCT_MAJOR_VERSION;
-		mcfg->usb_phy->Version_Minor = FSP_USB_STRUCT_MINOR_VERSION;
-		mcfg->usb_phy->TableLength = sizeof(struct usb_phy_config);
+		lcl_usb_phy.Version_Major = FSP_USB_STRUCT_MAJOR_VERSION;
+		lcl_usb_phy.Version_Minor = FSP_USB_STRUCT_MINOR_VERSION;
+		lcl_usb_phy.TableLength = sizeof(struct usb_phy_config);
+		if ((uintptr_t)&lcl_usb_phy <= UINT32_MAX) {
+			mcfg->usb_phy_ptr = (uint32_t)(uintptr_t)&lcl_usb_phy;
+		} else {
+			printk(BIOS_ERR, "USB PHY config struct above 4GB; can't pass USB PHY "
+					 "configuration to 32 bit FSP.\n");
+			mcfg->usb_phy_ptr = 0;
+		}
 	} else {
-		mcfg->usb_phy = NULL;
+		mcfg->usb_phy_ptr = 0;
 	}
 
 	if (config->edp_phy_override) {
