@@ -35,17 +35,12 @@ void set_cstate_io_addr(void)
 	wrmsr(MSR_CSTATE_ADDRESS, cst_addr);
 }
 
-static uint32_t get_sme_reserved_address_bits(void)
+/* Number of most significant physical address bits reserved for secure memory encryption */
+unsigned int get_reserved_phys_addr_bits(void)
 {
-	if (rdmsr(SYSCFG_MSR).raw & SYSCFG_MSR_SMEE)
-		return (cpuid_ebx(CPUID_EBX_MEM_ENCRYPT) &
-			CPUID_EBX_MEM_ENCRYPT_ADDR_BITS_MASK) >>
-			CPUID_EBX_MEM_ENCRYPT_ADDR_BITS_SHIFT;
-	else
+	if (!(rdmsr(SYSCFG_MSR).raw & SYSCFG_MSR_SMEE))
 		return 0;
-}
 
-uint32_t get_usable_physical_address_bits(void)
-{
-	return cpu_phys_address_size() - get_sme_reserved_address_bits();
+	return (cpuid_ebx(CPUID_EBX_MEM_ENCRYPT) & CPUID_EBX_MEM_ENCRYPT_ADDR_BITS_MASK) >>
+			CPUID_EBX_MEM_ENCRYPT_ADDR_BITS_SHIFT;
 }
