@@ -5,8 +5,11 @@
 
 #include <acpi/acpi.h>
 #include <amdblocks/gpio.h>
+#include <device/device.h>
 #include <types.h>
 
+#define ACPI_SCI_IRQ 9
+
 /* ACPI MMIO registers 0xfed80800 */
 #define MMIO_ACPI_PM1_EVT_BLK		0x00
 #define  MMIO_ACPI_PM1_STS		0x00
@@ -15,7 +18,6 @@
 	  /* sleep types defined in include/acpi/acpi.h */
 #define   ACPI_PM1_CNT_SCIEN		BIT(0)
 #define MMIO_ACPI_PM_TMR_BLK		0x08
-#define MMIO_ACPI_CPU_CONTROL		0x0c
 #define MMIO_ACPI_GPE0_BLK		0x14
 #define  MMIO_ACPI_GPE0_STS		0x14
 #define  MMIO_ACPI_GPE0_EN		0x18
@@ -50,16 +52,18 @@ struct chipset_power_state {
 	struct gpio_wake_state gpio_state;
 };
 
+unsigned long soc_acpi_write_tables(const struct device *device, unsigned long current,
+				    acpi_rsdp_t *rsdp);
+
+unsigned long acpi_add_fsp_tables(unsigned long current, acpi_rsdp_t *rsdp);
+unsigned long acpi_add_opensil_tables(unsigned long current, acpi_rsdp_t *rsdp);
+
 unsigned long southbridge_write_acpi_tables(const struct device *device, unsigned long current,
 					    struct acpi_rsdp *rsdp);
 
-unsigned long acpi_fill_madt_irqoverride(unsigned long current);
-void acpi_fill_root_complex_tom(const struct device *device);
-
-uintptr_t add_agesa_fsp_acpi_table(guid_t guid, const char *name, acpi_rsdp_t *rsdp,
-				   uintptr_t current);
-
 void acpi_log_events(const struct chipset_power_state *ps);
-unsigned long acpi_fill_ivrs(acpi_ivrs_t *ivrs, unsigned long current);
+
+unsigned long acpi_add_crat_table(unsigned long current, acpi_rsdp_t *rsdp);
+unsigned long acpi_add_ivrs_table(unsigned long current, acpi_rsdp_t *rsdp);
 
 #endif /* AMD_BLOCK_ACPI_H */
