@@ -13,15 +13,15 @@
 
 #define BROADCAST_FABRIC_ID		0xff
 
-/* Index of IOAPIC resource associated with IOMMU */
-#define IOMMU_IOAPIC_IDX                0x20000120
-
 #define DF_MMIO_REG_OFFSET(instance) ((instance) * DF_MMIO_REG_SET_SIZE * sizeof(uint32_t))
 
 /* The number of data fabric MMIO registers is SoC-specific */
 #define DF_MMIO_BASE(reg)	(DF_MMIO_BASE0 + DF_MMIO_REG_OFFSET(reg))
 #define DF_MMIO_LIMIT(reg)	(DF_MMIO_LIMIT0 + DF_MMIO_REG_OFFSET(reg))
 #define DF_MMIO_CONTROL(reg)	(DF_MMIO_CTRL0 + DF_MMIO_REG_OFFSET(reg))
+#if CONFIG(SOC_AMD_COMMON_BLOCK_DATA_FABRIC_EXTENDED_MMIO)
+#define DF_MMIO_ADDR_EXT(reg)	(DF_MMIO_ADDR_EXT0 + DF_MMIO_REG_OFFSET(reg))
+#endif
 
 /* Last 12GB of the usable address space are reserved */
 #define DF_RESERVED_TOP_12GB_MMIO_SIZE		(12ULL * GiB)
@@ -44,17 +44,15 @@ void data_fabric_broadcast_write32(uint16_t fn_reg, uint32_t data)
 }
 
 void data_fabric_print_mmio_conf(void);
-void data_fabric_disable_mmio_reg(unsigned int reg);
-int data_fabric_find_unused_mmio_reg(void);
-void data_fabric_set_mmio_np(void);
 
-enum cb_err data_fabric_get_pci_bus_numbers(struct device *domain, uint8_t *first_bus,
-					    uint8_t *last_bus);
+enum cb_err data_fabric_get_pci_bus_numbers(struct device *domain, uint8_t *segment_group,
+					    uint8_t *first_bus, uint8_t *last_bus);
+
+void data_fabric_get_mmio_base_size(unsigned int reg, resource_t *mmio_base,
+				    resource_t *mmio_limit);
 
 /* Inform the resource allocator about the usable IO and MMIO regions and PCI bus numbers */
 void amd_pci_domain_read_resources(struct device *domain);
 void amd_pci_domain_scan_bus(struct device *domain);
 
-void amd_pci_domain_fill_ssdt(const struct device *domain);
-
 #endif /* AMD_BLOCK_DATA_FABRIC_H */
