@@ -7,4 +7,7 @@
 #define FCH_IOAPIC_ID		0
 #define GNB_IOAPIC_ID		1
 
+/* Index of IOAPIC resource associated with IOMMU */
+#define IOMMU_IOAPIC_IDX                0x20000120
+
 #endif /* AMD_BLOCK_IOAPIC_H */
