@@ -57,6 +57,12 @@ int psp_notify_dram(void);
 
 int psp_notify_smm(void);
 
+#if (CONFIG(SOC_AMD_COMMON_BLOCK_PSP_SMI))
+void psp_smi_handler(void);
+#else
+static inline void psp_smi_handler(void) {}
+#endif
+
 /*
  * type: identical to the corresponding PSP command, e.g. pass
  *       MBOX_BIOS_CMD_SMU_FW2 to load SMU FW2 blob.
@@ -71,7 +77,7 @@ enum psp_blob_type {
  * Notify PSP that the system is entering a sleep state.  sleep_state uses the
  * same definition as Pm1Cnt[SlpTyp], typically 0, 1, 3, 4, 5.
  */
-void psp_notify_sx_info(u8 sleep_type);
+void psp_notify_sx_info(uint8_t sleep_type);
 
 int psp_load_named_blob(enum psp_blob_type type, const char *name);
 
