@@ -70,10 +70,17 @@ enum spi100_speed {
 #define SPI100_HOST_PREF_CONFIG		0x2c
 #define   SPI_RD4DW_EN_HOST		BIT(15)
 
+#define SPI_ROM_PAGE			0x5c
+
 #define SPI_FIFO			0x80
 #define SPI_FIFO_LAST_BYTE		0xc6 /* 0xc7 for Cezanne */
 #define SPI_FIFO_DEPTH			(SPI_FIFO_LAST_BYTE - SPI_FIFO + 1)
 
+#define SPI_MISC_CNTRL			0xfc
+/* AMD has re-purposed this unused SPI controller register bit as a semaphore to synchronize
+   access to the SPI controller between SMM and non-SMM software/OS driver. */
+#define   SPI_SEMAPHORE_DRIVER_LOCKED	BIT(4)
+
 struct spi_config {
 	/*
 	 * Default values if not overridden by mainboard:
@@ -118,7 +125,7 @@ void spi_write16(uint8_t reg, uint16_t val);
 void spi_write32(uint8_t reg, uint32_t val);
 
 void fch_spi_config_modes(void);
-void mainboard_spi_fast_speed_override(uint8_t *fast_speed);
+void mainboard_spi_cfg_override(uint8_t *fast_speed, uint8_t *read_mode);
 
 /* Ensure you hold the mutex when performing SPI transactions */
 extern struct thread_mutex spi_hw_mutex;
