@@ -4,6 +4,7 @@
 #include <amdblocks/acpi.h>
 #include <console/console.h>
 #include <fsp/util.h>
+#include <FspGuids.h>
 #include <string.h>
 #include <types.h>
 
@@ -15,15 +16,15 @@ struct amd_fsp_acpi_hob_info {
 	uint16_t hob_payload[0xffc8]; /* maximum payload size */
 } __packed;
 
-uintptr_t add_agesa_fsp_acpi_table(guid_t guid, const char *name, acpi_rsdp_t *rsdp,
-				   uintptr_t current)
+static unsigned long add_agesa_fsp_acpi_table(guid_t guid, const char *name, acpi_rsdp_t *rsdp,
+					      unsigned long current)
 {
 	const struct amd_fsp_acpi_hob_info *data;
 	void *table = (void *)current;
 	size_t hob_size;
 
 	data = fsp_find_extension_hob_by_guid(guid.b, &hob_size);
-	if (!data) {
+	if (data == NULL) {
 		printk(BIOS_ERR, "AGESA %s ACPI table was not found.\n", name);
 		return current;
 	}
@@ -44,3 +45,12 @@ uintptr_t add_agesa_fsp_acpi_table(guid_t guid, const char *name, acpi_rsdp_t *r
 
 	return current;
 }
+
+unsigned long acpi_add_fsp_tables(unsigned long current, acpi_rsdp_t *rsdp)
+{
+	/* add ALIB SSDT from HOB */
+	current = acpi_align_current(current);
+	current = add_agesa_fsp_acpi_table(AMD_FSP_ACPI_ALIB_HOB_GUID, "ALIB", rsdp, current);
+
+	return current;
+}
