@@ -3,6 +3,12 @@
 #include <security/vboot/vbnv.h>
 #include <pc80/mc146818rtc.h>
 
+void vbnv_platform_init_cmos(void)
+{
+	/* The 0 argument tells cmos_init not to update CMOS unless it is invalid. */
+	cmos_init(0);
+}
+
 int vbnv_cmos_failed(void)
 {
 	/* If CMOS power has failed, the century will be set to 0xff */
