@@ -1,9 +1,8 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
 #include <bootblock_common.h>
-#include <console/console.h>
 #include <cpu/x86/tsc.h>
-#include <soc/psp_transfer.h>
+#include <psp_verstage/psp_transfer.h>
 #include <symbols.h>
 #include <timestamp.h>
 #include <types.h>
@@ -54,8 +53,8 @@ void boot_with_psp_timestamp(uint64_t base_timestamp)
 		 * part of coreboot uses the TSC tick time as granularity, so this needs to be
 		 * converted.
 		 */
-		tse->entry_stamp += timestamp_from_usec(psp_ts_table->base_time) +
-			base_timestamp;
+		tse->entry_stamp = timestamp_from_usec(psp_ts_table->base_time +
+						       tse->entry_stamp) + base_timestamp;
 	}
 
 	bootblock_main_with_timestamp(base_timestamp, psp_ts_table->entries,
