@@ -7,6 +7,7 @@
 #include <soc/pci_devs.h>
 #include <soc/platform_descriptors.h>
 #include <soc/soc_util.h>
+#include <static.h>
 #include <fsp/api.h>
 #include "chip.h"
 
@@ -56,6 +57,11 @@ static void fsps_update_emmc_config(FSP_S_CONFIG *scfg,
 		break;
 	}
 
+	/* Make sure that the FSP knows that the EMMC controller should be disabled when the
+	   corresponding MMIO device is disabled */
+	if (!is_dev_enabled(DEV_PTR(emmc)))
+		val = SD_DISABLE;
+
 	scfg->emmc0_mode = val;
 	scfg->emmc0_sdr104_hs400_driver_strength =
 		cfg->emmc_config.sdr104_hs400_driver_strength;
