@@ -3,7 +3,7 @@
 #ifndef AMD_PICASSO_LPC_H
 #define AMD_PICASSO_LPC_H
 
-#define SPIROM_BASE_ADDRESS_REGISTER	0xa0
+#define SPI_BASE_ADDRESS_REGISTER	0xa0
 #define   SPI_BASE_ALIGNMENT		BIT(8)
 #define   SPI_BASE_RESERVED		(BIT(5) | BIT(6) | BIT(7))
 #define   PSP_SPI_MMIO_SEL		BIT(4)
