@@ -3,6 +3,7 @@
 #include <acpi/acpi.h>
 #include <amdblocks/acpi.h>
 #include <amdblocks/acpimmio.h>
+#include <amdblocks/psp.h>
 #include <amdblocks/smi.h>
 #include <amdblocks/smm.h>
 #include <arch/hlt.h>
@@ -15,12 +16,17 @@
 #include <soc/southbridge.h>
 #include <types.h>
 
-static void fch_apmc_smi_handler(void)
+/*
+ * stoneyridge does not implement the APM_CNT_SMMINFO handler,
+ * so it needs a special version
+ */
+static void stoneyridge_fch_apmc_smi_handler(void)
 {
-	const uint8_t cmd = inb(pm_acpi_smi_cmd_port());
+	const uint8_t cmd = apm_get_apmc();
 
 	switch (cmd) {
 	case APM_CNT_ACPI_ENABLE:
+		acpi_clear_pm_gpe_status();
 		acpi_enable_sci();
 		break;
 	case APM_CNT_ACPI_DISABLE:
@@ -124,18 +130,14 @@ static void fch_slp_typ_handler(void)
 	}
 }
 
-int southbridge_io_trap_handler(int smif)
-{
-	return 0;
-}
-
 /*
  * Table of functions supported in the SMI handler.  Note that SMI source setup
  * in southbridge.c is unrelated to this list.
  */
 static const struct smi_sources_t smi_sources[] = {
-	{ .type = SMITYPE_SMI_CMD_PORT, .handler = fch_apmc_smi_handler },
+	{ .type = SMITYPE_SMI_CMD_PORT, .handler = stoneyridge_fch_apmc_smi_handler },
 	{ .type = SMITYPE_SLP_TYP, .handler = fch_slp_typ_handler},
+	{ .type = SMITYPE_PSP, .handler = psp_smi_handler },
 };
 
 void *get_smi_source_handler(int source)
