@@ -11,6 +11,7 @@
 #include <device/pci_ids.h>
 #include <cpu/x86/mp.h>
 #include <cpu/x86/msr.h>
+#include <cpu/intel/microcode.h>
 #include <cpu/intel/smm_reloc.h>
 #include <cpu/intel/turbo.h>
 #include <cpu/intel/common/common.h>
@@ -23,6 +24,7 @@
 #include <soc/msr.h>
 #include <soc/pci_devs.h>
 #include <soc/soc_chip.h>
+#include <static.h>
 #include <types.h>
 
 enum alderlake_model {
@@ -99,12 +101,6 @@ enum core_type get_soc_cpu_type(void)
 		return CPUID_CORE_TYPE_INTEL_CORE;
 }
 
-void soc_get_scaling_factor(u16 *big_core_scal_factor, u16 *small_core_scal_factor)
-{
-	*big_core_scal_factor = 127;
-	*small_core_scal_factor = 100;
-}
-
 bool soc_is_nominal_freq_supported(void)
 {
 	return true;
@@ -129,6 +125,9 @@ void soc_core_init(struct device *cpu)
 	/* Enable Direct Cache Access */
 	configure_dca_cap();
 
+	/* Set core type in struct cpu_info */
+	set_dev_core_type();
+
 	/* Set energy policy.  The "normal" EPB (6) is not suitable for Alder
 	 * Lake or Raptor Lake CPUs, as this results in higher uncore power. */
 	set_energy_perf_bias(7);
@@ -194,7 +193,7 @@ static const struct mp_ops mp_ops = {
 	.post_mp_init = post_mp_init,
 };
 
-void soc_init_cpus(struct bus *cpu_bus)
+void mp_init_cpus(struct bus *cpu_bus)
 {
 	/* TODO: Handle mp_init_with_smm failure? */
 	mp_init_with_smm(cpu_bus, &mp_ops);
@@ -243,12 +242,41 @@ enum adl_cpu_type get_adl_cpu_type(void)
 		PCI_DID_INTEL_ADL_N_ID_2,
 		PCI_DID_INTEL_ADL_N_ID_3,
 		PCI_DID_INTEL_ADL_N_ID_4,
+		PCI_DID_INTEL_ADL_N_ID_5,
+		PCI_DID_INTEL_ADL_N_ID_6,
+		PCI_DID_INTEL_ADL_N_ID_7,
+		PCI_DID_INTEL_ADL_N_ID_8,
+		PCI_DID_INTEL_ADL_N_ID_9,
+	};
+
+	const uint16_t rpl_hx_mch_ids[] = {
+		PCI_DID_INTEL_RPL_HX_ID_1,
+		PCI_DID_INTEL_RPL_HX_ID_2,
+		PCI_DID_INTEL_RPL_HX_ID_3,
+		PCI_DID_INTEL_RPL_HX_ID_4,
+		PCI_DID_INTEL_RPL_HX_ID_5,
+		PCI_DID_INTEL_RPL_HX_ID_6,
+		PCI_DID_INTEL_RPL_HX_ID_7,
+		PCI_DID_INTEL_RPL_HX_ID_8,
+	};
+
+	const uint16_t rpl_s_mch_ids[] = {
+		PCI_DID_INTEL_RPL_S_ID_1,
+		PCI_DID_INTEL_RPL_S_ID_2,
+		PCI_DID_INTEL_RPL_S_ID_3,
+		PCI_DID_INTEL_RPL_S_ID_4,
+		PCI_DID_INTEL_RPL_S_ID_5
 	};
 
 	const uint16_t rpl_p_mch_ids[] = {
 		PCI_DID_INTEL_RPL_P_ID_1,
 		PCI_DID_INTEL_RPL_P_ID_2,
 		PCI_DID_INTEL_RPL_P_ID_3,
+		PCI_DID_INTEL_RPL_P_ID_4,
+		PCI_DID_INTEL_RPL_P_ID_5,
+		PCI_DID_INTEL_RPL_P_ID_6,
+		PCI_DID_INTEL_RPL_P_ID_7,
+		PCI_DID_INTEL_RPL_P_ID_8,
 	};
 
 	const uint16_t mchid = pci_s_read_config16(PCI_DEV(0, PCI_SLOT(SA_DEVFN_ROOT),
@@ -270,11 +298,21 @@ enum adl_cpu_type get_adl_cpu_type(void)
 			return ADL_S;
 	}
 
+	for (size_t i = 0; i < ARRAY_SIZE(rpl_s_mch_ids); i++) {
+		if (rpl_s_mch_ids[i] == mchid)
+			return RPL_S;
+	}
+
 	for (size_t i = 0; i < ARRAY_SIZE(adl_n_mch_ids); i++) {
 		if (adl_n_mch_ids[i] == mchid)
 			return ADL_N;
 	}
 
+	for (size_t i = 0; i < ARRAY_SIZE(rpl_hx_mch_ids); i++) {
+		if (rpl_hx_mch_ids[i] == mchid)
+			return RPL_HX;
+	}
+
 	for (size_t i = 0; i < ARRAY_SIZE(rpl_p_mch_ids); i++) {
 		if (rpl_p_mch_ids[i] == mchid)
 			return RPL_P;
@@ -293,9 +331,32 @@ uint8_t get_supported_lpm_mask(void)
 	case RPL_P:
 		return LPM_S0i2_0 | LPM_S0i3_0;
 	case ADL_S:
+	case RPL_S:
+	case RPL_HX:
 		return LPM_S0i2_0 | LPM_S0i2_1;
 	default:
 		printk(BIOS_ERR, "Unknown ADL CPU type: %d\n", type);
 		return 0;
 	}
 }
+
+int soc_skip_ucode_update(u32 current_patch_id, u32 new_patch_id)
+{
+	if (!CONFIG(CHROMEOS))
+		return 0;
+	/*
+	 * Locked RO Descriptor Implications:
+	 *
+	 * - A locked descriptor signals the RO binary is fixed; the FIT will load the
+	 *   RO's microcode during system reset.
+	 * - Attempts to load newer microcode from the RW CBFS will cause a boot-time
+	 *   delay (~60ms, core-dependent), as the microcode must be reloaded on BSP+APs.
+	 * - The kernel can load microcode updates without impacting AP FW boot time.
+	 * - Skipping RW CBFS microcode loading is low-risk when the RO is locked,
+	 *   prioritizing fast boot times.
+	 */
+	if (CONFIG(LOCK_MANAGEMENT_ENGINE) && current_patch_id)
+		return 1;
+
+	return 0;
+}
