@@ -25,7 +25,9 @@ enum adl_cpu_type {
 	ADL_N,
 	ADL_P,
 	ADL_S,
+	RPL_HX,
 	RPL_P,
+	RPL_S,
 };
 
 enum adl_cpu_type get_adl_cpu_type(void);
