@@ -22,6 +22,6 @@
 #define R_SCS_PCR_5820		0x5820
 #define R_SCS_PCR_5C20		0x5C20
 #define R_SCS_PCR_1078		0x1078
-#define R_PMC_PWRM_LTR_IGN	0x1B0C
 
+#define R_PMC_PWRM_LTR_IGN	0x1b0c
 #endif
