@@ -54,8 +54,8 @@ static const struct soc_mem_cfg soc_mem_cfg[] = {
 			 * configuration.
 			 */
 			.half_channel = BIT(0),
-			/* In mixed topologies, channel 1 is always memory-down. */
-			.mixed_topo = BIT(1),
+			/* In mixed topologies, either channel 0 or 1 can be memory-down. */
+			.mixed_topo = BIT(0) | BIT(1),
 		},
 	},
 	[MEM_TYPE_DDR5] = {
@@ -70,8 +70,8 @@ static const struct soc_mem_cfg soc_mem_cfg[] = {
 			 * configuration.
 			 */
 			.half_channel = BIT(0),
-			/* In mixed topologies, channel 1 is always memory-down. */
-			.mixed_topo = BIT(1),
+			/* In mixed topologies, either channel 0 or 1 can be memory-down. */
+			.mixed_topo = BIT(0) | BIT(1),
 		},
 	},
 	[MEM_TYPE_LP4X] = {
@@ -233,6 +233,39 @@ static void ddr5_fill_dimm_module_info(FSP_M_CONFIG *mem_cfg, const struct mb_cf
 	mem_init_dqs_upds(mem_cfg, NULL, mb_cfg, true);
 }
 
+/*
+ * A memory channel will be disabled if corresponding bit in
+ * ch_disable_mask is set.
+ */
+static void mem_init_override_channel_mask(FSP_M_CONFIG *mem_cfg)
+{
+	uint8_t *disable_channel_upds[MRC_CHANNELS] = {
+		&mem_cfg->DisableMc0Ch0,
+		&mem_cfg->DisableMc0Ch1,
+		&mem_cfg->DisableMc0Ch2,
+		&mem_cfg->DisableMc0Ch3,
+		&mem_cfg->DisableMc1Ch0,
+		&mem_cfg->DisableMc1Ch1,
+		&mem_cfg->DisableMc1Ch2,
+		&mem_cfg->DisableMc1Ch3,
+	};
+
+	uint8_t ch_disable_mask = mb_get_channel_disable_mask();
+	if (ch_disable_mask == 0)
+		return;
+
+	/* Mc0Ch0 cannot be disabled */
+	if (ch_disable_mask & BIT(0)) {
+		printk(BIOS_ERR, "Cannot disable the first memory channel (Mc0Ch0).\n");
+		return;
+	}
+
+	for (size_t ch = 0; ch < MRC_CHANNELS; ch++) {
+		if (ch_disable_mask & BIT(ch))
+			*disable_channel_upds[ch] = 1;
+	}
+}
+
 void memcfg_init(FSPM_UPD *memupd, const struct mb_cfg *mb_cfg,
 		 const struct mem_spd *spd_info, bool half_populated)
 {
@@ -240,6 +273,9 @@ void memcfg_init(FSPM_UPD *memupd, const struct mb_cfg *mb_cfg,
 	bool dq_dqs_auto_detect = false;
 	FSP_M_CONFIG *mem_cfg = &memupd->FspmConfig;
 
+#if CONFIG(SOC_INTEL_RAPTORLAKE) && !CONFIG(FSP_USE_REPO)
+	mem_cfg->CsPiStartHighinEct = mb_cfg->cs_pi_start_high_in_ect;
+#endif
 	mem_cfg->ECT = mb_cfg->ect;
 	mem_cfg->UserBd = mb_cfg->UserBd;
 	set_rcomp_config(mem_cfg, mb_cfg);
@@ -280,6 +316,7 @@ void memcfg_init(FSPM_UPD *memupd, const struct mb_cfg *mb_cfg,
 	mem_populate_channel_data(memupd, &soc_mem_cfg[mb_cfg->type], spd_info, half_populated,
 			&data);
 	mem_init_spd_upds(mem_cfg, &data);
+	mem_init_override_channel_mask(mem_cfg);
 	mem_init_dq_upds(mem_cfg, &data, mb_cfg, dq_dqs_auto_detect);
 	mem_init_dqs_upds(mem_cfg, &data, mb_cfg, dq_dqs_auto_detect);
 }
