@@ -13,6 +13,7 @@
 #include <cpu/x86/mtrr.h>
 #include <cpu/x86/smm.h>
 #include <cpu/intel/em64t100_save_state.h>
+#include <cpu/intel/microcode.h>
 #include <cpu/intel/smm_reloc.h>
 #include <device/device.h>
 #include <device/pci.h>
@@ -80,6 +81,9 @@ void soc_core_init(struct device *cpu)
 
 	set_aesni_lock();
 
+	/* Set virtualization based on Kconfig option */
+	set_vmx_and_lock();
+
 	/*
 	 * Enable ACPI PM timer emulation, which also lets microcode know
 	 * location of ACPI_BASE_ADDRESS. This also enables other features
@@ -110,13 +114,13 @@ static struct device_operations cpu_dev_ops = {
 };
 
 static const struct cpu_device_id cpu_table[] = {
-	{ X86_VENDOR_INTEL, CPUID_APOLLOLAKE_A0 },
-	{ X86_VENDOR_INTEL, CPUID_APOLLOLAKE_B0 },
-	{ X86_VENDOR_INTEL, CPUID_APOLLOLAKE_E0 },
-	{ X86_VENDOR_INTEL, CPUID_GLK_A0 },
-	{ X86_VENDOR_INTEL, CPUID_GLK_B0 },
-	{ X86_VENDOR_INTEL, CPUID_GLK_R0 },
-	{ 0, 0 },
+	{ X86_VENDOR_INTEL, CPUID_APOLLOLAKE_A0, CPUID_EXACT_MATCH_MASK },
+	{ X86_VENDOR_INTEL, CPUID_APOLLOLAKE_B0, CPUID_EXACT_MATCH_MASK },
+	{ X86_VENDOR_INTEL, CPUID_APOLLOLAKE_E0, CPUID_EXACT_MATCH_MASK },
+	{ X86_VENDOR_INTEL, CPUID_GLK_A0, CPUID_EXACT_MATCH_MASK },
+	{ X86_VENDOR_INTEL, CPUID_GLK_B0, CPUID_EXACT_MATCH_MASK },
+	{ X86_VENDOR_INTEL, CPUID_GLK_R0, CPUID_EXACT_MATCH_MASK },
+	CPU_TABLE_END
 };
 
 static const struct cpu_driver driver __cpu_driver = {
@@ -161,7 +165,6 @@ static void pre_mp_init(void)
 	}
 	x86_setup_mtrrs_with_detect();
 	x86_mtrr_check();
-
 }
 
 #if !CONFIG(SOC_INTEL_COMMON_BLOCK_CPU_MPINIT)
@@ -262,21 +265,41 @@ static const struct mp_ops mp_ops = {
 	.post_mp_init = post_mp_init,
 };
 
-void soc_init_cpus(struct bus *cpu_bus)
+void mp_init_cpus(struct bus *cpu_bus)
 {
 	/* Clear for take-off */
 	/* TODO: Handle mp_init_with_smm failure? */
 	mp_init_with_smm(cpu_bus, &mp_ops);
-}
 
-void apollolake_init_cpus(struct device *dev)
-{
+	/* MTRR setup happens later, so we're done here. */
 	if (CONFIG(SOC_INTEL_COMMON_BLOCK_CPU_MPINIT))
 		return;
-	soc_init_cpus(dev->link_list);
 
 	/* Temporarily cache the memory-mapped boot media. */
 	if (CONFIG(BOOT_DEVICE_MEMORY_MAPPED) &&
 		CONFIG(BOOT_DEVICE_SPI_FLASH))
 		fast_spi_cache_bios_region();
 }
+
+#if CONFIG(SOC_INTEL_GEMINILAKE)
+int soc_skip_ucode_update(u32 current_patch_id, u32 new_patch_id)
+{
+	/*
+	 * If PRMRR/SGX is supported the FIT microcode load will set the msr
+	 * 0x08b with the Patch revision id one less than the id in the
+	 * microcode binary. The PRMRR support is indicated in the MSR
+	 * MTRRCAP[12]. If SGX is not enabled, check and avoid reloading the
+	 * same microcode during CPU initialization. If SGX is enabled, as
+	 * part of SGX BIOS initialization steps, the same microcode needs to
+	 * be reloaded after the core PRMRR MSRs are programmed.
+	 */
+	const msr_t mtrr_cap = rdmsr(MTRR_CAP_MSR);
+	if (mtrr_cap.lo & MTRR_CAP_PRMRR) {
+		const msr_t prmrr_phys_base = rdmsr(MSR_PRMRR_PHYS_BASE);
+		if (prmrr_phys_base.raw) {
+			return 0;
+		}
+	}
+	return current_patch_id == new_patch_id - 1;
+}
+#endif
