@@ -9,7 +9,6 @@
 #include <console/console.h>
 #include <device/device.h>
 #include <device/pci.h>
-#include <device/pci_def.h>
 #include <intelblocks/msr.h>
 #include <intelblocks/pmclib.h>
 #include <intelblocks/rtc.h>
@@ -20,6 +19,7 @@
 #include <soc/pm.h>
 #include <soc/smbus.h>
 #include <security/vboot/vbnv.h>
+#include <static.h>
 
 #include "chip.h"
 
@@ -56,7 +56,7 @@ const char *const *soc_smi_sts_array(size_t *a)
 		[SERIRQ_SMI_STS_BIT] = "SERIRQ",
 		[SMBUS_SMI_STS_BIT] = "SMBUS_SMI",
 		[XHCI_SMI_STS_BIT] = "XHCI",
-		[SCS_SMI_STS_BIT] = "HOST_SMBUS",
+		[HSMBUS_SMI_STS_BIT] = "HOST_SMBUS",
 		[SCS_SMI_STS_BIT] = "SCS",
 		[PCI_EXP_SMI_STS_BIT] = "PCI_EXP_SMI",
 		[SCC2_SMI_STS_BIT] = "SCC2",
@@ -133,9 +133,18 @@ void soc_clear_pm_registers(uintptr_t pmc_bar)
 {
 	uint32_t gen_pmcon1;
 
-	gen_pmcon1 = read32((void *)(pmc_bar + GEN_PMCON1));
+	gen_pmcon1 = read32p(pmc_bar + GEN_PMCON1);
 	/* Clear the status bits. The RPS field is cleared on a 0 write. */
-	write32((void *)(pmc_bar + GEN_PMCON1), gen_pmcon1 & ~RPS);
+	write32p(pmc_bar + GEN_PMCON1, gen_pmcon1 & ~RPS);
+}
+
+static void gpe0_different_values(const struct soc_intel_apollolake_config *config)
+{
+	bool result = (config->gpe0_dw1 != config->gpe0_dw2) &&
+			 (config->gpe0_dw1 != config->gpe0_dw3) &&
+			 (config->gpe0_dw2 != config->gpe0_dw3);
+
+	assert(result);
 }
 
 void soc_get_gpi_gpe_configs(uint8_t *dw0, uint8_t *dw1, uint8_t *dw2)
@@ -144,6 +153,8 @@ void soc_get_gpi_gpe_configs(uint8_t *dw0, uint8_t *dw1, uint8_t *dw2)
 
 	config = config_of_soc();
 
+	gpe0_different_values(config);
+
 	/* Assign to out variable */
 	*dw0 = config->gpe0_dw1;
 	*dw1 = config->gpe0_dw2;
@@ -157,10 +168,10 @@ void soc_fill_power_state(struct chipset_power_state *ps)
 	ps->tco1_sts = tco_read_reg(TCO1_STS);
 	ps->tco2_sts = tco_read_reg(TCO2_STS);
 
-	ps->prsts = read32((void *)(pmc_bar0 + PRSTS));
-	ps->gen_pmcon1 = read32((void *)(pmc_bar0 + GEN_PMCON1));
-	ps->gen_pmcon2 = read32((void *)(pmc_bar0 + GEN_PMCON2));
-	ps->gen_pmcon3 = read32((void *)(pmc_bar0 + GEN_PMCON3));
+	ps->prsts = read32p(pmc_bar0 + PRSTS);
+	ps->gen_pmcon1 = read32p(pmc_bar0 + GEN_PMCON1);
+	ps->gen_pmcon2 = read32p(pmc_bar0 + GEN_PMCON2);
+	ps->gen_pmcon3 = read32p(pmc_bar0 + GEN_PMCON3);
 
 	printk(BIOS_DEBUG, "prsts: %08x\n",
 	       ps->prsts);
@@ -200,7 +211,7 @@ int soc_get_rtc_failed(void)
 int vbnv_cmos_failed(void)
 {
 	uintptr_t pmc_bar = soc_read_pmc_base();
-	uint32_t gen_pmcon1 = read32((void *)(pmc_bar + GEN_PMCON1));
+	uint32_t gen_pmcon1 = read32p(pmc_bar + GEN_PMCON1);
 	int rtc_failure = rtc_failed(gen_pmcon1);
 
 	if (rtc_failure) {
@@ -212,7 +223,7 @@ int vbnv_cmos_failed(void)
 		/* RPS is write 0 to clear. */
 		gen_pmcon1 &= ~RPS;
 
-		write32((void *)(pmc_bar + GEN_PMCON1), gen_pmcon1);
+		write32p(pmc_bar + GEN_PMCON1, gen_pmcon1);
 	}
 
 	return rtc_failure;
@@ -221,18 +232,19 @@ int vbnv_cmos_failed(void)
 /* STM Support */
 uint16_t get_pmbase(void)
 {
-	return (uint16_t) ACPI_BASE_ADDRESS;
+	return (uint16_t)ACPI_BASE_ADDRESS;
 }
 
+/* Set which power state system will be after reapplying the power (from G3 State) */
 void pmc_soc_set_afterg3_en(const bool on)
 {
-	const uintptr_t gen_pmcon1 = soc_read_pmc_base() + GEN_PMCON1;
-	uint32_t reg32;
+	uint8_t reg8;
+	uint8_t *const pmcbase = pmc_mmio_regs();
 
-	reg32 = read32p(gen_pmcon1);
+	reg8 = read8(pmcbase + GEN_PMCON_A);
 	if (on)
-		reg32 &= ~SLEEP_AFTER_POWER_FAIL;
+		reg8 &= ~SLEEP_AFTER_POWER_FAIL;
 	else
-		reg32 |= SLEEP_AFTER_POWER_FAIL;
-	write32p(gen_pmcon1, reg32);
+		reg8 |= SLEEP_AFTER_POWER_FAIL;
+	write8(pmcbase + GEN_PMCON_A, reg8);
 }
