@@ -67,7 +67,7 @@ static void configure_host_mode_port0(struct device *dev)
 		}
 	}
 
-	printk(BIOS_INFO, "XDCI port 0 host switch over took %lu ms\n",
+	printk(BIOS_INFO, "XDCI port 0 host switch over took %lld ms\n",
 		stopwatch_duration_msecs(&sw));
 }
 
