@@ -22,7 +22,7 @@ static void log_power_and_resets(const struct chipset_power_state *ps)
 	if (ps->gen_pmcon1 & RPS)
 		elog_add_event(ELOG_TYPE_RTC_RESET);
 
-	if (ps->tco_sts & SECOND_TO_STS)
+	if (ps->tco_sts & TCO1_32_STS_SECOND_TO_STS)
 		elog_add_event(ELOG_TYPE_TCO_RESET);
 
 	if (ps->pm1_sts & PRBTNOR_STS)
