@@ -5,7 +5,4 @@
 
 #include <acpi/acpi.h>
 
-int acpi_sci_irq(void);
-unsigned long acpi_madt_irq_overrides(unsigned long current);
-
 #endif /* _BAYTRAIL_ACPI_H_ */
