@@ -1,18 +1,4 @@
-/*
- * This file is part of the coreboot project.
- *
- * Copyright (C) 2013 Google Inc.
- * Copyright (C) 2015 Intel Corp.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- */
+/* SPDX-License-Identifier: GPL-2.0-only */
 
 #ifndef _SOC_LPC_H_
 #define _SOC_LPC_H_
@@ -30,13 +16,18 @@
 #define UART_CONT	0x80
 #define RCBA		0xf0
 
+/* iLB Memory Mapped IO */
+#define ILB_OIC		0x60
+#define  SIRQEN		(1 << 12)
+
 /* Memory Mapped IO in LPC bridge */
 #define SCNT		0x10
 #define SCNT_MODE	(1 << 7) /* When cleared, SERIRQ is in quiet mode */
 
 #define RID_A_STEPPING_START 1
 #define RID_B_STEPPING_START 5
-#define RID_C_STEPPING_START 0xe
+#define RID_C_STEPPING_START 0x21
+#define RID_D_STEPPING_START 0x35
 enum soc_stepping {
 	STEP_A0,
 	STEP_A1,
@@ -45,6 +36,7 @@ enum soc_stepping {
 	STEP_B2,
 	STEP_B3,
 	STEP_C0,
+	STEP_D1,
 };
 
 /* Registers behind the RCBA_BASE_ADDRESS bar. */
