@@ -6,11 +6,12 @@
 #include <arch/io.h>
 #include <assert.h>
 #include <bootmode.h>
+#include <console/console.h>
 #include <device/device.h>
 #include <device/mmio.h>
 #include <device/pci.h>
 #include <device/pci_ops.h>
-#include <console/console.h>
+#include <halt.h>
 #include <soc/iomap.h>
 #include <soc/lpc.h>
 #include <soc/pci_devs.h>
@@ -318,12 +319,12 @@ void clear_pmc_status(void)
 	uint32_t prsts;
 	uint32_t gen_pmcon1;
 
-	prsts = read32((void *)(PMC_BASE_ADDRESS + PRSTS));
-	gen_pmcon1 = read32((void *)(PMC_BASE_ADDRESS + GEN_PMCON1));
+	prsts = read32p(PMC_BASE_ADDRESS + PRSTS);
+	gen_pmcon1 = read32p(PMC_BASE_ADDRESS + GEN_PMCON1);
 
 	/* Clear the status bits. The RPS field is cleared on a 0 write. */
-	write32((void *)(PMC_BASE_ADDRESS + GEN_PMCON1), gen_pmcon1 & ~RPS);
-	write32((void *)(PMC_BASE_ADDRESS + PRSTS), prsts);
+	write32p(PMC_BASE_ADDRESS + GEN_PMCON1, gen_pmcon1 & ~RPS);
+	write32p(PMC_BASE_ADDRESS + PRSTS, prsts);
 }
 
 int rtc_failure(void)
@@ -356,3 +357,13 @@ int platform_is_resuming(void)
 
 	return acpi_sleep_from_pm1(inl(ACPI_BASE_ADDRESS + PM1_CNT)) == ACPI_S3;
 }
+
+void poweroff(void)
+{
+	uint32_t pm1_cnt;
+
+	/* Go to S5 */
+	pm1_cnt = inl(ACPI_BASE_ADDRESS + PM1_CNT);
+	pm1_cnt |= (0xf << 10);
+	outl(pm1_cnt, ACPI_BASE_ADDRESS + PM1_CNT);
+}
