@@ -1,18 +1,17 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
-#include <arch/cpu.h>
-#include <acpi/acpi.h>
 #include <acpi/acpi_pm.h>
 #include <console/console.h>
+#include <cpu/cpu.h>
 #include <cpu/intel/microcode.h>
 #include <cpu/x86/cr.h>
 #include <cpu/x86/msr.h>
 #include <device/device.h>
 #include <device/pci_def.h>
 #include <device/pci_ops.h>
-#include <intelblocks/acpi_wake_source.h>
 #include <fsp/util.h>
-#include <soc/gpio.h>
+#include <gpio.h>
+#include <intelblocks/acpi_wake_source.h>
 #include <soc/lpc.h>
 #include <soc/msr.h>
 #include <soc/pattrs.h>
@@ -68,11 +67,11 @@ static void fill_in_pattrs(void)
 	dev = pcidev_on_root(LPC_DEV, LPC_FUNC);
 	attrs->revid = pci_read_config8(dev, REVID);
 	/* The revision to stepping IDs have two values per metal stepping. */
-    if (attrs->revid >= RID_D_STEPPING_START) {
+	if (attrs->revid >= RID_D_STEPPING_START) {
 		attrs->stepping = (attrs->revid - RID_D_STEPPING_START) / 2;
 		attrs->stepping += STEP_D1;
 
-    } else if (attrs->revid >= RID_C_STEPPING_START) {
+	} else if (attrs->revid >= RID_C_STEPPING_START) {
 		attrs->stepping = (attrs->revid - RID_C_STEPPING_START) / 2;
 		attrs->stepping += STEP_C0;
 
