@@ -41,6 +41,6 @@ static const struct device_operations device_ops = {
 
 static const struct pci_driver southcluster __pci_driver = {
 	.ops		= &device_ops,
-	.vendor		= PCI_VENDOR_ID_INTEL,
+	.vendor		= PCI_VID_INTEL,
 	.device		= SD_DEVID,
 };
