@@ -1,6 +1,6 @@
 /* SPDX-License-Identifier: GPL-2.0-or-later */
 
-#include <intelblocks/gpio.h>
+#include <gpio.h>
 #include <intelblocks/pcr.h>
 #include <soc/pcr_ids.h>
 #include <soc/pmc.h>
