@@ -143,6 +143,7 @@ struct chipset_power_state {
 	uint32_t gen_pmcon_a;
 	uint32_t gen_pmcon_b;
 	uint32_t gblrst_cause[2];
+	uint32_t hpr_cause0;
 	uint32_t prev_sleep_state;
 } __packed;
 
@@ -155,9 +156,6 @@ uint16_t smbus_tco_regs(void);
 /* Set the DISB after DRAM init */
 void pmc_set_disb(void);
 
-/* Clear PMCON status bits */
-void pmc_clear_pmcon_sts(void);
-
 /* STM Support */
 uint16_t get_pmbase(void);
 
