@@ -861,23 +861,8 @@ int cse_hmrfpo_get_status(void)
 	return resp.status;
 }
 
-void print_me_fw_version(void *unused)
-{
-	struct me_fw_ver_resp resp = {0};
-
-	/* Ignore if UART debugging is disabled */
-	if (!CONFIG(CONSOLE_SERIAL))
-		return;
-
-	if (get_me_fw_version(&resp) == CB_SUCCESS) {
-		printk(BIOS_DEBUG, "ME: Version: %d.%d.%d.%d\n", resp.code.major,
-			resp.code.minor, resp.code.hotfix, resp.code.build);
-		return;
-	}
-	printk(BIOS_DEBUG, "ME: Version: Unavailable\n");
-}
-
-enum cb_err get_me_fw_version(struct me_fw_ver_resp *resp)
+/* Queries and gets ME firmware version */
+static enum cb_err get_me_fw_version(struct me_fw_ver_resp *resp)
 {
 	const struct mkhi_hdr fw_ver_msg = {
 		.group_id = MKHI_GROUP_ID_GEN,
@@ -894,13 +879,6 @@ enum cb_err get_me_fw_version(struct me_fw_ver_resp *resp)
 	if (!is_cse_enabled())
 		return CB_ERR;
 
-	/*
-	 * Ignore if ME Firmware SKU type is Lite since
-	 * print_boot_partition_info() logs RO(BP1) and RW(BP2) versions.
-	 */
-	if (cse_is_hfs3_fw_sku_lite())
-		return CB_ERR;
-
 	/*
 	 * Prerequisites:
 	 * 1) HFSTS1 Current Working State is Normal
@@ -924,6 +902,29 @@ enum cb_err get_me_fw_version(struct me_fw_ver_resp *resp)
 	return CB_SUCCESS;
 }
 
+void print_me_fw_version(void *unused)
+{
+	struct me_fw_ver_resp resp = {0};
+
+	/* Ignore if UART debugging is disabled */
+	if (!CONFIG(CONSOLE_SERIAL))
+		return;
+
+	/*
+	 * Skip if ME firmware is Lite SKU, as RO/RW versions are
+	 * already logged by `cse_print_boot_partition_info()`
+	 */
+	if (cse_is_hfs3_fw_sku_lite())
+		return;
+
+	if (get_me_fw_version(&resp) == CB_SUCCESS) {
+		printk(BIOS_DEBUG, "ME: Version: %d.%d.%d.%d\n", resp.code.major,
+			resp.code.minor, resp.code.hotfix, resp.code.build);
+		return;
+	}
+	printk(BIOS_DEBUG, "ME: Version: Unavailable\n");
+}
+
 void cse_trigger_vboot_recovery(enum csme_failure_reason reason)
 {
 	printk(BIOS_DEBUG, "cse: CSE status registers: HFSTS1: 0x%x, HFSTS2: 0x%x "
@@ -1258,7 +1259,6 @@ static void me_reset_with_count(void)
 			 */
 			printk(BIOS_ERR, "Failed to change ME state in %u attempts!\n",
 									 ME_DISABLE_ATTEMPTS);
-
 		}
 	} else {
 		printk(BIOS_DEBUG, "ME: Resetting");
@@ -1268,7 +1268,6 @@ static void me_reset_with_count(void)
 
 static void cse_set_state(struct device *dev)
 {
-
 	/* (CS)ME Disable Command */
 	struct me_disable_command {
 		struct mkhi_hdr hdr;
@@ -1420,6 +1419,9 @@ void cse_late_finalize(void)
 
 static void intel_cse_get_rw_version(void)
 {
+	if (CONFIG(SOC_INTEL_CSE_LITE_SYNC_BY_PAYLOAD))
+		return;
+
 	struct cse_specific_info *info = cbmem_find(CBMEM_ID_CSE_INFO);
 	if (info == NULL)
 		return;
@@ -1441,15 +1443,17 @@ static void cse_final(struct device *dev)
 	if (CONFIG(SOC_INTEL_STORE_CSE_FW_VERSION))
 		intel_cse_get_rw_version();
 	/*
-	 * SoC user can have two options for sending EOP:
+	 * SoC user can have three options for sending EOP:
 	 * 1. Choose to send EOP late
 	 * 2. Choose to send EOP cmd asynchronously
+	 * 3. Choose to send EOP cmd from payload i.e. skip here
 	 *
 	 * In case of sending EOP in asynchronous mode, the EOP command
 	 * has most likely not been completed yet. The finalization steps
 	 * will be run once the EOP command has successfully been completed.
 	 */
 	if (CONFIG(SOC_INTEL_CSE_SEND_EOP_LATE) ||
+	    CONFIG(SOC_INTEL_CSE_SEND_EOP_BY_PAYLOAD) ||
 	    CONFIG(SOC_INTEL_CSE_SEND_EOP_ASYNC))
 		return;
 
@@ -1475,6 +1479,9 @@ struct device_operations cse_ops = {
 };
 
 static const unsigned short pci_device_ids[] = {
+	PCI_DID_INTEL_PTL_H_CSE0,
+	PCI_DID_INTEL_PTL_U_H_CSE0,
+	PCI_DID_INTEL_LNL_CSE0,
 	PCI_DID_INTEL_MTL_CSE0,
 	PCI_DID_INTEL_APL_CSE0,
 	PCI_DID_INTEL_GLK_CSE0,
