@@ -67,13 +67,54 @@ static enum cse_cmd_result cse_disable_mei_bus(void)
 	return CSE_CMD_RESULT_SUCCESS;
 }
 
-static enum cse_cmd_result cse_send_eop(void)
+static enum cse_cmd_result cse_receive_eop(void)
 {
-	enum cse_tx_rx_status ret;
 	enum {
 		EOP_REQUESTED_ACTION_CONTINUE = 0,
 		EOP_REQUESTED_ACTION_GLOBAL_RESET = 1,
 	};
+	enum cse_tx_rx_status ret;
+	struct end_of_post_resp {
+		struct mkhi_hdr hdr;
+		uint32_t requested_actions;
+	} __packed resp = {};
+	size_t resp_size = sizeof(resp);
+
+	ret = heci_receive(&resp, &resp_size);
+	if (ret)
+		return decode_heci_send_receive_error(ret);
+
+	if (resp.hdr.group_id != MKHI_GROUP_ID_GEN ||
+	    resp.hdr.command != MKHI_END_OF_POST) {
+		printk(BIOS_ERR, "HECI: EOP Unexpected response group or command.\n");
+		if (CONFIG(SOC_INTEL_CSE_SEND_EOP_ASYNC))
+			printk(BIOS_ERR, "HECI: It could be a HECI command conflict.\n");
+		return CSE_CMD_RESULT_ERROR;
+	}
+
+	if (resp.hdr.result) {
+		printk(BIOS_ERR, "HECI: EOP Resp Failed: %u\n", resp.hdr.result);
+		return CSE_CMD_RESULT_ERROR;
+	}
+
+	printk(BIOS_INFO, "CSE: EOP requested action: ");
+
+	switch (resp.requested_actions) {
+	case EOP_REQUESTED_ACTION_GLOBAL_RESET:
+		printk(BIOS_INFO, "global reset\n");
+		return CSE_CMD_RESULT_GLOBAL_RESET_REQUESTED;
+	case EOP_REQUESTED_ACTION_CONTINUE:
+		printk(BIOS_INFO, "continue boot\n");
+		return CSE_CMD_RESULT_SUCCESS;
+	default:
+		printk(BIOS_INFO, "unknown %u\n", resp.requested_actions);
+		return CSE_CMD_RESULT_ERROR;
+	}
+}
+
+static enum cse_cmd_result cse_send_eop(void)
+{
+	enum cse_tx_rx_status ret;
 	struct end_of_post_msg {
 		struct mkhi_hdr hdr;
 	} __packed msg = {
@@ -82,21 +123,6 @@ static enum cse_cmd_result cse_send_eop(void)
 			.command = MKHI_END_OF_POST,
 		},
 	};
-	struct end_of_post_resp {
-		struct mkhi_hdr hdr;
-		uint32_t requested_actions;
-	} __packed resp = {};
-	size_t resp_size = sizeof(resp);
-
-	/* For a CSE-Lite SKU, if the CSE is running RO FW and the board is
-	   running vboot in recovery mode, the CSE is expected to be in SOFT
-	   TEMP DISABLE state. */
-	if (CONFIG(SOC_INTEL_CSE_LITE_SKU) && vboot_recovery_mode_enabled() &&
-	    cse_is_hfs1_com_soft_temp_disable()) {
-		printk(BIOS_INFO, "HECI: coreboot in recovery mode; found CSE in expected SOFT "
-		       "TEMP DISABLE state, skipping EOP\n");
-		return CSE_CMD_RESULT_SUCCESS;
-	}
 
 	/*
 	 * Prerequisites:
@@ -119,28 +145,22 @@ static enum cse_cmd_result cse_send_eop(void)
 
 	printk(BIOS_INFO, "HECI: Sending End-of-Post\n");
 
-	ret = heci_send_receive(&msg, sizeof(msg), &resp, &resp_size, HECI_MKHI_ADDR);
+	ret = heci_send(&msg, sizeof(msg), BIOS_HOST_ADDR, HECI_MKHI_ADDR);
 	if (ret)
 		return decode_heci_send_receive_error(ret);
 
-	if (resp.hdr.result) {
-		printk(BIOS_ERR, "HECI: EOP Resp Failed: %u\n", resp.hdr.result);
-		return CSE_CMD_RESULT_ERROR;
-	}
+	return CSE_CMD_RESULT_SUCCESS;
+}
 
-	printk(BIOS_INFO, "CSE: EOP requested action: ");
+static enum cse_cmd_result cse_send_and_receive_eop(void)
+{
+	enum cse_cmd_result ret;
 
-	switch (resp.requested_actions) {
-	case EOP_REQUESTED_ACTION_GLOBAL_RESET:
-		printk(BIOS_INFO, "global reset\n");
-		return CSE_CMD_RESULT_GLOBAL_RESET_REQUESTED;
-	case EOP_REQUESTED_ACTION_CONTINUE:
-		printk(BIOS_INFO, "continue boot\n");
-		return CSE_CMD_RESULT_SUCCESS;
-	default:
-		printk(BIOS_INFO, "unknown %u\n", resp.requested_actions);
-		return CSE_CMD_RESULT_ERROR;
-	}
+	ret = cse_send_eop();
+	if (ret != CSE_CMD_RESULT_SUCCESS)
+		return ret;
+
+	return cse_receive_eop();
 }
 
 static enum cse_cmd_result cse_send_cmd_retries(enum cse_cmd_result (*cse_send_command)(void))
@@ -199,11 +219,12 @@ static void handle_cse_eop_result(enum cse_cmd_result result)
 	}
 }
 
-static void do_send_end_of_post(void)
+static void do_send_end_of_post(bool wait_for_completion)
 {
-	static bool eop_sent = false;
+	static bool eop_sent = false, eop_complete = false;
+	enum cse_cmd_result ret;
 
-	if (eop_sent) {
+	if (eop_complete) {
 		printk(BIOS_WARNING, "EOP already sent\n");
 		return;
 	}
@@ -222,25 +243,83 @@ static void do_send_end_of_post(void)
 		return;
 	}
 
-	set_cse_device_state(PCH_DEVFN_CSE, DEV_ACTIVE);
+	if (!eop_sent) {
+		set_cse_device_state(PCH_DEVFN_CSE, DEV_ACTIVE);
+		timestamp_add_now(TS_ME_END_OF_POST_START);
+		ret = cse_send_cmd_retries(cse_send_eop);
+		if (ret == CSE_CMD_RESULT_SUCCESS)
+			eop_sent = true;
+	}
 
-	timestamp_add_now(TS_ME_END_OF_POST_START);
-	handle_cse_eop_result(cse_send_cmd_retries(cse_send_eop));
+	if (!wait_for_completion)
+		return;
+
+	set_cse_device_state(PCH_DEVFN_CSE, DEV_ACTIVE);
+	ret = cse_receive_eop();
+	if (ret != CSE_CMD_RESULT_SUCCESS) {
+		ret = cse_send_cmd_retries(cse_send_and_receive_eop);
+		handle_cse_eop_result(ret);
+	}
 	timestamp_add_now(TS_ME_END_OF_POST_END);
 
 	set_cse_device_state(PCH_DEVFN_CSE, DEV_IDLE);
 
-	eop_sent = true;
+	eop_complete = true;
+}
+
+/*
+ * Don't send EOP if the following conditions are met:
+ * CSE Lite:
+ * 1. "The platform is running CSE-Lite SKU" AND
+ * 2. 'The CSE is running the RO FW" AND
+ * 3. "The board is in recovery mode"
+ *
+ * Other CSE Type:
+ * 1. "The board is in recovery mode"
+ *
+ * The above conditions summarize that the CSE is in "SOFT TEMP DISABLE" state,
+ * hence, don't send the EOP command to CSE.
+ */
+static bool is_cse_eop_supported(void)
+{
+	/* CSE Lite */
+	if ((CONFIG(SOC_INTEL_CSE_LITE_SKU) && vboot_recovery_mode_enabled()) &&
+		cse_is_hfs1_com_soft_temp_disable()) {
+		printk(BIOS_INFO, "HECI: coreboot in recovery mode; found CSE Lite in expected "
+		       "SOFT TEMP DISABLE state, skipping EOP\n");
+		return false;
+	}
+	/* Other CSE Type */
+	if (cse_is_hfs1_com_soft_temp_disable()) {
+		printk(BIOS_INFO, "HECI: coreboot in recovery mode; found CSE in expected "
+		       "SOFT TEMP DISABLE state, skipping EOP\n");
+		return false;
+	}
+
+	return true;
 }
 
 void cse_send_end_of_post(void)
 {
-	return do_send_end_of_post();
+	if (!is_cse_eop_supported())
+		return;
+
+	return do_send_end_of_post(!CONFIG(SOC_INTEL_CSE_SEND_EOP_ASYNC));
 }
 
-static void set_cse_end_of_post(void *unused)
+static void send_cse_eop_with_late_finalize(void *unused)
 {
-	return do_send_end_of_post();
+	if (CONFIG(SOC_INTEL_CSE_SEND_EOP_BY_PAYLOAD)) {
+		printk(BIOS_INFO, "Deferring CSE EOP to payload\n");
+		return;
+	}
+
+	if (is_cse_eop_supported())
+		do_send_end_of_post(true);
+
+	if (CONFIG(SOC_INTEL_CSE_SEND_EOP_LATE) ||
+	    CONFIG(SOC_INTEL_CSE_SEND_EOP_ASYNC))
+		cse_late_finalize();
 }
 
 /*
@@ -253,7 +332,7 @@ static void set_cse_end_of_post(void *unused)
  * BS_PAYLOAD_BOOT instead.
  */
 #if !CONFIG(HECI_DISABLE_USING_SMM)
-BOOT_STATE_INIT_ENTRY(BS_PAYLOAD_BOOT, BS_ON_ENTRY, set_cse_end_of_post, NULL);
+BOOT_STATE_INIT_ENTRY(BS_PAYLOAD_BOOT, BS_ON_ENTRY, send_cse_eop_with_late_finalize, NULL);
 #else
-BOOT_STATE_INIT_ENTRY(BS_PAYLOAD_LOAD, BS_ON_ENTRY, set_cse_end_of_post, NULL);
+BOOT_STATE_INIT_ENTRY(BS_PAYLOAD_LOAD, BS_ON_ENTRY, send_cse_eop_with_late_finalize, NULL);
 #endif
