@@ -42,7 +42,7 @@ static uint32_t fast_spi_flash_ctrlr_reg_read(struct fast_spi_flash_ctx *ctx,
 	uint16_t reg)
 {
 	uintptr_t addr =  ALIGN_DOWN(ctx->mmio_base + reg, sizeof(uint32_t));
-	return read32((void *)addr);
+	return read32p(addr);
 }
 
 /* Write to register in FAST_SPI flash controller. */
@@ -50,43 +50,53 @@ static void fast_spi_flash_ctrlr_reg_write(struct fast_spi_flash_ctx *ctx,
 					uint16_t reg, uint32_t val)
 {
 	uintptr_t addr =  ALIGN_DOWN(ctx->mmio_base + reg, sizeof(uint32_t));
-	write32((void *)addr, val);
+	write32p(addr, val);
 }
 
 /*
- * The hardware datasheet is not clear on what HORD values actually do. It
- * seems that HORD_SFDP provides access to the first 8 bytes of the SFDP, which
- * is the signature and revision fields. HORD_JEDEC provides access to the
- * actual flash parameters, and is most likely what you want to use when
- * probing the flash from software.
+ * Via component field (bits 15-14) we can select either 1st or 2nd flash
+ * (in dual flash setups).
+ * Via HORD - Header or Data (bits 13-12) - we can select either:
+ *   - SFDP Header
+ *   - Param Table Header
+ *   - Data (JEDEC params, including density)
+ *
  * It's okay to rely on SFDP, since the SPI flash controller requires an SFDP
  * 1.5 or newer compliant FAST_SPI flash chip.
  * NOTE: Due to the register layout of the hardware, all accesses will be
  * aligned to a 4 byte boundary.
  */
-static uint32_t fast_spi_flash_read_sfdp_param(struct fast_spi_flash_ctx *ctx,
-					  uint16_t sfdp_reg)
+static uint32_t fast_spi_flash_read_sfdp(struct fast_spi_flash_ctx *ctx,
+						uint32_t ptinx_reg)
 {
-	uint32_t ptinx_index = sfdp_reg & SPIBAR_PTINX_IDX_MASK;
-	fast_spi_flash_ctrlr_reg_write(ctx, SPIBAR_PTINX,
-				   ptinx_index | SPIBAR_PTINX_HORD_JEDEC);
+	fast_spi_flash_ctrlr_reg_write(ctx, SPIBAR_PTINX, ptinx_reg);
 	return fast_spi_flash_ctrlr_reg_read(ctx, SPIBAR_PTDATA);
 }
 
 /* Fill FDATAn FIFO in preparation for a write transaction. */
 static void fill_xfer_fifo(struct fast_spi_flash_ctx *ctx, const void *data,
-			   size_t len)
+				size_t len)
 {
-	/* YES! memcpy() works. FDATAn does not require 32-bit accesses. */
-	memcpy((void *)(ctx->mmio_base + SPIBAR_FDATA(0)), data, len);
+	const uint32_t *data32 = (const uint32_t *)data;
+	for (size_t i = 0; i < len / sizeof(uint32_t); i++)
+		write32p(ctx->mmio_base + SPIBAR_FDATA(i), *data32++);
+
+	const uint8_t *data8 = (const uint8_t *)data32;
+	for (size_t i = 0; i < len % sizeof(uint32_t); i++)
+		write8p(ctx->mmio_base + SPIBAR_FDATA(len / sizeof(uint32_t)) + i, *data8++);
 }
 
 /* Drain FDATAn FIFO after a read transaction populates data. */
-static void drain_xfer_fifo(struct fast_spi_flash_ctx *ctx, void *dest,
+static void drain_xfer_fifo(struct fast_spi_flash_ctx *ctx, void *data,
 				size_t len)
 {
-	/* YES! memcpy() works. FDATAn does not require 32-bit accesses. */
-	memcpy(dest, (void *)(ctx->mmio_base + SPIBAR_FDATA(0)), len);
+	uint32_t *data32 = (uint32_t *)data;
+	for (size_t i = 0; i < len / sizeof(uint32_t); i++)
+		*data32++ = read32p(ctx->mmio_base + SPIBAR_FDATA(i));
+
+	uint8_t *data8 = (uint8_t *)data32;
+	for (size_t i = 0; i < len % sizeof(uint32_t); i++)
+		*data8++ = read8p(ctx->mmio_base + SPIBAR_FDATA(len / sizeof(uint32_t)) + i);
 }
 
 /* Fire up a transfer using the hardware sequencer. */
@@ -312,15 +322,30 @@ static int fast_spi_flash_probe(const struct spi_slave *dev,
 {
 	BOILERPLATE_CREATE_CTX(ctx);
 	uint32_t flash_bits;
+	uint32_t ptinx_reg;
 
 	/*
 	 * bytes = (bits + 1) / 8;
 	 * But we need to do the addition in a way which doesn't overflow for
 	 * 4 Gbit devices (flash_bits == 0xffffffff).
 	 */
-	flash_bits = fast_spi_flash_read_sfdp_param(ctx, 0x04);
+	ptinx_reg = SPIBAR_PTINX_COMP_0 | SPIBAR_PTINX_HORD_JEDEC | SFDP_PARAM_DENSITY;
+	flash_bits = fast_spi_flash_read_sfdp(ctx, ptinx_reg);
 	flash->size = (flash_bits >> 3) + 1;
 
+	/*
+	 * Now check if we have a second flash component.
+	 * Check SFDP header for the SFDP signature. If valid, then 2nd component is present.
+	 * Increase the flash size if 2nd component is found, analogically like the 1st
+	 * component.
+	 */
+	ptinx_reg = SPIBAR_PTINX_COMP_1 | SPIBAR_PTINX_HORD_SFDP | SFDP_HDR_SIG;
+	if (fast_spi_flash_read_sfdp(ctx, ptinx_reg) == SFDP_SIGNATURE) {
+		ptinx_reg = SPIBAR_PTINX_COMP_1 | SPIBAR_PTINX_HORD_JEDEC | SFDP_PARAM_DENSITY;
+		flash_bits = fast_spi_flash_read_sfdp(ctx, ptinx_reg);
+		flash->size += ((flash_bits >> 3) + 1);
+	}
+
 	memcpy(&flash->spi, dev, sizeof(*dev));
 
 	/* Can erase both 4 KiB and 64 KiB chunks. Declare the smaller size. */
@@ -378,7 +403,7 @@ static int fast_spi_flash_protect(const struct spi_flash *flash,
 
 	/* Find first empty FPR */
 	for (fpr = 0; fpr < SPIBAR_FPR_MAX; fpr++) {
-		reg = read32((void *)fpr_base);
+		reg = read32p(fpr_base);
 		if (reg == 0)
 			break;
 		fpr_base += sizeof(uint32_t);
@@ -408,8 +433,8 @@ static int fast_spi_flash_protect(const struct spi_flash *flash,
 	reg = SPI_FPR(start, end) | protect_mask;
 
 	/* Set the FPR register and verify it is protected */
-	write32((void *)fpr_base, reg);
-	reg = read32((void *)fpr_base);
+	write32p(fpr_base, reg);
+	reg = read32p(fpr_base);
 	if (!(reg & protect_mask)) {
 		printk(BIOS_ERR, "Unable to set SPI FPR %d\n", fpr);
 		return -1;
