@@ -21,6 +21,30 @@ struct device_operations hda_ops = {
 };
 
 static const unsigned short pci_device_ids[] = {
+	PCI_DID_INTEL_PTL_H_AUDIO_1,
+	PCI_DID_INTEL_PTL_H_AUDIO_2,
+	PCI_DID_INTEL_PTL_H_AUDIO_3,
+	PCI_DID_INTEL_PTL_H_AUDIO_4,
+	PCI_DID_INTEL_PTL_H_AUDIO_5,
+	PCI_DID_INTEL_PTL_H_AUDIO_6,
+	PCI_DID_INTEL_PTL_H_AUDIO_7,
+	PCI_DID_INTEL_PTL_H_AUDIO_8,
+	PCI_DID_INTEL_PTL_U_H_AUDIO_1,
+	PCI_DID_INTEL_PTL_U_H_AUDIO_2,
+	PCI_DID_INTEL_PTL_U_H_AUDIO_3,
+	PCI_DID_INTEL_PTL_U_H_AUDIO_4,
+	PCI_DID_INTEL_PTL_U_H_AUDIO_5,
+	PCI_DID_INTEL_PTL_U_H_AUDIO_6,
+	PCI_DID_INTEL_PTL_U_H_AUDIO_7,
+	PCI_DID_INTEL_PTL_U_H_AUDIO_8,
+	PCI_DID_INTEL_LNL_AUDIO_1,
+	PCI_DID_INTEL_LNL_AUDIO_2,
+	PCI_DID_INTEL_LNL_AUDIO_3,
+	PCI_DID_INTEL_LNL_AUDIO_4,
+	PCI_DID_INTEL_LNL_AUDIO_5,
+	PCI_DID_INTEL_LNL_AUDIO_6,
+	PCI_DID_INTEL_LNL_AUDIO_7,
+	PCI_DID_INTEL_LNL_AUDIO_8,
 	PCI_DID_INTEL_MTL_AUDIO_1,
 	PCI_DID_INTEL_MTL_AUDIO_2,
 	PCI_DID_INTEL_MTL_AUDIO_3,
@@ -30,13 +54,20 @@ static const unsigned short pci_device_ids[] = {
 	PCI_DID_INTEL_MTL_AUDIO_7,
 	PCI_DID_INTEL_MTL_AUDIO_8,
 	PCI_DID_INTEL_RPP_P_AUDIO,
+	PCI_DID_INTEL_RPP_S_AUDIO_1,
+	PCI_DID_INTEL_RPP_S_AUDIO_2,
+	PCI_DID_INTEL_RPP_S_AUDIO_3,
+	PCI_DID_INTEL_RPP_S_AUDIO_4,
+	PCI_DID_INTEL_RPP_S_AUDIO_5,
+	PCI_DID_INTEL_RPP_S_AUDIO_6,
+	PCI_DID_INTEL_RPP_S_AUDIO_7,
+	PCI_DID_INTEL_RPP_S_AUDIO_8,
 	PCI_DID_INTEL_APL_AUDIO,
 	PCI_DID_INTEL_GLK_AUDIO,
 	PCI_DID_INTEL_LWB_AUDIO,
 	PCI_DID_INTEL_LWB_AUDIO_SUPER,
 	PCI_DID_INTEL_CNL_AUDIO,
 	PCI_DID_INTEL_CNP_H_AUDIO,
-	PCI_DID_INTEL_ICL_AUDIO,
 	PCI_DID_INTEL_CMP_AUDIO,
 	PCI_DID_INTEL_CMP_H_AUDIO,
 	PCI_DID_INTEL_BSW_AUDIO,
