@@ -44,6 +44,7 @@
 #define  PAD_CFG0_ROUTE_SMI		(1 << 18)
 #define  PAD_CFG0_ROUTE_SCI		(1 << 19)
 #define  PAD_CFG0_ROUTE_IOAPIC		(1 << 20)
+#define  PAD_CFG0_ROUTE_SWAPPED		(1 << 27)
 #define PAD_CFG0_RXTENCFG_MASK		(3 << 21)
 #define PAD_CFG0_RXINV_MASK		(1 << 23)
 #define  PAD_CFG0_RX_POL_INVERT		(1 << 23)
@@ -336,12 +337,26 @@
 		PAD_TRIG(trig) | PAD_RX_POL(NONE) | PAD_BUF(TX_DISABLE),	\
 		PAD_PULL(pull) | PAD_CFG_OWN_GPIO(own))
 
+#define PAD_CFG_GPI_TRIG_OWN_SWAPPED(pad, pull, rst, trig, own)				\
+	_PAD_CFG_STRUCT(pad,							\
+		PAD_FUNC(GPIO) | PAD_RESET(rst) |				\
+		PAD_TRIG(trig) | PAD_RX_POL(NONE) | PAD_BUF(TX_DISABLE) |	\
+		PAD_IRQ_ROUTE(SWAPPED),	\
+		PAD_PULL(pull) | PAD_CFG_OWN_GPIO(own))
+
 #define PAD_CFG_GPI_TRIG_OWN_LOCK(pad, pull, rst, trig, own, lock_action)	\
 	_PAD_CFG_STRUCT_LOCK(pad,						\
 		PAD_FUNC(GPIO) | PAD_RESET(rst) |				\
 		PAD_TRIG(trig) | PAD_RX_POL(NONE) | PAD_BUF(TX_DISABLE),	\
 		PAD_PULL(pull) | PAD_CFG_OWN_GPIO(own), PAD_LOCK(lock_action))
 
+#define PAD_CFG_GPI_TRIG_OWN_LOCK_SWAPPED(pad, pull, rst, trig, own, lock_action)	\
+	_PAD_CFG_STRUCT_LOCK(pad,						\
+		PAD_FUNC(GPIO) | PAD_RESET(rst) |				\
+		PAD_TRIG(trig) | PAD_RX_POL(NONE) | PAD_BUF(TX_DISABLE) |	\
+		PAD_IRQ_ROUTE(SWAPPED),	\
+		PAD_PULL(pull) | PAD_CFG_OWN_GPIO(own), PAD_LOCK(lock_action))
+
 #define PAD_CFG_GPI_GPIO_DRIVER(pad, pull, rst)					\
 	_PAD_CFG_STRUCT(pad,							\
 		PAD_FUNC(GPIO) | PAD_RESET(rst) |				\
@@ -370,10 +385,16 @@
 #define PAD_CFG_GPI_INT(pad, pull, rst, trig)	\
 		PAD_CFG_GPI_TRIG_OWN(pad, pull, rst, trig, DRIVER)
 
+#define PAD_CFG_GPI_INT_SWAPPED(pad, pull, rst, trig)	\
+		PAD_CFG_GPI_TRIG_OWN_SWAPPED(pad, pull, rst, trig, DRIVER)
+
 /* GPIO Interrupt with lock */
 #define PAD_CFG_GPI_INT_LOCK(pad, pull, trig, lock_action)	\
 		PAD_CFG_GPI_TRIG_OWN_LOCK(pad, pull, PWROK, trig, DRIVER, lock_action)
 
+#define PAD_CFG_GPI_INT_LOCK_SWAPPED(pad, pull, trig, lock_action)	\
+		PAD_CFG_GPI_TRIG_OWN_LOCK_SWAPPED(pad, pull, PWROK, trig, DRIVER, lock_action)
+
 /*
  * No Connect configuration for unconnected or unused pad.
  * Both TX and RX are disabled. RX disabling is done to avoid unnecessary
@@ -524,4 +545,16 @@
 
 #endif /* CONFIG_SOC_INTEL_COMMON_BLOCK_GPIO_DUAL_ROUTE_SUPPORT */
 
+/* Native function configuration */
+#define PAD_CFG_NF_OWNERSHIP(pad, pull, rst, func, own)				\
+	_PAD_CFG_STRUCT(pad,							\
+		PAD_RESET(rst) | PAD_FUNC(func) | PAD_TRIG(OFF),		\
+		PAD_PULL(pull) | PAD_IOSSTATE(TxLASTRxE) |			\
+		PAD_CFG_OWN_GPIO(own))
+
+#define PAD_CFG_GPIO_OWNERSHIP(pad, pull, rst, own)				\
+	_PAD_CFG_STRUCT(pad,							\
+		PAD_FUNC(GPIO) | PAD_RESET(rst) | PAD_TRIG(OFF),		\
+		PAD_PULL(pull) | PAD_CFG_OWN_GPIO(own))
+
 #endif /* _SOC_BLOCK_GPIO_DEFS_H_ */
