@@ -17,7 +17,4 @@ void prmrr_core_configure(void);
  */
 void sgx_configure(void *unused);
 
-/* Fill GNVS data with SGX status, EPC base and length */
-void sgx_fill_gnvs(struct global_nvs *gnvs);
-
 #endif	/* SOC_INTEL_COMMON_BLOCK_SGX_H */
