@@ -5,6 +5,8 @@
 
 #include <stdint.h>
 
+/* Get base address of TCO I/O registers. */
+uint16_t tco_get_bar(void);
 /*
  * Enable TCO BAR using SMBUS TCO base to access TCO related register
  * also disable the timer.
@@ -20,4 +22,11 @@ uint32_t tco_reset_status(void);
 uint16_t tco_read_reg(uint16_t tco_reg);
 void tco_write_reg(uint16_t tco_reg, uint16_t value);
 
+/* Get TCO timer period in milliseconds */
+uint32_t tco_get_timer_period(void);
+/* Get the minimum time value for the TCO timer */
+uint32_t tco_get_timer_min_value(void);
+/* Get the maximum time value for the TCO timer */
+uint32_t tco_get_timer_max_value(void);
+
 #endif /* SOC_INTEL_COMMON_BLOCK_TCO_H */
