@@ -12,15 +12,20 @@ struct device_operations ipu_pci_ops = {
 };
 
 static const uint16_t pci_device_ids[] = {
-	PCI_DEVICE_ID_INTEL_TGL_IPU,
-	PCI_DEVICE_ID_INTEL_TGL_H_IPU,
-	PCI_DEVICE_ID_INTEL_JSL_IPU,
-	PCI_DEVICE_ID_INTEL_ADL_IPU,
+	PCI_DID_INTEL_PTL_IPU,
+	PCI_DID_INTEL_LNL_IPU,
+	PCI_DID_INTEL_RPL_IPU,
+	PCI_DID_INTEL_MTL_IPU,
+	PCI_DID_INTEL_TGL_IPU,
+	PCI_DID_INTEL_TGL_H_IPU,
+	PCI_DID_INTEL_JSL_IPU,
+	PCI_DID_INTEL_ADL_IPU,
+	PCI_DID_INTEL_ADL_N_IPU,
 	0
 };
 
 static const struct pci_driver intel_ipu __pci_driver = {
 	.ops		= &ipu_pci_ops,
-	.vendor		= PCI_VENDOR_ID_INTEL,
+	.vendor		= PCI_VID_INTEL,
 	.devices	= pci_device_ids,
 };
