@@ -2,7 +2,6 @@
 
 #define __SIMPLE_DEVICE__
 
-#include <console/console.h>
 #include <device/pci.h>
 #include <device/pci_ids.h>
 #include <intelblocks/p2sb.h>
@@ -28,7 +27,7 @@ void ioe_p2sb_enable_bar(void)
 
 static void read_resources(struct device *dev)
 {
-	mmio_resource_kb(dev, 0, IOE_P2SB_BAR / KiB, IOE_P2SB_SIZE / KiB);
+	mmio_range(dev, 0, IOE_P2SB_BAR, IOE_P2SB_SIZE);
 }
 
 struct device_operations device_ops = {
@@ -38,6 +37,8 @@ struct device_operations device_ops = {
 };
 
 static const unsigned short pci_device_ids[] = {
+	PCI_DID_INTEL_PTL_H_P2SB2,
+	PCI_DID_INTEL_PTL_U_H_P2SB2,
 	PCI_DID_INTEL_MTL_IOE_M_P2SB,
 	PCI_DID_INTEL_MTL_IOE_P_P2SB,
 	0,
