@@ -1,11 +1,12 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
 #include <console/console.h>
+#include <device/device.h>
 #include <device/pci.h>
-#include <device/pciexp.h>
-#include <device/pci_def.h>
 #include <device/pci_ids.h>
 #include <device/pci_ops.h>
+#include <device/pciexp.h>
+#include <stdint.h>
 
 #define CACHE_LINE_SIZE	0x10
 
@@ -47,8 +48,8 @@ static void pch_pcie_init(struct device *dev)
 
 static void pcie_get_ltr_max_latencies(u16 *max_snoop, u16 *max_nosnoop)
 {
-	*max_snoop = PCIE_LTR_MAX_SNOOP_LATENCY_3146US;
-	*max_nosnoop = PCIE_LTR_MAX_NO_SNOOP_LATENCY_3146US;
+	*max_snoop = CONFIG_PCIE_LTR_MAX_SNOOP_LATENCY;
+	*max_nosnoop = CONFIG_PCIE_LTR_MAX_NO_SNOOP_LATENCY;
 }
 
 static struct pci_operations pcie_ops = {
@@ -66,6 +67,36 @@ struct device_operations pcie_rp_ops = {
 };
 
 static const unsigned short pcie_device_ids[] = {
+	PCI_DID_INTEL_PTL_H_PCIE_RP1,
+	PCI_DID_INTEL_PTL_H_PCIE_RP2,
+	PCI_DID_INTEL_PTL_H_PCIE_RP3,
+	PCI_DID_INTEL_PTL_H_PCIE_RP4,
+	PCI_DID_INTEL_PTL_H_PCIE_RP5,
+	PCI_DID_INTEL_PTL_H_PCIE_RP6,
+	PCI_DID_INTEL_PTL_H_PCIE_RP7,
+	PCI_DID_INTEL_PTL_H_PCIE_RP8,
+	PCI_DID_INTEL_PTL_H_PCIE_RP9,
+	PCI_DID_INTEL_PTL_H_PCIE_RP10,
+	PCI_DID_INTEL_PTL_U_H_PCIE_RP1,
+	PCI_DID_INTEL_PTL_U_H_PCIE_RP2,
+	PCI_DID_INTEL_PTL_U_H_PCIE_RP3,
+	PCI_DID_INTEL_PTL_U_H_PCIE_RP4,
+	PCI_DID_INTEL_PTL_U_H_PCIE_RP5,
+	PCI_DID_INTEL_PTL_U_H_PCIE_RP6,
+	PCI_DID_INTEL_PTL_U_H_PCIE_RP7,
+	PCI_DID_INTEL_PTL_U_H_PCIE_RP8,
+	PCI_DID_INTEL_PTL_U_H_PCIE_RP9,
+	PCI_DID_INTEL_PTL_U_H_PCIE_RP10,
+	PCI_DID_INTEL_PTL_U_H_PCIE_RP11,
+	PCI_DID_INTEL_PTL_U_H_PCIE_RP12,
+	PCI_DID_INTEL_LNL_PCIE_RP1,
+	PCI_DID_INTEL_LNL_PCIE_RP2,
+	PCI_DID_INTEL_LNL_PCIE_RP3,
+	PCI_DID_INTEL_LNL_PCIE_RP4,
+	PCI_DID_INTEL_LNL_PCIE_RP5,
+	PCI_DID_INTEL_LNL_PCIE_RP6,
+	PCI_DID_INTEL_LNL_PCIE_RP7,
+	PCI_DID_INTEL_LNL_PCIE_RP8,
 	PCI_DID_INTEL_RPL_P_PCIE_RP1,
 	PCI_DID_INTEL_RPL_P_PCIE_RP2,
 	PCI_DID_INTEL_RPL_P_PCIE_RP3,
@@ -327,6 +358,34 @@ static const unsigned short pcie_device_ids[] = {
 	PCI_DID_INTEL_ADP_M_N_PCIE_RP10,
 	PCI_DID_INTEL_ADP_N_PCIE_RP11,
 	PCI_DID_INTEL_ADP_N_PCIE_RP12,
+	PCI_DID_INTEL_RPP_S_PCIE_RP1,
+	PCI_DID_INTEL_RPP_S_PCIE_RP2,
+	PCI_DID_INTEL_RPP_S_PCIE_RP3,
+	PCI_DID_INTEL_RPP_S_PCIE_RP4,
+	PCI_DID_INTEL_RPP_S_PCIE_RP5,
+	PCI_DID_INTEL_RPP_S_PCIE_RP6,
+	PCI_DID_INTEL_RPP_S_PCIE_RP7,
+	PCI_DID_INTEL_RPP_S_PCIE_RP8,
+	PCI_DID_INTEL_RPP_S_PCIE_RP9,
+	PCI_DID_INTEL_RPP_S_PCIE_RP10,
+	PCI_DID_INTEL_RPP_S_PCIE_RP11,
+	PCI_DID_INTEL_RPP_S_PCIE_RP12,
+	PCI_DID_INTEL_RPP_S_PCIE_RP13,
+	PCI_DID_INTEL_RPP_S_PCIE_RP14,
+	PCI_DID_INTEL_RPP_S_PCIE_RP15,
+	PCI_DID_INTEL_RPP_S_PCIE_RP16,
+	PCI_DID_INTEL_RPP_S_PCIE_RP17,
+	PCI_DID_INTEL_RPP_S_PCIE_RP18,
+	PCI_DID_INTEL_RPP_S_PCIE_RP19,
+	PCI_DID_INTEL_RPP_S_PCIE_RP20,
+	PCI_DID_INTEL_RPP_S_PCIE_RP21,
+	PCI_DID_INTEL_RPP_S_PCIE_RP22,
+	PCI_DID_INTEL_RPP_S_PCIE_RP23,
+	PCI_DID_INTEL_RPP_S_PCIE_RP24,
+	PCI_DID_INTEL_RPP_S_PCIE_RP25,
+	PCI_DID_INTEL_RPP_S_PCIE_RP26,
+	PCI_DID_INTEL_RPP_S_PCIE_RP27,
+	PCI_DID_INTEL_RPP_S_PCIE_RP28,
 	0
 };
 
