@@ -13,25 +13,6 @@
 #include <soc/iomap.h>
 #include "chip.h"
 
-/*
- * The "ExternalFacingPort" and "HotPlugSupportInD3" properties are defined at
- * https://docs.microsoft.com/en-us/windows-hardware/drivers/pci/dsd-for-pcie-root-ports
- */
-#define PCIE_EXTERNAL_PORT_UUID "EFCC06CC-73AC-4BC3-BFF0-76143807C389"
-#define PCIE_EXTERNAL_PORT_PROPERTY "ExternalFacingPort"
-
-#define PCIE_HOTPLUG_IN_D3_UUID "6211E2C0-58A3-4AF3-90E1-927A4E0C55A4"
-#define PCIE_HOTPLUG_IN_D3_PROPERTY "HotPlugSupportInD3"
-
-/*
- * This UUID and the resulting ACPI Device Property is defined by the
- * Power Management for Storage Hardware Devices:
- *
- * https://docs.microsoft.com/en-us/windows-hardware/design/component-guidelines/power-management-for-storage-hardware-devices-intro
- */
-#define PCIE_RTD3_STORAGE_UUID "5025030F-842F-4AB4-A561-99A5189762D0"
-#define PCIE_RTD3_STORAGE_PROPERTY "StorageD3Enable"
-
 /* PCIe Root Port registers for link status and L23 control. */
 #define PCH_PCIE_CFG_LSTS 0x52	  /* Link Status Register */
 #define PCH_PCIE_CFG_SPR 0xe0	  /* Scratchpad */
@@ -47,6 +28,9 @@
 /* ACPI path to the mutex that protects accesses to PMC ModPhy power gating registers */
 #define RTD3_MUTEX_PATH "\\_SB.PCI0.R3MX"
 
+/* ACPI path to control PCIE CLK by P2SB */
+#define RTD3_PCIE_CLK_ENABLE_PATH "\\_SB.PCI0.SPCO"
+
 enum modphy_pg_state {
 	PG_DISABLE = 0,
 	PG_ENABLE = 1,
@@ -140,11 +124,24 @@ static void pcie_rtd3_acpi_method_srck(unsigned int pcie_rp,
 	acpigen_pop_len(); /* Method */
 }
 
+/* Method to enable/disable pcie clock by p2sb*/
+static void p2sb_acpi_set_pci_clock(u8 srcclk_pin, bool enable)
+{
+	acpigen_write_if_cond_ref_of(RTD3_PCIE_CLK_ENABLE_PATH);
+	acpigen_emit_namestring(RTD3_PCIE_CLK_ENABLE_PATH);
+	acpigen_write_integer(srcclk_pin);
+	acpigen_write_integer(enable);
+	acpigen_write_if_end();
+}
+
 static void
 pcie_rtd3_acpi_method_on(unsigned int pcie_rp,
 			 const struct soc_intel_common_block_pcie_rtd3_config *config,
-			 enum pcie_rp_type rp_type)
+			 enum pcie_rp_type rp_type,
+			 const struct device *dev)
 {
+	const struct device *parent = dev->upstream->dev;
+
 	acpigen_write_method_serialized("_ON", 0);
 
 	/* When this feature is enabled, ONSK indicates if the previous _OFF was
@@ -154,6 +151,26 @@ pcie_rtd3_acpi_method_on(unsigned int pcie_rp,
 	if (config->skip_on_off_support)
 		acpigen_write_if_lequal_namestr_int("ONSK", 0);
 
+	/* The _STA returns current power status of device, so we can skip _ON
+	 * if _STA returns 1
+	 * Example:
+	 * Local0 = \_SB.PCI0.RP01.RTD3._STA ()
+	 * If ((Local0 == One))
+	 * {
+	 *   Return (One)
+	 * }
+	 */
+	acpigen_write_store();
+	acpigen_emit_namestring(acpi_device_path_join(parent, "RTD3._STA"));
+	acpigen_emit_byte(LOCAL0_OP);
+	acpigen_write_if_lequal_op_int(LOCAL0_OP, ONE_OP);
+	acpigen_write_return_op(ONE_OP);
+	acpigen_write_if_end();
+
+	if (config->use_rp_mutex)
+		acpigen_write_acquire(acpi_device_path_join(parent, RP_MUTEX_NAME),
+			ACPI_MUTEX_NO_TIMEOUT);
+
 	/* Disable modPHY power gating for PCH RPs. */
 	if (rp_type == PCIE_RP_PCH)
 		pcie_rtd3_enable_modphy_pg(pcie_rp, PG_DISABLE);
@@ -165,9 +182,13 @@ pcie_rtd3_acpi_method_on(unsigned int pcie_rp,
 			acpigen_write_sleep(config->enable_delay_ms);
 	}
 
-	/* Enable SRCCLK for root port if pin is defined. */
-	if (config->srcclk_pin >= 0)
-		pmc_ipc_acpi_set_pci_clock(pcie_rp, config->srcclk_pin, true);
+	/* Enable SRCCLK for this root port if pin is defined. */
+	if (config->srcclk_pin >= 0) {
+		if (CONFIG(PCIE_CLOCK_CONTROL_THROUGH_P2SB))
+			p2sb_acpi_set_pci_clock(config->srcclk_pin, true);
+		else
+			pmc_ipc_acpi_set_pci_clock(pcie_rp, config->srcclk_pin, true);
+	}
 
 	/* De-assert reset GPIO to bring device out of reset. */
 	if (config->reset_gpio.pin_count) {
@@ -180,6 +201,9 @@ pcie_rtd3_acpi_method_on(unsigned int pcie_rp,
 	if (!config->disable_l23)
 		pcie_rtd3_acpi_l23_exit();
 
+	if (config->use_rp_mutex)
+		acpigen_write_release(acpi_device_path_join(parent, RP_MUTEX_NAME));
+
 	if (config->skip_on_off_support) {
 		/* If current _ON is skipped, ONSK is decremented so that _ON will be
 		 * executed normally until _OFF is skipped again.
@@ -196,8 +220,12 @@ pcie_rtd3_acpi_method_on(unsigned int pcie_rp,
 static void
 pcie_rtd3_acpi_method_off(int pcie_rp,
 			  const struct soc_intel_common_block_pcie_rtd3_config *config,
-			  enum pcie_rp_type rp_type)
+			  enum pcie_rp_type rp_type,
+			  const struct device *dev)
+
 {
+	const struct device *parent = dev->upstream->dev;
+
 	acpigen_write_method_serialized("_OFF", 0);
 
 	/* When this feature is enabled, ONSK is checked to see if the device
@@ -208,6 +236,10 @@ pcie_rtd3_acpi_method_off(int pcie_rp,
 	if (config->skip_on_off_support)
 		acpigen_write_if_lequal_namestr_int("OFSK", 0);
 
+	if (config->use_rp_mutex)
+		acpigen_write_acquire(acpi_device_path_join(parent, RP_MUTEX_NAME),
+			ACPI_MUTEX_NO_TIMEOUT);
+
 	/* Trigger L23 ready entry flow unless disabled by config. */
 	if (!config->disable_l23)
 		pcie_rtd3_acpi_l23_entry();
@@ -224,8 +256,12 @@ pcie_rtd3_acpi_method_off(int pcie_rp,
 		pcie_rtd3_enable_modphy_pg(pcie_rp, PG_ENABLE);
 
 	/* Disable SRCCLK for this root port if pin is defined. */
-	if (config->srcclk_pin >= 0)
-		pmc_ipc_acpi_set_pci_clock(pcie_rp, config->srcclk_pin, false);
+	if (config->srcclk_pin >= 0) {
+		if (CONFIG(PCIE_CLOCK_CONTROL_THROUGH_P2SB))
+			p2sb_acpi_set_pci_clock(config->srcclk_pin, false);
+		else
+			pmc_ipc_acpi_set_pci_clock(pcie_rp, config->srcclk_pin, false);
+	}
 
 	/* De-assert enable GPIO to turn off device power. */
 	if (config->enable_gpio.pin_count) {
@@ -234,6 +270,9 @@ pcie_rtd3_acpi_method_off(int pcie_rp,
 			acpigen_write_sleep(config->enable_off_delay_ms);
 	}
 
+	if (config->use_rp_mutex)
+		acpigen_write_release(acpi_device_path_join(parent, RP_MUTEX_NAME));
+
 	if (config->skip_on_off_support) {
 		/* If current _OFF is skipped, ONSK is incremented so that the
 		 * following _ON will also be skipped. In addition, OFSK is decremented
@@ -259,25 +298,40 @@ pcie_rtd3_acpi_method_status(const struct soc_intel_common_block_pcie_rtd3_confi
 	const struct acpi_gpio *gpio;
 
 	acpigen_write_method("_STA", 0);
+	/*
+	 * Depending on the board configuration we use either the "enable" or
+	 * the "reset" pin to detect the status of the device. The logic for
+	 * each pin is detailed below.
+	 *
+	 * 1. For the "enable" pin:
+	 * | polarity    | tx value | get_tx_gpio() | State |
+	 * |-------------+----------+---------------+-------|
+	 * | active high |     0    |     0         |   0   |
+	 * | active high |     1    |     1(active) |   1   |
+	 * | active low  |     0    |     1(active) |   1   |
+	 * | active low  |     1    |     0         |   0   |
+	 *
+	 * 2. For the "reset" pin:
+	 * | polarity    | tx value | get_tx_gpio() | State |
+	 * |-------------+----------+---------------+-------|
+	 * | active high |     0    |     0         |   1   |
+	 * | active high |     1    |     1(active) |   0   |
+	 * | active low  |     0    |     1(active) |   0   |
+	 * | active low  |     1    |     0         |   1   |
+	 */
 
 	/* Use enable GPIO for status if provided, otherwise use reset GPIO. */
-	if (config->enable_gpio.pin_count)
+	if (config->enable_gpio.pin_count) {
 		gpio = &config->enable_gpio;
-	else
+		/* Read current GPIO state into Local0. */
+		acpigen_get_tx_gpio(gpio);
+	} else {
 		gpio = &config->reset_gpio;
-
-	/* Read current GPIO value into Local0. */
-	acpigen_get_tx_gpio(gpio);
-
-	/* Ensure check works for both active low and active high GPIOs. */
-	acpigen_write_store_int_to_op(gpio->active_low, LOCAL1_OP);
-
-	acpigen_write_if_lequal_op_op(LOCAL0_OP, LOCAL1_OP);
-	acpigen_write_return_op(ZERO_OP);
-	acpigen_write_else();
-	acpigen_write_return_op(ONE_OP);
-	acpigen_pop_len(); /* Else */
-
+		/* Read current GPIO state into Local0. */
+		acpigen_get_tx_gpio(gpio);
+		acpigen_write_not(LOCAL0_OP, LOCAL0_OP);
+	}
+	acpigen_write_return_op(LOCAL0_OP);
 	acpigen_pop_len(); /* Method */
 }
 
@@ -331,7 +385,7 @@ static void pcie_rtd3_acpi_fill_ssdt(const struct device *dev)
 
 	const struct soc_intel_common_block_pcie_rtd3_config *config = config_of(dev);
 	static const char *const power_res_states[] = {"_PR0"};
-	const struct device *parent = dev->bus->dev;
+	const struct device *parent = dev->upstream->dev;
 	const char *scope = acpi_device_path(parent);
 	const struct opregion opregion = OPREGION("PXCS", PCI_CONFIG, 0, 0xff);
 	const struct fieldlist fieldlist[] = {
@@ -347,7 +401,7 @@ static void pcie_rtd3_acpi_fill_ssdt(const struct device *dev)
 		FIELDLIST_NAMESTR(ACPI_REG_PCI_L23_RDY_DETECT, 1),
 	};
 	int pcie_rp;
-	struct acpi_dp *dsd, *pkg;
+	struct acpi_dp *dsd;
 
 	if (!is_dev_enabled(parent)) {
 		printk(BIOS_ERR, "%s: root port not enabled\n", __func__);
@@ -386,9 +440,10 @@ static void pcie_rtd3_acpi_fill_ssdt(const struct device *dev)
 			return;
 		}
 	}
-	if (config->srcclk_pin == 0) {
+	if (config->srcclk_pin == -1) {
 		if (config->ext_pm_support & ACPI_PCIE_RP_EMIT_SRCK) {
-			printk(BIOS_ERR, "%s: Can not export SRCK method\n", __func__);
+			printk(BIOS_ERR, "%s: Can not export SRCK method since clock source gating is not enabled\n",
+				__func__);
 			return;
 		}
 	}
@@ -407,6 +462,9 @@ static void pcie_rtd3_acpi_fill_ssdt(const struct device *dev)
 	/* The RTD3 power resource is added to the root port, not the device. */
 	acpigen_write_scope(scope);
 
+	if (config->use_rp_mutex)
+		acpigen_write_mutex(RP_MUTEX_NAME, 0);
+
 	if (config->desc)
 		acpigen_write_name_string("_DDN", config->desc);
 
@@ -448,22 +506,22 @@ static void pcie_rtd3_acpi_fill_ssdt(const struct device *dev)
 	}
 
 	pcie_rtd3_acpi_method_status(config);
-	pcie_rtd3_acpi_method_on(pcie_rp, config, rp_type);
-	pcie_rtd3_acpi_method_off(pcie_rp, config, rp_type);
+	pcie_rtd3_acpi_method_on(pcie_rp, config, rp_type, dev);
+	pcie_rtd3_acpi_method_off(pcie_rp, config, rp_type, dev);
 	acpigen_pop_len(); /* PowerResource */
 
 	/* Indicate to the OS that device supports hotplug in D3. */
 	dsd = acpi_dp_new_table("_DSD");
-	pkg = acpi_dp_new_table(PCIE_HOTPLUG_IN_D3_UUID);
-	acpi_dp_add_integer(pkg, PCIE_HOTPLUG_IN_D3_PROPERTY, 1);
-	acpi_dp_add_package(dsd, pkg);
+	acpi_device_add_hotplug_support_in_d3(dsd);
 
 	/* Indicate to the OS if the device provides an External facing port. */
-	if (config->is_external) {
-		pkg = acpi_dp_new_table(PCIE_EXTERNAL_PORT_UUID);
-		acpi_dp_add_integer(pkg, PCIE_EXTERNAL_PORT_PROPERTY, 1);
-		acpi_dp_add_package(dsd, pkg);
-	}
+	if (config->add_acpi_external_facing_port)
+		acpi_device_add_external_facing_port(dsd);
+
+	/* Indicate to the OS if the device has DMA property. */
+	if (config->add_acpi_dma_property)
+		acpi_device_add_dma_property(dsd);
+
 	acpi_dp_write(dsd);
 
 	/*
@@ -475,13 +533,12 @@ static void pcie_rtd3_acpi_fill_ssdt(const struct device *dev)
 		acpigen_write_device(acpi_device_name(dev));
 		acpigen_write_ADR(0);
 		acpigen_write_STA(ACPI_STATUS_DEVICE_ALL_ON);
-		acpigen_write_name_integer("_S0W", ACPI_DEVICE_SLEEP_D3_COLD);
+		if (CONFIG(D3COLD_SUPPORT))
+			acpigen_write_name_integer("_S0W", ACPI_DEVICE_SLEEP_D3_COLD);
+		else
+			acpigen_write_name_integer("_S0W", ACPI_DEVICE_SLEEP_D3_HOT);
 
-		dsd = acpi_dp_new_table("_DSD");
-		pkg = acpi_dp_new_table(PCIE_RTD3_STORAGE_UUID);
-		acpi_dp_add_integer(pkg, PCIE_RTD3_STORAGE_PROPERTY, 1);
-		acpi_dp_add_package(dsd, pkg);
-		acpi_dp_write(dsd);
+		acpi_device_add_storage_d3_enable(NULL);
 
 		acpigen_pop_len(); /* Device */
 
@@ -510,6 +567,6 @@ static void pcie_rtd3_acpi_enable(struct device *dev)
 }
 
 struct chip_operations soc_intel_common_block_pcie_rtd3_ops = {
-	CHIP_NAME("Intel PCIe Runtime D3")
+	.name = "Intel PCIe Runtime D3",
 	.enable_dev = pcie_rtd3_acpi_enable
 };
