@@ -430,6 +430,9 @@ static int pmc_prev_sleep_state(const struct chipset_power_state *ps)
 
 		/* Clear SLP_TYP. */
 		pmc_write_pm1_control(ps->pm1_cnt & ~(SLP_TYP));
+
+		/* Clear PM1_STATUS */
+		pmc_clear_pm1_status();
 	}
 
 	prev_sleep_state = soc_prev_sleep_state(ps, prev_sleep_state);
@@ -440,6 +443,34 @@ static int pmc_prev_sleep_state(const struct chipset_power_state *ps)
 	return prev_sleep_state;
 }
 
+static bool pmc_get_global_reset_sts_mmio(void)
+{
+	uint8_t *addr = pmc_mmio_regs();
+
+	return !!(read32p((uintptr_t)(addr + GEN_PMCON_A)) & GBL_RST_STS);
+}
+
+static bool pmc_get_global_reset_sts_pci(void)
+{
+#if defined(__SIMPLE_DEVICE__)
+	pci_devfn_t dev = PCI_DEV(0, PCI_SLOT(PCH_DEVFN_PMC), PCI_FUNC(PCH_DEVFN_PMC));
+#else
+	struct device *dev = pcidev_path_on_root(PCH_DEVFN_PMC);
+	if (!dev)
+		return false;
+#endif
+
+	return !!(pci_read_config32(dev, GEN_PMCON_A) & GBL_RST_STS);
+}
+
+static bool pmc_get_global_reset_sts(void)
+{
+	if (CONFIG(SOC_INTEL_MEM_MAPPED_PM_CONFIGURATION))
+		return pmc_get_global_reset_sts_mmio();
+	else
+		return pmc_get_global_reset_sts_pci();
+}
+
 void pmc_fill_pm_reg_info(struct chipset_power_state *ps)
 {
 	int i;
@@ -450,6 +481,21 @@ void pmc_fill_pm_reg_info(struct chipset_power_state *ps)
 	ps->pm1_en = inw(ACPI_BASE_ADDRESS + PM1_EN);
 	ps->pm1_cnt = pmc_read_pm1_control();
 
+	/*
+	 * Before system memory initialization, AP firmware should check the wake status
+	 * to determine if Intel CSE has reset the system and system sleep state (PM1_CNT)
+	 * holds a valid sleep entry?
+	 *
+	 * If not, then AP FW should force to take a S5 exit path (by programming the PM1_CNT)
+	 * register as per PM register initialization requirement for CSE.
+	 */
+	if (pmc_get_global_reset_sts() && (ps->pm1_sts & WAK_STS) && !(ps->pm1_cnt & SLP_TYP)) {
+		printk(BIOS_DEBUG, "Enforcing the S5 exit path\n");
+		uint32_t pm1_cnt_slp_type = SLP_TYP_S5 << SLP_TYP_SHIFT;
+		ps->pm1_cnt |= pm1_cnt_slp_type;
+		pmc_enable_pm1_control(pm1_cnt_slp_type);
+	}
+
 	printk(BIOS_DEBUG, "pm1_sts: %04x pm1_en: %04x pm1_cnt: %08x\n",
 	       ps->pm1_sts, ps->pm1_en, ps->pm1_cnt);
 
@@ -888,20 +934,16 @@ void pmc_send_bios_reset_pci_enum_done(void)
 		printk(BIOS_ERR, "PMC: Failed sending PCI Enumeration Done Command\n");
 }
 
-/*
- * This function reads and prints SoC QDF information using PMC interface
- * if SOC_QDF_DYNAMIC_READ_PMC config is enabled.
- */
-void pmc_dump_soc_qdf_info(void)
+char *retrieve_soc_qdf_info_via_pmc_ipc(void)
 {
 	struct pmc_ipc_buffer req = { 0 };
 	struct pmc_ipc_buffer rsp;
 	uint32_t cmd_reg;
 	int r;
-	char qdf_info[5];
+	static char qdf_info[5] = { 0 };
 
 	if (!CONFIG(SOC_QDF_DYNAMIC_READ_PMC))
-		return;
+		return NULL;
 
 	req.buf[0] = PMC_IPC_CMD_REGID_SOC_QDF;
 	cmd_reg = pmc_make_ipc_cmd(PMC_IPC_CMD_SOC_REG_ACC,
@@ -913,7 +955,7 @@ void pmc_dump_soc_qdf_info(void)
 	if (r < 0 || rsp.buf[0] == 0) {
 		printk(BIOS_ERR, "%s: pmc_send_ipc_cmd failed or QDF not available.\n",
 				__func__);
-		return;
+		return NULL;
 	}
 
 	qdf_info[0] = ((rsp.buf[0] >> 24) & 0xFF);
@@ -921,5 +963,18 @@ void pmc_dump_soc_qdf_info(void)
 	qdf_info[2] = ((rsp.buf[0] >> 8) & 0xFF);
 	qdf_info[3] = (rsp.buf[0] & 0xFF);
 	qdf_info[4] = '\0';
-	printk(BIOS_INFO, "SoC QDF: %s\n", qdf_info);
+
+	return qdf_info;
+}
+
+/*
+ * This function reads and prints SoC QDF information using PMC interface
+ * if SOC_QDF_DYNAMIC_READ_PMC config is enabled.
+ */
+void pmc_dump_soc_qdf_info(void)
+{
+	char *qdf = retrieve_soc_qdf_info_via_pmc_ipc();
+
+	if (qdf != NULL)
+		printk(BIOS_INFO, "SoC QDF: %s\n", qdf);
 }
