@@ -6,7 +6,6 @@
 #include <device/pci_ops.h>
 #include <device/device.h>
 #include <device/pci.h>
-#include <device/pci_def.h>
 #include <intelblocks/gpmr.h>
 #include <intelblocks/pcr.h>
 #include <intelblocks/pmclib.h>
@@ -23,8 +22,11 @@
 #define  TCO_BASE_EN		(1 << 8)
 #define  TCO_BASE_LOCK		(1 << 0)
 
-/* Get base address of TCO I/O registers. */
-static uint16_t tco_get_bar(void)
+#define TCO_TMR_MIN_VALUE	2
+#define TCO_TMR_MAX_VALUE	1023
+#define TCO_TMR_PERIOD_MS	600
+
+uint16_t tco_get_bar(void)
 {
 	return TCO_BASE_ADDRESS;
 }
@@ -57,7 +59,7 @@ void tco_lockdown(void)
 
 	/* TCO Lock down */
 	tcocnt = tco_read_reg(TCO1_CNT);
-	tcocnt |= TCO_LOCK;
+	tcocnt |= TCO1_LOCK;
 	tco_write_reg(TCO1_CNT, tcocnt);
 }
 
@@ -72,7 +74,10 @@ uint32_t tco_reset_status(void)
 
 	/* TCO Status 2 register */
 	tco2_sts = tco_read_reg(TCO2_STS);
-	tco_write_reg(TCO2_STS, tco2_sts | TCO_STS_SECOND_TO);
+	tco_write_reg(TCO2_STS, tco2_sts | TCO2_STS_SECOND_TO);
+
+	if (CONFIG(ACPI_WDAT_WDT))
+		tco_write_reg(TCO_MESSAGE1, tco2_sts & TCO2_STS_SECOND_TO);
 
 	return (tco2_sts << 16) | tco1_sts;
 }
@@ -84,7 +89,7 @@ static void tco_timer_disable(void)
 
 	/* Program TCO timer halt */
 	tcocnt = tco_read_reg(TCO1_CNT);
-	tcocnt |= TCO_TMR_HLT;
+	tcocnt |= TCO1_TMR_HLT;
 	tco_write_reg(TCO1_CNT, tcocnt);
 }
 
@@ -95,8 +100,8 @@ static void tco_intruder_smi_enable(void)
 
 	/* Make TCO issue an SMI on INTRD_DET assertion */
 	tcocnt = tco_read_reg(TCO2_CNT);
-	tcocnt &= ~TCO_INTRD_SEL_MASK;
-	tcocnt |= TCO_INTRD_SEL_SMI;
+	tcocnt &= ~TCO2_INTRD_SEL_MASK;
+	tcocnt |= TCO2_INTRD_SEL_SMI;
 	tco_write_reg(TCO2_CNT, tcocnt);
 }
 
@@ -138,3 +143,18 @@ void tco_configure(void)
 	if (CONFIG(SOC_INTEL_COMMON_BLOCK_SMM_TCO_ENABLE))
 		tco_intruder_smi_enable();
 }
+
+uint32_t tco_get_timer_period(void)
+{
+	return TCO_TMR_PERIOD_MS;
+}
+
+uint32_t tco_get_timer_min_value(void)
+{
+	return TCO_TMR_MIN_VALUE;
+}
+
+uint32_t tco_get_timer_max_value(void)
+{
+	return TCO_TMR_MAX_VALUE;
+}
