@@ -15,6 +15,7 @@
 #include <soc/nvs.h>
 #include <soc/pci_devs.h>
 #include <soc/systemagent.h>
+#include <static.h>
 #include <types.h>
 #include "systemagent_def.h"
 
@@ -274,7 +275,7 @@ static void systemagent_read_resources(struct device *dev)
 	int index = 0;
 
 	/**
-	 * If SoC has multiple PCIe domains, only reading resources from the first one.
+	 * If SoC has multiple PCIe domains, only read resources from the first one.
 	 */
 	if (!is_dev_on_domain0(dev))
 		return;
@@ -427,6 +428,8 @@ static const unsigned short systemagent_ids[] = {
 	PCI_DID_INTEL_PTL_U_ID_1,
 	PCI_DID_INTEL_PTL_H_ID_1,
 	PCI_DID_INTEL_PTL_H_ID_2,
+	PCI_DID_INTEL_PTL_H_ID_3,
+	PCI_DID_INTEL_PTL_H_ID_4,
 	PCI_DID_INTEL_LNL_M_ID,
 	PCI_DID_INTEL_LNL_M_ID_1,
 	PCI_DID_INTEL_MTL_M_ID,
@@ -531,6 +534,10 @@ static const unsigned short systemagent_ids[] = {
 	PCI_DID_INTEL_ADL_N_ID_3,
 	PCI_DID_INTEL_ADL_N_ID_4,
 	PCI_DID_INTEL_ADL_N_ID_5,
+	PCI_DID_INTEL_ADL_N_ID_6,
+	PCI_DID_INTEL_ADL_N_ID_7,
+	PCI_DID_INTEL_ADL_N_ID_8,
+	PCI_DID_INTEL_ADL_N_ID_9,
 	PCI_DID_INTEL_RPL_HX_ID_1,
 	PCI_DID_INTEL_RPL_HX_ID_2,
 	PCI_DID_INTEL_RPL_HX_ID_3,
