@@ -11,15 +11,15 @@
 #include <intelblocks/systemagent.h>
 #include <intelblocks/tcss.h>
 #include <inttypes.h>
+#include <lib.h>
 #include <security/vboot/vboot_common.h>
 #include <soc/pci_devs.h>
 #include <soc/pcr_ids.h>
 #include <soc/tcss.h>
 #include <drivers/intel/pmc_mux/conn/chip.h>
 
-#define BIAS_CTRL_VW_INDEX_SHIFT		16
-#define BIAS_CTRL_BIT_POS_SHIFT			8
 #define WAIT_FOR_DISPLAYPORT_TIMEOUT_MS		1000
+#define WAIT_FOR_DP_MODE_ENTRY_TIMEOUT_MS	1500
 #define WAIT_FOR_HPD_TIMEOUT_MS			3000
 
 static uint32_t tcss_make_conn_cmd(int u, int u3, int u2, int ufp, int hsl,
@@ -39,7 +39,6 @@ static uint32_t tcss_make_alt_mode_cmd_buf_0(int u, int u3, int m)
 	return TCSS_ALT_FIELD(USAGE, u) |
 		TCSS_ALT_FIELD(USB3, u3) |
 		TCSS_ALT_FIELD(MODE, m);
-
 }
 
 static uint32_t tcss_make_alt_mode_cmd_buf_1(int p, int c, int ufp, int dp)
@@ -63,7 +62,6 @@ static uint32_t tcss_make_hpd_mode_cmd(int u, int u3, int hpd_lvl, int hpd_irq)
 		TCSS_HPD_FIELD(USB3, u3) |
 		TCSS_HPD_FIELD(LVL, hpd_lvl) |
 		TCSS_HPD_FIELD(IRQ, hpd_irq);
-
 }
 
 static int send_pmc_req(int cmd_type, const struct pmc_ipc_buffer *req,
@@ -202,7 +200,21 @@ static int send_pmc_dp_hpd_request(int port, const struct usbc_mux_info *mux_dat
 	req.buf[0] = cmd;
 
 	return send_pmc_req(HPD_REQ, &req, &rsp, PMC_IPC_HPD_REQ_SIZE);
+}
 
+static uint8_t get_dp_mode(uint8_t dp_pin_mode)
+{
+	switch (dp_pin_mode) {
+	case MODE_DP_PIN_A:
+	case MODE_DP_PIN_B:
+	case MODE_DP_PIN_C:
+	case MODE_DP_PIN_D:
+	case MODE_DP_PIN_E:
+	case MODE_DP_PIN_F:
+		return log2(dp_pin_mode) + 1;
+	default:
+		return 0;
+	}
 }
 
 static int send_pmc_dp_mode_request(int port, const struct usbc_mux_info *mux_data,
@@ -228,30 +240,7 @@ static int send_pmc_dp_mode_request(int port, const struct usbc_mux_info *mux_da
 		GET_TCSS_ALT_FIELD(USB3, cmd),
 		GET_TCSS_ALT_FIELD(MODE, cmd));
 
-	switch (mux_data->dp_pin_mode) {
-	case MODE_DP_PIN_A:
-		dp_mode = 1;
-		break;
-	case MODE_DP_PIN_B:
-		dp_mode = 2;
-		break;
-	case MODE_DP_PIN_C:
-		dp_mode = 3;
-		break;
-	case MODE_DP_PIN_D:
-		dp_mode = 4;
-		break;
-	case MODE_DP_PIN_E:
-		dp_mode = 5;
-		break;
-	case MODE_DP_PIN_F:
-		dp_mode = 6;
-		break;
-	default:
-		dp_mode = 0;
-		break;
-	}
-
+	dp_mode = get_dp_mode(mux_data->dp_pin_mode);
 	cmd = tcss_make_alt_mode_cmd_buf_1(
 		mux_data->polarity,
 		mux_data->cable,
@@ -276,7 +265,7 @@ static int send_pmc_dp_mode_request(int port, const struct usbc_mux_info *mux_da
 	return 0;
 }
 
-static void tcss_init_mux(int port, const struct tcss_port_map *port_map)
+static void disconnect_tcss_devices(int port, const struct tcss_port_map *port_map)
 {
 	int ret;
 
@@ -312,6 +301,10 @@ static void tcss_configure_dp_mode(const struct tcss_port_map *port_map, size_t
 		if (ret < 0)
 			continue;
 
+		ret = ops->dp_ops.wait_for_dp_mode_entry(i, WAIT_FOR_DP_MODE_ENTRY_TIMEOUT_MS);
+		if (ret < 0)
+			continue;
+
 		ret = ops->dp_ops.wait_for_hpd(i, WAIT_FOR_HPD_TIMEOUT_MS);
 		if (ret < 0)
 			continue;
@@ -324,25 +317,51 @@ static void tcss_configure_dp_mode(const struct tcss_port_map *port_map, size_t
 
 		ret = send_pmc_connect_request(i, &mux_info, port_info);
 		if (ret) {
-			printk(BIOS_ERR, "Port %zd connect request failed\n", i);
+			printk(BIOS_ERR, "Port %zu connect request failed\n", i);
 			continue;
 		}
 		ret = send_pmc_safe_mode_request(i, &mux_info, port_info);
 		if (ret) {
-			printk(BIOS_ERR, "Port %zd safe mode request failed\n", i);
+			printk(BIOS_ERR, "Port %zu safe mode request failed\n", i);
 			continue;
 		}
 
 		ret = send_pmc_dp_mode_request(i, &mux_info, port_info);
 		if (ret) {
-			printk(BIOS_ERR, "Port C%zd mux set failed with error %d\n", i, ret);
+			printk(BIOS_ERR, "Port C%zu mux set failed with error %d\n", i, ret);
 		} else {
-			printk(BIOS_INFO, "Port C%zd is configured to DP mode!\n", i);
+			printk(BIOS_INFO, "Port C%zu is configured to DP mode!\n", i);
 			return;
 		}
 	}
 }
 
+static void tcss_configure_usb_mode(const struct tcss_port_map *port_map, size_t num_ports)
+{
+	int ret;
+	size_t i;
+	const struct usbc_ops *ops;
+	struct usbc_mux_info mux_info;
+	const struct tcss_port_map *port_info;
+
+	ops = usbc_get_ops();
+	if (ops == NULL)
+		return;
+
+	for (i = 0; i < num_ports; i++) {
+		ret = ops->mux_ops.get_mux_info(i, &mux_info);
+		if ((ret < 0) || !mux_info.usb || (mux_info.dp && mux_info.hpd_lvl))
+			continue;
+
+		port_info = &port_map[i];
+		ret = send_pmc_connect_request(i, &mux_info, port_info);
+		if (ret) {
+			printk(BIOS_ERR, "Port %zu connect request failed\n", i);
+			continue;
+		}
+	}
+}
+
 static uint32_t calc_bias_ctrl_reg_value(gpio_t pad)
 {
 	unsigned int vw_index, vw_bit;
@@ -419,13 +438,12 @@ void tcss_configure(const struct typec_aux_bias_pads aux_bias_pads[MAX_TYPE_C_PO
 	size_t i;
 
 	port_map = tcss_get_port_info(&num_ports);
-	if (port_map == NULL)
+	if ((port_map == NULL) || platform_is_resuming())
 		return;
 
-	if (!platform_is_resuming()) {
+	if (CONFIG(TCSS_HAS_USBC_OPS))
 		for (i = 0; i < num_ports; i++)
-			tcss_init_mux(i, &port_map[i]);
-	}
+			disconnect_tcss_devices(i, &port_map[i]);
 
 	/* This should be performed before alternate modes are entered */
 	if (tcss_ops.configure_aux_bias_pads)
@@ -433,6 +451,9 @@ void tcss_configure(const struct typec_aux_bias_pads aux_bias_pads[MAX_TYPE_C_PO
 
 	if (CONFIG(ENABLE_TCSS_DISPLAY_DETECTION))
 		tcss_configure_dp_mode(port_map, num_ports);
+
+	if (CONFIG(ENABLE_TCSS_USB_DETECTION))
+		tcss_configure_usb_mode(port_map, num_ports);
 }
 
 bool tcss_valid_tbt_auth(void)
