@@ -4,7 +4,6 @@
 #include <acpi/acpi_device.h>
 #include <device/device.h>
 #include <device/pci.h>
-#include <device/pci_def.h>
 #include <device/pci_ids.h>
 #include <intelblocks/tcss.h>
 #include <soc/pci_devs.h>
@@ -53,6 +52,10 @@ static void tbt_dma_fill_ssdt(const struct device *dev)
 #endif
 
 static const unsigned short pci_device_ids[] = {
+	PCI_DID_INTEL_PTL_TBT_DMA0,
+	PCI_DID_INTEL_PTL_TBT_DMA1,
+	PCI_DID_INTEL_LNL_TBT_DMA0,
+	PCI_DID_INTEL_LNL_TBT_DMA1,
 	PCI_DID_INTEL_RPL_TBT_DMA0,
 	PCI_DID_INTEL_RPL_TBT_DMA1,
 	PCI_DID_INTEL_MTL_M_TBT_DMA0,
