@@ -5,6 +5,7 @@
 #include <device/pci_ids.h>
 #include <intelblocks/xdci.h>
 #include <security/vboot/vboot_common.h>
+#include <stdbool.h>
 
 __weak void soc_xdci_init(struct device *dev) { /* no-op */ }
 
@@ -27,6 +28,8 @@ struct device_operations usb_xdci_ops = {
 };
 
 static const unsigned short pci_device_ids[] = {
+	PCI_DID_INTEL_PTL_H_XDCI,
+	PCI_DID_INTEL_PTL_U_H_XDCI,
 	PCI_DID_INTEL_MTL_XDCI,
 	PCI_DID_INTEL_APL_XDCI,
 	PCI_DID_INTEL_CNL_LP_XDCI,
@@ -42,6 +45,7 @@ static const unsigned short pci_device_ids[] = {
 	PCI_DID_INTEL_ADP_P_XDCI,
 	PCI_DID_INTEL_ADP_S_XDCI,
 	PCI_DID_INTEL_ADP_M_XDCI,
+	PCI_DID_INTEL_RPP_S_XDCI,
 	0
 };
 
