@@ -3,6 +3,7 @@
 #include <acpi/acpi_device.h>
 #include <console/console.h>
 #include <device/device.h>
+#include <device/mmio.h>
 #include <device/pci.h>
 #include <device/pci_ids.h>
 #include <drivers/usb/acpi/chip.h>
@@ -27,7 +28,7 @@ static uint8_t *xhci_mem_base(void)
 	if (mem_base == 0 || mem_base == 0xffffffff)
 		return 0;
 
-	return (uint8_t *)(mem_base & ~PCI_BASE_ADDRESS_MEM_ATTR_MASK);
+	return (uint8_t *)(uintptr_t)(mem_base & ~PCI_BASE_ADDRESS_MEM_ATTR_MASK);
 }
 
 void xhci_host_reset(void)
@@ -68,7 +69,7 @@ static bool is_usb_port_connected(const struct xhci_usb_info *info,
 	else
 		port_sts_reg = (uintptr_t)res->base +
 				info->usb3_port_status_reg + port_id * 0x10;
-	port_status = read32((void *)port_sts_reg);
+	port_status = read32p(port_sts_reg);
 
 	/* Ensure that the status is not all 1s */
 	if (port_status == 0xffffffff)
@@ -91,8 +92,8 @@ void usb_xhci_disable_unused(bool (*ext_usb_xhci_en_cb)(unsigned int port_type,
 		return;
 	}
 
-	while ((hub = dev_bus_each_child(xhci->link_list, hub)) != NULL) {
-		while ((port = dev_bus_each_child(hub->link_list, port)) != NULL) {
+	while ((hub = dev_bus_each_child(xhci->downstream, hub)) != NULL) {
+		while ((port = dev_bus_each_child(hub->downstream, port)) != NULL) {
 			enable = true;
 			config = config_of(port);
 			if (config->type == UPC_TYPE_INTERNAL) {
@@ -130,6 +131,9 @@ struct device_operations usb_xhci_ops = {
 };
 
 static const unsigned short pci_device_ids[] = {
+	PCI_DID_INTEL_PTL_H_XHCI,
+	PCI_DID_INTEL_PTL_U_H_XHCI,
+	PCI_DID_INTEL_LNL_XHCI,
 	PCI_DID_INTEL_MTL_XHCI,
 	PCI_DID_INTEL_APL_XHCI,
 	PCI_DID_INTEL_CNL_LP_XHCI,
@@ -147,6 +151,8 @@ static const unsigned short pci_device_ids[] = {
 	PCI_DID_INTEL_ADP_P_XHCI,
 	PCI_DID_INTEL_ADP_S_XHCI,
 	PCI_DID_INTEL_ADP_M_XHCI,
+	PCI_DID_INTEL_RPP_S_XHCI,
+	PCI_DID_INTEL_SNR_XHCI,
 	0
 };
 
