@@ -74,16 +74,16 @@ static void sanity_check_pci_mmconf(void)
 		break;
 	}
 
-	assert(base == CONFIG_MMCONF_BASE_ADDRESS);
-	assert(length == CONFIG_MMCONF_BUS_NUMBER);
+	assert(base == CONFIG_ECAM_MMCONF_BASE_ADDRESS);
+	assert(length == CONFIG_ECAM_MMCONF_BUS_NUMBER);
 }
 
 void bootblock_soc_early_init(void)
 {
-
 #if (CONFIG(CONSOLE_SERIAL))
 	early_uart_init();
 #endif
+	fast_spi_early_init(DEFAULT_SPI_BASE);
 };
 
 void bootblock_soc_init(void)
