@@ -112,7 +112,9 @@ static void save_dimm_info(void)
 					meminfo_hob->VddVoltage[memProfNum],
 					meminfo_hob->EccSupport,
 					src_dimm->MfgId,
-					src_dimm->SpdModuleType);
+					src_dimm->SpdModuleType,
+					node,
+					meminfo_hob->MaximumMemoryClockSpeed);
 				index++;
 			}
 		}
