@@ -108,11 +108,7 @@ struct soc_intel_jasperlake_config {
 		SaGv_Enabled,
 	} SaGv;
 
-	/* Rank Margin Tool
-	 *
-	 * true: Enable
-	 * false: Disable
-	 */
+	/* Rank Margin Tool */
 	bool RMT;
 
 	/* USB related */
@@ -156,6 +152,9 @@ struct soc_intel_jasperlake_config {
 	/* Probe CLKREQ# signal before enabling CLKREQ# based power management.*/
 	bool PcieRpClkReqDetect[CONFIG_MAX_ROOT_PORTS];
 
+	/* PCIe LTR: Enable (1) / Disable (0) */
+	uint8_t PcieRpLtrEnable[CONFIG_MAX_ROOT_PORTS];
+
 	/* PCIe RP L1 substate */
 	enum L1_substates_control PcieRpL1Substates[CONFIG_MAX_ROOT_PORTS];
 
@@ -178,7 +177,6 @@ struct soc_intel_jasperlake_config {
 	/* Gfx related */
 	bool SkipExtGfxScan;
 
-	/* Enable/Disable EIST. true:Enabled, false:Disabled */
 	bool eist_enable;
 
 	/* Enable C6 DRAM */
@@ -229,9 +227,6 @@ struct soc_intel_jasperlake_config {
 	/* Enable Pch iSCLK */
 	bool pch_isclk;
 
-	/* CNVi BT Audio Offload: Enable/Disable BT Audio Offload. */
-	bool CnviBtAudioOffload;
-
 	/* Tcss */
 	bool TcssXhciEn;
 	bool TcssXdciEn;
@@ -263,10 +258,8 @@ struct soc_intel_jasperlake_config {
 	uint8_t DdiPortAConfig;
 	uint8_t DdiPortBConfig;
 
-	/* HDP config
-	 *
-	 * true: Enable HDB
-	 * false: Disable HDP
+	/*
+	 * HDP config
 	 */
 	bool DdiPortAHpd;
 	bool DdiPortBHpd;
@@ -276,10 +269,8 @@ struct soc_intel_jasperlake_config {
 	bool DdiPort3Hpd;
 	bool DdiPort4Hpd;
 
-	/* DDC config
-	 *
-	 * true: Enable DDC
-	 * false: Disable DDC
+	/*
+	 * DDC config
 	 */
 	bool DdiPortADdc;
 	bool DdiPortBDdc;
@@ -411,9 +402,6 @@ struct soc_intel_jasperlake_config {
 
 	/*
 	 * Enable or Disable Acoustic Noise Mitigation feature.
-	 *
-	 * false: Disabled
-	 * true: Enabled
 	 */
 	bool AcousticNoiseMitigation;
 
