@@ -24,6 +24,7 @@
 #include <soc/pm.h>
 #include <soc/smbus.h>
 #include <soc/soc_chip.h>
+#include <static.h>
 #include <types.h>
 
 /*
@@ -149,12 +150,23 @@ uint32_t *soc_pmc_etr_addr(void)
 	return (uint32_t *)(soc_read_pmc_base() + ETR);
 }
 
+static void pmc_gpe0_different_values(const struct soc_intel_meteorlake_config *config)
+{
+	bool result = (config->pmc_gpe0_dw0 != config->pmc_gpe0_dw1) &&
+			 (config->pmc_gpe0_dw0 != config->pmc_gpe0_dw2) &&
+			 (config->pmc_gpe0_dw1 != config->pmc_gpe0_dw2);
+
+	assert(result);
+}
+
 void soc_get_gpi_gpe_configs(uint8_t *dw0, uint8_t *dw1, uint8_t *dw2)
 {
 	DEVTREE_CONST struct soc_intel_meteorlake_config *config;
 
 	config = config_of_soc();
 
+	pmc_gpe0_different_values(config);
+
 	/* Assign to out variable */
 	*dw0 = config->pmc_gpe0_dw0;
 	*dw1 = config->pmc_gpe0_dw1;
