@@ -8,7 +8,7 @@
 
 #define PCH_P2SB_EPMASK0		0x220
 
-extern struct device_operations soc_p2sb_ops;
-extern struct device_operations soc_p2sb_2_ops;
+extern struct device_operations pcd_p2sb_ops;
+extern struct device_operations pcd_p2sb_2_ops;
 
-#endif /* _SOC_PANTHERLAKE_P2SB_H_ */
+#endif
