@@ -2,20 +2,10 @@
 
 #include <device/mmio.h>
 #include <intelblocks/cfg.h>
-#include <intelblocks/lpc_lib.h>
 #include <intelblocks/pmclib.h>
 #include <intelpch/lockdown.h>
 #include <soc/pm.h>
 
-static void lpc_lockdown_config(int chipset_lockdown)
-{
-	/* Set BIOS Interface Lock, BIOS Lock */
-	if (chipset_lockdown == CHIPSET_LOCKDOWN_COREBOOT) {
-		lpc_set_bios_interface_lock_down();
-		lpc_set_lock_enable();
-	}
-}
-
 static void pmc_lockdown_config(void)
 {
 	uint8_t *pmcbase;
@@ -33,9 +23,6 @@ static void pmc_lockdown_config(void)
 
 void soc_lockdown_config(int chipset_lockdown)
 {
-	/* LPC lock down configuration */
-	lpc_lockdown_config(chipset_lockdown);
-
 	/* PMC lock down configuration */
 	pmc_lockdown_config();
 }
