@@ -149,13 +149,13 @@ struct soc_intel_tigerlake_config {
 	uint8_t TcssD3HotDisable;
 
 	/* Enable DPTF support */
-	int dptf_enable;
+	bool dptf_enable;
 
 	/* Deep SX enable for both AC and DC */
-	int deep_s3_enable_ac;
-	int deep_s3_enable_dc;
-	int deep_s5_enable_ac;
-	int deep_s5_enable_dc;
+	bool deep_s3_enable_ac;
+	bool deep_s3_enable_dc;
+	bool deep_s5_enable_ac;
+	bool deep_s5_enable_dc;
 
 	/* Deep Sx Configuration
 	 *  DSX_EN_WAKE_PIN       - Enable WAKE# pin
@@ -285,12 +285,10 @@ struct soc_intel_tigerlake_config {
 
 	/* Gfx related */
 	uint8_t SkipExtGfxScan;
-
-	/* Enable/Disable EIST. true:Enabled, false:Disabled */
 	bool eist_enable;
 
 	/* Enable C6 DRAM */
-	uint8_t enable_c6dram;
+	bool enable_c6dram;
 
 	/*
 	 * SerialIO device mode selection:
@@ -504,29 +502,8 @@ struct soc_intel_tigerlake_config {
 	 *  - PM_CFG.SLP_LAN_MIN_ASST_WDTH
 	 */
 	uint8_t PchPmPwrCycDur;
-
-	/*
-	 * External Clock Gate
-	 * true = Mainboard design uses external clock gating
-	 * false = Mainboard design does not use external clock gating
-	 *
-	 */
 	bool external_clk_gated;
-
-	/*
-	 * External PHY Gate
-	 * true = Mainboard design uses external phy gating
-	 * false = Mainboard design does not use external phy gating
-	 *
-	 */
 	bool external_phy_gated;
-
-	/*
-	 * External Bypass Enable
-	 * true = Mainboard design uses external bypass rail
-	 * false = Mainboard design does not use external bypass rail
-	 *
-	 */
 	bool external_bypass;
 
 	/* i915 struct for GMA backlight control */
