@@ -20,6 +20,7 @@
 #include <soc/pci_devs.h>
 #include <soc/pm.h>
 #include <soc/soc_chip.h>
+#include <static.h>
 #include <bootstate.h>
 
 #define PMC_HID		"INTC1026"
@@ -84,7 +85,7 @@ static void soc_pmc_read_resources(struct device *dev)
 	struct resource *res;
 
 	/* Add the fixed MMIO resource */
-	mmio_resource_kb(dev, 0, PCH_PWRM_BASE_ADDRESS / KiB, PCH_PWRM_BASE_SIZE / KiB);
+	mmio_range(dev, PWRMBASE, PCH_PWRM_BASE_ADDRESS, PCH_PWRM_BASE_SIZE);
 
 	/* Add the fixed I/O resource */
 	res = new_resource(dev, 1);
@@ -106,8 +107,7 @@ static void soc_pmc_fill_ssdt(const struct device *dev)
 
 	acpigen_write_name_string("_HID", PMC_HID);
 	acpigen_write_name_string("_DDN", "Intel(R) Tiger Lake IPC Controller");
-	/* Hide the device so that Windows does not complain on missing driver */
-	acpigen_write_STA(ACPI_STATUS_DEVICE_HIDDEN_ON);
+	acpigen_write_STA(ACPI_STATUS_DEVICE_ALL_ON);
 
 	/*
 	 * Part of the PCH's reserved 32 MB MMIO range (0xFC800000 - 0xFE7FFFFF).
