@@ -34,10 +34,8 @@ void get_iiostack_info(struct iiostack_resource *info);
 
 const struct SystemMemoryMapHob *get_system_memory_map(void);
 
-uint8_t socket0_get_ubox_busno(const uint8_t stack);
 uint8_t get_cxl_node_count(void);
 
-int soc_get_stack_for_port(int port);
 void soc_set_mrc_cold_boot_flag(bool cold_boot_required);
 
 #endif /* _SOC_UTIL_H_ */
