@@ -9,9 +9,9 @@
 		.mask_bits = mask_bits_, .description = desc_,            \
 	}
 
-#define MAP_ENTRY_BASE_64(reg_, desc_) MAP_ENTRY(reg_, 1, 0, 0, desc_)
+#define MAP_ENTRY_BASE_64(reg_, desc_) MAP_ENTRY(reg_, 1, 0, 12, desc_)
 #define MAP_ENTRY_LIMIT_64(reg_, mask_bits_, desc_) MAP_ENTRY(reg_, 1, 1, mask_bits_, desc_)
-#define MAP_ENTRY_BASE_32(reg_, desc_) MAP_ENTRY(reg_, 0, 0, 0, desc_)
+#define MAP_ENTRY_BASE_32(reg_, desc_) MAP_ENTRY(reg_, 0, 0, 12, desc_)
 #define MAP_ENTRY_LIMIT_32(reg_, mask_bits_, desc_) MAP_ENTRY(reg_, 0, 1, mask_bits_, desc_)
 
 // SPI BAR0 MMIO base address
@@ -22,13 +22,6 @@
 #define ACPI_BASE_ADDRESS            CONFIG_INTEL_ACPI_BASE_ADDRESS
 #define ACPI_BASE_SIZE		0x100
 
-/* Video RAM */
-#define VGA_BASE_ADDRESS             0xa0000
-#define VGA_BASE_SIZE                0x20000
-
-/* High Performance Event Timer */
-#define HPET_BASE_ADDRESS            0xfed00000
-
 #define HECI1_BASE_ADDRESS	0xfed1a000
 
 #define PCH_PWRM_BASE_ADDRESS   CONFIG_INTEL_PCH_PWRM_BASE_ADDRESS
