@@ -4,6 +4,7 @@
 #include <cbmem.h>
 #include <console/console.h>
 #include <device/pci_ops.h>
+#include <device/pci_ids.h>
 #include <cpu/x86/smm.h>
 #include <soc/soc_util.h>
 #include <soc/pci_devs.h>
@@ -29,12 +30,13 @@ void smm_region(uintptr_t *start, size_t *size)
 
 void fill_postcar_frame(struct postcar_frame *pcf)
 {
-	const uintptr_t top_of_ram = (uintptr_t)cbmem_top();
+	const uintptr_t top_of_ram = cbmem_top();
 	uintptr_t cbmem_base;
 	size_t cbmem_size;
 
 	/* Try account for the CBMEM region currently used and for future use */
-	cbmem_get_region((void **)&cbmem_base, &cbmem_size);
+	if (cbmem_get_region((void **)&cbmem_base, &cbmem_size))
+		die("Could not find cbmem region");
 	printk(BIOS_DEBUG, "top_of_ram = 0x%lx\n", top_of_ram);
 	printk(BIOS_DEBUG, "cbmem base_ptr: 0x%lx, size: 0x%zx\n", cbmem_base, cbmem_size);
 	/* Assume 4MiB will be enough for future cbmem objects (FSP-S, ramstage, ...) */
@@ -53,7 +55,6 @@ void fill_postcar_frame(struct postcar_frame *pcf)
 #if !defined(__SIMPLE_DEVICE__)
 union dpr_register txt_get_chipset_dpr(void)
 {
-	const IIO_UDS *hob = get_iio_uds();
 	union dpr_register dpr;
 	struct device *dev = VTD_DEV(0);
 
@@ -66,28 +67,15 @@ union dpr_register txt_get_chipset_dpr(void)
 
 	dpr.raw = pci_read_config32(dev, VTD_LTDPR);
 
-	/* Compare the LTDPR register on all iio stacks */
-	for (int socket = 0; socket < hob->PlatformData.numofIIO; ++socket) {
-		for (int stack = 0; stack < MAX_IIO_STACK; ++stack) {
-			const STACK_RES *ri =
-				&hob->PlatformData.IIO_resource[socket].StackRes[stack];
-			if (!is_iio_stack_res(ri))
-				continue;
-			uint8_t bus = ri->BusBase;
-			dev = VTD_DEV(bus);
-
-			if (!dev) {
-				printk(BIOS_ERR, "BUS %x: Unable to find VTD PCI dev\n", bus);
-				dpr.raw = 0;
-				return  dpr;
-			}
-
-			union dpr_register test_dpr = { .raw = pci_read_config32(dev, VTD_LTDPR) };
-			if (dpr.raw != test_dpr.raw) {
-				printk(BIOS_ERR, "LTDPR not the same on all IIO's");
-				dpr.raw = 0;
-				return dpr;
-			}
+	dev = NULL;
+	/* Look for VTD devices on all sockets */
+	while ((dev = dev_find_device(PCI_VID_INTEL, MMAP_VTD_STACK_CFG_REG_DEVID, dev))) {
+		/* Compare the LTDPR register on all iio stacks */
+		union dpr_register test_dpr = { .raw = pci_read_config32(dev, VTD_LTDPR) };
+		if (dpr.raw != test_dpr.raw) {
+			printk(BIOS_ERR, "LTDPR not the same on all IIO's");
+			dpr.raw = 0;
+			return dpr;
 		}
 	}
 	return dpr;
