@@ -9,13 +9,8 @@
 #define xSTACK_RES STACK_RES
 #define xIIO_RESOURCE_INSTANCE IIO_RESOURCE_INSTANCE
 
-void config_reset_cpl3_csrs(void);
-
 const struct SystemMemoryMapHob *get_system_memory_map(void);
 
-uint8_t socket0_get_ubox_busno(const uint8_t stack);
-
-int soc_get_stack_for_port(int port);
 uint8_t get_cxl_node_count(void);
 
 #endif /* _SOC_UTIL_H_ */
