@@ -8,10 +8,14 @@ struct power_domain_data {
 	u32 pwr_sta_mask;
 	u32 sram_pdn_mask;
 	u32 sram_ack_mask;
+	u32 ext_buck_iso_bits;
 	u32 caps;
 };
 
-#define SCPD_SRAM_ISO	(1U << 0)
+#define SCPD_SRAM_ISO		BIT(0)
+#define SCPD_EXT_BUCK_ISO	BIT(1)
+
+void mtcmos_set_scpd_ext_buck_iso(const struct power_domain_data *pd);
 
 void mtcmos_power_on(const struct power_domain_data *pd);
 void mtcmos_adsp_power_on(void);
