@@ -22,6 +22,8 @@ enum mtk_regulator {
 	MTK_REGULATOR_VSRAM_PROC12,
 	MTK_REGULATOR_VRF12,
 	MTK_REGULATOR_VCN33,
+	MTK_REGULATOR_VDD18,
+	MTK_REGULATOR_VIO18,
 	MTK_REGULATOR_NUM,
 };
 
