@@ -5,8 +5,6 @@
 
 #include <soc/mcu_common.h>
 
-#define SPM_SYSTEM_BASE_OFFSET	0x40000000
-
 struct pcm_desc {
 	u32 pmem_words;
 	u32 total_words;
@@ -27,5 +25,8 @@ void spm_reset_and_init_pcm(void);
 void spm_set_wakeup_event(const struct pwr_ctrl *pwrctrl);
 void spm_extern_initialize(void);
 int spm_init(void);
+void spm_set_pcm_flags(const struct pwr_ctrl *pwrctrl);
+void spm_init_pcm_register(void);
+void spm_kick_pcm_to_run(const struct pwr_ctrl *pwrctrl);
 
 #endif  /* SOC_MEDIATEK_SPM_COMMON_H */
