@@ -1,13 +1,11 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
 #include <boot/coreboot_tables.h>
-#include <commonlib/stdlib.h>
 #include <console/console.h>
 #include <device/device.h>
 #include <device/mmio.h>
 #include <device/pci.h>
 #include <device/pci_ids.h>
-#include <device/resource.h>
 #include <delay.h>
 #include <lib.h>
 #include <soc/addressmap.h>
@@ -15,7 +13,6 @@
 #include <soc/pcie.h>
 #include <soc/pcie_common.h>
 #include <soc/soc_chip.h>
-#include <stdlib.h>
 #include <types.h>
 
 #define PCIE_SETTING_REG		0x80
@@ -99,7 +96,7 @@ static const char *const ltssm_str[] = {
 
 static uintptr_t mtk_pcie_get_controller_base(pci_devfn_t devfn)
 {
-	struct device *root_dev;
+	DEVTREE_CONST struct device *root_dev;
 	const mtk_soc_config_t *config;
 	static uintptr_t base = 0;
 
@@ -127,11 +124,23 @@ volatile union pci_bank *pci_map_bus(pci_devfn_t dev)
 	return (void *)(base + PCIE_CFG_OFFSET_ADDR);
 }
 
-static int mtk_pcie_set_trans_window(struct device *dev, uintptr_t table,
+static void mtk_pcie_set_table(uintptr_t table, uint32_t cpu_addr,
+			       uint32_t pci_addr, uint32_t size, uint32_t attr)
+{
+	write32p(table, cpu_addr | PCIE_ATR_SIZE(__fls(size)));
+	write32p(table + PCIE_ATR_SRC_ADDR_MSB_OFFSET, 0);
+	write32p(table + PCIE_ATR_TRSL_ADDR_LSB_OFFSET, pci_addr);
+	write32p(table + PCIE_ATR_TRSL_ADDR_MSB_OFFSET, 0);
+	write32p(table + PCIE_ATR_TRSL_PARAM_OFFSET, attr);
+}
+
+static int mtk_pcie_set_trans_window(size_t *count, uintptr_t table_base,
 				     const struct mtk_pcie_mmio_res *mmio_res)
 {
 	const char *range_type;
+	uintptr_t table;
 	uint32_t table_attr;
+	uint32_t cpu_addr, pci_addr, remaining, size;
 
 	if (!mmio_res)
 		return -1;
@@ -148,17 +157,44 @@ static int mtk_pcie_set_trans_window(struct device *dev, uintptr_t table,
 		return -1;
 	}
 
-	write32p(table, mmio_res->cpu_addr |
-		 PCIE_ATR_SIZE(__fls(mmio_res->size)));
-	write32p(table + PCIE_ATR_SRC_ADDR_MSB_OFFSET, 0);
-	write32p(table + PCIE_ATR_TRSL_ADDR_LSB_OFFSET, mmio_res->pci_addr);
-	write32p(table + PCIE_ATR_TRSL_ADDR_MSB_OFFSET, 0);
-	write32p(table + PCIE_ATR_TRSL_PARAM_OFFSET, table_attr);
+	cpu_addr = mmio_res->cpu_addr;
+	pci_addr = mmio_res->pci_addr;
+	remaining = mmio_res->size;
 
-	printk(BIOS_INFO,
-	       "%s: set %s trans window: cpu_addr = %#x, pci_addr = %#x, size = %#x\n",
-	       __func__, range_type, mmio_res->cpu_addr, mmio_res->pci_addr,
-	       mmio_res->size);
+	while (remaining && *count < PCIE_MAX_TRANS_TABLES) {
+		/*
+		 * The table size needs to be a power of 2.
+		 * In addition, cpu_addr needs to be aligned to the size.
+		 */
+		size = BIT(__fls(remaining));
+
+		if (cpu_addr > 0)
+			size = MIN(size, BIT(__ffs(cpu_addr)));
+
+		/* Minimum size of translate table is 4KiB */
+		if (size < 4 * KiB) {
+			printk(BIOS_ERR, "%s: table size %#x is less than 4KiB\n",
+			       __func__, size);
+			return -1;
+		}
+
+		table = table_base + *count * PCIE_ATR_TLB_SET_OFFSET;
+		mtk_pcie_set_table(table, cpu_addr, pci_addr, size, table_attr);
+
+		printk(BIOS_INFO,
+		       "%s: set %s trans window: cpu_addr = %#x, pci_addr = %#x, size = %#x\n",
+		       __func__, range_type, cpu_addr, pci_addr, size);
+		cpu_addr += size;
+		pci_addr += size;
+		remaining -= size;
+		(*count)++;
+	}
+
+	if (remaining) {
+		printk(BIOS_ERR, "%s: Not enough translation windows, remaining size: %#x\n",
+		       __func__, remaining);
+		return -1;
+	}
 
 	return 0;
 }
@@ -194,22 +230,33 @@ void mtk_pcie_domain_set_resources(struct device *dev)
 {
 	const mtk_soc_config_t *config = config_of(dev);
 	const struct mtk_pcie_config *conf = &config->pcie_config;
-	uintptr_t table;
+	uintptr_t table_base = conf->base + PCIE_TRANS_TABLE_BASE_REG;
+	size_t count = 0;
 
 	/* Initialize I/O space constraints. */
-	table = conf->base + PCIE_TRANS_TABLE_BASE_REG;
-	if (mtk_pcie_set_trans_window(dev, table, &conf->mmio_res_io) < 0)
-		printk(BIOS_ERR, "%s: Failed to set IO window\n", __func__);
+	if (mtk_pcie_set_trans_window(&count, table_base, &conf->mmio_res_io) < 0) {
+		printk(BIOS_ERR, "%s: Failed to set IO window, ignore it\n",
+		       __func__);
+		count = 0;
+	}
 
 	/* Initialize memory resources constraints. */
-	table = conf->base + PCIE_TRANS_TABLE_BASE_REG +
-		PCIE_ATR_TLB_SET_OFFSET;
-	if (mtk_pcie_set_trans_window(dev, table, &conf->mmio_res_mem) < 0)
+	if (mtk_pcie_set_trans_window(&count, table_base, &conf->mmio_res_mem) < 0)
 		printk(BIOS_ERR, "%s: Failed to set MEM window\n", __func__);
 
 	pci_domain_set_resources(dev);
 }
 
+void mtk_pcie_reset(uintptr_t base_reg, bool enable)
+{
+	uint32_t flags = PCIE_MAC_RSTB | PCIE_PHY_RSTB | PCIE_BRG_RSTB | PCIE_PE_RSTB;
+
+	if (enable)
+		setbits32p(base_reg + PCIE_RST_CTRL_REG, flags);
+	else
+		clrbits32p(base_reg + PCIE_RST_CTRL_REG, flags);
+}
+
 enum cb_err fill_lb_pcie(struct lb_pcie *pcie)
 {
 	if (!pci_root_bus())
@@ -219,30 +266,9 @@ enum cb_err fill_lb_pcie(struct lb_pcie *pcie)
 	return CB_SUCCESS;
 }
 
-void mtk_pcie_domain_enable(struct device *dev)
+static void wait_perst_asserted(uintptr_t base)
 {
-	const mtk_soc_config_t *config = config_of(dev);
-	const struct mtk_pcie_config *conf = &config->pcie_config;
-	const char *ltssm_state;
 	long perst_time_us;
-	size_t tries = 0;
-	uint32_t val;
-
-	/* Set as RC mode */
-	val = read32p(conf->base + PCIE_SETTING_REG);
-	val |= PCIE_RC_MODE;
-	write32p(conf->base + PCIE_SETTING_REG, val);
-
-	/* Set class code */
-	val = read32p(conf->base + PCIE_PCI_IDS_1);
-	val &= ~GENMASK(31, 8);
-	val |= PCI_CLASS(PCI_CLASS_BRIDGE_PCI << 8);
-	write32p(conf->base + PCIE_PCI_IDS_1, val);
-
-	/* Mask all INTx interrupts */
-	val = read32p(conf->base + PCIE_INT_ENABLE_REG);
-	val &= ~PCIE_INTX_ENABLE;
-	write32p(conf->base + PCIE_INT_ENABLE_REG, val);
 
 	perst_time_us = early_init_get_elapsed_time_us(EARLY_INIT_PCIE);
 	printk(BIOS_DEBUG, "%s: %ld us elapsed since assert PERST#\n",
@@ -260,7 +286,7 @@ void mtk_pcie_domain_enable(struct device *dev)
 			printk(BIOS_WARNING,
 			       "%s: PCIe early init data not found, sleeping 100ms\n",
 			       __func__);
-			mtk_pcie_reset(conf->base + PCIE_RST_CTRL_REG, true);
+			mtk_pcie_reset(base, true);
 		} else {
 			printk(BIOS_WARNING,
 			       "%s: Need an extra %ld us delay to meet PERST# deassertion requirement\n",
@@ -269,9 +295,59 @@ void mtk_pcie_domain_enable(struct device *dev)
 
 		udelay(min_perst_time_us - perst_time_us);
 	}
+}
 
+static void deassert_perst(uintptr_t base)
+{
+	/* Set as RC mode */
+	setbits32p(base + PCIE_SETTING_REG, PCIE_RC_MODE);
+
+	/* Set class code */
+	clrsetbits32p(base + PCIE_PCI_IDS_1, GENMASK(31, 8),
+		      PCI_CLASS(PCI_CLASS_BRIDGE_PCI << 8));
+
+	/* Mask all INTx interrupts */
+	clrbits32p(base + PCIE_INT_ENABLE_REG, PCIE_INTX_ENABLE);
+
+	/* Above registers must be set before de-asserting PERST# */
 	/* De-assert reset signals */
-	mtk_pcie_reset(conf->base + PCIE_RST_CTRL_REG, false);
+	mtk_pcie_reset(base, false);
+}
+
+static void wait_perst_done(uintptr_t base)
+{
+	long perst_time_us;
+
+	wait_perst_asserted(base);
+
+	perst_time_us = early_init_get_elapsed_time_us(EARLY_INIT_PCIE_RESET);
+	printk(BIOS_DEBUG, "%s: %ld us elapsed since de-assert PERST#\n",
+	       __func__, perst_time_us);
+
+	if (!perst_time_us) {
+		printk(BIOS_INFO, "%s: PCIe early PERST# de-assertion is not done, "
+		       "de-assert PERST# now\n", __func__);
+		deassert_perst(base);
+	}
+}
+
+void mtk_pcie_deassert_perst(void)
+{
+	uintptr_t base = mtk_pcie_get_controller_base(0);
+
+	wait_perst_done(base);
+	early_init_save_time(EARLY_INIT_PCIE_RESET);
+}
+
+void mtk_pcie_domain_enable(struct device *dev)
+{
+	const mtk_soc_config_t *config = config_of(dev);
+	const struct mtk_pcie_config *conf = &config->pcie_config;
+	const char *ltssm_state;
+	size_t tries = 0;
+	uint32_t val;
+
+	wait_perst_done(conf->base);
 
 	if (!retry(100,
 		   (tries++, read32p(conf->base + PCIE_LINK_STATUS_REG) &
