@@ -21,15 +21,15 @@ static void tracker_dump_data(void)
 	for (j = 0; j < TRACKER_NUM; j++) {
 		tra = &tracker_data[j];
 
-		if (!(read32((void *)(tra->base_addr)) & tra->timeout))
+		if (!(read32p(tra->base_addr) & tra->timeout))
 			continue;
 
 		printk(BIOS_INFO, "**Dump %s debug register start**\n", tra->str);
-		for (k = 0; k < 2; k++) {
+		for (k = 0; k < tra->offsets_size; k++) {
 			size = 2 * tra->entry;
 			for (i = 0; i < size; i++) {
-				reg = tra->base_addr + tra->offset[k] + i * 4;
-				printk(BIOS_INFO, "%#lx:%#x,", reg, read32((void *)reg));
+				reg = tra->base_addr + tra->offsets[k] + i * 4;
+				printk(BIOS_INFO, "%#lx:%#x,", reg, read32p(reg));
 
 				if (i % 4 == 3 || i == size - 1)
 					printk(BIOS_INFO, "\n");
