@@ -6,9 +6,6 @@
 #include <device/mmio.h>
 #include <soc/addressmap.h>
 #include <soc/i2c.h>
-#include <soc/pll.h>
-
-#define I2C_CLK_HZ (AXI_HZ / 16)
 
 struct mtk_i2c mtk_i2c_bus_controller[7] = {
 	/* i2c0 setting */
@@ -52,6 +49,9 @@ struct mtk_i2c mtk_i2c_bus_controller[7] = {
 	}
 };
 
+_Static_assert(ARRAY_SIZE(mtk_i2c_bus_controller) == I2C_BUS_NUMBER,
+	       "Wrong size of mtk_i2c_bus_controller");
+
 #define I2CTAG                "[I2C][PL] "
 
 #if CONFIG(DEBUG_I2C)
@@ -60,8 +60,6 @@ struct mtk_i2c mtk_i2c_bus_controller[7] = {
 #define I2CLOG(fmt, arg...)
 #endif /* CONFIG_DEBUG_I2C */
 
-#define I2CERR(fmt, arg...)   printk(BIOS_ERR, I2CTAG fmt, ##arg)
-
 void mtk_i2c_bus_init(uint8_t bus)
 {
 	uint8_t step_div;
