@@ -8,7 +8,6 @@
 #include <console/console.h>
 #include <device/mmio.h>
 #include <delay.h>
-#include <stddef.h>
 #include <timer.h>
 
 #include <soc/addressmap.h>
@@ -468,7 +467,7 @@ void mt_pll_init(void)
 			INFRACFG_AO_PERI_BUS_REG0_2, 1);
 
 	for (i = 0; i < ARRAY_SIZE(mux_sels); i++)
-		mux_set_sel(&muxes[mux_sels[i].id], mux_sels[i].sel);
+		pll_mux_set_sel(&muxes[mux_sels[i].id], mux_sels[i].sel);
 
 	/* [4] SCP_CORE_CK_CG, [5] SEJ_CG */
 	write32(&mt8186_infracfg_ao->module_sw_cg_0_clr, 0x00000030);
@@ -525,6 +524,12 @@ void mt_pll_set_usb_clock(void)
 	SET32_BITFIELDS(&mtk_topckgen->usb_top_cfg, USB_TOP_CFG_MACRO_CTRL, 3);
 }
 
+void mt_pll_spmi_mux_select(void)
+{
+	/* 4: ulposc1_d10 */
+	pll_mux_set_sel(&muxes[TOP_SPMI_MST_SEL], 4);
+}
+
 u32 mt_fmeter_get_freq_khz(enum fmeter_type type, u32 id)
 {
 	u32 output, count, clk_dbg_cfg, clk_misc_cfg_0, clk26cali_0, clk26cali_1;
