@@ -1,8 +1,10 @@
 /* SPDX-License-Identifier: GPL-2.0-only OR MIT */
 
 #include <bootblock_common.h>
+#include <soc/eint_event.h>
 #include <soc/mmu_operations.h>
 #include <soc/pll.h>
+#include <soc/lastbus_v2.h>
 #include <soc/tracker_common.h>
 #include <soc/wdt.h>
 
@@ -10,6 +12,8 @@ void bootblock_soc_init(void)
 {
 	mtk_mmu_init();
 	bustracker_init();
+	lastbus_init();
 	mtk_wdt_init();
 	mt_pll_init();
+	unmask_eint_event_mask();
 }
