@@ -6,32 +6,38 @@
 static const struct apc_infra_peri_dom_16 infra_ao_sys0_devices[] = {
 	/* 0 */
 	DAPC_INFRA_AO_SYS0_ATTR("SPM_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN4,
+				NO_PROTECTION, FORBIDDEN),
 	DAPC_INFRA_AO_SYS0_ATTR("SPM_APB_S-1",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN6),
 	DAPC_INFRA_AO_SYS0_ATTR("SPM_APB_S-2",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN6),
 	DAPC_INFRA_AO_SYS0_ATTR("SPM_APB_S-4",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN6),
 	DAPC_INFRA_AO_SYS0_ATTR("APMIXEDSYS_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN2, NO_PROTECTION2, FORBIDDEN3,
+				NO_PROTECTION2, FORBIDDEN4, NO_PROTECTION, FORBIDDEN),
 	DAPC_INFRA_AO_SYS0_ATTR("APMIXEDSYS_APB_S-1",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN4,
+				NO_PROTECTION, FORBIDDEN),
 	DAPC_INFRA_AO_SYS0_ATTR("TINSYS_AO_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_INFRA_AO_SYS0_ATTR("TOPCKGEN_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN2, NO_PROTECTION2, FORBIDDEN3,
+				NO_PROTECTION2, FORBIDDEN6),
 	DAPC_INFRA_AO_SYS0_ATTR("INFRACFG_AO_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+				NO_PROTECTION2, FORBIDDEN4, NO_PROTECTION, FORBIDDEN),
 	DAPC_INFRA_AO_SYS0_ATTR("INFRACFG_AO_MEM_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN6),
 	/* 10 */
 	DAPC_INFRA_AO_SYS0_ATTR("PERICFG_AO_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN6),
 	DAPC_INFRA_AO_SYS0_ATTR("GPIO_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+				NO_PROTECTION2, FORBIDDEN6),
 	DAPC_INFRA_AO_SYS0_ATTR("TOPRGU_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN6),
 	DAPC_INFRA_AO_SYS0_ATTR("DSP_IRQ_APB_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_INFRA_AO_SYS0_ATTR("DEVICE_APC_INFRA_AO_APB_S",
@@ -39,18 +45,19 @@ static const struct apc_infra_peri_dom_16 infra_ao_sys0_devices[] = {
 	DAPC_INFRA_AO_SYS0_ATTR("BCRM_INFRA_AO_APB_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_INFRA_AO_SYS0_ATTR("DEBUG_CTRL_INFRA_AO_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN6),
 	DAPC_INFRA_AO_SYS0_ATTR("AP_CIRQ_EINT_APB_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_INFRA_AO_SYS0_ATTR("PMIC_WRAP_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN6),
 	DAPC_INFRA_AO_SYS0_ATTR("KP_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN6),
 	/* 20 */
 	DAPC_INFRA_AO_SYS0_ATTR("TOP_MISC_APB_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_INFRA_AO_SYS0_ATTR("DVFSRC_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+				NO_PROTECTION2, FORBIDDEN6),
 	DAPC_INFRA_AO_SYS0_ATTR("MBIST_AO_APB_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_INFRA_AO_SYS0_ATTR("HDMI_CEC_APB_S",
@@ -62,7 +69,8 @@ static const struct apc_infra_peri_dom_16 infra_ao_sys0_devices[] = {
 	DAPC_INFRA_AO_SYS0_ATTR("IRRX_APB_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_INFRA_AO_SYS0_ATTR("SYS_TIMER_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+				NO_PROTECTION2, FORBIDDEN6),
 	DAPC_INFRA_AO_SYS0_ATTR("MODEM_TEMP_SHARE_APB_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_INFRA_AO_SYS0_ATTR("PMIF1_APB_S",
@@ -71,9 +79,9 @@ static const struct apc_infra_peri_dom_16 infra_ao_sys0_devices[] = {
 	DAPC_INFRA_AO_SYS0_ATTR("PMICSPI_MST_APB_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_INFRA_AO_SYS0_ATTR("TIA_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN6),
 	DAPC_INFRA_AO_SYS0_ATTR("TOPCKGEN_INFRA_CFG_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN6),
 	DAPC_INFRA_AO_SYS0_ATTR("DRM_DEBUG_TOP_APB_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_INFRA_AO_SYS0_ATTR("EFUSE_DEBUG_AO_APB_S",
@@ -96,24 +104,24 @@ static const struct apc_infra_peri_dom_16 infra_ao_sys0_devices[] = {
 	DAPC_INFRA_AO_SYS0_ATTR("DEVICE_APC_FMEM_AO_APB_S",
 				SEC_RW_ONLY, FORBIDDEN15),
 	DAPC_INFRA_AO_SYS0_ATTR("PWM_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN6),
 	DAPC_INFRA_AO_SYS0_ATTR("PMSR_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN6),
 	DAPC_INFRA_AO_SYS0_ATTR("SRCLKEN_RC_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN6),
 	DAPC_INFRA_AO_SYS0_ATTR("MFG_S_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_INFRA_AO_SYS0_ATTR("MFG_S_S-1",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_INFRA_AO_SYS0_ATTR("MFG_S_S-2",
-				NO_PROTECTION, FORBIDDEN15),
+				SEC_RW_ONLY, FORBIDDEN15),
 	DAPC_INFRA_AO_SYS0_ATTR("MFG_S_S-3",
 				NO_PROTECTION, FORBIDDEN15),
 	/* 50 */
 	DAPC_INFRA_AO_SYS0_ATTR("MFG_S_S-4",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_INFRA_AO_SYS0_ATTR("MFG_S_S-5",
-				NO_PROTECTION, FORBIDDEN15),
+				SEC_RW_ONLY, FORBIDDEN15),
 	DAPC_INFRA_AO_SYS0_ATTR("MFG_S_S-6",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_INFRA_AO_SYS0_ATTR("MFG_S_S-7",
@@ -125,24 +133,30 @@ static const struct apc_infra_peri_dom_16 infra_ao_sys0_devices[] = {
 	DAPC_INFRA_AO_SYS0_ATTR("APU_S_S-1",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_INFRA_AO_SYS0_ATTR("APU_S_S-2",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN2, SEC_RW_ONLY, FORBIDDEN4,
+				SEC_RW_ONLY, FORBIDDEN7),
 	DAPC_INFRA_AO_SYS0_ATTR("APU_S_S-3",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_INFRA_AO_SYS0_ATTR("APU_S_S-4",
 				NO_PROTECTION, FORBIDDEN15),
 	/* 60 */
 	DAPC_INFRA_AO_SYS0_ATTR("APU_S_S-5",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN2, SEC_RW_ONLY, FORBIDDEN4,
+				SEC_RW_ONLY, FORBIDDEN7),
 	DAPC_INFRA_AO_SYS0_ATTR("MCUSYS_CFGREG_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN6),
 	DAPC_INFRA_AO_SYS0_ATTR("MCUSYS_CFGREG_APB_S-1",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN4,
+				NO_PROTECTION, FORBIDDEN),
 	DAPC_INFRA_AO_SYS0_ATTR("MCUSYS_CFGREG_APB_S-2",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN4,
+				NO_PROTECTION, FORBIDDEN),
 	DAPC_INFRA_AO_SYS0_ATTR("MCUSYS_CFGREG_APB_S-3",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN4,
+				NO_PROTECTION, FORBIDDEN),
 	DAPC_INFRA_AO_SYS0_ATTR("MCUSYS_CFGREG_APB_S-4",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN4,
+				NO_PROTECTION, FORBIDDEN),
 	DAPC_INFRA_AO_SYS0_ATTR("L3C_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_INFRA_AO_SYS0_ATTR("L3C_S-1",
@@ -150,7 +164,7 @@ static const struct apc_infra_peri_dom_16 infra_ao_sys0_devices[] = {
 	DAPC_INFRA_AO_SYS0_ATTR("L3C_S-2",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_INFRA_AO_SYS0_ATTR("PCIE0_AXI_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN, NO_PROTECTION, FORBIDDEN13),
 	/* 70 */
 	DAPC_INFRA_AO_SYS0_ATTR("VIOSYS_APB0_S",
 				NO_PROTECTION, FORBIDDEN15),
@@ -167,28 +181,28 @@ static const struct apc_infra_peri_dom_16 infra_ao_sys0_devices[] = {
 static const struct apc_infra_peri_dom_4 infra_ao_sys1_devices[] = {
 	/* 0 */
 	DAPC_INFRA_AO_SYS1_ATTR("MM_S_S",
-				NO_PROTECTION, FORBIDDEN3),
+				NO_PROTECTION2, FORBIDDEN2),
 	DAPC_INFRA_AO_SYS1_ATTR("MM_S_S-1",
-				NO_PROTECTION, FORBIDDEN3),
+				NO_PROTECTION2, FORBIDDEN2),
 	DAPC_INFRA_AO_SYS1_ATTR("MM_S_S-2",
-				NO_PROTECTION, FORBIDDEN3),
+				NO_PROTECTION2, FORBIDDEN2),
 	DAPC_INFRA_AO_SYS1_ATTR("MM_S_S-3",
-				NO_PROTECTION, FORBIDDEN3),
+				NO_PROTECTION2, FORBIDDEN2),
 	DAPC_INFRA_AO_SYS1_ATTR("MM_S_S-4",
-				NO_PROTECTION, FORBIDDEN3),
+				NO_PROTECTION2, FORBIDDEN2),
 	DAPC_INFRA_AO_SYS1_ATTR("MM_S_S-5",
-				NO_PROTECTION, FORBIDDEN3),
+				NO_PROTECTION2, FORBIDDEN2),
 	DAPC_INFRA_AO_SYS1_ATTR("MM_S_S-6",
 				NO_PROTECTION, FORBIDDEN3),
 	DAPC_INFRA_AO_SYS1_ATTR("MM_S_S-7",
-				NO_PROTECTION, FORBIDDEN3),
+				NO_PROTECTION2, FORBIDDEN2),
 	DAPC_INFRA_AO_SYS1_ATTR("MM_S_S-8",
-				NO_PROTECTION, FORBIDDEN3),
+				NO_PROTECTION2, FORBIDDEN2),
 	DAPC_INFRA_AO_SYS1_ATTR("MM_S_S-9",
-				NO_PROTECTION, FORBIDDEN3),
+				NO_PROTECTION2, FORBIDDEN2),
 	/* 10 */
 	DAPC_INFRA_AO_SYS1_ATTR("MM_S_S-10",
-				NO_PROTECTION, FORBIDDEN3),
+				NO_PROTECTION2, FORBIDDEN2),
 	DAPC_INFRA_AO_SYS1_ATTR("MM_S_S-11",
 				NO_PROTECTION, FORBIDDEN3),
 	DAPC_INFRA_AO_SYS1_ATTR("MM_S_S-12",
@@ -202,7 +216,7 @@ static const struct apc_infra_peri_dom_4 infra_ao_sys1_devices[] = {
 	DAPC_INFRA_AO_SYS1_ATTR("MM_S_S-16",
 				NO_PROTECTION, FORBIDDEN3),
 	DAPC_INFRA_AO_SYS1_ATTR("MM_S_S-17",
-				NO_PROTECTION, FORBIDDEN3),
+				NO_PROTECTION2, FORBIDDEN2),
 	DAPC_INFRA_AO_SYS1_ATTR("MM_S_S-18",
 				NO_PROTECTION, FORBIDDEN3),
 	DAPC_INFRA_AO_SYS1_ATTR("MM_S_S-19",
@@ -324,7 +338,7 @@ static const struct apc_infra_peri_dom_4 infra_ao_sys1_devices[] = {
 	DAPC_INFRA_AO_SYS1_ATTR("MM_S_S-74",
 				NO_PROTECTION, FORBIDDEN3),
 	DAPC_INFRA_AO_SYS1_ATTR("MM_S_S-75",
-				NO_PROTECTION, FORBIDDEN3),
+				SEC_RW_ONLY, FORBIDDEN3),
 	DAPC_INFRA_AO_SYS1_ATTR("MM_S_S-76",
 				NO_PROTECTION, FORBIDDEN3),
 	DAPC_INFRA_AO_SYS1_ATTR("MM_S_S-77",
@@ -427,7 +441,7 @@ static const struct apc_infra_peri_dom_4 infra_ao_sys1_devices[] = {
 	DAPC_INFRA_AO_SYS1_ATTR("MDP_S_S",
 				NO_PROTECTION, FORBIDDEN3),
 	DAPC_INFRA_AO_SYS1_ATTR("MDP_S_S-1",
-				NO_PROTECTION, FORBIDDEN3),
+				NO_PROTECTION2, FORBIDDEN2),
 	DAPC_INFRA_AO_SYS1_ATTR("MDP_S_S-2",
 				NO_PROTECTION, FORBIDDEN3),
 	DAPC_INFRA_AO_SYS1_ATTR("MDP_S_S-3",
@@ -450,7 +464,7 @@ static const struct apc_infra_peri_dom_4 infra_ao_sys1_devices[] = {
 	DAPC_INFRA_AO_SYS1_ATTR("MDP_S_S-11",
 				NO_PROTECTION, FORBIDDEN3),
 	DAPC_INFRA_AO_SYS1_ATTR("MDP_S_S-12",
-				NO_PROTECTION, FORBIDDEN3),
+				NO_PROTECTION2, FORBIDDEN2),
 	DAPC_INFRA_AO_SYS1_ATTR("MDP_S_S-13",
 				NO_PROTECTION, FORBIDDEN3),
 	DAPC_INFRA_AO_SYS1_ATTR("MDP_S_S-14",
@@ -484,7 +498,7 @@ static const struct apc_infra_peri_dom_4 infra_ao_sys1_devices[] = {
 	DAPC_INFRA_AO_SYS1_ATTR("MDP_S_S-27",
 				NO_PROTECTION, FORBIDDEN3),
 	DAPC_INFRA_AO_SYS1_ATTR("MDP_S_S-28",
-				NO_PROTECTION, FORBIDDEN3),
+				SEC_RW_ONLY, FORBIDDEN3),
 	DAPC_INFRA_AO_SYS1_ATTR("MDP_S_S-29",
 				NO_PROTECTION, FORBIDDEN3),
 	DAPC_INFRA_AO_SYS1_ATTR("MDP_S_S-30",
@@ -524,9 +538,9 @@ static const struct apc_infra_peri_dom_4 infra_ao_sys1_devices[] = {
 				NO_PROTECTION, FORBIDDEN3),
 	/* 170 */
 	DAPC_INFRA_AO_SYS1_ATTR("MDP_S_S-47",
-				NO_PROTECTION, FORBIDDEN3),
+				NO_PROTECTION2, FORBIDDEN2),
 	DAPC_INFRA_AO_SYS1_ATTR("MDP_S_S-48",
-				NO_PROTECTION, FORBIDDEN3),
+				NO_PROTECTION2, FORBIDDEN2),
 	DAPC_INFRA_AO_SYS1_ATTR("MDP_S_S-49",
 				NO_PROTECTION, FORBIDDEN3),
 	DAPC_INFRA_AO_SYS1_ATTR("MDP_S_S-50",
@@ -580,9 +594,9 @@ static const struct apc_infra_peri_dom_4 infra_ao_sys1_devices[] = {
 	DAPC_INFRA_AO_SYS1_ATTR("MDP_S_S-73",
 				NO_PROTECTION, FORBIDDEN3),
 	DAPC_INFRA_AO_SYS1_ATTR("MDP_S_S-74",
-				NO_PROTECTION, FORBIDDEN3),
+				NO_PROTECTION2, FORBIDDEN2),
 	DAPC_INFRA_AO_SYS1_ATTR("MDP_S_S-75",
-				NO_PROTECTION, FORBIDDEN3),
+				NO_PROTECTION2, FORBIDDEN2),
 	DAPC_INFRA_AO_SYS1_ATTR("MDP_S_S-76",
 				NO_PROTECTION, FORBIDDEN3),
 	/* 200 */
@@ -913,97 +927,141 @@ static const struct apc_infra_peri_dom_16 peri_ao_sys0_devices[] = {
 	DAPC_PERI_AO_SYS0_ATTR("DEBUG_CTRL_PERI_AO_APB_S",
 			       NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI_AO_SYS0_ATTR("PWR_MD32_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("PWR_MD32_S-1",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("PWR_MD32_S-2",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("PWR_MD32_S-3",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("PWR_MD32_S-4",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("PWR_MD32_S-5",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("PWR_MD32_S-6",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	/* 10 */
 	DAPC_PERI_AO_SYS0_ATTR("PWR_MD32_S-7",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("PWR_MD32_S-8",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("PWR_MD32_S-9",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("PWR_MD32_S-10",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DEBUGSYS_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION, FORBIDDEN),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_MD32_S0_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_MD32_S0_APB_S-1",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_MD32_S1_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_MD32_S1_APB_S-1",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH0_TOP0_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	/* 20 */
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH0_TOP1_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH0_TOP2_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH0_TOP3_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH0_TOP4_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH0_TOP5_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH0_TOP6_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH1_TOP0_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH1_TOP1_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH1_TOP2_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH1_TOP3_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	/* 30 */
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH1_TOP4_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH1_TOP5_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH1_TOP6_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH2_TOP0_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH2_TOP1_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH2_TOP2_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH2_TOP3_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH2_TOP4_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH2_TOP5_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH2_TOP6_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	/* 40 */
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH3_TOP0_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH3_TOP1_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH3_TOP2_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH3_TOP3_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH3_TOP4_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH3_TOP5_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("DRAMC_CH3_TOP6_APB_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI_AO_SYS0_ATTR("CCIF2_AP_APB_S",
 			       NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI_AO_SYS0_ATTR("CCIF2_MD_APB_S",
@@ -1022,9 +1080,11 @@ static const struct apc_infra_peri_dom_16 peri_ao_sys0_devices[] = {
 	DAPC_PERI_AO_SYS0_ATTR("CCIF5_MD_APB_S",
 			       NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI_AO_SYS0_ATTR("SSC_INFRA_APB0_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION, FORBIDDEN7),
 	DAPC_PERI_AO_SYS0_ATTR("SSC_INFRA_APB1_S",
-			       NO_PROTECTION, FORBIDDEN15),
+			       NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+			       NO_PROTECTION, FORBIDDEN7),
 	DAPC_PERI_AO_SYS0_ATTR("DEVICE_MPU_ACP_APB_S",
 			       SEC_RW_ONLY, FORBIDDEN15),
 };
@@ -1046,7 +1106,7 @@ static const struct apc_infra_peri_dom_16 peri2_ao_sys0_devices[] = {
 	DAPC_PERI2_AO_SYS0_ATTR("BND_EAST_APB0_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI2_AO_SYS0_ATTR("BND_EAST_APB1_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN13, NO_PROTECTION, FORBIDDEN),
 	DAPC_PERI2_AO_SYS0_ATTR("BND_EAST_APB2_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI2_AO_SYS0_ATTR("BND_EAST_APB3_S",
@@ -1103,7 +1163,8 @@ static const struct apc_infra_peri_dom_16 peri2_ao_sys0_devices[] = {
 	DAPC_PERI2_AO_SYS0_ATTR("BND_NORTH_APB1_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI2_AO_SYS0_ATTR("BND_NORTH_APB2_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN4, NO_PROTECTION, FORBIDDEN8,
+				NO_PROTECTION, FORBIDDEN),
 	DAPC_PERI2_AO_SYS0_ATTR("BND_NORTH_APB3_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI2_AO_SYS0_ATTR("BND_NORTH_APB4_S",
@@ -1195,7 +1256,8 @@ static const struct apc_infra_peri_dom_16 peri2_ao_sys0_devices[] = {
 	DAPC_PERI2_AO_SYS0_ATTR("MBIST_PDN_APB_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI2_AO_SYS0_ATTR("INFRACFG_PDN_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+				NO_PROTECTION2, FORBIDDEN6),
 	DAPC_PERI2_AO_SYS0_ATTR("TRNG_APB_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI2_AO_SYS0_ATTR("GCPU_APB_S",
@@ -1206,7 +1268,7 @@ static const struct apc_infra_peri_dom_16 peri2_ao_sys0_devices[] = {
 				NO_PROTECTION, FORBIDDEN15),
 	/* 80 */
 	DAPC_PERI2_AO_SYS0_ATTR("SRAMROM_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN6),
 	DAPC_PERI2_AO_SYS0_ATTR("INFRACFG_MEM_APB_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI2_AO_SYS0_ATTR("ECC_TOP_APB_S",
@@ -1222,18 +1284,19 @@ static const struct apc_infra_peri_dom_16 peri2_ao_sys0_devices[] = {
 	DAPC_PERI2_AO_SYS0_ATTR("DEBUG_TRACKER_APB1_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI2_AO_SYS0_ATTR("INFRA_IOMMU_WRAP_APB0_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN6),
 	DAPC_PERI2_AO_SYS0_ATTR("INFRA_IOMMU_WRAP_APB1_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN6),
 	/* 90 */
 	DAPC_PERI2_AO_SYS0_ATTR("INFRA_IOMMU_WRAP_APB2_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN6),
 	DAPC_PERI2_AO_SYS0_ATTR("INFRA_IOMMU_WRAP_APB3_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN6),
 	DAPC_PERI2_AO_SYS0_ATTR("INFRA_IOMMU_WRAP_APB4_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN6),
 	DAPC_PERI2_AO_SYS0_ATTR("EMI_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+				NO_PROTECTION, FORBIDDEN7),
 	DAPC_PERI2_AO_SYS0_ATTR("EMI_MPU_APB_S",
 				SEC_RW_ONLY, FORBIDDEN15),
 	DAPC_PERI2_AO_SYS0_ATTR("DEVICE_MPU_PDN_APB_S",
@@ -1262,7 +1325,8 @@ static const struct apc_infra_peri_dom_16 peri2_ao_sys0_devices[] = {
 	DAPC_PERI2_AO_SYS0_ATTR("PERI_SLOW_M_APB_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI2_AO_SYS0_ATTR("EMI_SUB_INFRA_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+				NO_PROTECTION, FORBIDDEN7),
 	DAPC_PERI2_AO_SYS0_ATTR("EMI_MPU_SUB_INFRA_APB_S",
 				SEC_RW_ONLY, FORBIDDEN15),
 	DAPC_PERI2_AO_SYS0_ATTR("DEVICE_MPU_PDN_SUB_INFRA_APB_S",
@@ -1271,7 +1335,8 @@ static const struct apc_infra_peri_dom_16 peri2_ao_sys0_devices[] = {
 	DAPC_PERI2_AO_SYS0_ATTR("MBIST_PDN_SUB_INFRA_APB_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI2_AO_SYS0_ATTR("INFRACFG_MEM_SUB_INFRA_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+				NO_PROTECTION, FORBIDDEN7),
 	DAPC_PERI2_AO_SYS0_ATTR("BCRM_SUB_INFRA_AO_APB_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI2_AO_SYS0_ATTR("DEBUG_CTRL_SUB_INFRA_AO_APB_S",
@@ -1279,11 +1344,13 @@ static const struct apc_infra_peri_dom_16 peri2_ao_sys0_devices[] = {
 	DAPC_PERI2_AO_SYS0_ATTR("BCRM_SUB_INFRA_PDN_APB_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI2_AO_SYS0_ATTR("SSC_SUB_INFRA_APB1_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+				NO_PROTECTION, FORBIDDEN7),
 	DAPC_PERI2_AO_SYS0_ATTR("SSC_SUB_INFRA_APB2_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+				NO_PROTECTION, FORBIDDEN7),
 	DAPC_PERI2_AO_SYS0_ATTR("INFRACFG_AO_MEM_SUB_INFRA_APB_S",
-				NO_PROTECTION, FORBIDDEN15),
+				NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN6),
 	DAPC_PERI2_AO_SYS0_ATTR("SUB_FAKE_ENGINE_MM_S",
 				NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI2_AO_SYS0_ATTR("SUB_FAKE_ENGINE_MDP_S",
@@ -1323,7 +1390,7 @@ static const struct apc_infra_peri_dom_16 peri_par_ao_sys0_devices[] = {
 	DAPC_PERI_PAR_AO_SYS0_ATTR("MSDC2_S",
 				   NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI_PAR_AO_SYS0_ATTR("PCIE0_AHB_S",
-				   NO_PROTECTION, FORBIDDEN15),
+				   NO_PROTECTION, FORBIDDEN, NO_PROTECTION, FORBIDDEN13),
 	DAPC_PERI_PAR_AO_SYS0_ATTR("SSUSB_P2_S",
 				   NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI_PAR_AO_SYS0_ATTR("SSUSB_P3_S",
@@ -1331,7 +1398,8 @@ static const struct apc_infra_peri_dom_16 peri_par_ao_sys0_devices[] = {
 	DAPC_PERI_PAR_AO_SYS0_ATTR("AUXADC_APB_S",
 				   NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI_PAR_AO_SYS0_ATTR("UART0_APB_S",
-				   NO_PROTECTION, FORBIDDEN15),
+				   NO_PROTECTION, FORBIDDEN2, NO_PROTECTION, FORBIDDEN4,
+				   NO_PROTECTION, FORBIDDEN5, NO_PROTECTION, FORBIDDEN),
 	DAPC_PERI_PAR_AO_SYS0_ATTR("UART1_APB_S",
 				   NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI_PAR_AO_SYS0_ATTR("UART2_APB_S",
@@ -1346,7 +1414,8 @@ static const struct apc_infra_peri_dom_16 peri_par_ao_sys0_devices[] = {
 	DAPC_PERI_PAR_AO_SYS0_ATTR("SPI0_APB_S",
 				   NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI_PAR_AO_SYS0_ATTR("PTP_THERM_CTRL_APB_S",
-				   NO_PROTECTION, FORBIDDEN15),
+				   NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN4,
+				   NO_PROTECTION, FORBIDDEN),
 	DAPC_PERI_PAR_AO_SYS0_ATTR("PERI_MBIST_PDN_APB_S",
 				   NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI_PAR_AO_SYS0_ATTR("DISP_PWM_APB_S",
@@ -1384,9 +1453,10 @@ static const struct apc_infra_peri_dom_16 peri_par_ao_sys0_devices[] = {
 	DAPC_PERI_PAR_AO_SYS0_ATTR("DEVICE_APC_PERI_PAR_PDN_APB_S",
 				   NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI_PAR_AO_SYS0_ATTR("PTP_THERM_CTRL2_APB_S",
-				   NO_PROTECTION, FORBIDDEN15),
+				   NO_PROTECTION, FORBIDDEN8, NO_PROTECTION, FORBIDDEN4,
+				   NO_PROTECTION, FORBIDDEN),
 	DAPC_PERI_PAR_AO_SYS0_ATTR("IIC_P2P_REMAP_APB_S",
-				   NO_PROTECTION, FORBIDDEN15),
+				   NO_PROTECTION, FORBIDDEN13, NO_PROTECTION, FORBIDDEN),
 	DAPC_PERI_PAR_AO_SYS0_ATTR("NOR_APB_S",
 				   NO_PROTECTION, FORBIDDEN15),
 	DAPC_PERI_PAR_AO_SYS0_ATTR("PERICFG2_AO_APB_S",
@@ -1422,7 +1492,6 @@ static void set_infra_ao_apc(uintptr_t base)
 		for (j = 0; j < ARRAY_SIZE(infra_ao_sys2_devices[i].d_permission); j++)
 			set_module_apc(base + SYS2_D0_APC_0, i, domain_map[j],
 				       infra_ao_sys2_devices[i].d_permission[j]);
-
 }
 
 static void set_peri_ao_apc(uintptr_t base)
@@ -1446,7 +1515,6 @@ static void set_peri_ao_apc(uintptr_t base)
 		for (j = 0; j < ARRAY_SIZE(peri_ao_sys1_devices[i].d_permission); j++)
 			set_module_apc(base + SYS1_D0_APC_0, i, domain_map[j],
 				       peri_ao_sys1_devices[i].d_permission[j]);
-
 }
 
 static void set_peri2_ao_apc(uintptr_t base)
@@ -1457,7 +1525,6 @@ static void set_peri2_ao_apc(uintptr_t base)
 		for (j = 0; j < ARRAY_SIZE(peri2_ao_sys0_devices[i].d_permission); j++)
 			set_module_apc(base + SYS0_D0_APC_0, i, domain_map[j],
 				       peri2_ao_sys0_devices[i].d_permission[j]);
-
 }
 
 static void set_peri_par_ao_apc(uintptr_t base)
@@ -1468,7 +1535,6 @@ static void set_peri_par_ao_apc(uintptr_t base)
 		for (j = 0; j < ARRAY_SIZE(peri_par_ao_sys0_devices[i].d_permission); j++)
 			set_module_apc(base + SYS0_D0_APC_0, i, domain_map[j],
 				       peri_par_ao_sys0_devices[i].d_permission[j]);
-
 }
 
 static void dump_infra_ao_apc(uintptr_t base)
@@ -1529,7 +1595,6 @@ static void dump_peri2_ao_apc(uintptr_t base)
 		for (i = 0; i < reg_max; i++)
 			printk(BIOS_DEBUG, "[DEVAPC] (PERI2_AO_SYS0)D%d_APC_%d: %#x\n", d,
 			       i, read32(getreg_domain(base, SYS0_D0_APC_0, d, i)));
-
 }
 
 static void dump_peri_par_ao_apc(uintptr_t base)
@@ -1547,10 +1612,70 @@ static void dump_peri_par_ao_apc(uintptr_t base)
 	       read32(getreg(base, MAS_SEC_0)));
 }
 
+static void dump_fmem_ao(uintptr_t base)
+{
+	printk(BIOS_DEBUG, "[DEVAPC] (DEVAPC_FMEM_AO_BASE %#lx)DOM_REMAP_0_0:%#x\n",
+	       base, read32(getreg(base, DOM_REMAP_0_0)));
+	printk(BIOS_DEBUG, "[DEVAPC] (DEVAPC_FMEM_AO_BASE %#lx)MAS_DOM_1:%#x\n",
+	       base, read32(getreg(base, MAS_DOM_1)));
+}
+
+static void dump_infra2_ao(uintptr_t base)
+{
+	printk(BIOS_DEBUG, "[DEVAPC] (DEVAPC_INFRA2_AO_BASE %#lx)DOM_REMAP_0_0:%#x\n",
+	       base, read32(getreg(base, DOM_REMAP_0_0)));
+}
+
+static void dump_scp_master(uintptr_t base)
+{
+	printk(BIOS_DEBUG, "[DEVAPC] SCP_DOM0:%#x SCP_DOM1:%#x SCP_DOM2:%#x Lock:%#x\n",
+	       read32(getreg(base, SCP_DOM0)),
+	       read32(getreg(base, SCP_DOM1)),
+	       read32(getreg(base, SCP_DOM2)),
+	       read32(getreg(base, ONETIME_LOCK)));
+}
+
+static void dump_sec_mfg_hyp(uintptr_t base)
+{
+	printk(BIOS_DEBUG, "[DEVAPC] (DEVAPC_INFRA_BASE %#lx)INFRA_AO_SEC_MFG_HYP:%#x\n",
+	       base, read32(getreg(base, 0)));
+}
+
 static void infra_init(uintptr_t base)
 {
+	void *reg;
+
 	/* Side-band */
-	SET32_BITFIELDS(getreg(base, MAS_SEC_0), MCUPM_SEC, SECURE_TRANS);
+	SET32_BITFIELDS(getreg(base, MAS_SEC_0), CPU_EB_SEC, SECURE_TRANS);
+	SET32_BITFIELDS(getreg(base, MAS_SEC_0), SCP_SSPM_SEC, SECURE_TRANS);
+
+	/* Master Domain */
+	SET32_BITFIELDS(getreg(base, MAS_DOM_0),
+			SCP_SSPM_DOM, DOMAIN_3,
+			CPU_EB_DOM, DOMAIN_14);
+
+	/*
+	 * Domain Remap: INFRA (4-bit) -> MMSYS (2-bit)
+	 *               domain 0      -> domain 0
+	 *               domain 8      -> domain 1   (SCP)
+	 *               others        -> domain 3
+	 */
+	reg = getreg(base, DOM_REMAP_2_0);
+	write32(reg, 0xFFFFFFFF);
+	SET32_BITFIELDS(reg,
+			TWO_BIT_DOM_REMAP_0, DOMAIN_0,
+			TWO_BIT_DOM_REMAP_8, DOMAIN_1);
+
+	/*
+	 * Domain Remap: TINYSYS (3-bit) -> INFRA (4-bit)
+	 *               domain 0        -> domain 4  (DSP)
+	 *               others          -> domain 15
+	 */
+	reg = getreg(base, DOM_REMAP_0_0);
+	write32(reg, 0xFFFFFFFF);
+	SET32_BITFIELDS(reg,
+			FOUR_BIT_DOM_REMAP_0, DOMAIN_4);
+
 
 	/* TODO: Setup SCP, SSPM and MCUPM permissions in APC . */
 	set_infra_ao_apc(base);
@@ -1558,8 +1683,26 @@ static void infra_init(uintptr_t base)
 
 static void peri_init(uintptr_t base)
 {
+	void *reg;
+
 	/* Default APC setting */
 	set_peri_ao_apc(base);
+
+	/* Master Domain */
+	SET32_BITFIELDS(getreg(base, MAS_DOM_0), SPM_DOM, DOMAIN_9);
+
+	/*
+	 * Domain Remap: INFRA (4-bit) -> TINYSYS (3-bit)
+	 *               domain 0      -> domain 0
+	 *               domain 4      -> domain 0   (DSP)
+	 *               others        -> domain 7
+	 */
+	reg = getreg(base, DOM_REMAP_0_0);
+	write32(reg, 0xFFFFFFFF);
+	SET32_BITFIELDS(reg,
+			THREE_BIT_DOM_REMAP_0, DOMAIN_0,
+			THREE_BIT_DOM_REMAP_4, DOMAIN_0);
+	write32(getreg(base, DOM_REMAP_0_1), 0xFFFFFFFF);
 }
 
 static void peri2_init(uintptr_t base)
@@ -1572,6 +1715,83 @@ static void peri_par_init(uintptr_t base)
 {
 	/* Default APC setting */
 	set_peri_par_ao_apc(base);
+
+	/* Master Domain */
+	SET32_BITFIELDS(getreg_domain(base, MAS_DOM_0, 0, 4),
+			PCIE0_DOM, DOMAIN_2);
+}
+
+static void fmem_master_init(uintptr_t base)
+{
+	/* Master Domain */
+	SET32_BITFIELDS(getreg(base, MAS_DOM_1),
+			MFG_M0_DOM, DOMAIN_6);
+
+	/*
+	 * Domain Remap: TINYSYS to EMI (3-bit to 4-bit)
+	 *     1. DSP from 0 to 4
+	 *     2. others from XXX to 15
+	 */
+	SET32_BITFIELDS(getreg(base, DOM_REMAP_0_0),
+			FOUR_BIT_DOM_REMAP_0, DOMAIN_4,
+			FOUR_BIT_DOM_REMAP_1, DOMAIN_15,
+			FOUR_BIT_DOM_REMAP_2, DOMAIN_15,
+			FOUR_BIT_DOM_REMAP_3, DOMAIN_15,
+			FOUR_BIT_DOM_REMAP_4, DOMAIN_15,
+			FOUR_BIT_DOM_REMAP_5, DOMAIN_15,
+			FOUR_BIT_DOM_REMAP_6, DOMAIN_15,
+			FOUR_BIT_DOM_REMAP_7, DOMAIN_15);
+}
+
+static void infra2_master_init(uintptr_t base)
+{
+	/*
+	 * Domain Remap: TINYSYS to EMI (3-bit to 4-bit)
+	 *     1. DSP from 0 to 4
+	 *     2. others from XXX to 15
+	 */
+	SET32_BITFIELDS(getreg(base, DOM_REMAP_0_0),
+			FOUR_BIT_DOM_REMAP_0, DOMAIN_4,
+			FOUR_BIT_DOM_REMAP_1, DOMAIN_15,
+			FOUR_BIT_DOM_REMAP_2, DOMAIN_15,
+			FOUR_BIT_DOM_REMAP_3, DOMAIN_15,
+			FOUR_BIT_DOM_REMAP_4, DOMAIN_15,
+			FOUR_BIT_DOM_REMAP_5, DOMAIN_15,
+			FOUR_BIT_DOM_REMAP_6, DOMAIN_15,
+			FOUR_BIT_DOM_REMAP_7, DOMAIN_15);
+}
+
+static void scp_master_init(uintptr_t base)
+{
+	SET32_BITFIELDS(getreg(base, SCP_DOM0),
+			FOUR_BIT_DOM_REMAP_0, DOMAIN_8,
+			FOUR_BIT_DOM_REMAP_2, DOMAIN_8,
+			FOUR_BIT_DOM_REMAP_4, DOMAIN_8,
+			FOUR_BIT_DOM_REMAP_6, DOMAIN_8);
+
+	SET32_BITFIELDS(getreg(base, SCP_DOM1),
+			FOUR_BIT_DOM_REMAP_0, DOMAIN_8,
+			FOUR_BIT_DOM_REMAP_2, DOMAIN_8,
+			FOUR_BIT_DOM_REMAP_4, DOMAIN_8,
+			FOUR_BIT_DOM_REMAP_6, DOMAIN_8);
+
+	SET32_BITFIELDS(getreg(base, SCP_DOM2),
+			FOUR_BIT_DOM_REMAP_0, DOMAIN_8);
+
+	/* Let SCP_DOM registers be read-only for security */
+	write32(getreg(base, ONETIME_LOCK), 0x5);
+}
+
+static void infra_sec_mfg_hyp_init(uintptr_t base)
+{
+	/* Set GPU protection mode */
+	SET32_BITFIELDS(getreg(base, MFG_HPY_OFT), OSID0, MFG_NS_D6);
+	SET32_BITFIELDS(getreg(base, MFG_HPY_OFT), OSID1, MFG_NS_D6);
+	SET32_BITFIELDS(getreg(base, MFG_HPY_OFT), OSID2, MFG_NS_D6);
+	SET32_BITFIELDS(getreg(base, MFG_HPY_OFT), OSID3, MFG_NS_D6);
+	SET32_BITFIELDS(getreg(base, MFG_HPY_OFT), FM_EN, MFG_NS_D6);
+	SET32_BITFIELDS(getreg(base, MFG_HPY_OFT), SEC_EN, MFG_S_D6);
+	SET32_BITFIELDS(getreg(base, MFG_HPY_OFT), REMAP_EN, 1);
 }
 
 const struct devapc_init_ops devapc_init[] = {
@@ -1579,6 +1799,13 @@ const struct devapc_init_ops devapc_init[] = {
 	{ DEVAPC_PERI_AO_BASE, peri_init, dump_peri_ao_apc },
 	{ DEVAPC_PERI2_AO_BASE, peri2_init, dump_peri2_ao_apc },
 	{ DEVAPC_PERI_PAR_AO_BASE, peri_par_init, dump_peri_par_ao_apc },
+	{ DEVAPC_FMEM_AO_BASE, fmem_master_init, dump_fmem_ao },
+	{ DEVAPC_INFRA2_AO_BASE, infra2_master_init, dump_infra2_ao },
+	{ SCP_CFG_BASE, scp_master_init, dump_scp_master },
+	{ INFRACFG_AO_BASE + INFRA_AO_SEC_MFG_HYP,
+	  infra_sec_mfg_hyp_init, dump_sec_mfg_hyp },
+	{ SUB_INFRACFG_AO_BASE + INFRA_AO_SEC_MFG_HYP2,
+	  infra_sec_mfg_hyp_init, dump_sec_mfg_hyp },
 };
 
 const size_t devapc_init_cnt = ARRAY_SIZE(devapc_init);
