@@ -41,6 +41,7 @@ enum {
 	DEVAPC_PERI_PAR_AO_BASE	= IO_PHYS + 0x0003C000,
 	PERI_PAR_AO_BASE        = IO_PHYS + 0x00040000,
 	FMEM_AO_BASE            = IO_PHYS + 0x00042000,
+	DEVAPC_FMEM_AO_BASE     = IO_PHYS + 0x00044000,
 	DBG_TRACKER_BASE	= IO_PHYS + 0x00208000,
 	PERI_TRACKER_BASE	= IO_PHYS + 0x00218000,
 	EMI0_BASE		= IO_PHYS + 0x00219000,
@@ -52,10 +53,13 @@ enum {
 	I2C4_DMA_BASE		= IO_PHYS + 0x00220380,
 	I2C5_DMA_BASE		= IO_PHYS + 0x00220480,
 	I2C6_DMA_BASE		= IO_PHYS + 0x00220600,
+	DEVAPC_INFRA2_AO_BASE	= IO_PHYS + 0x00228000,
 	DRAMC_CHA_AO_BASE	= IO_PHYS + 0x00230000,
+	SUB_INFRACFG_AO_BASE	= IO_PHYS + 0x0030E000,
 	INFRA_TRACKER_BASE	= IO_PHYS + 0x00314000,
 	SSPM_SRAM_BASE          = IO_PHYS + 0x00400000,
 	SSPM_CFG_BASE		= IO_PHYS + 0x00440000,
+	SCP_CFG_BASE		= IO_PHYS + 0x00700000,
 	SCP_ADSP_CFG_BASE	= IO_PHYS + 0x00720000,
 	DPM_PM_SRAM_BASE	= IO_PHYS + 0x00900000,
 	DPM_DM_SRAM_BASE	= IO_PHYS + 0x00920000,
