@@ -9,6 +9,8 @@
 #include <soc/spm_common.h>
 #include <types.h>
 
+#define SPM_SYSTEM_BASE_OFFSET	0x40000000
+
 /* SPM READ/WRITE CFG */
 #define SPM_PROJECT_CODE			0xb16
 #define SPM_REGWR_CFG_KEY			(SPM_PROJECT_CODE << 16)
@@ -437,7 +439,7 @@ enum {
 };
 
 struct mtk_spm_regs {
-	u32 poweron_config_en;
+	u32 poweron_config_set;
 	u32 spm_power_on_val0;
 	u32 spm_power_on_val1;
 	u32 spm_clk_con;
@@ -733,15 +735,7 @@ struct mtk_spm_regs {
 	u32 spm_sw_debug_0;
 	u32 spm_sw_flag_1;
 	u32 spm_sw_debug_1;
-	u32 spm_sw_rsv_0;
-	u32 spm_sw_rsv_1;
-	u32 spm_sw_rsv_2;
-	u32 spm_sw_rsv_3;
-	u32 spm_sw_rsv_4;
-	u32 spm_sw_rsv_5;
-	u32 spm_sw_rsv_6;
-	u32 spm_sw_rsv_7;
-	u32 spm_sw_rsv_8;
+	u32 spm_sw_rsv[9];
 	u32 spm_bk_wake_event;
 	u32 spm_bk_vtcxo_dur;
 	u32 spm_bk_wake_misc;
@@ -985,30 +979,12 @@ check_member(mtk_spm_regs, spm_pmsr_len_con2, 0xff4);
 static struct mtk_spm_regs *const mtk_spm = (void *)SPM_BASE;
 
 static const struct power_domain_data disp[] = {
-	{
-		.pwr_con = &mtk_spm->vppsys0_pwr_con,
-		.pwr_sta_mask = BIT(11),
-		.sram_pdn_mask = BIT(8),
-		.sram_ack_mask = BIT(12),
-	},
 	{
 		.pwr_con = &mtk_spm->vdosys0_pwr_con,
 		.pwr_sta_mask = BIT(13),
 		.sram_pdn_mask = BIT(8),
 		.sram_ack_mask = BIT(12),
 	},
-	{
-		.pwr_con = &mtk_spm->vppsys1_pwr_con,
-		.pwr_sta_mask = BIT(12),
-		.sram_pdn_mask = BIT(8),
-		.sram_ack_mask = BIT(12),
-	},
-	{
-		.pwr_con = &mtk_spm->vdosys1_pwr_con,
-		.pwr_sta_mask = BIT(14),
-		.sram_pdn_mask = BIT(8),
-		.sram_ack_mask = BIT(12),
-	},
 	{
 		.pwr_con = &mtk_spm->edp_tx_pwr_con,
 		.pwr_sta_mask = BIT(17),
@@ -1019,14 +995,21 @@ static const struct power_domain_data disp[] = {
 
 static const struct power_domain_data audio[] = {
 	{
-		.pwr_con = &mtk_spm->adsp_pwr_con,
+		.pwr_con = &mtk_spm->adsp_ao_pwr_con,
+		.pwr_sta_mask = BIT(10),
+		.ext_buck_iso_bits = BIT(10),
+		.caps = SCPD_EXT_BUCK_ISO,
+	},
+	{
+		.pwr_con = &mtk_spm->adsp_infra_pwr_con,
 		.pwr_sta_mask = BIT(10),
 		.sram_pdn_mask = BIT(8),
 		.sram_ack_mask = BIT(12),
+		.caps = SCPD_SRAM_ISO,
 	},
 	{
 		.pwr_con = &mtk_spm->audio_pwr_con,
-		.pwr_sta_mask = BIT(8),
+		.pwr_sta_mask = BIT(6),
 		.sram_pdn_mask = BIT(8),
 		.sram_ack_mask = BIT(12),
 	},
