@@ -3,7 +3,6 @@
 #include <console/console.h>
 #include <device/mmio.h>
 #include <delay.h>
-#include <stddef.h>
 #include <timer.h>
 
 #include <soc/addressmap.h>
@@ -256,7 +255,7 @@ static const struct mux_sel mux_sels[] = {
 	{ .id = TOP_SCP_SEL, .sel = 5 },			/* 5: mainpll_d4_d2 */
 	{ .id = TOP_BUS_AXIMEM_SEL, .sel = 1 },			/* 1: mainpll_d7_d2 */
 	/* CLK_CFG_1 */
-	{ .id = TOP_VPP_SEL, .sel = 8 },			/* 8: univpll_d6 */
+	{ .id = TOP_VPP_SEL, .sel = 11 },			/* 11: tvdpll1_ck */
 	{ .id = TOP_ETHDR_SEL, .sel = 8 },			/* 8: univpll_d6 */
 	{ .id = TOP_IPE_SEL, .sel = 8 },			/* 8: mainpll_d4_d2 */
 	{ .id = TOP_CAM_SEL, .sel = 9 },			/* 9: mainpll_d4_d2 */
@@ -435,19 +434,19 @@ static const struct pll plls[] = {
 	    NO_RSTB_SHIFT, 22, adsppll_con1, 24, adsppll_con1, 0,
 	    pll_div_rate),
 	PLL(APMIXED_APLL1, apll1_con0, apll1_con4,
-	    NO_RSTB_SHIFT, 32, apll1_con2, 24, apll1_con2, 0,
+	    NO_RSTB_SHIFT, 32, apll1_con1, 24, apll1_con2, 0,
 	    pll_div_rate),
 	PLL(APMIXED_APLL2, apll2_con0, apll2_con4,
-	    NO_RSTB_SHIFT, 32, apll2_con2, 24, apll2_con2, 0,
+	    NO_RSTB_SHIFT, 32, apll2_con1, 24, apll2_con2, 0,
 	    pll_div_rate),
 	PLL(APMIXED_APLL3, apll3_con0, apll3_con4,
-	    NO_RSTB_SHIFT, 32, apll3_con2, 24, apll3_con2, 0,
+	    NO_RSTB_SHIFT, 32, apll3_con1, 24, apll3_con2, 0,
 	    pll_div_rate),
 	PLL(APMIXED_APLL4, apll4_con0, apll4_con4,
-	    NO_RSTB_SHIFT, 32, apll4_con2, 24, apll4_con2, 0,
+	    NO_RSTB_SHIFT, 32, apll4_con1, 24, apll4_con2, 0,
 	    pll_div_rate),
 	PLL(APMIXED_APLL5, apll5_con0, apll5_con4,
-	    NO_RSTB_SHIFT, 32, apll5_con2, 24, apll5_con2, 0,
+	    NO_RSTB_SHIFT, 32, apll5_con1, 24, apll5_con2, 0,
 	    pll_div_rate),
 	PLL(APMIXED_MFGPLL, mfgpll_con0, mfgpll_con3,
 	    NO_RSTB_SHIFT, 22, mfgpll_con1, 24, mfgpll_con1, 0,
@@ -573,7 +572,7 @@ void mt_pll_init(void)
 	 * TOP CLKMUX -- DO NOT CHANGE WITHOUT ADJUSTING <soc/pll.h> CONSTANTS!
 	 */
 	for (i = 0; i < ARRAY_SIZE(mux_sels); i++)
-		mux_set_sel(&muxes[mux_sels[i].id], mux_sels[i].sel);
+		pll_mux_set_sel(&muxes[mux_sels[i].id], mux_sels[i].sel);
 
 	/* turn off unused clock in infra_ao */
 	write32(&mt8188_infracfg_ao->module_sw_cg_1_set, 0x00004000);
@@ -633,9 +632,9 @@ void mt_pll_set_tvd_pll1_freq(u32 freq)
 	udelay(PLL_EN_DELAY);
 }
 
-void edp_mux_set_sel(u32 sel)
+void mt_pll_edp_mux_set_sel(u32 sel)
 {
-	mux_set_sel(&muxes[TOP_EDP_SEL], sel);
+	pll_mux_set_sel(&muxes[TOP_EDP_SEL], sel);
 }
 
 void mt_pll_set_usb_clock(void)
