@@ -1,4 +1,4 @@
-/* SPDX-License-Identifier: GPL-2.0-only */
+/* SPDX-License-Identifier: GPL-2.0-only OR MIT */
 
 #ifndef MTK_MT8195_SPI_H
 #define MTK_MT8195_SPI_H
@@ -7,8 +7,8 @@
 
 #define SPI_BUS_NUMBER 6
 
-#define GET_SCK_REG(x) x->spi_cfg2_reg
-#define GET_TICK_DLY_REG(x) x->spi_cfg1_reg
+#define GET_SCK_REG(x) ((x)->spi_cfg2_reg)
+#define GET_TICK_DLY_REG(x) ((x)->spi_cfg1_reg)
 
 DEFINE_BITFIELD(SPI_CFG_CS_HOLD, 15, 0)
 DEFINE_BITFIELD(SPI_CFG_CS_SETUP, 31, 16)
