@@ -3,8 +3,11 @@
 #include <arch/lib_helpers.h>
 #include <commonlib/helpers.h>
 #include <delay.h>
+#include <soc/timer.h>
 
 void init_timer(void)
 {
-	raw_write_cntfrq_el0(13 * MHz);
+	timer_prepare();
+
+	raw_write_cntfrq_el0(TIMER_MHZ * MHz);
 }
