@@ -1,21 +1,9 @@
-/*
- * Copyright (c) 2013-2015, NVIDIA CORPORATION.  All rights reserved.
- *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms and conditions of the GNU General Public License,
- * version 2, as published by the Free Software Foundation.
- *
- * This program is distributed in the hope it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
- * more details.
- */
+/* SPDX-License-Identifier: GPL-2.0-only */
 
 #ifndef _TEGRA210_CLK_RST_H_
 #define _TEGRA210_CLK_RST_H_
 #include <stdint.h>
 #include <stddef.h>
-#include <compiler.h>
 
 /* Clock/Reset Controller (CLK_RST_CONTROLLER_) regs */
 struct  __packed clk_rst_ctlr {
@@ -414,7 +402,7 @@ enum {
 #define PLLM_MISC2_KCP_SHIFT		1
 #define PLLM_MISC2_KVCO_SHIFT		0
 #define PLLM_OUT1_RSTN_RESET_DISABLE	(1 << 0)
-#define PLLM_EN_LCKDET          	(1 << 4)
+#define PLLM_EN_LCKDET			(1 << 4)
 
 /* PLLU specific registers */
 #define PLLU_MISC_IDDQ			(1U << 31)
@@ -525,12 +513,12 @@ enum {
 #define SCLK_DIVISOR_MASK		(0xff << SCLK_DIVISOR_SHIFT)
 
 /* CLK_RST_CONTROLLER_CLK_SYSTEM_RATE 0x30 */
-#define HCLK_DISABLE 			(1 << 7)
-#define HCLK_DIVISOR_SHIFT    		4
-#define HCLK_DIVISOR_MASK     		(3 << AHB_RATE_SHIFT)
-#define PCLK_DISABLE 			(1 << 3)
-#define PCLK_DIVISOR_SHIFT    		0
-#define PCLK_DIVISOR_MASK     		(3 << AHB_RATE_SHIFT)
+#define HCLK_DISABLE			(1 << 7)
+#define HCLK_DIVISOR_SHIFT		4
+#define HCLK_DIVISOR_MASK		(3 << AHB_RATE_SHIFT)
+#define PCLK_DISABLE			(1 << 3)
+#define PCLK_DIVISOR_SHIFT		0
+#define PCLK_DIVISOR_MASK		(3 << AHB_RATE_SHIFT)
 
 /* CPU_SOFTRST_CTRL2_0 0x388 */
 #define CAR2PMC_CPU_ACK_WIDTH_MASK	0xfff
