@@ -1,19 +1,4 @@
-/*
- * Copyright 2014 Google Inc.
- * Copyright 2013-2015, NVIDIA CORPORATION.  All rights reserved.
- *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms and conditions of the GNU General Public License,
- * version 2, as published by the Free Software Foundation.
- *
- * This program is distributed in the hope it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
- * more details.
- */
-
-#include <stdint.h>
-#include <compiler.h>
+/* SPDX-License-Identifier: GPL-2.0-only */
 
 /* Function unit addresses. */
 enum {
@@ -41,7 +26,6 @@ enum {
 	UP_TAG_AVP = 0xaaaaaaaa
 };
 
-
 /*  APB Misc JTAG Configuration Register */
 static uint32_t *misc_pp_config_ctl_ptr = (void *)(APB_MISC_BASE + 0x24);
 enum {
@@ -55,7 +39,6 @@ enum {
 	CFG2TMC_RAM_SVOP_PDP_VAL_2 = 0x2 << 24,
 };
 
-
 /* PINMUX registers. */
 static uint32_t *pinmux_pwr_i2c_scl_ptr = (void *)(PINMUX_BASE + 0xdc);
 static uint32_t *pinmux_pwr_i2c_sda_ptr = (void *)(PINMUX_BASE + 0xe0);
@@ -72,7 +55,6 @@ enum {
 static uint32_t *timer_us_ptr = (void *)(TIMER_BASE + 0x10);
 static uint32_t *timer_us_cfg_ptr = (void *)(TIMER_BASE + 0x14);
 
-
 /* Clock and reset controller registers. */
 static uint32_t *clk_rst_rst_devices_l_ptr = (void *)(CLK_RST_BASE + 0x4);
 enum {
@@ -279,7 +261,6 @@ enum {
 	ACTIVE_SLOW = 0x1 << 0
 };
 
-
 /* Power management controller registers. */
 enum {
 	PARTID_CRAIL = 0,
@@ -361,7 +342,6 @@ enum {
 static uint32_t *sb_aa64_reset_low = (void *)(SECURE_BOOT_BASE + 0x30);
 static uint32_t *sb_aa64_reset_high = (void *)(SECURE_BOOT_BASE + 0x34);
 
-
 /* EMC registers */
 static uint32_t *pmacro_cfg_pm_global = (void *)(EMC_BASE + 0xc30);
 enum {
@@ -423,11 +403,9 @@ enum {
 #define MAX77621_VOUT_VAL	(0x80 | 0x27)
 #define MAX77621_VOUT_DATA	(MAX77621_VOUT_REG | (MAX77621_VOUT_VAL << 8))
 
-
 /* Utility functions. */
 
-static inline void __attribute__((always_inline))
-		   __attribute__((noreturn)) halt(void)
+static __always_inline void __noreturn halt(void)
 {
 	for (;;);
 }
@@ -452,13 +430,13 @@ static inline void clrbits32(uint32_t bits, void *addr)
 	write32(addr, read32(addr) & ~bits);
 }
 
-static void __attribute__((noreturn)) reset(void)
+static void __noreturn reset(void)
 {
 	write32(clk_rst_rst_devices_l_ptr, SWR_TRIG_SYS_RST);
 	halt();
 }
 
-static void udelay(unsigned usecs)
+static void udelay(unsigned int usecs)
 {
 	uint32_t start = read32(timer_us_ptr);
 	while (read32(timer_us_ptr) - start < usecs)
@@ -608,7 +586,6 @@ static void enable_select_cpu_clocks(void)
 	udelay(10);
 }
 
-
 /* Function unit configuration. */
 
 static void config_core_sight(void)
@@ -625,7 +602,6 @@ static void config_core_sight(void)
 	write32(clk_rst_rst_dev_u_clr_ptr, SWR_CSITE_RST);
 }
 
-
 /* RAM repair */
 
 void ram_repair(void)
@@ -637,10 +613,9 @@ void ram_repair(void)
 		;
 }
 
-
 /* Power. */
 
-static void power_on_partition(unsigned id)
+static void power_on_partition(unsigned int id)
 {
 	uint32_t bit = 0x1 << id;
 	if (!(read32(pmc_pwrgate_status_ptr) & bit)) {
@@ -780,7 +755,6 @@ static void mbist_workaround(void)
 	write32(clk_rst_lvl2_clk_gate_ovrd_ptr, 0x01000000);	/* QSPI OVR=1 */
 	write32(clk_rst_lvl2_clk_gate_ovre_ptr, 0x00000c00);
 
-
 	clks_to_be_cleared = read32(clk_rst_clk_out_enb_l_ptr);
 	clks_to_be_cleared &= ~MBIST_CLK_ENB_L_0;
 	write32(clk_rst_clk_enb_l_clr_ptr, clks_to_be_cleared);
@@ -1101,7 +1075,6 @@ void lp0_resume(void)
 		        FLOW_MODE_STOP | EVENT_JTAG);
 }
 
-
 /* Header. */
 
 extern uint8_t blob_data;
