@@ -24,5 +24,7 @@ DECLARE_REGION(dram_modem_extra)
 DECLARE_REGION(dram_wlan)
 DECLARE_REGION(dram_wpss)
 DECLARE_REGION(shrm)
+DECLARE_REGION(dram_cpucp)
+DECLARE_REGION(dram_modem)
 
 #endif // _SOC_QUALCOMM_SYMBOLS_COMMON_H_
