@@ -6,7 +6,6 @@
 #include <device/mmio.h>
 #include <soc/addressmap.h>
 #include <soc/qspi_common.h>
-#include <soc/gpio.h>
 #include <soc/clock.h>
 #include <symbols.h>
 #include <assert.h>
@@ -66,7 +65,7 @@ static void dma_transfer_chain(struct cmd_desc *chain)
 	uint32_t mstr_int_status;
 
 	write32(&qcom_qspi->mstr_int_sts, 0xFFFFFFFF);
-	write32(&qcom_qspi->next_dma_desc_addr, (uint32_t)(uintptr_t) chain);
+	write32(&qcom_qspi->next_dma_desc_addr, (uint32_t)(uintptr_t)chain);
 
 	while (1) {
 		mstr_int_status = read32(&qcom_qspi->mstr_int_sts);
@@ -87,15 +86,15 @@ static void flush_chain(void)
 		if (desc->direction == MASTER_READ) {
 			if (desc->bounce_length == 0)
 				dcache_invalidate_by_mva(
-					(void *)(uintptr_t) desc->data_address,
+					(void *)(uintptr_t)desc->data_address,
 					desc->length);
 			else {
-				src = (void *)(uintptr_t) desc->bounce_src;
-				dst = (void *)(uintptr_t) desc->bounce_dst;
+				src = (void *)(uintptr_t)desc->bounce_src;
+				dst = (void *)(uintptr_t)desc->bounce_dst;
 				memcpy(dst, src, desc->bounce_length);
 			}
 		}
-		desc = (void *)(uintptr_t) desc->next_descriptor;
+		desc = (void *)(uintptr_t)desc->next_descriptor;
 	}
 	curr_desc_idx = -1;
 }
@@ -112,7 +111,7 @@ static struct cmd_desc *allocate_descriptor(void)
 	index = ++curr_desc_idx;
 	next = &dma->descriptors[index];
 
-	next->data_address = (uint32_t) (uintptr_t) dma->buffers[index];
+	next->data_address = (uint32_t)(uintptr_t)dma->buffers[index];
 
 	next->next_descriptor = 0;
 	next->direction = MASTER_READ;
@@ -131,7 +130,7 @@ static struct cmd_desc *allocate_descriptor(void)
 	next->bounce_length = 0;
 
 	if (current)
-		current->next_descriptor = (uint32_t)(uintptr_t) next;
+		current->next_descriptor = (uint32_t)(uintptr_t)next;
 
 	return next;
 }
@@ -164,13 +163,13 @@ static void queue_bounce_data(uint8_t *data, uint32_t data_bytes,
 	desc = allocate_descriptor();
 	desc->direction = write;
 	desc->multi_io_mode = data_mode;
-	ptr = (void *)(uintptr_t) desc->data_address;
+	ptr = (void *)(uintptr_t)desc->data_address;
 
 	if (write) {
 		memcpy(ptr, data, data_bytes);
 	} else {
-		desc->bounce_src = (uint32_t)(uintptr_t) ptr;
-		desc->bounce_dst = (uint32_t)(uintptr_t) data;
+		desc->bounce_src = (uint32_t)(uintptr_t)ptr;
+		desc->bounce_dst = (uint32_t)(uintptr_t)data;
 		desc->bounce_length = data_bytes;
 	}
 
@@ -185,7 +184,7 @@ static void queue_direct_data(uint8_t *data, uint32_t data_bytes,
 	desc = allocate_descriptor();
 	desc->direction = write;
 	desc->multi_io_mode = data_mode;
-	desc->data_address = (uint32_t)(uintptr_t) data;
+	desc->data_address = (uint32_t)(uintptr_t)data;
 	desc->length = data_bytes;
 
 	if (write)
@@ -221,26 +220,11 @@ static void queue_data(uint8_t *data, uint32_t data_bytes,
 		queue_bounce_data(epilog_ptr, epilog_bytes, data_mode, write);
 }
 
-/*
- * The way to encode the sampling delay is:
- *
- * QSPI_SAMPLE_CLK_CONFIG	delay (cycle)
- * ----------------------------------------
- * 0xFFFh = 1111 1111 1111b	7/8
- * 0xDB6h = 1101 1011 0110b	6/8
- * 0xB6Dh = 1011 0110 1101b	5/8
- * 0x924h = 1001 0010 0100b	4/8
- * 0x6DBh = 0110 1101 1011b	3/8
- * 0x492h = 0100 1001 0010b	2/8
- * 0x249h = 0010 0100 1001b	1/8
- * 0x000h = 0000 0000 0000b	None
- */
-static void reg_init(uint32_t sdelay)
+static void reg_init(void)
 {
 	uint32_t spi_mode;
 	uint32_t tx_data_oe_delay, tx_data_delay;
 	uint32_t mstr_config;
-	uint32_t sampling_delay;
 
 	spi_mode = 0;
 
@@ -251,6 +235,7 @@ static void reg_init(uint32_t sdelay)
 		(tx_data_delay << TX_DATA_DELAY_SHIFT) | (SBL_EN) |
 		(spi_mode << SPI_MODE_SHIFT) |
 		(PIN_HOLDN) |
+		(FB_CLK_EN) |
 		(DMA_ENABLE) |
 		(FULL_CYCLE_MODE);
 
@@ -260,16 +245,14 @@ static void reg_init(uint32_t sdelay)
 	write32(&qcom_qspi->mstr_int_sts, 0xFFFFFFFF);
 	write32(&qcom_qspi->rd_fifo_cfg, 0x0);
 	write32(&qcom_qspi->rd_fifo_rst, RESET_FIFO);
-	sampling_delay = sdelay << 9 | sdelay << 6 | sdelay << 3 | sdelay << 0;
-	write32(&qcom_qspi->sampling_clk_cfg, sampling_delay);
 }
 
-void quadspi_init(uint32_t hz, uint32_t sdelay)
+void quadspi_init(uint32_t hz)
 {
 	assert(dcache_line_bytes() == CACHE_LINE_SIZE);
 	clock_configure_qspi(hz * 4);
 	configure_gpios();
-	reg_init(sdelay);
+	reg_init();
 }
 
 int qspi_claim_bus(const struct spi_slave *slave)
@@ -291,7 +274,7 @@ static int xfer(enum qspi_mode mode, const void *dout, size_t out_bytes,
 		return -1;
 	}
 
-	queue_data((uint8_t *) (out_bytes ? dout : din),
+	queue_data((uint8_t *)(out_bytes ? dout : din),
 		in_bytes | out_bytes, mode, !!out_bytes);
 
 	flush_chain();
