@@ -2,7 +2,7 @@
 
 #include <cbmem.h>
 
-void *cbmem_top_chipset(void)
+uintptr_t cbmem_top_chipset(void)
 {
-	return (void *)((uintptr_t)3 * GiB);
+	return (uintptr_t)3 * GiB;
 }
