@@ -1,9 +1,10 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
-#include <device/mmio.h>
 #include <assert.h>
+#include <commonlib/bsd/gcd.h>
 #include <console/console.h>
 #include <delay.h>
+#include <device/mmio.h>
 #include <lib.h>
 #include <soc/addressmap.h>
 #include <soc/clock.h>
@@ -11,7 +12,6 @@
 #include <soc/i2c.h>
 #include <soc/soc.h>
 #include <stdint.h>
-#include <string.h>
 
 struct pll_div {
 	u32	nr;
@@ -303,7 +303,6 @@ void rkclk_init(void)
 	write32(&cru_ptr->cru_mode_con,
 		RK_CLRSETBITS(GPLL_MODE_MSK, GPLL_MODE_NORM) |
 		RK_CLRSETBITS(CPLL_MODE_MSK, CPLL_MODE_NORM));
-
 }
 
 void rkclk_configure_cpu(enum apll_frequencies apll_freq)
@@ -438,16 +437,6 @@ void rkclk_configure_spi(unsigned int bus, unsigned int hz)
 	}
 }
 
-static u32 clk_gcd(u32 a, u32 b)
-{
-	while (b != 0) {
-		int r = b;
-		b = a % b;
-		a = r;
-	}
-	return a;
-}
-
 void rkclk_configure_i2s(unsigned int hz)
 {
 	int n, d;
@@ -462,7 +451,7 @@ void rkclk_configure_i2s(unsigned int hz)
 			      1 << 15 | 0 << 12 | 1 << 8 | 0 << 0));
 
 	/* set frac divider */
-	v = clk_gcd(GPLL_HZ, hz);
+	v = gcd(GPLL_HZ, hz);
 	n = (GPLL_HZ / v) & (0xffff);
 	d = (hz / v) & (0xffff);
 	assert(hz == GPLL_HZ / n * d);
@@ -674,5 +663,4 @@ unsigned int rkclk_i2c_clock_for_bus(unsigned int bus)
 	default:
 		return -1; /* Should never happen. */
 	}
-
 }
