@@ -13,7 +13,7 @@
 
 static void soc_init(struct device *dev)
 {
-	ram_resource(dev, 0, (uintptr_t)_dram/KiB, sdram_size_mb()*(MiB/KiB));
+	ram_range(dev, 0, (uintptr_t)_dram, sdram_size_mb() * MiB);
 	if (display_init_required())
 		rk_display_init(dev, (uintptr_t)_framebuffer,
 				REGION_SIZE(framebuffer));
@@ -33,6 +33,6 @@ static void enable_rk3288_dev(struct device *dev)
 }
 
 struct chip_operations soc_rockchip_rk3288_ops = {
-	CHIP_NAME("SOC Rockchip 3288")
+	.name = "SOC Rockchip 3288",
 	.enable_dev = enable_rk3288_dev,
 };
