@@ -7,7 +7,6 @@
 #include <acpi/acpi.h>
 #include <device/device.h>
 #include <device/pci.h>
-#include <device/pci_def.h>
 #include <device/pci_ids.h>
 #include <device/pci_ops.h>
 #include <types.h>
@@ -88,13 +87,12 @@ static void hudson_final(void *chip_info)
 {
 	if (CONFIG(HUDSON_IMC_FWM)) {
 		agesawrapper_fchecfancontrolservice();
-		if (!CONFIG(ACPI_ENABLE_THERMAL_ZONE))
-			enable_imc_thermal_zone();
+		enable_imc_thermal_zone();
 	}
 }
 
 struct chip_operations southbridge_amd_pi_hudson_ops = {
-	CHIP_NAME("ATI HUDSON")
+	.name = "ATI HUDSON",
 	.enable_dev = hudson_enable,
 	.init = hudson_init,
 	.final = hudson_final
