@@ -4,133 +4,20 @@
 #include <delay.h>
 #include <device/device.h>
 #include <device/pci.h>
-#include <device/pci_def.h>
 #include <device/pci_ops.h>
 #include <string.h>
+#include <timer.h>
 
 #include "chip.h"
 #include "pch.h"
 
-int pch_silicon_revision(void)
-{
-	static int pch_revision_id = -1;
-
-#ifdef __SIMPLE_DEVICE__
-	pci_devfn_t dev = PCI_DEV(0, 0x1f, 0);
-#else
-	struct device *dev = pcidev_on_root(0x1f, 0);
-#endif
-
-	if (pch_revision_id < 0)
-		pch_revision_id = pci_read_config8(dev,	PCI_REVISION_ID);
-	return pch_revision_id;
-}
-
-int pch_silicon_type(void)
-{
-	static int pch_type = -1;
-
-#ifdef __SIMPLE_DEVICE__
-	pci_devfn_t dev = PCI_DEV(0, 0x1f, 0);
-#else
-	struct device *dev = pcidev_on_root(0x1f, 0);
-#endif
-
-	if (pch_type < 0)
-		pch_type = pci_read_config8(dev, PCI_DEVICE_ID + 1);
-	return pch_type;
-}
-
-static int pch_silicon_supported(int type, int rev)
-{
-	int cur_type = pch_silicon_type();
-	int cur_rev = pch_silicon_revision();
-
-	switch (type) {
-	case PCH_TYPE_CPT:
-		/* CougarPoint minimum revision */
-		if (cur_type == PCH_TYPE_CPT && cur_rev >= rev)
-			return 1;
-		/* PantherPoint any revision */
-		if (cur_type == PCH_TYPE_PPT)
-			return 1;
-		break;
-
-	case PCH_TYPE_PPT:
-		/* PantherPoint minimum revision */
-		if (cur_type == PCH_TYPE_PPT && cur_rev >= rev)
-			return 1;
-		break;
-	}
-
-	return 0;
-}
-
-#define IOBP_RETRY 1000
-static inline int iobp_poll(void)
-{
-	unsigned int try = IOBP_RETRY;
-	u32 data;
-
-	while (try--) {
-		data = RCBA32(IOBPS);
-		if ((data & 1) == 0)
-			return 1;
-		udelay(10);
-	}
-
-	printk(BIOS_ERR, "IOBP timeout\n");
-	return 0;
-}
-
-void pch_iobp_update(u32 address, u32 andvalue, u32 orvalue)
-{
-	u32 data;
-
-	/* Set the address */
-	RCBA32(IOBPIRI) = address;
-
-	/* READ OPCODE */
-	if (pch_silicon_supported(PCH_TYPE_CPT, PCH_STEP_B0))
-		RCBA32(IOBPS) = IOBPS_RW_BX;
-	else
-		RCBA32(IOBPS) = IOBPS_READ_AX;
-	if (!iobp_poll())
-		return;
-
-	/* Read IOBP data */
-	data = RCBA32(IOBPD);
-	if (!iobp_poll())
-		return;
-
-	/* Check for successful transaction */
-	if ((RCBA32(IOBPS) & 0x6) != 0) {
-		printk(BIOS_ERR, "IOBP read 0x%08x failed\n", address);
-		return;
-	}
-
-	/* Update the data */
-	data &= andvalue;
-	data |= orvalue;
-
-	/* WRITE OPCODE */
-	if (pch_silicon_supported(PCH_TYPE_CPT, PCH_STEP_B0))
-		RCBA32(IOBPS) = IOBPS_RW_BX;
-	else
-		RCBA32(IOBPS) = IOBPS_WRITE_AX;
-	if (!iobp_poll())
-		return;
-
-	/* Write IOBP data */
-	RCBA32(IOBPD) = data;
-	if (!iobp_poll())
-		return;
-}
-
-#ifndef __SIMPLE_DEVICE__
 /* Set bit in function disable register to hide this device */
 static void pch_hide_devfn(unsigned int devfn)
 {
+	struct device *dev = pcidev_path_on_root(devfn);
+	if (dev)
+		dev->hidden = true;
+
 	switch (devfn) {
 	case PCI_DEVFN(20, 0): /* xHCI */
 		if (pch_silicon_type() == PCH_TYPE_PPT) {
@@ -297,6 +184,52 @@ static void pch_pcie_devicetree_update(
 	       sizeof(new_hotplug_map));
 }
 
+static void check_device_present(struct device *dev)
+{
+	struct southbridge_intel_bd82x6x_config *config = dev->chip_info;
+	struct stopwatch timeout;
+	bool present, hot_plugable;
+	uint32_t cap;
+
+	/* Set slot implemented. */
+	cap = pci_find_capability(dev, PCI_CAP_ID_PCIE);
+	pci_or_config16(dev, cap + PCI_EXP_FLAGS, PCI_EXP_FLAGS_SLOT);
+
+	/*
+	 * By setting the PCI_EXP_FLAGS_SLOT bit in register PCI_EXP_FLAGS the
+	 * PCI_EXP_SLTSTA_PDS bit will be updated with in band device
+	 * detection from the PCIe PHY. While this is primarly used for PCIe
+	 * hot-plug detection, it is more reliable than probing for downstream
+	 * devices by reading DID/VID PCI registers of such.
+	 *
+	 * Usually the PCI_EXP_FLAGS_SLOT isn't set for integrated devices,
+	 * but to simplify device detection it's set for all ports.
+	 *
+	 * It also allows to detect device before PCI enumeration has run.
+	 */
+	hot_plugable = config && config->pcie_hotplug_map[PCI_FUNC(dev->path.pci.devfn)];
+	present = !!(pci_read_config16(dev, cap + PCI_EXP_SLTSTA) & PCI_EXP_SLTSTA_PDS);
+
+	printk(BIOS_DEBUG, "%s: %s downstream device\n",
+	       dev_path(dev), present ? "Found a" : "No");
+
+	if (!present && !hot_plugable) {
+		/* No device present. */
+		stopwatch_init_usecs_expire(&timeout, 50 * 1000);
+		pci_or_config32(dev, 0x338, 1 << 26);
+
+		while (!stopwatch_expired(&timeout)) {
+			if ((pci_read_config32(dev, 0x328) & (0x1f << 23)) == 0)
+				break;
+			udelay(100);
+		}
+		dev->enabled = 0;
+	} else if (present && !hot_plugable && !dev->enabled) {
+		/* Port will be disabled, but device present. Disable link. */
+		pci_or_config32(dev, cap + PCI_EXP_LNKCTL, PCI_EXP_LNKCTL_LD);
+	}
+}
+
 /* Special handling for PCIe Root Port devices */
 static void pch_pcie_enable(struct device *dev)
 {
@@ -305,6 +238,8 @@ static void pch_pcie_enable(struct device *dev)
 	if (!config)
 		return;
 
+	check_device_present(dev);
+
 	/*
 	 * Save a copy of the Root Port Function Number map when
 	 * starting to walk the list of PCIe Root Ports so it can
@@ -319,7 +254,7 @@ static void pch_pcie_enable(struct device *dev)
 		 * or the other devices will not be enumerated by the OS.
 		 */
 		if (!dev->enabled)
-			config->pcie_port_coalesce = 1;
+			config->pcie_port_coalesce = true;
 
 		if (config->pcie_port_coalesce)
 			printk(BIOS_INFO,
@@ -327,7 +262,7 @@ static void pch_pcie_enable(struct device *dev)
 	}
 
 	if (!dev->enabled) {
-		printk(BIOS_DEBUG, "%s: Disabling device\n",  dev_path(dev));
+		printk(BIOS_DEBUG, "%s: Disabling device\n", dev_path(dev));
 
 		/*
 		 * PCIE Power Savings for PantherPoint and CougarPoint/B1+
@@ -408,7 +343,7 @@ void pch_enable(struct device *dev)
 		return pch_pcie_enable(dev);
 
 	if (!dev->enabled) {
-		printk(BIOS_DEBUG, "%s: Disabling device\n",  dev_path(dev));
+		printk(BIOS_DEBUG, "%s: Disabling device\n", dev_path(dev));
 
 		/* Ensure memory, io, and bus master are all disabled */
 		pci_and_config16(dev, PCI_COMMAND,
@@ -423,7 +358,6 @@ void pch_enable(struct device *dev)
 }
 
 struct chip_operations southbridge_intel_bd82x6x_ops = {
-	CHIP_NAME("Intel Series 6/7 (Cougar Point/Panther Point) Southbridge")
+	.name = "Intel Series 6/7 (Cougar Point/Panther Point) Southbridge",
 	.enable_dev = pch_enable,
 };
-#endif
