@@ -1,10 +1,9 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
-#include <stdint.h>
 #include <arch/io.h>
 #include <device/pci_ops.h>
-#include <device/device.h>
-#include <device/pci.h>
+#include <device/pci_type.h>
+#include <stdint.h>
 
 #include "gpio.h"
 
