@@ -4,10 +4,11 @@
 #include <acpi/acpigen.h>
 #include <device/device.h>
 #include <device/pci.h>
+#include <stdbool.h>
 
 #include "pciehp.h"
 
-void intel_acpi_pcie_hotplug_generator(u8 *hotplug_map, int port_number)
+void intel_acpi_pcie_hotplug_generator(bool *hotplug_map, int port_number)
 {
 	int port;
 	int have_hotplug = 0;
@@ -45,9 +46,9 @@ void intel_acpi_pcie_hotplug_generator(u8 *hotplug_map, int port_number)
 
 			acpigen_write_method("_RMV", 0);
 			/* ReturnOp  */
-			acpigen_emit_byte (0xa4);
+			acpigen_emit_byte(0xa4);
 			/* One  */
-			acpigen_emit_byte (0x01);
+			acpigen_emit_byte(0x01);
 			acpigen_pop_len();
 			acpigen_pop_len();
 			acpigen_pop_len();
@@ -113,5 +114,4 @@ void intel_acpi_pcie_hotplug_generator(u8 *hotplug_map, int port_number)
 	}
 	acpigen_pop_len();
 	acpigen_pop_len();
-
 }
