@@ -4,14 +4,17 @@
 #include <arch/io.h>
 #include <arch/ioapic.h>
 #include <console/console.h>
+#include <cpu/x86/smm.h>
 #include <device/device.h>
 #include <device/pci.h>
 #include <device/pci_ids.h>
 #include <device/pci_ops.h>
 #include <option.h>
-#include <pc80/mc146818rtc.h>
-#include <pc80/isa-dma.h>
 #include <pc80/i8259.h>
+#include <pc80/isa-dma.h>
+#include <pc80/mc146818rtc.h>
+#include <types.h>
+
 #include "chip.h"
 #include "i82801dx.h"
 
@@ -19,20 +22,6 @@
 
 typedef struct southbridge_intel_i82801dx_config config_t;
 
-/**
- * Enable ACPI I/O range.
- *
- * @param dev PCI device with ACPI and PM BAR's
- */
-static void i82801dx_enable_acpi(struct device *dev)
-{
-	/* Set ACPI base address (I/O space). */
-	pci_write_config32(dev, PMBASE, (PMBASE_ADDR | 1));
-
-	/* Enable ACPI I/O range decode and ACPI power management. */
-	pci_write_config8(dev, ACPI_CNTL, ACPI_EN);
-}
-
 /**
  * Set miscellaneous static southbridge features.
  *
@@ -50,9 +39,9 @@ static void i82801dx_enable_ioapic(struct device *dev)
 	pci_write_config32(dev, GEN_CNTL, reg32);
 	printk(BIOS_DEBUG, "IOAPIC Southbridge enabled %x\n", reg32);
 
-	setup_ioapic(VIO_APIC_VADDR, 0x02);
+	register_new_ioapic_gsi0(IO_APIC_ADDR);
 
-	ioapic_set_boot_config(VIO_APIC_VADDR, true);
+	ioapic_set_boot_config(IO_APIC_ADDR, true);
 }
 
 static void i82801dx_enable_serial_irqs(struct device *dev)
@@ -96,21 +85,21 @@ static void i82801dx_power_options(struct device *dev)
 
 	reg8 = pci_read_config8(dev, GEN_PMCON_3);
 	reg8 &= 0xfe;
-	switch (pwr_on) {
-		case MAINBOARD_POWER_OFF:
-			reg8 |= 1;
-			state = "off";
-			break;
-		case MAINBOARD_POWER_ON:
-			reg8 &= ~1;
-			state = "on";
-			break;
-		case MAINBOARD_POWER_KEEP:
-			reg8 &= ~1;
-			state = "state keep";
-			break;
-		default:
-			state = "undefined";
+	switch (pwr_on)	{
+	case MAINBOARD_POWER_OFF:
+		reg8 |= 1;
+		state = "off";
+		break;
+	case MAINBOARD_POWER_ON:
+		reg8 &= ~1;
+		state = "on";
+		break;
+	case MAINBOARD_POWER_KEEP:
+		reg8 &= ~1;
+		state = "state keep";
+		break;
+	default:
+		state = "undefined";
 	}
 
 	reg8 &= ~(1 << 3);	/* minimum assertion is 1 to 2 RTCCLK */
@@ -153,12 +142,6 @@ static void i82801dx_power_options(struct device *dev)
 	outl(reg32, pmbase + 0x04);
 }
 
-static void gpio_init(struct device *dev)
-{
-	/* This should be done in romstage.c already */
-	pci_write_config32(dev, GPIO_BASE, (GPIOBASE_ADDR | 1));
-	pci_write_config8(dev, GPIO_CNTL, 0x10);
-}
 
 static void i82801dx_rtc_init(struct device *dev)
 {
@@ -180,6 +163,15 @@ static void i82801dx_rtc_init(struct device *dev)
 	pci_write_config8(dev, RTC_CONF, 0x04);
 }
 
+static void i82801dx_set_acpi_mode(struct device *dev)
+{
+	if (!acpi_is_wakeup_s3()) {
+		apm_control(APM_CNT_ACPI_DISABLE);
+	} else {
+		apm_control(APM_CNT_ACPI_ENABLE);
+	}
+}
+
 static void i82801dx_lpc_route_dma(struct device *dev, u8 mask)
 {
 	u16 reg16;
@@ -195,17 +187,6 @@ static void i82801dx_lpc_route_dma(struct device *dev, u8 mask)
 	pci_write_config16(dev, PCI_DMA_CFG, reg16);
 }
 
-static void i82801dx_lpc_decode_en(struct device *dev)
-{
-	/* Decode 0x3F8-0x3FF (COM1) for COMA port, 0x2F8-0x2FF (COM2) for COMB.
-	 * LPT decode defaults to 0x378-0x37F and 0x778-0x77F.
-	 * Floppy decode defaults to 0x3F0-0x3F5, 0x3F7.
-	 * We also need to set the value for LPC I/F Enables Register.
-	 */
-	pci_write_config8(dev, COM_DEC, 0x10);
-	pci_write_config16(dev, LPC_EN, 0x300F);
-}
-
 /* ICH4 does not mention HPET in the docs, but
  * all ICH3 and ICH4 do have HPETs built in.
  */
@@ -245,7 +226,6 @@ static void enable_hpet(struct device *dev)
 
 static void lpc_init(struct device *dev)
 {
-	i82801dx_enable_acpi(dev);
 	/* IO APIC initialization. */
 	i82801dx_enable_ioapic(dev);
 
@@ -257,9 +237,6 @@ static void lpc_init(struct device *dev)
 	/* Setup power options. */
 	i82801dx_power_options(dev);
 
-	/* Set the state of the GPIO lines. */
-	gpio_init(dev);
-
 	/* Initialize the real time clock. */
 	i82801dx_rtc_init(dev);
 
@@ -269,19 +246,12 @@ static void lpc_init(struct device *dev)
 	/* Initialize ISA DMA. */
 	isa_dma_init();
 
-	/* Setup decode ports and LPC I/F enables. */
-	i82801dx_lpc_decode_en(dev);
-
 	/* Initialize the High Precision Event Timers */
 	enable_hpet(dev);
 
 	setup_i8259();
 
-	/* Don't allow evil boot loaders, kernels, or
-	 * userspace applications to deceive us:
-	 */
-	if (CONFIG(SMM_LEGACY_ASEG))
-		aseg_smm_lock();
+	i82801dx_set_acpi_mode(dev);
 }
 
 static void i82801dx_lpc_read_resources(struct device *dev)
