@@ -47,7 +47,7 @@ void i82801ix_early_init(void)
 {
 	const pci_devfn_t d31f0 = PCI_DEV(0, 0x1f, 0);
 
-	if (ENV_ROMSTAGE)
+	if (ENV_RAMINIT)
 		enable_smbus();
 
 	/* Set up RCBA. */
