@@ -1,12 +1,12 @@
-#include <console/console.h>
+/* SPDX-License-Identifier: GPL-2.0-only */
+
 #include <device/device.h>
 #include <device/pci.h>
 #include <device/pci_ids.h>
 #include <device/pci_ops.h>
-#include <pc80/mc146818rtc.h>
 #include "82870.h"
 
-static void p64h2_pcix_init(device_t dev)
+static void p64h2_pcix_init(struct device *dev)
 {
 	u32 dword;
 	u8 byte;
@@ -20,7 +20,6 @@ static void p64h2_pcix_init(device_t dev)
 	pci_write_config32(dev, ACNF, dword);
 	byte = 0x08;
 	pci_write_config8(dev, MTT, byte);
-
 }
 static struct device_operations pcix_ops  = {
 	.read_resources   = pci_bus_read_resources,
@@ -33,6 +32,10 @@ static struct device_operations pcix_ops  = {
 
 static const struct pci_driver pcix_driver __pci_driver = {
 	.ops    = &pcix_ops,
-	.vendor = PCI_VENDOR_ID_INTEL,
-	.device = PCI_DEVICE_ID_INTEL_82870_1F0,
+	.vendor = PCI_VID_INTEL,
+	.device = PCI_DID_INTEL_82870_1F0,
+};
+
+struct chip_operations southbridge_intel_i82870_ops = {
+	.name = "Intel 82870",
 };
