@@ -15,7 +15,6 @@
 #include <device/device.h>
 #include <device/pci.h>
 #include <device/pci_ids.h>
-#include <device/pci_def.h>
 #include <string.h>
 #include <delay.h>
 #include <elog.h>
@@ -543,6 +542,9 @@ void intel_me_finalize(struct device *dev)
 	/* Try to send EOP command so ME stops accepting other commands */
 	mkhi_end_of_post();
 
+	if (!CONFIG(DISABLE_ME_PCI))
+		return;
+
 	/* Make sure IO is disabled */
 	pci_and_config16(dev, PCI_COMMAND,
 			 ~(PCI_COMMAND_MASTER | PCI_COMMAND_MEMORY | PCI_COMMAND_IO));
@@ -721,7 +723,7 @@ static u32 me_to_host_words_pending(void)
 
 struct mbp_payload {
 	union mbp_header header;
-	u32 data[0];
+	u32 data[];
 };
 
 /*
@@ -903,7 +905,7 @@ static void intel_me_init(struct device *dev)
 static void intel_me_enable(struct device *dev)
 {
 	/* Avoid talking to the device in S3 path */
-	if (acpi_is_wakeup_s3()) {
+	if (acpi_is_wakeup_s3() && CONFIG(DISABLE_ME_PCI)) {
 		dev->enabled = 0;
 		pch_disable_devfn(dev);
 	}
@@ -921,6 +923,7 @@ static struct device_operations device_ops = {
 
 static const unsigned short pci_device_ids[] = {
 	PCI_DID_INTEL_LPT_H_MEI,
+	PCI_DID_INTEL_LPT_H_MEI_9,
 	PCI_DID_INTEL_LPT_LP_MEI,
 	0
 };
