@@ -1,31 +1,20 @@
-/*
- * This file is part of the coreboot project.
- *
- * Copyright (C) 2008-2009 coresystems GmbH
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of
- * the License.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- */
+/* SPDX-License-Identifier: GPL-2.0-only */
 
+#include <assert.h>
+#include <commonlib/helpers.h>
 #include <console/console.h>
 #include <device/device.h>
 #include <device/pci.h>
 #include <device/pciexp.h>
 #include <device/pci_ids.h>
+#include <device/pci_ops.h>
+#include "iobp.h"
 #include "pch.h"
 #include <southbridge/intel/common/gpio.h>
+#include <stdint.h>
+#include "chip.h"
 
-/* LynxPoint-LP has 6 root ports while non-LP has 8. */
 #define MAX_NUM_ROOT_PORTS 8
-#define H_NUM_ROOT_PORTS MAX_NUM_ROOT_PORTS
-#define LP_NUM_ROOT_PORTS (MAX_NUM_ROOT_PORTS - 2)
 
 struct root_port_config {
 	/* RPFN is a write-once register so keep a copy until it is written */
@@ -38,38 +27,48 @@ struct root_port_config {
 	u32 b0d28f0_32c;
 	u32 b0d28f4_32c;
 	u32 b0d28f5_32c;
-	int coalesce;
+	bool coalesce;
 	int gbe_port;
 	int num_ports;
-	device_t ports[MAX_NUM_ROOT_PORTS];
+	struct device *ports[MAX_NUM_ROOT_PORTS];
 };
 
 static struct root_port_config rpc;
 
 static inline int max_root_ports(void)
 {
-	if (pch_is_lp())
-		return LP_NUM_ROOT_PORTS;
-	else
-		return H_NUM_ROOT_PORTS;
+	if (pch_is_lp() || pch_silicon_id() == PCI_DID_INTEL_LPT_H81)
+		return 6;
+
+	return 8;
 }
 
-static inline int root_port_is_first(device_t dev)
+static inline int root_port_is_first(struct device *dev)
 {
 	return PCI_FUNC(dev->path.pci.devfn) == 0;
 }
 
-static inline int root_port_is_last(device_t dev)
+static inline int root_port_is_last(struct device *dev)
 {
 	return PCI_FUNC(dev->path.pci.devfn) == (rpc.num_ports - 1);
 }
 
 /* Root ports are numbered 1..N in the documentation. */
-static inline int root_port_number(device_t dev)
+static inline int root_port_number(struct device *dev)
 {
 	return PCI_FUNC(dev->path.pci.devfn) + 1;
 }
 
+static bool is_rp_enabled(int rp)
+{
+	ASSERT(rp > 0 && rp <= ARRAY_SIZE(rpc.ports));
+
+	if (rpc.ports[rp - 1] == NULL)
+		return false;
+
+	return rpc.ports[rp - 1]->enabled;
+}
+
 static void root_port_config_update_gbe_port(void)
 {
 	/* Is the Gbe Port enabled? */
@@ -100,7 +99,39 @@ static void root_port_config_update_gbe_port(void)
 	}
 }
 
-static void root_port_init_config(device_t dev)
+static void update_num_ports(void)
+{
+	/*
+	 * According to existing code in 'root_port_check_disable()', which does
+	 * not agree with the confusing information on the datasheets, the last
+	 * visible function depends on the strapped root port width as follows:
+	 *
+	 * +-----+----+----+----+----+
+	 * | RPC | #5 | #6 | #7 | #8 |
+	 * +-----+----+----+----+----+
+	 * |  0  | x1 | x1 | x1 | x1 |
+	 * |  1  | x2 |    | x1 | x1 |
+	 * |  2  | x2 |    | x2 |    |
+	 * |  3  | x4 |    |    |    |
+	 * +-----+----+----+----+----+
+	 */
+	switch ((rpc.strpfusecfg2 >> 14) & 0x3) {
+	case 0:
+	case 1:
+		break;
+	case 2:
+		rpc.num_ports = MIN(rpc.num_ports, 7);
+		break;
+	case 3:
+		rpc.num_ports = MIN(rpc.num_ports, 5);
+		break;
+	}
+
+	printk(BIOS_DEBUG, "Adjusted number of PCIe root ports to %d as per strpfusecfg2\n",
+	       rpc.num_ports);
+}
+
+static void root_port_init_config(struct device *dev)
 {
 	int rp;
 
@@ -137,6 +168,10 @@ static void root_port_init_config(device_t dev)
 	case 5:
 		rpc.strpfusecfg2 = pci_read_config32(dev, 0xfc);
 		rpc.b0d28f4_32c = pci_read_config32(dev, 0x32c);
+
+		if (!pch_is_lp())
+			update_num_ports();
+
 		break;
 	case 6:
 		rpc.b0d28f5_32c = pci_read_config32(dev, 0x32c);
@@ -153,8 +188,8 @@ static void root_port_init_config(device_t dev)
 /* Update devicetree with new Root Port function number assignment */
 static void pch_pcie_device_set_func(int index, int pci_func)
 {
-	device_t dev;
-	unsigned new_devfn;
+	struct device *dev;
+	unsigned int new_devfn;
 
 	dev = rpc.ports[index];
 
@@ -165,7 +200,7 @@ static void pch_pcie_device_set_func(int index, int pci_func)
 	/* Determine the new devfn for this port */
 	new_devfn = PCI_DEVFN(PCH_PCIE_DEV_SLOT, pci_func);
 
-	if (dev->path.pci.devfn != new_devfn) {
+	if (dev && dev->path.pci.devfn != new_devfn) {
 		printk(BIOS_DEBUG,
 		       "PCH: PCIe map %02x.%1x -> %02x.%1x\n",
 		       PCI_SLOT(dev->path.pci.devfn),
@@ -186,50 +221,49 @@ static void pcie_enable_clock_gating(void)
 	enabled_ports = 0;
 
 	for (i = 0; i < rpc.num_ports; i++) {
-		device_t dev;
+		struct device *dev;
 		int rp;
 
 		dev = rpc.ports[i];
+		if (!dev)
+			continue;
+
 		rp = root_port_number(dev);
 
-		if (!dev->enabled) {
-			static const uint32_t high_bit = (1UL << 31);
-
+		if (!is_rp_enabled(rp)) {
 			/* Configure shared resource clock gating. */
 			if (rp == 1 || rp == 5 || (rp == 6 && is_lp))
-				pci_update_config8(dev, 0xe1, 0xc3, 0x3c);
+				pci_or_config8(dev, 0xe1, 0x3c);
 
 			if (!is_lp) {
-				if (rp == 1 && !rpc.ports[1]->enabled &&
-				    !rpc.ports[2]->enabled &&
-				    !rpc.ports[3]->enabled) {
-					pci_update_config8(dev, 0xe2, ~1, 1);
-					pci_update_config8(dev, 0xe1, 0x7f, 0x80);
+				if (rp == 1 && !is_rp_enabled(2) &&
+				    !is_rp_enabled(3) && !is_rp_enabled(4)) {
+					pci_or_config8(dev, 0xe2, 1);
+					pci_or_config8(dev, 0xe1, 1 << 7);
 				}
-				if (rp == 5 && !rpc.ports[5]->enabled &&
-				    !rpc.ports[6]->enabled &&
-				    !rpc.ports[7]->enabled) {
-					pci_update_config8(dev, 0xe2, ~1, 1);
-					pci_update_config8(dev, 0xe1, 0x7f, 0x80);
+				if (rp == 5 && !is_rp_enabled(6) &&
+				    !is_rp_enabled(7) && !is_rp_enabled(8)) {
+					pci_or_config8(dev, 0xe2, 1);
+					pci_or_config8(dev, 0xe1, 1 << 7);
 				}
 				continue;
 			}
 
-			pci_update_config8(dev, 0xe2, ~(3 << 4), (3 << 4));
-			pci_update_config32(dev, 0x420, ~high_bit, high_bit);
+			pci_or_config8(dev, 0xe2, 3 << 4);
+			pci_or_config32(dev, 0x420, 1 << 31);
 
 			/* Per-Port CLKREQ# handling. */
 			if (is_lp && gpio_is_native(18 + rp - 1))
-				pci_update_config32(dev, 0x420, ~0, (3 << 29));
+				pci_or_config32(dev, 0x420, 3 << 29);
 
 			/* Enable static clock gating. */
-			if (rp == 1 && !rpc.ports[1]->enabled &&
-			    !rpc.ports[2]->enabled && !rpc.ports[3]->enabled) {
-				pci_update_config8(dev, 0xe2, ~1, 1);
-				pci_update_config8(dev, 0xe1, 0x7f, 0x80);
+			if (rp == 1 && !is_rp_enabled(2) &&
+			    !is_rp_enabled(3) && !is_rp_enabled(4)) {
+				pci_or_config8(dev, 0xe2, 1);
+				pci_or_config8(dev, 0xe1, 1 << 7);
 			} else if (rp == 5 || rp == 6) {
-				pci_update_config8(dev, 0xe2, ~1, 1);
-				pci_update_config8(dev, 0xe1, 0x7f, 0x80);
+				pci_or_config8(dev, 0xe2, 1);
+				pci_or_config8(dev, 0xe1, 1 << 7);
 			}
 			continue;
 		}
@@ -237,29 +271,29 @@ static void pcie_enable_clock_gating(void)
 		enabled_ports++;
 
 		/* Enable dynamic clock gating. */
-		pci_update_config8(dev, 0xe1, 0xfc, 0x03);
+		pci_or_config8(dev, 0xe1, 0x03);
 
 		if (is_lp) {
-			pci_update_config8(dev, 0xe2, ~(1 << 6), (1 << 6));
+			pci_or_config8(dev, 0xe2, 1 << 6);
 			pci_update_config8(dev, 0xe8, ~(3 << 2), (2 << 2));
 		}
 
 		/* Update PECR1 register. */
-		pci_update_config8(dev, 0xe8, ~0, 1);
+		pci_or_config8(dev, 0xe8, 1);
 
-		pci_update_config8(dev, 0x324, ~(1 << 5), (1 < 5));
+		pci_or_config8(dev, 0x324, 1 << 5);
 
 		/* Per-Port CLKREQ# handling. */
 		if (is_lp && gpio_is_native(18 + rp - 1))
-			pci_update_config32(dev, 0x420, ~0, (3 << 29));
+			pci_or_config32(dev, 0x420, 3 << 29);
 
 		/* Configure shared resource clock gating. */
 		if (rp == 1 || rp == 5 || (rp == 6 && is_lp))
-			pci_update_config8(dev, 0xe1, 0xc3, 0x3c);
+			pci_or_config8(dev, 0xe1, 0x3c);
 	}
 
-	if (!enabled_ports && is_lp)
-		pci_update_config8(rpc.ports[0], 0xe1, ~(1 << 6), (1 << 6));
+	if (!enabled_ports && is_lp && rpc.ports[0])
+		pci_or_config8(rpc.ports[0], 0xe1, 1 << 6);
 }
 
 static void root_port_commit_config(void)
@@ -267,15 +301,14 @@ static void root_port_commit_config(void)
 	int i;
 
 	/* If the first root port is disabled the coalesce ports. */
-	if (!rpc.ports[0]->enabled)
-		rpc.coalesce = 1;
+	if (!is_rp_enabled(1))
+		rpc.coalesce = true;
 
 	/* Perform clock gating configuration. */
 	pcie_enable_clock_gating();
 
 	for (i = 0; i < rpc.num_ports; i++) {
-		device_t dev;
-		u32 reg32;
+		struct device *dev;
 
 		dev = rpc.ports[i];
 
@@ -287,13 +320,11 @@ static void root_port_commit_config(void)
 		if (dev->enabled)
 			continue;
 
-		printk(BIOS_DEBUG, "%s: Disabling device\n",  dev_path(dev));
+		printk(BIOS_DEBUG, "%s: Disabling device\n", dev_path(dev));
 
 		/* Ensure memory, io, and bus master are all disabled */
-		reg32 = pci_read_config32(dev, PCI_COMMAND);
-		reg32 &= ~(PCI_COMMAND_MASTER |
-			   PCI_COMMAND_MEMORY | PCI_COMMAND_IO);
-		pci_write_config32(dev, PCI_COMMAND, reg32);
+		pci_and_config16(dev, PCI_COMMAND,
+				~(PCI_COMMAND_MASTER | PCI_COMMAND_MEMORY | PCI_COMMAND_IO));
 
 		/* Disable this device if possible */
 		pch_disable_devfn(dev);
@@ -307,7 +338,7 @@ static void root_port_commit_config(void)
 		 * function numbers. */
 		current_func = 0;
 		for (i = 0; i < rpc.num_ports; i++) {
-			if (!rpc.ports[i]->enabled)
+			if (!is_rp_enabled(i + 1))
 				continue;
 			pch_pcie_device_set_func(i, current_func);
 			current_func++;
@@ -315,7 +346,7 @@ static void root_port_commit_config(void)
 
 		/* Allocate the disabled devices' PCI function number. */
 		for (i = 0; i < rpc.num_ports; i++) {
-			if (rpc.ports[i]->enabled)
+			if (is_rp_enabled(i + 1))
 				continue;
 			pch_pcie_device_set_func(i, current_func);
 			current_func++;
@@ -327,7 +358,7 @@ static void root_port_commit_config(void)
 	RCBA32(RPFN) = rpc.new_rpfn;
 }
 
-static void root_port_mark_disable(device_t dev)
+static void root_port_mark_disable(struct device *dev)
 {
 	/* Mark device as disabled. */
 	dev->enabled = 0;
@@ -335,7 +366,7 @@ static void root_port_mark_disable(device_t dev)
 	rpc.new_rpfn |= RPFN_HIDE(PCI_FUNC(dev->path.pci.devfn));
 }
 
-static void root_port_check_disable(device_t dev)
+static void root_port_check_disable(struct device *dev)
 {
 	int rp;
 	int is_lp;
@@ -394,7 +425,7 @@ static void root_port_check_disable(device_t dev)
 		case 7:
 			if (is_lp)
 				break;
-			/* Root Port 3 is disabled in config 11b (1x4 links). */
+			/* Root Port 7 is disabled in config 11b (1x4 links). */
 			if (((rpc.strpfusecfg2 >> 14) & 0x3) == 0x3) {
 				root_port_mark_disable(dev);
 				return;
@@ -468,14 +499,10 @@ static void pcie_add_0x0202000_iobp(u32 reg)
 
 static void pch_pcie_early(struct device *dev)
 {
-	int rp;
-	int do_aspm;
-	int is_lp;
 	struct southbridge_intel_lynxpoint_config *config = dev->chip_info;
-
-	rp = root_port_number(dev);
-	do_aspm = 0;
-	is_lp = pch_is_lp();
+	int do_aspm = 0;
+	int rp = root_port_number(dev);
+	int is_lp = pch_is_lp();
 
 	if (is_lp) {
 		switch (rp) {
@@ -483,19 +510,25 @@ static void pch_pcie_early(struct device *dev)
 		case 2:
 		case 3:
 		case 4:
-			/* Bits 31:28 of b0d28f0 0x32c register correspnd to
-			 * Root Ports 4:1. */
+			/*
+			 * Bits 31:28 of b0d28f0 0x32c register correspond to
+			 * Root Ports 4:1.
+			 */
 			do_aspm = !!(rpc.b0d28f0_32c & (1 << (28 + rp - 1)));
 			break;
 		case 5:
-			/* Bit 28 of b0d28f4 0x32c register correspnd to
-			 * Root Ports 4:1. */
+			/*
+			 * Bit 28 of b0d28f4 0x32c register corresponds to
+			 * Root Port 5.
+			 */
 			do_aspm = !!(rpc.b0d28f4_32c & (1 << 28));
 			break;
 		case 6:
-			/* Bit 28 of b0d28f5 0x32c register correspnd to
-			 * Root Ports 4:1. */
-			do_aspm = !!(rpc.b0d28f5_32c & (1 << 28));
+			/*
+			 * Bit 29 of b0d28f5 0x32c register corresponds to
+			 * Root Port 6.
+			 */
+			do_aspm = !!(rpc.b0d28f5_32c & (1 << 29));
 			break;
 		}
 	} else {
@@ -504,16 +537,20 @@ static void pch_pcie_early(struct device *dev)
 		case 2:
 		case 3:
 		case 4:
-			/* Bits 31:28 of b0d28f0 0x32c register correspnd to
-			 * Root Ports 4:1. */
+			/*
+			 * Bits 31:28 of b0d28f0 0x32c register correspond to
+			 * Root Ports 4:1.
+			 */
 			do_aspm = !!(rpc.b0d28f0_32c & (1 << (28 + rp - 1)));
 			break;
 		case 5:
 		case 6:
 		case 7:
 		case 8:
-			/* Bit 31:28 of b0d28f4 0x32c register correspnd to
-			 * Root Ports 8:5. */
+			/*
+			 * Bits 31:28 of b0d28f4 0x32c register correspond to
+			 * Root Ports 8:5.
+			 */
 			do_aspm = !!(rpc.b0d28f4_32c & (1 << (28 + rp - 5)));
 			break;
 		}
@@ -533,9 +570,6 @@ static void pch_pcie_early(struct device *dev)
 		/* Set unique clock exit latency in MPC register. */
 		pci_update_config32(dev, 0xd8, ~(0x7 << 18), (0x7 << 18));
 
-		/* Set L1 exit latency in LCAP register. */
-		pci_update_config32(dev, 0x4c, ~(0x7 << 15), (0x4 << 15));
-
 		if (is_lp) {
 			switch (rp) {
 			case 1:
@@ -603,44 +637,55 @@ static void pch_pcie_early(struct device *dev)
 			}
 		}
 
-		pci_update_config32(dev, 0x338, ~(1 << 26), 0);
+		pci_and_config32(dev, 0x338, ~(1 << 26));
 	}
 
-	/* Enable LTR in Root Port. */
-	pci_update_config32(dev, 0x64, ~(1 << 11), (1 << 11));
-	pci_update_config32(dev, 0x68, ~(1 << 10), (1 << 10));
+	/* Enable LTR in Root Port. Disable OBFF. */
+	pci_update_config32(dev, 0x64, ~(3 << 18), 1 << 11);
+	pci_update_config16(dev, 0x68, ~(3 << 13), 1 << 10);
 
-	pci_update_config32(dev, 0x318, ~(0xffffUL << 16), (0x1414UL << 16));
+	pci_update_config32(dev, 0x318, ~(0xffff << 16), (0x1414 << 16));
 
 	/* Set L1 exit latency in LCAP register. */
-	if (!do_aspm && (pci_read_config8(dev, 0xf5) & 0x1))
+	if ((pci_read_config8(dev, 0xf5) & 0x1) || do_aspm)
 		pci_update_config32(dev, 0x4c, ~(0x7 << 15), (0x4 << 15));
 	else
 		pci_update_config32(dev, 0x4c, ~(0x7 << 15), (0x2 << 15));
 
-	pci_update_config32(dev, 0x314, 0x0, 0x743a361b);
+	pci_update_config32(dev, 0x314, 0, 0x743a361b);
 
 	/* Set Common Clock Exit Latency in MPC register. */
 	pci_update_config32(dev, 0xd8, ~(0x7 << 15), (0x3 << 15));
 
 	pci_update_config32(dev, 0x33c, ~0x00ffffff, 0x854c74);
 
-	/* Set Invalid Recieve Range Check Enable in MPC register. */
-	pci_update_config32(dev, 0xd8, ~0, (1 << 25));
+	/* Set Invalid Receive Range Check Enable in MPC register. */
+	pci_or_config32(dev, 0xd8, 1 << 25);
 
-	pci_update_config8(dev, 0xf5, 0x3f, 0);
+	pci_and_config8(dev, 0xf5, 0x0f);
 
 	if (rp == 1 || rp == 5 || (is_lp && rp == 6))
-		pci_update_config8(dev, 0xf7, ~0xc, 0);
+		pci_and_config8(dev, 0xf7, ~0x0c);
 
 	/* Set EOI forwarding disable. */
-	pci_update_config32(dev, 0xd4, ~0, (1 << 1));
+	pci_or_config32(dev, 0xd4, 1 << 1);
 
-	/* Set something involving advanced error reporting. */
-	pci_update_config32(dev, 0x100, ~((1 << 20) - 1), 0x10001);
+	/* Set AER Extended Cap ID to 01h */
+	u32 aech = CONFIG(PCIEXP_AER) ? 0x10001 : 0;
 
+	/* For PCH-LP, set Next Cap Pointer to 200h. */
 	if (is_lp)
-		pci_update_config32(dev, 0x100, ~0, (1 << 29));
+		aech |= 1 << 29;
+
+	pci_update_config32(dev, 0x100, ~0xfffff, aech);
+
+	if (is_lp) {
+		/* Set L1 Sub-State Cap ID to 1Eh and Next Cap Pointer to None. */
+		if (CONFIG(PCIEXP_L1_SUB_STATE))
+			pci_update_config32(dev, 0x200, ~0xfffff, 0x001e);
+		else
+			pci_update_config32(dev, 0x200, ~0xfffff, 0);
+	}
 
 	/* Read and write back write-once capability registers. */
 	pci_update_config32(dev, 0x34, ~0, 0);
@@ -649,52 +694,28 @@ static void pch_pcie_early(struct device *dev)
 	pci_update_config32(dev, 0x90, ~0, 0);
 }
 
-static void pci_init(struct device *dev)
+static void pch_pcie_init(struct device *dev)
 {
-	u16 reg16;
-	u32 reg32;
-
 	printk(BIOS_DEBUG, "Initializing PCH PCIe bridge.\n");
 
 	/* Enable SERR */
-	reg32 = pci_read_config32(dev, PCI_COMMAND);
-	reg32 |= PCI_COMMAND_SERR;
-	pci_write_config32(dev, PCI_COMMAND, reg32);
+	pci_or_config16(dev, PCI_COMMAND, PCI_COMMAND_SERR);
 
 	/* Enable Bus Master */
-	reg32 = pci_read_config32(dev, PCI_COMMAND);
-	reg32 |= PCI_COMMAND_MASTER;
-	pci_write_config32(dev, PCI_COMMAND, reg32);
+	pci_or_config16(dev, PCI_COMMAND, PCI_COMMAND_MASTER);
 
 	/* Set Cache Line Size to 0x10 */
 	// This has no effect but the OS might expect it
 	pci_write_config8(dev, 0x0c, 0x10);
 
-	reg16 = pci_read_config16(dev, 0x3e);
-	reg16 &= ~(1 << 0); /* disable parity error response */
-	// reg16 &= ~(1 << 1); /* disable SERR */
-	reg16 |= (1 << 2); /* ISA enable */
-	pci_write_config16(dev, 0x3e, reg16);
-
-#ifdef EVEN_MORE_DEBUG
-	reg32 = pci_read_config32(dev, 0x20);
-	printk(BIOS_SPEW, "    MBL    = 0x%08x\n", reg32);
-	reg32 = pci_read_config32(dev, 0x24);
-	printk(BIOS_SPEW, "    PMBL   = 0x%08x\n", reg32);
-	reg32 = pci_read_config32(dev, 0x28);
-	printk(BIOS_SPEW, "    PMBU32 = 0x%08x\n", reg32);
-	reg32 = pci_read_config32(dev, 0x2c);
-	printk(BIOS_SPEW, "    PMLU32 = 0x%08x\n", reg32);
-#endif
+	pci_and_config16(dev, PCI_BRIDGE_CONTROL, ~PCI_BRIDGE_CTL_PARITY);
 
 	/* Clear errors in status registers */
-	reg16 = pci_read_config16(dev, 0x06);
-	pci_write_config16(dev, 0x06, reg16);
-	reg16 = pci_read_config16(dev, 0x1e);
-	pci_write_config16(dev, 0x1e, reg16);
+	pci_update_config16(dev, 0x06, ~0, 0);
+	pci_update_config16(dev, 0x1e, ~0, 0);
 }
 
-static void pch_pcie_enable(device_t dev)
+static void pch_pcie_enable(struct device *dev)
 {
 	/* Add this device to the root port config structure. */
 	root_port_init_config(dev);
@@ -714,42 +735,44 @@ static void pch_pcie_enable(device_t dev)
 		root_port_commit_config();
 }
 
-static void pcie_set_subsystem(device_t dev, unsigned vendor, unsigned device)
-{
-	/* NOTE: This is not the default position! */
-	if (!vendor || !device) {
-		pci_write_config32(dev, 0x94,
-				pci_read_config32(dev, 0));
-	} else {
-		pci_write_config32(dev, 0x94,
-				((device & 0xffff) << 16) | (vendor & 0xffff));
-	}
-}
-
-static struct pci_operations pci_ops = {
-	.set_subsystem = pcie_set_subsystem,
-};
-
 static struct device_operations device_ops = {
 	.read_resources		= pci_bus_read_resources,
 	.set_resources		= pci_dev_set_resources,
 	.enable_resources	= pci_bus_enable_resources,
-	.init			= pci_init,
+	.init			= pch_pcie_init,
 	.enable			= pch_pcie_enable,
 	.scan_bus		= pciexp_scan_bridge,
-	.ops_pci		= &pci_ops,
+	.ops_pci		= &pci_dev_ops_pci,
 };
 
 static const unsigned short pci_device_ids[] = {
-	/* Lynxpoint Mobile */
-	0x8c10, 0x8c12, 0x8c14, 0x8c16, 0x8c18, 0x8c1a, 0x8c1c, 0x8c1e,
-	/* Lynxpoint Low Power */
-	0x9c10, 0x9c12, 0x9c14, 0x9c16, 0x9c18, 0x9c1a,
+	PCI_DID_INTEL_LPT_H_PCIE_RP1,
+	PCI_DID_INTEL_LPT_H_PCIE_RP2,
+	PCI_DID_INTEL_LPT_H_PCIE_RP3,
+	PCI_DID_INTEL_LPT_H_PCIE_RP4,
+	PCI_DID_INTEL_LPT_H_PCIE_RP5,
+	PCI_DID_INTEL_LPT_H_PCIE_RP6,
+	PCI_DID_INTEL_LPT_H_PCIE_RP7,
+	PCI_DID_INTEL_LPT_H_PCIE_RP8,
+	PCI_DID_INTEL_LPT_H_PCIE_RP1_9,
+	PCI_DID_INTEL_LPT_H_PCIE_RP2_9,
+	PCI_DID_INTEL_LPT_H_PCIE_RP3_9,
+	PCI_DID_INTEL_LPT_H_PCIE_RP4_9,
+	PCI_DID_INTEL_LPT_H_PCIE_RP5_9,
+	PCI_DID_INTEL_LPT_H_PCIE_RP6_9,
+	PCI_DID_INTEL_LPT_H_PCIE_RP7_9,
+	PCI_DID_INTEL_LPT_H_PCIE_RP8_9,
+	PCI_DID_INTEL_LPT_LP_PCIE_RP1,
+	PCI_DID_INTEL_LPT_LP_PCIE_RP2,
+	PCI_DID_INTEL_LPT_LP_PCIE_RP3,
+	PCI_DID_INTEL_LPT_LP_PCIE_RP4,
+	PCI_DID_INTEL_LPT_LP_PCIE_RP5,
+	PCI_DID_INTEL_LPT_LP_PCIE_RP6,
 	0
 };
 
 static const struct pci_driver pch_pcie __pci_driver = {
 	.ops	 = &device_ops,
-	.vendor	 = PCI_VENDOR_ID_INTEL,
+	.vendor	 = PCI_VID_INTEL,
 	.devices = pci_device_ids,
 };
