@@ -8,7 +8,6 @@
 #include <arch/io.h>
 #include <device/device.h>
 #include <device/pci.h>
-#include <device/pci_def.h>
 #include <console/console.h>
 #include <security/vboot/vbnv.h>
 #include <security/vboot/vboot_common.h>
@@ -356,7 +355,7 @@ void enable_tco_sci(void)
 	u16 gpe0_sts = pch_is_lp() ? LP_GPE0_STS_4 : GPE0_STS;
 
 	/* Clear pending events */
-	outl(get_pmbase() + gpe0_sts, TCOSCI_STS);
+	outl(TCOSCI_STS, get_pmbase() + gpe0_sts);
 
 	/* Enable TCO SCI events */
 	enable_gpe(TCOSCI_EN);
@@ -448,7 +447,7 @@ static u32 clear_lpt_gpe_status(void)
 	};
 
 	/* High bits */
-	print_gpe_status(reset_gpe_status(GPE0_STS_2, GPE0_EN_2),
+	print_gpe_status(reset_gpe_status(GPE0_STS + sizeof(uint32_t), GPE0_EN + sizeof(uint32_t)),
 			 gpe0_sts_bits_high);
 
 	/* Standard GPE and GPIO 0-31 */
@@ -508,7 +507,7 @@ void enable_all_gpe(u32 set1, u32 set2, u32 set3, u32 set4)
 		outl(set4, pmbase + LP_GPE0_EN_4);
 	} else {
 		outl(set1, pmbase + GPE0_EN);
-		outl(set2, pmbase + GPE0_EN_2);
+		outl(set2, pmbase + GPE0_EN + sizeof(u32));
 	}
 }
 
