@@ -231,6 +231,18 @@ static const unsigned short pci_device_ids[] = {
 	PCI_DID_INTEL_LPT_H_MOBILE_SATA_RAID_PREM,
 	PCI_DID_INTEL_LPT_H_MOBILE_SATA_IDE_P45,
 	PCI_DID_INTEL_LPT_H_MOBILE_SATA_RAID_2,
+	PCI_DID_INTEL_LPT_H_DESKTOP_SATA_IDE_9,
+	PCI_DID_INTEL_LPT_H_DESKTOP_SATA_AHCI_9,
+	PCI_DID_INTEL_LPT_H_DESKTOP_SATA_RAID_1_9,
+	PCI_DID_INTEL_LPT_H_DESKTOP_SATA_RAID_PREM_9,
+	PCI_DID_INTEL_LPT_H_DESKTOP_SATA_IDE_P45_9,
+	PCI_DID_INTEL_LPT_H_DESKTOP_SATA_RAID_2_9,
+	PCI_DID_INTEL_LPT_H_MOBILE_SATA_IDE_9,
+	PCI_DID_INTEL_LPT_H_MOBILE_SATA_AHCI_9,
+	PCI_DID_INTEL_LPT_H_MOBILE_SATA_RAID_1_9,
+	PCI_DID_INTEL_LPT_H_MOBILE_SATA_RAID_PREM_9,
+	PCI_DID_INTEL_LPT_H_MOBILE_SATA_IDE_P45_9,
+	PCI_DID_INTEL_LPT_H_MOBILE_SATA_RAID_2_9,
 	PCI_DID_INTEL_LPT_LP_SATA_AHCI,
 	PCI_DID_INTEL_LPT_LP_SATA_RAID_1,
 	PCI_DID_INTEL_LPT_LP_SATA_RAID_PREM,
