@@ -112,6 +112,6 @@ static void enable_dev(struct device *dev)
 }
 
 struct chip_operations superio_ite_it8720f_ops = {
-	CHIP_NAME("ITE IT8720F Super I/O")
+	.name = "ITE IT8720F Super I/O",
 	.enable_dev = enable_dev,
 };
