@@ -102,6 +102,6 @@ static void enable_dev(struct device *dev)
 }
 
 struct chip_operations superio_nuvoton_nct6791d_ops = {
-	CHIP_NAME("NUVOTON NCT6791D Super I/O")
+	.name = "NUVOTON NCT6791D Super I/O",
 	.enable_dev = enable_dev,
 };
