@@ -13,14 +13,22 @@
 
 void cse_board_reset(void)
 {
-	int ret;
+	tpm_result_t rc;
 	struct cr50_firmware_version version;
 
+	if (CONFIG(CSE_RESET_CLEAR_EC_AP_IDLE_FLAG))
+		google_chromeec_clear_ec_ap_idle();
+
+	/*
+	 * Assuming that if particular TPM implementation is enabled at compile
+	 * time, it's the one being used.  This isn't generic code, so can
+	 * probably get away with it.
+	 */
 	if (CONFIG(TPM2) && CONFIG(TPM_GOOGLE_CR50)) {
 		/* Initialize TPM and get the cr50 firmware version. */
-		ret = tlcl_lib_init();
-		if (ret != VB2_SUCCESS) {
-			printk(BIOS_ERR, "tlcl_lib_init() failed: 0x%x\n", ret);
+		rc = tlcl_lib_init();
+		if (rc != TPM_SUCCESS) {
+			printk(BIOS_ERR, "tlcl_lib_init() failed: %#x\n", rc);
 			return;
 		}
 
