@@ -21,9 +21,9 @@
 
 static void reset_imd(void)
 {
-	imd.lg.limit = (uintptr_t)NULL;
+	imd.lg.limit = 0;
 	imd.lg.r = NULL;
-	imd.sm.limit = (uintptr_t)NULL;
+	imd.sm.limit = 0;
 	imd.sm.r = NULL;
 
 	cbmem_initialized = 0;
@@ -81,7 +81,7 @@ static void test_cbmem_top(void **state)
 {
 	cbmem_top_init_once();
 
-	if (ENV_ROMSTAGE)
+	if (ENV_CREATES_CBMEM)
 		assert_ptr_equal(cbmem_top_chipset(), cbmem_top());
 
 	if (ENV_POSTCAR || ENV_RAMSTAGE)
