@@ -1,10 +1,19 @@
 package main
 
 import "fmt"
+import "strings"
 
 type sandybridgemc struct {
 }
 
+func MakeSPDMap(ctx Context) string {
+	var values []string
+	for _, addr := range GuessSPDMap(ctx) {
+		values = append(values, fmt.Sprintf("0x%02x", addr))
+	}
+	return "{"+strings.Join(values, ", ")+"}"
+}
+
 func (i sandybridgemc) Scan(ctx Context, addr PCIDevData) {
 	inteltool := ctx.InfoSource.GetInteltool()
 
@@ -33,45 +42,18 @@ func (i sandybridgemc) Scan(ctx Context, addr PCIDevData) {
 			"gpu_cpu_backlight":                   FormatHex32(inteltool.IGD[0x48254]),
 			"gpu_pch_backlight":                   FormatHex32((inteltool.IGD[0xc8254] >> 16) * 0x10001),
 			"gfx": fmt.Sprintf("GMA_STATIC_DISPLAYS(%d)", (inteltool.IGD[0xc6200] >> 12) & 1),
+			"spd_addresses": MakeSPDMap(ctx)+"\" # FIXME: Put proper SPD map here",
 		},
 		Children: []DevTreeNode{
-			{
-				Chip: "cpu_cluster",
-				Dev:  0,
-				Children: []DevTreeNode{
-					{
-						Chip:    "cpu/intel/model_206ax",
-						Comment: "FIXME: check all registers",
-						Registers: map[string]string{
-							/* FIXME:XX hardcoded.  */
-							"acpi_c1": "1",
-							"acpi_c2": "3",
-							"acpi_c3": "5",
-						},
-						Children: []DevTreeNode{
-							{
-								Chip: "lapic",
-								Dev:  0,
-							},
-							{
-								Chip:     "lapic",
-								Dev:      0xacac,
-								Disabled: true,
-							},
-						},
-					},
-				},
-			},
-
 			{
 				Chip:          "domain",
 				Dev:           0,
 				PCIController: true,
 				ChildPCIBus:   0,
 				PCISlots: []PCISlot{
-					PCISlot{PCIAddr: PCIAddr{Dev: 0x0, Func: 0}, writeEmpty: true, additionalComment: "Host bridge"},
-					PCISlot{PCIAddr: PCIAddr{Dev: 0x1, Func: 0}, writeEmpty: true, additionalComment: "PEG"},
-					PCISlot{PCIAddr: PCIAddr{Dev: 0x2, Func: 0}, writeEmpty: true, additionalComment: "iGPU"},
+					PCISlot{PCIAddr: PCIAddr{Dev: 0x0, Func: 0}, writeEmpty: true, alias: "host_bridge", additionalComment: "Host bridge"},
+					PCISlot{PCIAddr: PCIAddr{Dev: 0x1, Func: 0}, writeEmpty: true, alias: "peg10", additionalComment: "PEG"},
+					PCISlot{PCIAddr: PCIAddr{Dev: 0x2, Func: 0}, writeEmpty: true, alias: "igd", additionalComment: "iGPU"},
 				},
 			},
 		},
