@@ -166,6 +166,10 @@ static void eventlog_print_type(const struct event_header *event)
 		{ELOG_TYPE_CROS_DIAGNOSTICS, "Diagnostics Mode"},
 		{ELOG_TYPE_FW_VBOOT_INFO, "Firmware vboot info"},
 		{ELOG_TYPE_FW_EARLY_SOL, "Early Sign of Life"},
+		{ELOG_TYPE_PSR_DATA_BACKUP, "PSR data backup"},
+		{ELOG_TYPE_PSR_DATA_LOST, "PSR data lost"},
+		{ELOG_TYPE_FW_SPLASH_SCREEN, "Firmware Splash Screen"},
+		{ELOG_TYPE_FW_CSE_SYNC, "Firmware CSE sync"},
 		{ELOG_TYPE_EOL, "End of log"},
 	};
 
@@ -408,6 +412,8 @@ static int eventlog_print_data(const struct event_header *event)
 		{POSTCODE_FSP_MULTI_PHASE_SI_INIT_EXIT, "FPS-S Init Exit"},
 		{POSTCODE_FSP_NOTIFY_AFTER_ENUMERATE, "FSP Notify After Enumerate"},
 		{POSTCODE_FSP_NOTIFY_AFTER_FINALIZE, "FSP Notify After Finalize"},
+		{POSTCODE_FSP_MULTI_PHASE_MEM_INIT_ENTRY, "FSP-M Init Enter"},
+		{POSTCODE_FSP_MULTI_PHASE_MEM_INIT_EXIT, "FPS-M Init Exit"},
 		{POSTCODE_INVALID_ROM, "Invalid ROM"},
 		{POSTCODE_INVALID_CBFS, "Invalid CBFS"},
 		{POSTCODE_INVALID_VENDOR_BINARY, "Invalid Vendor Binary"},
@@ -472,6 +478,19 @@ static int eventlog_print_data(const struct event_header *event)
 		{0, NULL},
 	};
 
+	static const struct valstr psr_data_backup_statuses[] = {
+		{ELOG_PSR_DATA_BACKUP_SUCCESS, "Success"},
+		{ELOG_PSR_DATA_BACKUP_FAILED, "Fail"},
+		{0, NULL},
+	};
+
+	static const struct valstr cse_sync_path_types[] = {
+		{ELOG_FW_PRE_RAM_CSE_SYNC, "Pre-RAM CSE Sync"},
+		{ELOG_FW_POST_RAM_CSE_SYNC, "Post-RAM CSE Sync"},
+		{ELOG_FW_CSE_SYNC_AT_PAYLOAD, "CSE Sync at Payload"},
+		{0, NULL},
+	};
+
 	size_t elog_type_to_min_size[] = {
 		[ELOG_TYPE_LOG_CLEAR]		= sizeof(uint16_t),
 		[ELOG_TYPE_BOOT]		= sizeof(uint32_t),
@@ -491,6 +510,9 @@ static int eventlog_print_data(const struct event_header *event)
 		[ELOG_TYPE_CROS_DIAGNOSTICS]	= sizeof(uint8_t),
 		[ELOG_TYPE_FW_VBOOT_INFO]	= sizeof(uint16_t),
 		[ELOG_TYPE_FW_EARLY_SOL]	= sizeof(uint8_t),
+		[ELOG_TYPE_PSR_DATA_BACKUP]	= sizeof(uint8_t),
+		[ELOG_TYPE_FW_SPLASH_SCREEN]	= sizeof(uint8_t),
+		[ELOG_TYPE_FW_CSE_SYNC]		= sizeof(uint8_t),
 		[0xff]				= 0,
 	};
 
@@ -647,6 +669,21 @@ static int eventlog_print_data(const struct event_header *event)
 		eventlog_printf("%s", val2str(*sol_event, early_sol_path_types));
 		break;
 	}
+	case ELOG_TYPE_PSR_DATA_BACKUP: {
+		const uint8_t *psr_backup_event = event_get_data(event);
+		eventlog_printf("%s", val2str(*psr_backup_event, psr_data_backup_statuses));
+		break;
+	}
+	case ELOG_TYPE_FW_SPLASH_SCREEN: {
+		const uint8_t *fw_splash_screen_event = event_get_data(event);
+		eventlog_printf("%s", *fw_splash_screen_event ? "Enabled" : "Disabled");
+		break;
+	}
+	case ELOG_TYPE_FW_CSE_SYNC: {
+		const uint8_t *cse_event = event_get_data(event);
+		eventlog_printf("%s", val2str(*cse_event, cse_sync_path_types));
+		break;
+	}
 	default:
 		break;
 	}
