@@ -17,6 +17,7 @@
 #define FIT_HEADER_VERSION 0x0100
 #define FIT_HEADER_ADDRESS "_FIT_   "
 #define FIT_MICROCODE_VERSION 0x0100
+#define FIT_PLATFORM_BOOT_POLICY_VERSION 0x0100
 #define FIT_TXT_VERSION 0x0100
 
 #define FIT_SIZE_ALIGNMENT 16
@@ -275,8 +276,10 @@ parse_microcode_blob(struct cbfs_image *image,
 	struct cbfs_file *mcode_file;
 
 	mcode_file = cbfs_get_entry(image, blob_name);
-	if (!mcode_file)
+	if (!mcode_file) {
+		ERROR("Couldn't find microcode blob.\n");
 		return 1;
+	}
 
 	fit_location_from_cbfs_header(&current_offset, &file_length,
 				      mcode_file);
@@ -297,9 +300,15 @@ parse_microcode_blob(struct cbfs_image *image,
 		uint32_t total_size = mcu_header->total_size ?: 2048;
 
 		/* Quickly sanity check a prospective microcode update. */
-		if (total_size < sizeof(*mcu_header))
+		if (total_size < sizeof(*mcu_header) ||
+		    total_size > file_length)
 			break;
 
+		if (num_mcus == max_fit_entries) {
+			ERROR("Maximum of FIT entries reached.\n");
+			return 1;
+		}
+
 		/* FIXME: Should the checksum be validated? */
 		mcus[num_mcus].offset = current_offset;
 		mcus[num_mcus].size = total_size;
@@ -308,9 +317,6 @@ parse_microcode_blob(struct cbfs_image *image,
 		current_offset += mcus[num_mcus].size;
 		file_length -= mcus[num_mcus].size;
 		num_mcus++;
-		/* Reached limit of FIT entries. */
-		if (num_mcus == max_fit_entries)
-			break;
 		if (file_length < sizeof(struct microcode_header))
 			break;
 	}
@@ -362,6 +368,18 @@ static void update_fit_bios_acm_entry(struct fit_table *fit,
 	fit_entry_add_size(&fit->header, sizeof(struct fit_entry));
 }
 
+static void update_fit_pbp_entry(struct fit_table *fit,
+				struct fit_entry *entry,
+				const uint64_t pbp_addr)
+{
+	entry->address = pbp_addr;
+	entry->size_reserved = 0;
+	entry->type_checksum_valid = FIT_TYPE_PLATFORM_BOOT_POLICY;
+	entry->version = FIT_PLATFORM_BOOT_POLICY_VERSION;
+	entry->checksum = 0;
+	fit_entry_add_size(&fit->header, sizeof(struct fit_entry));
+}
+
 /*
  * In case there's a FIT_TYPE_BIOS_ACM entry, at least one
  * FIT_TYPE_BIOS_STARTUP entry must exist.
@@ -491,13 +509,6 @@ int fit_add_microcode_file(struct fit_table *fit,
 
 	if (parse_microcode_blob(image, blob_name, &mcus_found, mcus,
 				 max_fit_entries)) {
-		ERROR("Couldn't parse microcode blob.\n");
-		free(mcus);
-		return 1;
-	}
-
-	if (mcus_found > fit_free_space(fit, max_fit_entries)) {
-		ERROR("Maximum of FIT entries reached.\n");
 		free(mcus);
 		return 1;
 	}
@@ -609,6 +620,9 @@ int fit_dump(struct fit_table *fit)
 		case FIT_TYPE_BIOS_ACM:
 			name = "BIOS ACM";
 			break;
+		case FIT_TYPE_PLATFORM_BOOT_POLICY:
+			name = "Platform Boot Policy";
+			break;
 		case FIT_TYPE_BIOS_STARTUP:
 			name = "BIOS Startup Module";
 			break;
@@ -678,6 +692,7 @@ int fit_is_supported_type(const enum fit_type type)
 	switch (type) {
 	case FIT_TYPE_MICROCODE:
 	case FIT_TYPE_BIOS_ACM:
+	case FIT_TYPE_PLATFORM_BOOT_POLICY:
 	case FIT_TYPE_BIOS_STARTUP:
 	case FIT_TYPE_BIOS_POLICY:
 	case FIT_TYPE_TXT_POLICY:
@@ -730,6 +745,9 @@ int fit_add_entry(struct fit_table *fit,
 	case FIT_TYPE_BIOS_ACM:
 		update_fit_bios_acm_entry(fit, entry, offset);
 		break;
+	case FIT_TYPE_PLATFORM_BOOT_POLICY:
+		update_fit_pbp_entry(fit, entry, offset);
+		break;
 	case FIT_TYPE_BIOS_STARTUP:
 		update_fit_bios_startup_entry(fit, entry, offset, len);
 		break;
