@@ -1,3 +1,5 @@
+/* SPDX-License-Identifier: GPL-2.0-only */
+
 #ifndef GPIO_NAMES_GPIO_GROUPS_H
 #define GPIO_NAMES_GPIO_GROUPS_H
 
@@ -5,6 +7,11 @@ struct gpio_group {
 	const char *display;
 	size_t pad_count;
 	size_t func_count;
+	/*
+	 * This field is necessary for EBG, since the pad configuration registers
+	 * within a community are no longer contiguous.
+	 */
+	uint32_t pad_offset;
 	const char *const *pad_names; /* indexed by 'pad * func_count + func' */
 };
 
